/*Uncomment line 2090 for CSI mandatory*/
package com.tin.tds;

/*TRANSACTIONTYPE_CORRECTION_DEDUCTEE
 *   FVU Modifications
 *  ------------------------------------------------------------------------------------------------------------------------------------------
 *  Modifications
 *  ------------- 
 *  M01      [M01_B  - Indicates beginning of the code change for M01  & M01_E - End of code change for M01]
 *  ----
 *  Description   : For C3, Section should get populated, irrespective of challan updation indicator.
 *  				(section should not be NULL for C3).  Message is shown in the file if Section is null for C3.
 *  			    Remarks1 = 'T' should be allowed for Section 194C and 
 *  				Remarks1 = 'B' should be allowed only for Section 194, 194A, 194EE & 193. 
 *  				Section check for Remarks1 should be made only for add and update records, irrespective of the Challan updation indicator. 
 *  Modified By   : Dhanya P
 *  Modified Date : 09/12/2010 
 *  
 *  ------------------------------------------------------------------------------------------------------------------------------------------
 *  
 *  M02		 [M02_B  - Indicates beginning of the code change for M02  & M02_E - End of code change for M02]        
 *  ---
 *  Description : In Case of Correction, for Book Entry Y, allowing user to digitize BSR and    Transfer Voucher Fields for Non Nil Challan
 *  Modified By   : Dhanya P
 *  Modified Date : 13/12/2010
 *  
 *  ------------------------------------------------------------------------------------------------------------------------------------------
 *  
 *  M03	    [M03_B  - Indicates beginning of the code change for M03  & M03_E - End of code change for M03]	
 *  --- 
 *  Description   :  Change in logic for validation of Tax Deducted Amount (TDS).
 *  				 The following new check is added 
 *  
 *  				 	.  The file must be rejected if TDS amount in statement ( TDS_Stmnt)  <  expected TDS amount (TDS_Expected) * 90 / 100	
 *  				
 *  				 TDS_Expected is calculated as Amount of payment * 
 of deduction
 *   
 *  Modified By    : Dhanya P
 *  Modififed Date : 15/12/2010
 *  
 *  ------------------------------------------------------------------------------------------------------------------------------------------
 *    
 *  M04	    [M04_B  - Indicates beginning of the code change for M04  & M04_E - End of code change for M04]	
 *  --- 
 *  Description   :  Change in logic for validation of PAN  Reference Number 
 *  						Pan Reference Number (Last Employee/Party PAN Ref No  in the statement)
 *  					    should be allowed for all the statements( i.e. Regular and Correction)
 *  Modified By    : Dhanya P
 *  Modififed Date : 21/12/2010
 *  
 *  ------------------------------------------------------------------------------------------------------------------------------------------
 *    
 *  M05	    [M05_B  - Indicates beginning of the code change for M05  & M05_E - End of code change for M05]	
 *  --- 
 *  Description   :  Mobile No ['Remark' field] in Batch header is optional for deductor type 
 *  				 STATE and CENTRAL GOVERNMENT and for the rest it is mandatory.
 *  Modified By    : Dhanya P
 *  Modififed Date : 27/12/2010
 *  
 *  ------------------------------------------------------------------------------------------------------------------------------------------
 *      
 *  M06	    [M06_B  - Indicates beginning of the code change for M06  & M06_E - End of code change for M06]	
 *  --- 
 *  Description    : Remarks1 field of deductee details records is allowed to hold the value of 'Threshold' only for form 26Q
 *  				 and the only value Remark1 can have for Threshold flag is 'Y'.   
 *  		
 *  FVU 3.2, the following will apply.				
 *  if the flag is Y then amount of deduction, deposit, rate of deduction can be > = 0 (zero)
 *  
 *  Modified By    : Dhanya P
 *  Modififed Date : 05/01/2011
 *      
 *      
 *  ------------------------------------------------------------------------------------------------------------------------------------------
 * 
 *  M07     [M07_B  - Indicates beginning of the code change for M07  & M07_E - End of code change for M07]
 *  ---
 * 
 *  Description    : Allowing values for BookEntry flag for C5 corrections.  All other validations will remain same.   
 *  Modified By    : Dhanya P
 *  Modififed Date : 28/01/2011
 * 
 * ------------------------------------------------------------------------------------------------------------------------------------------
 * M08
 * ---
 * type of the variable 'sumOfSalDelTotTaxableIncome' is changed from double to 'BigDecimal' as the money is not
 * getting displayed properly if the value is in crores. 
 * 
 * 
 * 
 * ############################################################################################################
 *  Classname 				:FormValidator
 *
 *  Copyright notice		:TCS
 * 
 * ############################################################################################################
 *  
 *  Note : Variables which are Name of Fields in the File format are starts with First Letter Capital
 *  Example : EmployerName which is Name of Employer in the File Format.
 *  Local Variables starts with small letter.
 *  String Buffer are declared with Capital Letters.
 */


import java.io.*;
import java.sql.Types;
import java.util.*;
import java.util.Map.Entry;
import java.math.BigDecimal;

import javax.swing.JOptionPane;
import javax.swing.text.html.HTMLDocument.HTMLReader.IsindexAction;

import com.tin.tds.util.*;
import com.tin.tds.bean.FileStatistics;
import com.tin.tds.util.Hash;
import com.tin.FVU.*;


public class FormValidator extends StringBufferTemp implements FileValidatorInterface {

	// static Logger log1 = Logger.getLogger("TDSLogging");
	Calendar cal = new GregorianCalendar();
	public StringBufferTemp obj_StringBuffer;

	FieldValidation obj_FieldValidation = new FieldValidation();

	FileReader fr = null;
	BufferedReader br = null;

	private char fileStatus;
	String flagForPanCorr = "false";
	String statDataDelemiter = "^";
	String tab = "^";
	String statPANRepDelemiter = "&";
	String consHashinFile = null;
	FileGenerator obj_FileGenerator = new FileGenerator();

	int LineCount = 0; // Line Count with in a file
	int BatchCount = 0; // Batch count with in a file
	int ChallanCount = 0; // Challan Count with in a batch
	int DeducteeCount = 0; // Deductee count within a Challan
	String LineNo = null; // Line Number
	String BatchLineNo = null;
	String RecType = null; // Record Type

	String UploadType = null; // Uplaod Type
	String FileType = null; // File Type
	String FileCrDt = null; // File Creation Date
	String FileSeqNo = null; // File Sequence Number
	String TanTfcIdIndicator = null; // TAN /TFC Id Indicator
	String TanDedtr = null; // TAN /TFC Id
	String NoBatches = null; // Number of Batches
	String FinancialYr = null; // Financial Year
	String TransactionType = null; // Transaction Type
	String LastDeductorType = null; // Last Deductor Type ADDED BY AMI
	String DeductorType = null; // Deductor Type
	String FormNo = null; // Form Number
	String GrossTDSTotalAsPerChallan = null; // Gross TDS of TDS as per Challan
	String BankChallanNo = null; // Bank Challan Number
	String BankBranchCode = null; // Bank Branch Code
	String DateOfBankChallanNo = null; // Date Of Bank Challan Number
	String TotalOfDepositAmountAsPerChallan = null;
	String BatchUpdationIndicator = null;
	String LastTanOfDeductor = null;
	// Only for correction file value will be present only in C1 transaction
	// type.Incase of C2 if the batch updation indicator is 1 this field should be
	// provided
	String TanOfDeductor = null;
	String Period = null; // Challan Period
	String Qperiod = null; // Batch Period

	// Added for FVU 5.0

	String TanFromCSIFile = null;
	String TanNameFromCSIFile = null;
	String TanFromTxtFile = null;
	String TanNameFromTxtFile = null;
	private static javax.swing.JPanel jContentPane = null;
	boolean bypassTanTanNameValidate = false;
	boolean forCSIfile = false;
	int tanFlag = 0;
	int tanNameFlag = 0;
	int readCSIFile = 0;
	// added for FVU 5.5
	String FVU_Higher_Version = null;
	String FVU_Lower_Version = null;
	String FVU_24Q4_Version = null;
	// ended for FVU 5.5

	// End :: Added for FVU 5.0
	private String RpuType = null; // RpuType AMI
	private String FVUVer = null;
	private String FileHash = null;
	private String SAMVer = null;
	private String SAMHash = null;
	private String SCMVer = null;
	private String SCMHash = null;
	private boolean byPassBooking = false;
	private boolean paperReturnRelax = false;

	String TotalTaxDepositedAsPerDeducteeAnex = null;
	String SumTotalIncTaxDedAtSource = null;
	// Total Of Income Tax Deposited as per Deductee Annexeur
	String Mode = null; // Mode
	String NillChallanIndicator = null; // Nil Challan Indicator
	String Filler = null; // Filler field

	String lineNoOfBatchRec = "";
	/*
	 * To store Line Number of the Batch Record whose Challan, Deductee or Salary
	 * Detail Record we validate. This line number is specified in Error File for
	 * the Errors occured in Control Total Fields of Batch Record
	 */
	String lineNoOfChallanRec = "";
	/*
	 * To store Line Number of the Challan Record whose Deductee we validate. This
	 * line number is specified in Error File for the Errors occured in Control
	 * Total Fields Challan Records
	 */

	String returnRecordType = null;
	// Used to store the Record Type Value form SalaryDetailValidation.java class
	int returnLineCount = 0; // Used to store the Line counter Value form SalaryDetailValidation.java class
	String returnRecord = null; // Used to store the Last Record processed in SalaryDetailValidation.java class
	boolean deducteeDetailAddMode = false;

	Calendar RRRDatePresentDate = null;
	// If Uploaded by Deductor Current date is stored in the variable else RRR Date
	// is stored

	double pval = 0; // Total Income tax deducted at source ,when mode is A,U,O
	double nval = 0;
	double pvalTotalIncomeTaxDeposited = 0;
	double nvalTotalIncomeTaxDeposited = 0;

	double sumTotalTdsSurCess = 0; // Sum Total of TDS + Surcharge + Cess

	double sumOfTotalIncomeTaxDeposited = 0; // Total Income tax Deposited at source, when mode is D
	double sumOfTotalIncomeTaxDeducted = 0; // Total Income tax deducted at source, when mode is D
	// Added by faizan for fvu 4.5
	double challanWiseTDSfield30 = 0;
	double SumTDSIncomeTaxDDfield14 = 0;
	double challanWiseTDSfield31 = 0;
	double SumTDSIncomeTaxDDfield15 = 0;
	double challanWiseTDSfield32 = 0;
	double SumTDSIncomeTaxDDfield16 = 0;

	String CountOfChallanRec = null;
	// Used to pass Count of Challan Detail Record to ValidateChallanHeader Method
	String CountOfSalaryDetailRec = null;
	// Used to pass Count of Salary Detail Record to SalaryDetailValidator Method
	String GrossTotalIncomeSD = null;
	// Used to pass Gross Total Income of Salary Detail to SalaryDetailValidator
	// Method

	double sumOfTotalOfDepositAmountAsPerChallan = 0;

	String ERROR_FILE;

	HashSet RRRNumberHS = new HashSet(); // Used to store RRR Number to check for duplicate RRR Number in file.

	int prevChallanRecCount = 0; // Used to store the Challan Detail Record Number in Case of Correction File
	int prevDeducteeRecCount = 0; // Used to store the Deductee Detail Record Number in Case of Correction File

	long lastBatchError1 = 0; // Used to store the length of Error StringBuffer before Entering Batch
								// Validation

	long lastBatchError2 = 0; // Used to store the length of Error StringBuffer After Exiting Batch Validation

	long lastChallanError1 = 0; // Used to store the length of Error StringBuffer before Entering Challan
								// Validation

	long lastChallanError2 = 0; // Used to store the length of Error StringBuffer After Exiting Batch Validation

	long lastSalaryDeducteeError1 = 0; // Used to store the length of Error StringBuffer before Entering SalaryDeductee
										// Validation

	long lastSalaryDeducteeError2 = 0; // Used to store the length of Error StringBuffer after Exiting SalaryDeductee
										// Validation

	boolean lastBatchErrorFlag = false; // Used to check if Error found in File Format after Validating Last Batch of
										// File

	boolean lastChallanErrorFlag = false; // Used to check if Error found in File Format after Validating Last Challan
											// of
											// File

	boolean lastSalaryDeducteeFlag = false; // Used to check if Error found in File Format after Validating Last Salary
											// Detail of File

	boolean salaryDetailRecordFlag = false; // used to check if Salary Detail records present in File

	boolean deducteeLevlErrFlag = false; // Used to check if any error occured while Deductee Record Validation

	/*
	 * Used to check if any error occured while Challan Record and Deductee Record
	 * Validation If NO ERROR is found this flag is set TRUE
	 */
	boolean challanLevlErrFlag = false;

	boolean batchRecFoundFlag = false; // This flag is set to TRUE if a Batch Record is found while looking for Salary
										// Detail record

	boolean ddRecValidatedFlag = false; // This flag is set TRUE after validating all the Deductee Records.

	boolean zCorrectionZeroDDRecFlag = false; // This falg is set TRUE after validating a 'Z' Correction Batch with 0
												// deductee
												// Records

	boolean bhChallanCountZero = false; // Used For PAN Correction C5, to Check that at Either Count of Challan or Count
										// of Salary Detail at Batch must be Greater than 0

	boolean transferVoucherNoProvided = false; // Used to check Book/Cash Entry at Deductee Record. Marked TRUE if
												// Transfer
												// Voucher is present in challan.

	boolean bankChallanNoProvided = false; // Used to check Book/Cash Entry at Deductee Record. Marked TRUE if Bank
											// Challan
											// No is present in challan.

	/*
	 * The flag is SET TRUE if its Paper Return i.e. NS1 / SL1 / TC1. The flag is
	 * SET FALSE if its Paper Return i.e. NS9 / SL9 / TC9 There are certain
	 * validations which are relaxed in case of Paper Return. To Bypass these
	 * validation for Paper Return this flag is checked.
	 */
	boolean paperReturnFile = false;

	// boolean is set to TRUE if the Error is Logged for Batch so that Error Logging
	// is not repeated
	boolean errorLoggedForInvalidBH = false;

	/*
	 * 13-07-2005 To check that Form Number, TAN, Assessment Year, Financial Year,
	 * and Quarter are same across all the Batches in the File
	 */
	String formNoOfFirstBatch = null; // Store Form Number of First Batch in the File
	String tanOfFirstBatch = null; // Store TAN of First Batch in the File
	String assessmentYearOfFirstBatch = null; // Store Assessment Year of First Batch in the File
	String financialYearOfFirstBatch = null; // Store Financial of First Batch in the File
	String quarterOfFirstBatch = null; // Store Quarter of First Batch in the File
	String origRRRNoOfFirstBatch = null;
	String previousRRRNoOfFirstBatch = null;

	// variable added to validate the % of structurally valid PAN :: Manvendra Singh
	// 31 - Aug - 2007

	// ##########################################################################################
	public int totalPANtoVaildate;
	public int validPANtoValidate;
	public boolean PerformValidation = false;
	public int TotalDeducteeInFile;
	Calendar CurrentDate = Calendar.getInstance();
	Calendar validationStartdate = new GregorianCalendar(Integer.parseInt(Parameters.validation_param_date.substring(4, 8)), Integer.parseInt(Parameters.validation_param_date.substring(2, 4)) - 1,
			Integer.parseInt(Parameters.validation_param_date.substring(0, 2)));
	public int totalPANtoVaildate_ignoring_remark;
	public int validPANtoValidate_ignoring_remark;
	Parameters prm = new Parameters();
	Calendar tempRRRdate = new GregorianCalendar(Integer.parseInt(Parameters.validation_param_date.substring(4, 8)) - 1, Integer.parseInt(Parameters.validation_param_date.substring(2, 4)) - 1,
			Integer.parseInt(Parameters.validation_param_date.substring(0, 2)));

	// public StringBufferTemp obj_StringBuffer_PAN_Validation;
	// ##########################################################################################
	// ArrayList AllRRRdates = new ArrayList();

	// ########### variables added for new validation of PAN :: Manvendra Singh
	// 14-Feb-2008
	Calendar newValidationStartDate = new GregorianCalendar(Integer.parseInt(Parameters.validation_new_param_date.substring(4, 8)), Integer.parseInt(Parameters.validation_new_param_date.substring(2, 4)) - 1,
			Integer.parseInt(Parameters.validation_new_param_date.substring(0, 2)));

	public int totalPANtoValidate_in_batch;
	public int validPANtovalidate_in_batch;
	public int totalPANtoVaildate_in_batch_ignoring_remark;
	public int validPANtoValidate_in_batch_ignoring_remark;
	Calendar tempRRRDateforBatch = new GregorianCalendar(Integer.parseInt(Parameters.validation_new_param_date.substring(4, 8)) - 1, Integer.parseInt(Parameters.validation_new_param_date.substring(2, 4)) - 1,
			Integer.parseInt(Parameters.validation_new_param_date.substring(0, 2)));
	public boolean performValidationAtbatchLevel = false;
	public String sectionForThisChallan = ".";
	public String sectionForThisDD = ".";
	public boolean validPANflag = false;
	public String ChallanUpdationIndicatorForcurrentchallan = null;
	private boolean performNewValidation = false;
	public boolean performDDvalidation = true;
	// Nahush
	public String currentUploadType = "NA";
	public String fileHeaderUploadType = "NA";
	public String CurrentchallanDetailRecordNo = null;
	public String CurrentDeducteeDetailRecNo = null;
	// ######################################################################
	// ---------------Added by Nahush for validating Deductor PAN against PAN of
	// deductee.
	public String PANForThisBatch = null;
	// ---------------
	// ********************************Metreing
	// Variables***************************************************//
	private String meteringFileSeqNo = "";
	private String meteringUploadType = "";
	private String meteringFileType = "";

	private Vector meteTANList = new Vector(); // Store List of TAN present in file
	private Vector meteDDNumber = new Vector(); // Store List of Number of Deductee present in file for respective TAN

	private Vector meteOrigRRRNo = new Vector();
	private Vector meteChlnDetailRecNo = new Vector();
	private Vector meteTransactionTypeList = new Vector();

	private Vector meteChlnVector = new Vector();

	private int meteDDCount = 0;
	private int meteSDCount = 0;
	private String metORNo = "";
	private String meteCorrectionFile = "";
	private int numberOfLinesInFile = 0;

	// ********************************Metreing Variables
	// END**************************************************//

	/*
	 * General File Information This information is Stored in table, if the Format
	 * Validation of File is successful. This information will be used by NSDL for
	 * Billing purpose. General info of File like TAN, RRR No. Batch count etc are
	 * stored. Variables end with GFI ie. General File Information
	 */
	private String rrrNoGFI = "-";
	private String orgRRRNoGFI = "-";
	private String rrrDateGFI = "-";
	private String tanGFI = "-";
	private String frmNoGFI = "-";
	private String qtrGFI = "-";
	private String finYrGFI = "-";
	private String trnsTypeGFI = "-";
	private String noOfChallansGFI = "-";
	private String noOfDDGFI = "-";
	private String noOfSDGFI = "-";
	private String fileTypeGFI = "-";
	private String tanTfcIdGFI = "-";
	private StringBuffer generalFileInfoBuffer = new StringBuffer();

	// ********************************** General File Information
	// END*************************************//

	// ******************************** Receipt File and Statistic File Generation
	// Variables ***************//

	String fileNamePrintedinStatRep = null;
	int receiptValidPAN = 0;
	int receiptSalValidPAN = 0;
	int receiptPanNotAvbl = 0;
	int receiptSalPanNotAvbl = 0;
	int receiptPanInvaild = 0;
	int receiptSalPanInvaild = 0;
	int receiptPanApplied = 0;
	int receiptSalPanApplied = 0;
	int receiptChallanDetailRecNo = 0;

	private String receiptLastDDNumber = "-";
	String receiptLastSDNumber = "-";
	private StringBuffer receiptString = new StringBuffer();
	private StringBuffer receiptChallanDDNumber = new StringBuffer();

	private String receiptTotalAmtPaidCrdtOriginalMode = "-";
	private String receiptTotalAmtPaidCrdtUpdateMode = "-";
	private String receiptTotalAmtPaidCrdtAddMode = "-";

	// private String statTotalITDeductedAtSrc = "-";
	private String receiptTotalITDeductedAtSrcUpdtMode = "-";
	private String receiptTotalITDeductedAtSrcAddMode = "-";
	private String receiptTotalITDeductedAtSrcDelMode = "-";
	private String receiptTotalITDeductedAtSrcOrigMode = "-";

	// private String statTotalofDepositedAmount = "-";
	private String receiptTotofDepdAmtOrigMode = "-";
	private String receiptTotofDepdAmtUpdtMode = "-";
	private String receiptTotofDepdAmtAddMode = "-";
	private String receiptTotofDepdAmtDelMode = "-";

	// private String receiptDDCountForC5 = "-";
	private String receiptSDCountForC5 = "-";

	private String statTotalNoOfDDRec = "-";
	private String statTotalValueofTurnover = "-";

	int batchNumberOfRecord = 0;
	StringBuffer batchRecDataForPanStat = new StringBuffer();

	/*
	 * This String Buffer is used to Store Statistics File Data, which will be
	 * printed in Statistics File
	 */
	private StringBuffer statisticFileStrBuff = new StringBuffer();

	// Added for change in statistics File Data ----- Nahush (21 Oct 08)

	private StringBuffer staisticsSalStrBuff = new StringBuffer();

	// This flag is used to check if PAN Statistics Report must be gererated or Not
	static boolean generateTdsPANStatBuffer = false;

	// String to Store Data for SAM / SCM
	private StringBuffer samScmData = new StringBuffer();
	private String samScmNoOfBatch = "";
	private int samScmLineCountOfFile = 0;
	private double samScmLastTotalIncomeTaxDeductedAtSource = 0.00;
	// LastTotalOfDepositAmountAsPerChallan
	private double totalOfLastTotalOfDepositAmountAsPerChallan = 0.00;

	private String samScmRrrNum = "-";
	private String samScmRrrDate = "-";
	boolean isModeValid = true;
	// 19-Feb-2009 Added for checking the BSR code -Nahush
	boolean bsrFound = false;
	String bsrFromFile = "";
	String bsrFromList = "";
	boolean bsrPresent = false;
	ArrayList bsrList = new ArrayList();;
	int bsrCount = 0;
	public String dateOfChallan = "";
	private StringBuffer bsrDetails = new StringBuffer();
	// **********CIN FILE VARIABL BY SOURABH********
	ArrayList consolidatedHash = new ArrayList();
	ArrayList cinChallanSeqNo = new ArrayList();
	ArrayList cinBsrCode = new ArrayList();
	ArrayList cinOltasPayDate = new ArrayList();
	ArrayList cinAmt = new ArrayList();
	ArrayList cinBatchNo = new ArrayList();
	ArrayList cinChallanDetailRecordNo = new ArrayList();
	ArrayList cinDateOfChallan = new ArrayList();
	ArrayList cinLineNo = new ArrayList();

	ArrayList cinChallanSeqNoView = new ArrayList();
	FileReader cinFr = null;
	BufferedReader cinBr = null;
	// **********CIN FILE VARIABL********
	// **********BIN FILE VARIABL BY SOURABH********
	ArrayList consolidatedHashBIN = new ArrayList();
	ArrayList binChallanSeqNo = new ArrayList();
	ArrayList binBsrCode = new ArrayList();
	ArrayList binOltasPayDate = new ArrayList();
	ArrayList binAmt = new ArrayList();
	ArrayList binBatchNo = new ArrayList();
	ArrayList binChallanDetailRecordNo = new ArrayList();
	ArrayList binDateOfChallan = new ArrayList();
	ArrayList binLineNo = new ArrayList();

	ArrayList binChallanSeqNoView = new ArrayList();
	// **********BIN FILE VARIABL********

	// Added by sourabh for Changes in statics file
	int statChallanCount = 0;
	int statTransferVoucher = 0;
	double challanAmountAsPerChallan = 0;
	double transferAmountAsPerTV = 0;
	String typeOfChallan = "";
	int totalChallanforCINCheck = 0;
	// End by sourabh

	String ConsHash = null;
	// Added By AMI For FVU 3.0
	int lineCountOfBtch = 0;
	public static StringBuffer unmatchedChalanCntStrBuff = new StringBuffer();
	boolean matchChlanCnt = false;
	boolean isMtchCntToBeUpdated = false;
	int positionOfBtch = 0;
	int unmtchChlnCnt = 0;
	String unMatchedChalanCnt = null;

	// M08_B
	// public static double sumOfSalDelTotTaxableIncome = 0; //commented by Dhanya
	// on 29/4/2011 as the datatype is changed to BigDecimal
	public static BigDecimal sumOfSalDelTotTaxableIncome = new BigDecimal("0");
	// M08_E

	boolean isSameBtch = false;
	int cntTaxDeductedAtHighRate = 0;

	// Added For Raw File Generation
	String receiptCntTaxDeductedAtHighRate = "-";
	String receiptUnmatchedChalanCnt = "-";
	String receiptSalDelTotTaxableIncome = "-";
	String statCntTaxDeductedAtHighRate = "0";

	// Added by Dhanya on 11/04/2011 for FVU 3.2
	double dExpectedTaxDeductedAmount = 0;

	public static StringBuffer samData;

	// Added For Mandatory CSI File
	public boolean cinMandatory = false;
	public boolean cinMandatoryWritten = false;

	// Added by Shalin
	public static boolean isFinYrGrtr = false;

	// Added by Shalin FVU 3.8
	public static boolean isFinYrGrtrthn = false;

	// Added by nik for FVU 4.6
	String AIN = null;
	boolean ain_chk = false;
	// Added for FVU 4.7
	ArrayList deducteePanDeatil;
	int chk_C5;

	// ----------------------------------------------------
	// ******************************** Receipt File and Statistic File Generation
	// Variables END ***************//

	/////////////////////////////////////////////////////////////////////////////////////////////////////////////
	/*
	 * readTextFile is a method which is used to reading the File. It reads the File
	 * Line by Line
	 */
	//////////////////////////////////////////////////////////////////////////////////////////////////////////////
	public void readFile(String inputFileName, String ERROR_FILE, int utilityLevel) throws Exception {

		try {
			this.ERROR_FILE = ERROR_FILE;
			obj_StringBuffer = new StringBufferTemp(ERROR_FILE);
			// added for 4.7
			deducteePanDeatil = new ArrayList();
			chk_C5 = 0;
			cal = new GregorianCalendar();

			File flName = new File(inputFileName);
			fileNamePrintedinStatRep = flName.getName();

			// Added By AMI For FVU 3.0
			String fileExtention = "";
			int indexOfExtnStart = fileNamePrintedinStatRep.lastIndexOf(".");
			int lengthOfFileName = fileNamePrintedinStatRep.trim().length();
			fileExtention = fileNamePrintedinStatRep.substring(indexOfExtnStart + 1, lengthOfFileName);

			if (utilityLevel != 0) {
				/*
				 * PAN Statistics Report must not be generated at SAM / SCM / STM To identify
				 * whether the code is at SAM / SCM / STM or Standalone, we check "utilityLevel"
				 *
				 * utilityLevel = 0 means Standalone FVU has called utilityLevel = 1 means SCM
				 * has called FVU utilityLevel = 2 means SAM has called FVU utilityLevel = 3
				 * means STM has called FVU
				 */
				generateTdsPANStatBuffer = false;
			} else {
				generateTdsPANStatBuffer = true;
			}

			fr = new FileReader(inputFileName);
			br = new BufferedReader(fr);
			FieldValidation obj_FieldValidation = new FieldValidation();
			FileGenerator obj_FileGenerator = new FileGenerator();

			boolean NullField = false;
			boolean error = false;
			boolean error_flag = false;
			boolean Caret = true;
			boolean FieldFound = false;
			boolean duplicateFileHeader = false;

			int CountField_FH = 1;
			int CountField_BH = 1;
			int CountField_CH = 1;
			int CountField_DD = 1;
			int countOfBatch = 0;
			int countOfChallan = 0;
			int countOfDeductee = 0;
			int countOfLocalSalaryDeductee = 0;
			int FieldCount = 0;

			double iGrossTDSTotalAsPerChallan = 0;
			double iTotalOfTDSAsPerDeducteeDetails = 0;

			String record = null;
			String FormNo = null;
			String NoChallan = null;
			String NoDeductee = null;
			String GrossTDSTotalAsPerChallan = null;
			String BH_BatchNo = null;
			String CH_BatchNo = null;
			String DD_BatchNo = null;
			String CountOfDeducteeDetail = null;
			String TransactionType = null;
			String ChallanDetailRecordNo = null;
			String DeducteeDetailSerialNo = null;
			String FileHdrHash = null;
			String temp = null;
			LineCount = 0;
			record = br.readLine(); // Reads the first line of the File
			LineCount++;

			StringTokenizer Obj_st = new StringTokenizer(record, FIELD_SEPERATOR, true);

			int caretCounter = 0;
			int localCountField_FH = 1;
			while (Obj_st.hasMoreTokens()) {
				String val = Obj_st.nextToken();
				NullField = false;
				FieldFound = false;
				if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
					NullField = true;
					FieldFound = true;
				}
				if (val.equals(FIELD_SEPERATOR)) {
					Caret = true;
					if (caretCounter == 0 && CountField_FH == 1) {
						// CountField_FH++;
						LineNo = "";
					}
					caretCounter++;
				} else {
					Caret = false;
					FieldFound = true;
				}
				if (localCountField_FH > 18) // CHANGE AMI
				{
					break;
				}
				if (FieldFound) {

					switch (CountField_FH) {
					case 1:
						LineNo = val;
						break;
					case 2:
						RecType = val;
						break;
					case 3:
						FileType = val;
						break;
					case 4:
						UploadType = val;
						break;
					case 5:
						FileCrDt = val;
						break;
					case 6:
						FileSeqNo = val;
						break;
					case 7:
						TanTfcIdIndicator = val;
						break;
					case 8:
						TanDedtr = val;
						break;
					case 9:
						NoBatches = val;
						break;
					// CHANGE AMI
					case 10:
						RpuType = val; // END
					case 11:
						FileHdrHash = val;
						break;
					case 12:
						FVUVer = val;
						break;
					case 13:
						FileHash = val;
						break;
					case 14:
						SAMVer = val;
						break;
					case 15:
						SAMHash = val;
						break;
					case 16:
						SCMVer = val;
						break;
					case 17:
						SCMHash = val;
						break;
					case 18:
						ConsHash = val;

					} // Closing SWITCH
					CountField_FH++;
					localCountField_FH++;

				} // Closing IF
			} // Closing WHILE
			/* Validating the File Header */

			if (UploadType.equals(UPLOADTYPE_REGULAR)) {
				fileHeaderUploadType = UPLOAD_TYPE_REGULAR;
				currentUploadType = UPLOAD_TYPE_REGULAR;
			}

			else if (UploadType.equals(UPLOADTYPE_CORRECTION)) {
				currentUploadType = UPLOAD_TYPE_CORRECTION;
				fileHeaderUploadType = UPLOAD_TYPE_CORRECTION;
			}

			if (caretCounter != 17) // CHANGE AMI
			{
				obj_StringBuffer.append(1 + tab + fileHeaderUploadType + tab + "NA" + tab + tab + tab + T_FV_1000_C + tab + T_FV_1000_M);
				obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
				return;
			}
			// If record type is File Header (FH) perform validation

			// Validation for cons hash by Manas
			if (UploadType.equals(UPLOADTYPE_REGULAR) && ConsHash != null) {
				obj_StringBuffer.append(1 + tab + fileHeaderUploadType + tab + "NA" + tab + tab + tab + T_FV_1036_C + tab + T_FV_1036_M);
			}

			if (Parameters.consMandatory) {
				if (UploadType.equals(UPLOADTYPE_CORRECTION) && (ConsHash == null || tab.equals(ConsHash))) {
					obj_StringBuffer.append(1 + tab + fileHeaderUploadType + tab + "NA" + tab + tab + tab + T_FV_1037_C + tab + T_FV_1037_M);
				}

			}

			if ((RecType.equals(FILE_HEADER_IDENTIFIER))) {
				long fileRecErrLengthBefore = obj_StringBuffer.errorBufferString.length();
				validateFileHeader(record, obj_StringBuffer);
				long fileRecErrLengthAfter = obj_StringBuffer.errorBufferString.length();
				// System.out.println("FileSeqNo in java : " + FileSeqNo);
				// System.out.println("FileType in java : " + FileType);
				// System.out.println(" ");

				// ---changed for validation of structurally valid DD --Manvendra Singh
				// --------------------------------------------------------------------
				// if (UploadType.equals(UPLOADTYPE_REGULAR))
				// {
				// PerformValidation = true;
				// performValidationAtbatchLevel = true;
				// }

				// removed in release 2.112 to make this validaion at batch level ....
				// --------------------------------------------------------------------

				RRRNumberHS.clear();
				meteringFileSeqNo = FileSeqNo;
				meteringUploadType = UploadType;
				meteringFileType = FileType;

				if ((fileRecErrLengthAfter - fileRecErrLengthBefore) != 0) {
					obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
					return;
				}

				countOfBatch = Integer.parseInt(NoBatches.trim());

				// meteringFileSeqNo = FileSeqNo;
				// meteringUploadType = UploadType;
				// meteringFileType = FileType;

				if (FileType.equals(FILETYPE_SALARY_ELECTRONIC) || FileType.equals(FILETYPE_SALARY_DIGITAL) || FileType.equals(FILETYPE_NONSALARY_ELECTRONIC) || FileType.equals(FILETYPE_NONSALARY_DIGITAL) || FileType.equals(FILETYPE_TCS_ELECTRONIC)
						|| FileType.equals(FILETYPE_TCS_DIGITAL)) {

					/*
					 * Batch Loop starts. We loop for number of Batches Specified in File Header(FH)
					 */

					System.out.println("BATCH VALIDATION STARTED");
					for (int i = 1; i <= (countOfBatch); i++) {
						// System.out.println("countOfBatch"+countOfBatch);
						sumOfTotalOfDepositAmountAsPerChallan = 0;
						// Added by sourabh for initilize challn count and amount and transfer voucer
						// count and amount to zero
						statChallanCount = 0;
						statTransferVoucher = 0;
						challanAmountAsPerChallan = 0;
						transferAmountAsPerTV = 0;
						typeOfChallan = "";
						totalChallanforCINCheck = 0;
						// End by sourabh

						// ---- Code added for continuing with validation of next batch for structurally
						// valid PAN--- Manvendra Singh :: 12-Feb-2008
						totalPANtoValidate_in_batch = 0;
						validPANtovalidate_in_batch = 0;

						// System.out.println("countOfBatch"+countOfBatch);
						// System.out.println("totalPANtoVaildate_in_batch_ignoring_remark\n" +
						// totalPANtoVaildate_in_batch_ignoring_remark);

						totalPANtoVaildate_in_batch_ignoring_remark = 0;
						validPANtoValidate_in_batch_ignoring_remark = 0;
						performValidationAtbatchLevel = false;
						performDDvalidation = true;
						// ------------------------------------------------------------

						// //Added By AMI For FVU 3.0
						// isSameBtch = true;

						// Generating the StringBuffer for Receipt and Statistic File .
						// If the count of i ie. when 1st Batch record is Traversed the we add the Data
						// to StringBuffer

						if (i > 1) {

							// Appending the Data for Provisional Receipt File generated by STM
							if ((LastTanOfDeductor != null) && LastTanOfDeductor.trim().length() != 0 && !LastTanOfDeductor.trim().equals("^")) {
								receiptString.append("BH=" + (i - 1) + "^P1=" + receiptPanApplied + "^P2=" + receiptPanInvaild + "^P3=" + receiptPanNotAvbl + "^T=" + LastTanOfDeductor + "^AO=" + receiptTotalAmtPaidCrdtOriginalMode + "^AU="
										+ receiptTotalAmtPaidCrdtUpdateMode + "^AA=" + receiptTotalAmtPaidCrdtAddMode + "^DO=" + receiptTotalITDeductedAtSrcOrigMode + "^DU=" + receiptTotalITDeductedAtSrcUpdtMode + "^DA="
										+ receiptTotalITDeductedAtSrcAddMode + "^DD=" + receiptTotalITDeductedAtSrcDelMode + "^TO=" + receiptTotofDepdAmtOrigMode + "^TU=" + receiptTotofDepdAmtUpdtMode + "^TA=" + receiptTotofDepdAmtAddMode + "^TD="
										+ receiptTotofDepdAmtDelMode + "^VP=" + statTotalValueofTurnover + "^DD=" + statTotalNoOfDDRec + "^SD=" + receiptSDCountForC5);

								if (utilityLevel == 0 || utilityLevel == 3) {
									receiptString.append("^LS=" + receiptLastSDNumber + receiptChallanDDNumber);
									// receiptString.append("~"); //Commented for FVU 3.0
								}
								// Commented for FVU 3.0
								/*
								 * else { receiptString.append("^~"); }
								 */
								if (utilityLevel == 1) {

									receiptString.append("^DH=" + receiptCntTaxDeductedAtHighRate); // No of deductee
																									// records where tax
																									// deducted at
																									// higher rate
									receiptString.append("^UC=" + receiptUnmatchedChalanCnt); // No of Unmatched Chllans
																								// Of CSI File
									if (FormNo.equals("24Q") && Qperiod.equals("Q4") && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || UploadType.equals(UPLOADTYPE_REGULAR))) {

										// M08_B
										// receiptSalDelTotTaxableIncome = Double.toString(sumOfSalDelTotTaxableIncome);
										receiptSalDelTotTaxableIncome = sumOfSalDelTotTaxableIncome.toString();
										// M08_E
									}

									receiptString.append("^NT=" + receiptSalDelTotTaxableIncome); // Net Taxable Income
																									// of SDs.
									receiptString.append("^~");
								} else {
									if (utilityLevel == 0 || utilityLevel == 3)
										receiptString.append("~");
									else
										receiptString.append("^~");
								}
							} else {
								receiptString.append("BH=" + (i - 1) + "^P1=" + receiptPanApplied + "^P2=" + receiptPanInvaild + "^P3=" + receiptPanNotAvbl + "^T=" + "-" + "^AO=" + receiptTotalAmtPaidCrdtOriginalMode + "^AU="
										+ receiptTotalAmtPaidCrdtUpdateMode + "^AA=" + receiptTotalAmtPaidCrdtAddMode + "^DO=" + receiptTotalITDeductedAtSrcOrigMode + "^DU=" + receiptTotalITDeductedAtSrcUpdtMode + "^DA="
										+ receiptTotalITDeductedAtSrcAddMode + "^DD=" + receiptTotalITDeductedAtSrcDelMode + "^TO=" + receiptTotofDepdAmtOrigMode + "^TU=" + receiptTotofDepdAmtUpdtMode + "^TA=" + receiptTotofDepdAmtAddMode + "^TD="
										+ receiptTotofDepdAmtDelMode + "^VP=" + statTotalValueofTurnover + "^DD=" + statTotalNoOfDDRec + "^SD=" + receiptSDCountForC5);
								if (utilityLevel == 0 || utilityLevel == 3) {
									receiptString.append("^LS=" + receiptLastSDNumber + receiptChallanDDNumber);
									// receiptString.append("~"); //Commented for FVU 3.0
								}
								// Commented for FVU 3.0
								/*
								 * else { receiptString.append("^~"); }
								 */
								if (utilityLevel == 1) {

									receiptString.append("^DH=" + receiptCntTaxDeductedAtHighRate); // No of deductee
																									// records where tax
																									// deducted at
																									// higher rate
									receiptString.append("^UC=" + receiptUnmatchedChalanCnt); // No of Unmatched Chllans
																								// Of CSI File
									if (FormNo.equals("24Q") && Qperiod.equals("Q4") && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || UploadType.equals(UPLOADTYPE_REGULAR))) {

										// M08_B
										// receiptSalDelTotTaxableIncome = Double.toString(sumOfSalDelTotTaxableIncome);
										receiptSalDelTotTaxableIncome = sumOfSalDelTotTaxableIncome.toString();
										// M08_E
									}

									receiptString.append("^NT=" + receiptSalDelTotTaxableIncome); // Net Taxable Income
																									// of SDs.
									receiptString.append("^~");
								} else {
									if (utilityLevel == 0 || utilityLevel == 3)
										receiptString.append("~");
									else
										receiptString.append("^~");
								}
							}

							// Appending the Data for Statistic File generated by Standalone FVU

							// Added For FVU 3.0 Count of DD with Remark C
							if (!(receiptCntTaxDeductedAtHighRate.equals("-")))
								statCntTaxDeductedAtHighRate = receiptCntTaxDeductedAtHighRate;

							// System.out.println("statCntTaxDeductedAtHighRate"+statCntTaxDeductedAtHighRate);

							statisticFileStrBuff.append(statTotalNoOfDDRec + statDataDelemiter + receiptValidPAN + statDataDelemiter + statCntTaxDeductedAtHighRate + statDataDelemiter + "\n");

							statCntTaxDeductedAtHighRate = "0";

							// System.out.println("statisticFileStrBuff
							// ****************"+statisticFileStrBuff.toString());

							staisticsSalStrBuff.append(receiptSalValidPAN + statDataDelemiter + receiptSalPanApplied + statDataDelemiter + receiptSalPanNotAvbl + statDataDelemiter + receiptSalPanInvaild + statDataDelemiter + "\n");

							// ****************Metering *****************//
							if (UploadType.equals(UPLOADTYPE_REGULAR) && (TanOfDeductor != null) && TanOfDeductor.trim().length() != 0 && !TanOfDeductor.trim().equals("^")) {
								meteTANList.addElement(TanOfDeductor);
							} else if (UploadType.equals(UPLOADTYPE_CORRECTION) && (LastTanOfDeductor != null) && LastTanOfDeductor.trim().length() != 0 && !LastTanOfDeductor.trim().equals("^")) {
								meteTANList.addElement(LastTanOfDeductor);
							} else
								meteTANList.addElement("TANNOTAVBL");

							meteOrigRRRNo.addElement(metORNo);

							if (meteDDCount != 0)
								meteDDNumber.addElement(Integer.toString(meteDDCount));
							else if ((meteDDCount == 0) && (meteSDCount != 0))
								meteDDNumber.addElement(Integer.toString(meteSDCount));
							else
								meteDDNumber.addElement("0");

							meteDDCount = 0;
							meteSDCount = 0;
							meteTransactionTypeList.addElement(TransactionType);

							meteChlnVector.add(meteChlnDetailRecNo);

							meteChlnDetailRecNo = new Vector();

							// ****************Metering END*****************//

							// General File information STring Buffer
							generalFileInfoBuffer.append(rrrNoGFI + "^" + orgRRRNoGFI + "^" + rrrDateGFI + "^" + tanGFI + "^" + frmNoGFI + "^" + qtrGFI + "^" + finYrGFI + "^" + trnsTypeGFI + "^" + noOfChallansGFI + "^" + noOfDDGFI + "^" + noOfSDGFI
									+ "^" + fileTypeGFI + "^" + tanTfcIdGFI + "\n");

							rrrNoGFI = "-";
							orgRRRNoGFI = "-";
							rrrDateGFI = "-";
							tanGFI = "-";
							frmNoGFI = "-";
							qtrGFI = "-";
							finYrGFI = "-";
							trnsTypeGFI = "-";
							noOfChallansGFI = "-";
							noOfDDGFI = "-";
							noOfSDGFI = "-";

							try {
								if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
									samScmData.append(AdditionTotalAmountPaidCredited(receiptTotalAmtPaidCrdtUpdateMode, receiptTotalAmtPaidCrdtAddMode) + "^");
									samScmData.append(AdditionTotalTaxDeducted(receiptTotalITDeductedAtSrcUpdtMode, receiptTotalITDeductedAtSrcAddMode, receiptTotalITDeductedAtSrcDelMode) + "^");
									samScmData.append(AdditionTotalAmountDeposited(receiptTotofDepdAmtUpdtMode, receiptTotofDepdAmtAddMode, receiptTotofDepdAmtDelMode) + "^");
								} else {
									samScmData.append(receiptTotalAmtPaidCrdtOriginalMode + "^");
									samScmData.append(receiptTotalITDeductedAtSrcOrigMode + "^");
									samScmData.append(receiptTotofDepdAmtOrigMode + "^");
								}

								if (UploadType.equals(UPLOADTYPE_CORRECTION)) {
									totalOfLastTotalOfDepositAmountAsPerChallan = Math.round((double) (totalOfLastTotalOfDepositAmountAsPerChallan * 100)) / 100.0;
									String outputValue = obj_FieldValidation.changeNumberFormat(totalOfLastTotalOfDepositAmountAsPerChallan);
									samScmData.append(outputValue + "^");
								} else {
									samScmData.append("-" + "^");
								}

								if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
									samScmLastTotalIncomeTaxDeductedAtSource = Math.round((double) (samScmLastTotalIncomeTaxDeductedAtSource * 100)) / 100.0;
									String outputValue = obj_FieldValidation.changeNumberFormat(samScmLastTotalIncomeTaxDeductedAtSource);
									samScmData.append(outputValue + "^");
									// ///**********************
									samScmData.append(samScmRrrNum + "^");
									samScmData.append(samScmRrrDate + "^");
									// //**********************

									samScmData.append("\n");
								} else {
									samScmData.append("-" + "^");
									// ///**********************
									samScmData.append(samScmRrrNum + "^");
									samScmData.append(samScmRrrDate + "^" + "\n");
									// //**********************

								}
								// Reinitializing value of totalOfLastTotalOfDepositAmountAsPerChallan = 0.00
								totalOfLastTotalOfDepositAmountAsPerChallan = 0.00;
								// Reinitializing value of samScmLastTotalIncomeTaxDeductedAtSource = 0.00
								samScmLastTotalIncomeTaxDeductedAtSource = 0.00;
								samScmRrrNum = "-";
								samScmRrrDate = "-";
							} catch (Exception e) {
								e.printStackTrace();
							}
						}

						// System.out.println("receiptValidPAN"+receiptValidPAN);

						receiptValidPAN = 0; // re-initiallinging the Value to 0
						receiptPanApplied = 0; // re-initiallinging the Value to 0
						receiptPanInvaild = 0; // re-initiallinging the Value to 0
						receiptPanNotAvbl = 0; // re-initiallinging the Value to 0
						// Added By AMI For FVU 3.0
						receiptCntTaxDeductedAtHighRate = "-";
						receiptUnmatchedChalanCnt = "-"; // re-initiallinging the Value to 0

						// M08_B
						// sumOfSalDelTotTaxableIncome = 0;
						sumOfSalDelTotTaxableIncome = new BigDecimal("0");
						// M08_E

						receiptLastSDNumber = "-";
						receiptChallanDDNumber = new StringBuffer();

						receiptTotalAmtPaidCrdtOriginalMode = "-";
						receiptTotalAmtPaidCrdtUpdateMode = "-";
						receiptTotalAmtPaidCrdtAddMode = "-";
						receiptTotalITDeductedAtSrcOrigMode = "-";
						receiptTotalITDeductedAtSrcUpdtMode = "-";
						receiptTotalITDeductedAtSrcAddMode = "-";
						receiptTotalITDeductedAtSrcDelMode = "-";
						statTotalNoOfDDRec = "-";
						statTotalValueofTurnover = "-";
						receiptTotofDepdAmtOrigMode = "-";
						receiptTotofDepdAmtUpdtMode = "-";
						receiptTotofDepdAmtAddMode = "-";
						receiptTotofDepdAmtDelMode = "-";
						receiptSDCountForC5 = "-";
						// statPANReport = new StringBuffer();
						// END Generating the StringBuffer for Receipt and Statistic File .

						/*
						 * If the Record Type is not Batch Header(BH), we loop till we find a Batch
						 * Record(BH).
						 */
						if (RecType == null || !(RecType.equals(BATCH_HEADER_IDENTIFIER))) {
							while (!(RecType.equals(BATCH_HEADER_IDENTIFIER))) {
								record = br.readLine();
								LineCount++;
								// while reading the line if EOF is encountered
								if (record == null || record.trim().length() == 0) {
									obj_StringBuffer.append(1 + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1013_C + tab + T_FV_1013_M);
									obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
									return;
								}
								StringTokenizer st_BH = new StringTokenizer(record, FIELD_SEPERATOR, true);

								int localCaretCountBH1 = 0;
								int localCountField_BH1 = 1;

								while (st_BH.hasMoreTokens()) {
									String val = st_BH.nextToken();
									NullField = false;
									FieldFound = false;
									if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
										NullField = true;
										FieldFound = true;
									}
									if (val.equals(FIELD_SEPERATOR)) {
										Caret = true;
										if (localCountField_BH1 == 1 && localCaretCountBH1 == 0) {
											LineNo = val;
										}
										localCaretCountBH1++;
									} else {
										Caret = false;
										FieldFound = true;
									}
									if (localCountField_BH1 > 2) {
										break;
									}

									if (FieldFound) {
										switch (localCountField_BH1) {
										case 1:
											LineNo = val;
											break;
										case 2:
											RecType = val;
											break;

										} // Closing switch
										localCountField_BH1++;
									} // Closing if
								} // END while loop

								duplicateFileHeader = isDuplicateFileHeader(LineNo, RecType, obj_StringBuffer);
								if (duplicateFileHeader)
									return;
								// RecType is not FH,BH,CH,DD but some special character.then increment batch
								// count
								if ((i == 1) && !RecType.equals(BATCH_HEADER_IDENTIFIER)) {
									// Nahush 20 August 08
									if (Integer.parseInt(LineNo.trim()) != LineCount) {
										LineNo = "NA";
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "Batch Line Number" + tab + tab + tab + T_FV_2002_C + tab + T_FV_2002_M);
									}
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + BATCH_RECORD_TYPE + tab + "-" + tab + "-" + tab + T_FV_2004_C + tab + T_FV_2004_M);
									if (i == countOfBatch) { // If the File has Only ONE Batch and it is not in 3rd Line
																// of File we Return to
																// the Calling Program i.e FVU.java
										obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
										return;
									} else {
										// If the File has more than ONE Batch we SET the FLAG TRUE, increment the batch
										// count and Break
										errorLoggedForInvalidBH = true;
										BatchCount++;
										break;
									}
								} else if ((ddRecValidatedFlag || challanLevlErrFlag || zCorrectionZeroDDRecFlag) && !RecType.equals(BATCH_HEADER_IDENTIFIER)) {
									if (RecType.equals(CHALLAN_HEADER_IDENTIFIER)) {
										obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Challan_Detail_Record_Number + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
									} else if (RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Deductee_Detail_Record_Number + tab + tab + tab + T_FV_3126_C + tab + T_FV_3126_M);
									}
									// Changes commented for 6.7 on hold cr
									/*
									 * //skip validations for Fin Year 2019-20 onwards START else
									 * if(Integer.parseInt(FinancialYr) >= 201920) { break; }//skip validations for
									 * Fin Year 2019-20 onwards END
									 */ else if (RecType.equals(SALARY_STATEMENT_IDENTIFIER)) {
										obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Salary_Detail_Record_Number + tab + tab + tab + T_FV_2129_C + tab + T_FV_2129_M);
									} else if (RecType.equals(SECTION10_HEADER_IDENTIFIER)) {
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Section_Record_Number + tab + tab + tab + T_FV_6031_C + tab + T_FV_6031_M);
									}
									/*
									 * else if (RecType.equals(SECTION8889_HEADER_IDENTIFIER)) {
									 * obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + tab + tab +
									 * T_FV_6032_C + tab + T_FV_6032_M); }
									 */
									else if (RecType.equals(SECTIONVIA_HEADER_IDENTIFIER)) {
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Section_C6A_Number + tab + tab + tab + T_FV_6033_C + tab + T_FV_6033_M);
									} else if (RecType.equals(SECTION16_HEADER_IDENTIFIER)) {
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Section_16 + tab + tab + tab + T_FV_6030_C + tab + T_FV_6030_M);
									} else {
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2126_C + tab + T_FV_2126_M);
									}

								} else if ((TransactionType != null)
										&& (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC))
										&& !RecType.equals(BATCH_HEADER_IDENTIFIER)) {
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2066_C + tab + T_FV_2066_M);
								} else if (!RecType.equals(CHALLAN_HEADER_IDENTIFIER) && !RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
									if (!RecType.equals(BATCH_HEADER_IDENTIFIER)) {
										BatchCount++;
										// Nahush 20 August 08
										if (Integer.parseInt(LineNo.trim()) != LineCount) {
											LineNo = "NA";
											obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "Batch Line Number" + tab + tab + tab + T_FV_2002_C + tab + T_FV_2002_M);
										}
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + "-" + tab + "-" + tab + T_FV_2004_C + tab + T_FV_2004_M);
										i++;
									}
								}
							}
						} // if (!(RecType.equals(BATCH_HEADER_IDENTIFIER)))

						/*
						 * If Batch Header is found we call validateBatchHeader Method to validate Batch
						 * Record
						 */
						if ((RecType.equals(BATCH_HEADER_IDENTIFIER))) {
							BatchCount++;
							challanLevlErrFlag = false;
							ddRecValidatedFlag = false;
							zCorrectionZeroDDRecFlag = false;

							if (record == null || record.trim().length() == 0) {
								break;
							}

							CountField_BH = 1;
							int localCaretCounterBH88 = 0;
							StringTokenizer Obj_st_bh = new StringTokenizer(record, FIELD_SEPERATOR, true);
							while (Obj_st_bh.hasMoreTokens()) {
								String val = Obj_st_bh.nextToken();
								NullField = false;
								FieldFound = false;
								if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
									NullField = true;
									FieldFound = true;
								}
								if (val.equals(FIELD_SEPERATOR)) {
									Caret = true;
									if (localCaretCounterBH88 == 0 && CountField_BH == 1) {
										CountField_BH++;
										LineNo = "";
									}
									localCaretCounterBH88++;
								} else {
									Caret = false;
									FieldFound = true;
								}

								if (FieldFound) {
									switch (CountField_BH) {

									case 1:
										LineNo = val;
										break;
									case 2:
										RecType = val;
										break;
									case 3:
										BH_BatchNo = val;
										break;
									case 4:
										NoChallan = val;
										break;
									case 5:
										FormNo = val;
										break;
									case 6:
										TransactionType = val;
										break;
									case 47:
										GrossTDSTotalAsPerChallan = val;
									} // Closing switch
									CountField_BH++;

								} // Closing if
							} // Closing While
							CountField_BH = 1;
							cal = new GregorianCalendar();
							// Nahush
							BatchLineNo = LineNo;

							currentUploadType = TransactionType;

							// for FVU 3.8 by Shalin

							if (currentUploadType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								obj_StringBuffer.append(LineNo + tab + "Correction" + tab + "Update TAN" + tab + tab + tab + T_FV_2229_C + tab + T_FV_2229_M);
							}

							if ((currentUploadType.equals(FIELD_SEPERATOR) || currentUploadType.equals(FIELD_NULL)) && UploadType.equals(UPLOADTYPE_REGULAR)) {
								currentUploadType = UPLOAD_TYPE_REGULAR;
							}

							else if (currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								currentUploadType = UPLOAD_TYPE_C1;
							}

							else if (currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								currentUploadType = UPLOAD_TYPE_C2;
							}

							else if (currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								currentUploadType = UPLOAD_TYPE_C3;
							}

							else if (currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								currentUploadType = UPLOAD_TYPE_C4;
							}

							else if (currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								currentUploadType = UPLOAD_TYPE_C5;
							}

							else if (currentUploadType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								currentUploadType = UPLOAD_TYPE_C9;
							}

							else if (currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								currentUploadType = UPLOAD_TYPE_X;
							}

							else if (currentUploadType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) && UploadType.equals(UPLOADTYPE_CORRECTION)) {
								currentUploadType = UPLOAD_TYPE_Y;
							}

							else if (!(currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)
									|| currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || currentUploadType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)
									|| currentUploadType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || currentUploadType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)) && UploadType.equals(UPLOADTYPE_CORRECTION))

							{
								currentUploadType = UPLOAD_TYPE_CORRECTION;
							} else if (!(currentUploadType.equals(FIELD_SEPERATOR) || currentUploadType.equals(FIELD_NULL)) && UploadType.equals(UPLOADTYPE_REGULAR)) {
								currentUploadType = UPLOAD_TYPE_REGULAR;
							}

							// ---Changed for validating count of structurally valid DD --Manvendra Singh
							// #############################################

							if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
								PerformValidation = true;
								performValidationAtbatchLevel = true;
							}
							if (UploadType.equals(UPLOADTYPE_REGULAR)) {
								PerformValidation = true;
								performValidationAtbatchLevel = true;
							}
							// ########################################################

							if (countOfBatch == i) {
								lastBatchError1 = obj_StringBuffer.errorBufferString.length();
							}

							long batchRecErrLengthBefore = obj_StringBuffer.errorBufferString.length();
							// Added By AMI For FVU 3.0
							lineCountOfBtch = LineCount;
							// if(UploadType.equals(UPLOADTYPE_REGULAR)||TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)||(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)&&ChallanUpdationIndicator.equals("1"))||TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
							// unmatchedChalanCntStrBuff.append(lineCountOfBtch + statDataDelemiter);
							// positionOfBtch = unmatchedChalanCntStrBuff.length();

							validateBatchHeader(record, LineCount, UploadType, obj_StringBuffer);

							long batchRecErrLengthAfter = obj_StringBuffer.errorBufferString.length();

							/*
							 * Boolean is set to TRUE if Error is found whil;e validating Batch Record else
							 * boolean is set FALSE
							 */
							boolean errorInBatchRecord = false;
							if ((batchRecErrLengthAfter - batchRecErrLengthBefore) != 0) {
								errorInBatchRecord = true;
							} else {
								errorInBatchRecord = false;
							}

							if (countOfBatch == i) {
								lastBatchError2 = obj_StringBuffer.errorBufferString.length();
								if ((lastBatchError1 - lastBatchError2) == 0) {
									lastBatchErrorFlag = true;
								}
							}

							prevChallanRecCount = 0;
							cal = new GregorianCalendar();
							/*
							 * If Error is found in the Batch Record Validation and Transaction Type is not
							 * Batch Correction(C1) or Batch Cancellation(Y) We skip the Batch and
							 * underlying Challan, Deductee(if present) and Salary detail record(if present)
							 * and look for NEXT BATCH Record
							 */
							if (errorInBatchRecord && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && !TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) && !TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)) {
								boolean nullBatchRecordFlag = false;

								do {
									LineCount++;
									record = br.readLine();
									if (record == null || record.trim().length() == 0) {
										if (!(i <= (countOfBatch))) {

											obj_StringBuffer.append("" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1013_C + tab + T_FV_1013_M);
										}
										nullBatchRecordFlag = true;
										break;
									}

									StringTokenizer st_BH1 = new StringTokenizer(record, FIELD_SEPERATOR, true);

									int localCaretCountBH1 = 0;
									int localCountField_BH1 = 1;
									while (st_BH1.hasMoreTokens()) {
										String val = st_BH1.nextToken();
										NullField = false;
										FieldFound = false;
										if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
											NullField = true;
											FieldFound = true;
										}
										if (val.equals(FIELD_SEPERATOR)) {
											Caret = true;
											if (localCountField_BH1 == 1 && localCaretCountBH1 == 0) {
												localCountField_BH1++;
												LineNo = val;
											}
											localCaretCountBH1++;
										} else {
											Caret = false;
											FieldFound = true;
										}
										if (localCountField_BH1 > 2) {
											break;
										}

										if (FieldFound) {
											switch (localCountField_BH1) {
											case 1:
												LineNo = val;
												break;
											case 2:
												RecType = val;
												break;

											} // Closing switch
											localCountField_BH1++;
										} // Closing if
									} // END while loop

									duplicateFileHeader = isDuplicateFileHeader1(record, obj_StringBuffer);
									if (duplicateFileHeader)
										return;
								} while (!(RecType.equals(BATCH_HEADER_IDENTIFIER)));
								// CLOSING WHILE LOOP(SEARCHINGTILL NEXT BH IS ENCOUNTERED))

								if (RecType.equals(BATCH_HEADER_IDENTIFIER) && (i == countOfBatch) && !nullBatchRecordFlag) {
									obj_StringBuffer.append(1 + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
									break;
								}
								continue;
							} // CLOSING IF(THERE IS ERROR ON BH)

							/*
							 * If Transaction type is Batch Correction (C1) or Batch Cancellation (Y), only
							 * Batche Records are expected for correction\Cancellation We look for NEXT
							 * BATCH if we have not reached the Last Batch Record of the File.
							 */
							if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)) && i != countOfBatch) {
								record = br.readLine();
								LineCount++;
								if (record == null || record.trim().length() == 0) {
									obj_StringBuffer.append(1 + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
									break;
								}

								StringTokenizer st_BH1 = new StringTokenizer(record, FIELD_SEPERATOR, true);

								int localCaretCountBH1 = 0;
								int localCountField_BH1 = 1;
								while (st_BH1.hasMoreTokens()) {
									String val = st_BH1.nextToken();
									NullField = false;
									FieldFound = false;
									if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
										NullField = true;
										FieldFound = true;
									}
									if (val.equals(FIELD_SEPERATOR)) {
										Caret = true;
										if (localCountField_BH1 == 1 && localCaretCountBH1 == 0) {
											localCountField_BH1++;
											LineNo = val;
										}
										localCaretCountBH1++;
									} else {
										Caret = false;
										FieldFound = true;
									}
									if (localCountField_BH1 > 2) {
										break;
									}

									if (FieldFound) {
										switch (localCountField_BH1) {
										case 1:
											LineNo = val;
											break;
										case 2:
											RecType = val;
											break;

										} // Closing switch
										localCountField_BH1++;
									} // Closing if
								} // END while loop

								if (!(RecType.equals(BATCH_HEADER_IDENTIFIER))) {
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Batch_Record_Type + tab + tab + tab + T_FV_2066_C + tab + T_FV_2066_M);
								}
								continue;
							} // closing if upload type is C1

							/*
							 * Validating Challan, Deductee, and Salary record if the File Type is NOT Batch
							 * Record Correction(C1) If Transaction Type is Batch Record level
							 * Correction(C1), or Batch Record Level Cancellation we look for NEXT BATCH.
							 */
							if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && !TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) && !TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)) // If File is
																																																								// Batch
																																																								// Correction(C1)
																																																								// we don't
																																																								// check for
																																																								// Challan and
																																																								// Salary Detail
																																																								// Record
							{

								// added to do DD validation for everyBatch on the basis of
								// RRR date and sysdate added in 2.114 ...:: Manvendra Feb 2008

								// ##############################################################

								if (utilityLevel == 3 && TanTfcIdIndicator.equals(UPLOADED_BY_TFC)) {
									if (tempRRRDateforBatch.before(newValidationStartDate)) {
										performDDvalidation = false;
										performValidationAtbatchLevel = false;
									}
								}

								else if (CurrentDate.before(newValidationStartDate)) {
									performDDvalidation = false;
									performValidationAtbatchLevel = false;
								}

								// System.out.println("performValidationAtbatchLevel
								// \n"+performValidationAtbatchLevel);
								// ###############################################################
								/*
								 * If Transaction Type is Challan Level Correction(C2) or Deductee Level
								 * Correction(C3) or Cancellation(X) we traverse the File for Challan Records.
								 * If Transaction Type is Salary Level Correction(C4) or Salary Level
								 * Replacement(Z) we move to next part of If statement
								 */
								if (!(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY)) && !(TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY))) {
									countOfChallan = Integer.parseInt(NoChallan.trim());

									int challanErrBuffLeng1 = 0;
									// used to store the length of Error Buffer before doing Challan validation
									int challanErrBuffLeng2 = 0;
									// used to store the length of Error Buffer after doing Challan and Deductee
									// record validation

									int validChallanCount = 0;

									challanErrBuffLeng1 = obj_StringBuffer.errorBufferString.length();

									// Loop START for Challan Record Validation.
									// We will loop equal to the Count of Challan Specified in Batch record.
									for (int localCountChallan = 1; localCountChallan <= countOfChallan; localCountChallan++) {
										/*
										 * If Record Type is Not Challan (CD), we read next record until we find the
										 * Next Challan Record. We log Error if we find a Batch Record (Record Type
										 * 'BH') while looking for Challan record.
										 */
										if (localCountChallan > 1) {
											receiptChallanDDNumber.append("^LD" + receiptChallanDetailRecNo + "=" + receiptLastDDNumber);
										}
										receiptLastDDNumber = "-";

										if (RecType == null || !(RecType.equals(CHALLAN_HEADER_IDENTIFIER))) {
											record = br.readLine();
											LineCount++;
											int localCountField_CH1 = 1;
											int localCaretCountCH1 = 0;
											String localCHNo = "-";

											if (record == null || record.trim().length() == 0) {
												if (localCountChallan <= countOfChallan) {
													obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
												}
												break;
											}

											if (record != null || record.length() > 0) {
												StringTokenizer st_CH = new StringTokenizer(record, "^", true);
												Caret = false;
												while (st_CH.hasMoreTokens()) {
													String val = st_CH.nextToken();
													NullField = false;
													FieldFound = false;

													if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
														NullField = true;
														FieldFound = true;
													}

													if (val.equals(FIELD_SEPERATOR)) {
														Caret = true;
														if (localCountField_CH1 == 1 && localCaretCountCH1 == 0) {
															localCountField_CH1++;
															LineNo = "-";
														}
														localCaretCountCH1++;
													} else {
														Caret = false;
														FieldFound = true;
													}

													if (localCountField_CH1 > 4) {
														break;
													}

													if (FieldFound) {
														switch (localCountField_CH1) {
														case 1:
															LineNo = val;
															break;
														case 2:
															RecType = val;
															break;
														case 4:
															localCHNo = val;
															break;

														} // Closing switch
														localCountField_CH1++;
													} // Closing if
												}
											}

											if ((localCaretCountCH1 != 4) && (localCountField_CH1 < 4)) {
												if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH))
													obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + "-" + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);

												else
													obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + localCHNo + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);

												if (localCountChallan != countOfChallan) {
													do {
														record = br.readLine();
														LineCount++;
														if (record == null || record.trim().length() == 0) {
															if (!(i <= (countOfChallan))) {
																obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Challan_Detail_Record_Number + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
															}
															break;
														}

														int localCaretCountCH = 0;
														int localCountField_CH = 1;
														StringTokenizer st_CH = new StringTokenizer(record, "^", true);

														LineNo = "";
														RecType = "";
														localCHNo = "-";

														while (st_CH.hasMoreTokens()) {
															String val = st_CH.nextToken();
															NullField = false;
															FieldFound = false;
															if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
																NullField = true;
																FieldFound = true;
															}
															if (val.equals(FIELD_SEPERATOR)) {
																Caret = true;
																if (localCaretCountCH == 0 && localCountField_CH == 1) {
																	localCountField_CH++;
																	LineNo = "-";
																}
																localCaretCountCH++;
															} else {
																Caret = false;
																FieldFound = true;
															}

															if (localCountField_CH > 4) {
																break;
															}
															if (FieldFound) {
																switch (localCountField_CH) {
																case 1:
																	LineNo = val;
																	break;
																case 2:
																	RecType = val;
																	break;
																case 4:
																	localCHNo = val;

																} // Closing switch
																localCountField_CH++;
															} // Closing if
														}

														if (localCaretCountCH != 4 && ((LineNo == null || LineNo.length() == 0) || (RecType == null || RecType.length() == 0))) {
															if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH))

																obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + "-" + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);

															else

																obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + localCHNo + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);

															continue;
														}

														if (localCaretCountCH < 2) {
															if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH))

																obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + "-" + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);

															else

																obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + localCHNo + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);
															continue;
														}
													} while (!(RecType == null || RecType.equals(BATCH_HEADER_IDENTIFIER) || RecType.equals(CHALLAN_HEADER_IDENTIFIER)));
													continue;
												}
											}

											if (RecType.equals(BATCH_HEADER_IDENTIFIER)) {
												obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Challan_Detail_Record_Number + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
												break;
											}

										} // CLOSING IF if (!(RecType.equals(CHALLAN_HEADER_IDENTIFIER)
											// Reading the challan field by field

										if (record == null || record.trim().length() == 0) {
											obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Challan_Detail_Record_Number + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
											obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
											return;
										}

										if ((RecType.equals(CHALLAN_HEADER_IDENTIFIER))) {
											ddRecValidatedFlag = false;
											// Added by faizan for FVu 4.5
											challanWiseTDSfield30 = 0;
											SumTDSIncomeTaxDDfield14 = 0;
											challanWiseTDSfield31 = 0;
											SumTDSIncomeTaxDDfield15 = 0;
											challanWiseTDSfield32 = 0;
											SumTDSIncomeTaxDDfield16 = 0;

											CountField_CH = 1;
											int localCaretCounterCH1 = 0;
											StringTokenizer Obj_st_ch = new StringTokenizer(record, FIELD_SEPERATOR, true);
											while (Obj_st_ch.hasMoreTokens()) {
												String val = Obj_st_ch.nextToken();
												NullField = false;
												FieldFound = false;
												if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
													NullField = true;
													FieldFound = true;
												}
												if (val.equals(FIELD_SEPERATOR)) {
													Caret = true;
													if (localCaretCounterCH1 == 0 && CountField_CH == 1) {
														CountField_CH++;
														LineNo = "-";
													}
													localCaretCounterCH1++;
												} else {
													Caret = false;
													FieldFound = true;
												}
												if (CountField_CH > 5) {
													break;
												}
												if (FieldFound) {
													switch (CountField_CH) {

													case 1:
														LineNo = val;
														break;
													case 2:
														RecType = val;
														break;
													case 3:
														CH_BatchNo = val;
														break;
													case 4:
														ChallanDetailRecordNo = val;
														break;
													case 5:
														CountOfDeducteeDetail = val;
														break;

													} // Closing switch
													CountField_CH++;

												}
											}

											// -------------- Added by Nahush

											if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)) {
												CurrentchallanDetailRecordNo = "Null";
											}

											else {
												CurrentchallanDetailRecordNo = ChallanDetailRecordNo;
											}

											// -----------------------

											if ((localCaretCounterCH1 < 5) && (CountField_CH < 5)) {
												obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);
												break;
											}
											CountField_CH = 1;
											duplicateFileHeader = isDuplicateFileHeader(RecType, LineNo, obj_StringBuffer);

											if (duplicateFileHeader) {
												return;
											}

											ChallanCount++;
											validChallanCount++;
											cal = new GregorianCalendar();
											System.out.println("Validating Challan " + ChallanCount);
											if (localCountChallan == countOfChallan) {
												lastChallanError1 = obj_StringBuffer.errorBufferString.length();
											}

											long challanErrRecLengthBefore = obj_StringBuffer.errorBufferString.length();

											validateChallanHeader(record, LineCount, BH_BatchNo, FileType, FormNo, Qperiod, validChallanCount, GrossTDSTotalAsPerChallan, CountOfChallanRec, RRRDatePresentDate, UploadType, obj_StringBuffer,
													utilityLevel, fileExtention); // File Extention Added For FVU 3.0

											// Added for FVU 3.8 by Shalin
											/*
											 * if(currentUploadType.equals(UPLOADTYPE_REGULAR) &&
											 * NillChallanIndicator.equals("Y") &&
											 * Integer.parseInt(CountOfDeducteeDetail.trim()) == 0) {
											 * obj_StringBuffer.append(LineNo + tab + currentUploadType + tab +
											 * "NIL Challan Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab +
											 * T_FV_3163_C + tab + T_FV_3163_M);
											 * 
											 */

											// Added For Mandatory CSI File

											if (cinMandatory && !cinMandatoryWritten) {
												System.out.println("CSI File Mandatory");
												obj_StringBuffer.errorBufferString.insert(0, "1" + tab + "NA" + tab + "NA" + tab + tab + tab + T_FV_1041_C + tab + T_FV_1041_M);
												cinMandatoryWritten = true;
												forCSIfile = false;
											}
											// ****************************************************************************************************
											// Start :: Priya added to fvu 5.0 to read csi file

											try {
												// System.out.println(" DeductorType is :: "+DeductorType);
												// System.out.println("cinMandatory :;"+cinMandatory
												// +"cinMandatoryWritten"+cinMandatoryWritten);
												// System.out.println("(cinMandatory &&
												// !cinMandatoryWritten)"+(cinMandatory &&
												// !cinMandatoryWritten));

												// System.out.println("Value of bypassTanTanNameValidate ::
												// "+bypassTanTanNameValidate);
												System.out.println("Value of forCSIfile  :: " + forCSIfile);

												if (forCSIfile) {
													System.out.println(" cinmandatory");
													/*
													 * if(!bypassTanTanNameValidate) {
													 */
													// System.out.println(" Helloo ..inside in reading CSi file ");
													// System.out.println("the CIN file name is" +
													// FileStatistics.getCinFileName());
													cinFr = new FileReader(FileStatistics.getCinFileName());
													cinBr = new BufferedReader(cinFr);
													int recCount = 0;
													final String dlm = "^";
													String readln;
													// System.out
													// .println(" inbypassTanTanNameValidate");

													while ((readln = cinBr.readLine()) != null) {
														recCount++;
														if (recCount == 1) {
															int k = 0;
															k = readln.lastIndexOf("^");

															StringTokenizer st1 = new StringTokenizer(readln, dlm, false);
															// int tokenCount=0;

															if (st1.hasMoreElements()) {
																System.out.println("No of challan from csi file :: " + st1.nextToken());
															}
															if (st1.hasMoreElements()) {
																TanFromCSIFile = st1.nextToken();
																// System.out.println("TanFromCSIFile ::
																// "+TanFromCSIFile);
															}
															if (st1.hasMoreElements()) {
																TanNameFromCSIFile = st1.nextToken();
																// System.out.println("TanNameFromCSIFile :: "
																// +TanNameFromCSIFile);

															}
															// added for FVU 5.5
															if (st1.hasMoreElements()) {
																FVU_Higher_Version = st1.nextToken();
																System.out.println("The FVU Higher Version is " + FVU_Higher_Version);

															}
															if (st1.hasMoreElements()) {
																FVU_Lower_Version = st1.nextToken();
																System.out.println("The FVU lower Version is " + FVU_Lower_Version);

															}
															// Changes commented for 6.7 on hold cr
															/*
															 * //Changes added for 6.7^2.163^2.1295 CSI File by kiran
															 * if(st1.hasMoreElements()) { FVU_24Q4_Version = st1.nextToken();
															 * System.out.println("The FVU  Version for 24Q4  is " + FVU_24Q4_Version );
															 * 
															 * }
															 */

															// ended for FVU 5.5

														}
													}
													// }
												}

											}

											catch (Exception e) {
												System.out.println("Exception in Reading CSI file for validating TAN and TANNAME" + e);

											}
											// End :: Priya added to read csi file

											// Start :: priya Added for FVU 5.0 to validate TAN and TANNAme
											// System.out.println("batch no "+Integer.parseInt(BH_BatchNo));
											/*
											 * if (Integer.parseInt(BH_BatchNo) ==1) {
											 */
											System.out.println("TanNameFromTxtFile ::  " + TanNameFromTxtFile + "   TanNameFromCSIFile :: " + TanNameFromCSIFile);
											System.out.println("TanFromTxtFile ::  " + TanFromTxtFile + "   TanFromCSIFile  :: " + TanFromCSIFile);
											// System.out.println("bypassTanTanNameValidate :: "+
											// bypassTanTanNameValidate);
											// System.out.println("forCSIfile :: "+ forCSIfile);
											// System.out.println("!tanTanNameValidate && !forCSIfile :: "+
											// (!bypassTanTanNameValidate && !forCSIfile));

											if (forCSIfile) {
												/*
												 * if(!bypassTanTanNameValidate) {
												 */

												if (!TanFromCSIFile.equals(TanFromTxtFile)) {
													if (tanFlag == 0) {
														obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_6069_C + tab + T_FV_6069_M);
														tanFlag = 1;
													}
												}

												if (!TanNameFromTxtFile.equalsIgnoreCase(TanNameFromCSIFile)) {
													if (tanNameFlag == 0) {
														// changes added for funct point 4 for FVU 6.4 by puja
														String Error_msg = "TAN name provided in file is  '" + TanNameFromTxtFile + "',  however TAN name as per TAN master database of Income Tax Department (ITD) is  '" + TanNameFromCSIFile + "'.\n";
														obj_StringBuffer.append(BatchLineNo + tab + currentUploadType + tab + "NA" + tab + "-" + tab + tab + T_FV_3173_C + tab + Error_msg);
														tanNameFlag = 1;
													}
												}

												// added for FVU 5.5
												// version Commented for FVU 7.1
												//Commented FVU 7.2
												if (!TDSFVUVersion.equals(FVU_Higher_Version)) {
													obj_StringBuffer.errorBufferString.insert(0, "1" + tab + "NA" + tab + "NA" + tab + tab + tab + T_FV_3175_C + tab + T_FV_3175_M);
												}
												

												// ended for FVU 5.5

												// }
												// }
											}

											// End :: Added by priya for FVU 5.0 to validate TAN and TANNAme

											// *******************************************************************

											long challanErrRecLengthAfter = obj_StringBuffer.errorBufferString.length();

											/*
											 * Boolean is Set to TRUE if error is found while Validating Challan Record else
											 * if No error is found Boolean is Set FALSE
											 */
											boolean errorInChallanRecord = false;
											if ((challanErrRecLengthAfter - challanErrRecLengthBefore) != 0) {
												errorInChallanRecord = true;
											} else {
												errorInChallanRecord = false;
											}

											if (localCountChallan == countOfChallan) {
												lastChallanError2 = obj_StringBuffer.errorBufferString.length();
												if ((lastChallanError1 - lastChallanError2) == 0) {
													lastChallanErrorFlag = true;
												} else {
													lastChallanErrorFlag = false;
												}
											}

											prevDeducteeRecCount = 0;
											deducteeDetailAddMode = false;
											cal = new GregorianCalendar();
											/*
											 * If Error is found while validating Challan record or If Count of Deductee
											 * Detail record is 0(Zero) skip that challan and goto next challan. A regular
											 * File can have Challan Records with Zero(0) Deductee Records
											 */
											if (errorInChallanRecord
													|| (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && (Integer.parseInt(CountOfDeducteeDetail.trim()) == 0))) {

												if (localCountChallan != countOfChallan) {
													do {
														record = br.readLine();
														LineCount++;
														if (record == null || record.trim().length() == 0)
															break;

														StringTokenizer st_CH2 = new StringTokenizer(record, FIELD_SEPERATOR, true);

														int localCaretCountBH1 = 0;
														int localCountField_BH1 = 1;
														while (st_CH2.hasMoreTokens()) {
															String val = st_CH2.nextToken();
															NullField = false;
															FieldFound = false;
															if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
																NullField = true;
																FieldFound = true;
															}
															if (val.equals(FIELD_SEPERATOR)) {
																Caret = true;
																if (localCountField_BH1 == 1 && localCaretCountBH1 == 0) {
																	localCountField_BH1++;
																	LineNo = val;
																}
																localCaretCountBH1++;
															} else {
																Caret = false;
																FieldFound = true;
															}
															if (localCountField_BH1 > 2) {
																break;
															}

															if (FieldFound) {
																switch (localCountField_BH1) {
																case 1:
																	LineNo = val;
																	break;
																case 2:
																	RecType = val;
																	break;

																} // Closing switch
																localCountField_BH1++;
															} // Closing if
														} // END while loop

														duplicateFileHeader = isDuplicateFileHeader(RecType, LineNo, obj_StringBuffer);
														if (duplicateFileHeader) {
															return;
														} else if ((errorInChallanRecord == false) && !RecType.equals(CHALLAN_HEADER_IDENTIFIER) && !RecType.equals(BATCH_HEADER_IDENTIFIER) && !RecType.equals(SALARY_STATEMENT_IDENTIFIER)
																&& (Integer.parseInt(CountOfDeducteeDetail.trim()) == 0)) {
															/*
															 * If the Count of Deductee Detail record in the Challan is given Zero(0), but
															 * if Deductee records are given for that challan then we log error
															 */
															if (RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
																if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH))
																	obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + Deductee_Detail_Record_Number + tab + "-" + tab + tab + T_FV_3126_C + tab + T_FV_3126_M);

																else
																	obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + Deductee_Detail_Record_Number + tab + localCountChallan + tab + tab + T_FV_3126_C + tab + T_FV_3126_M);
															} else if (Integer.parseInt(FinancialYr) < 201920)// Skip
																												// validations
																												// for
																												// Fin
																												// Year
																												// 2019-20
															{
																obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_2126_C + tab + T_FV_2126_M);
															}
														}
													} while (!RecType.equals(CHALLAN_HEADER_IDENTIFIER) && !RecType.equals(BATCH_HEADER_IDENTIFIER) && !RecType.equals(SALARY_STATEMENT_IDENTIFIER));
													// CLOSING WHILE LOOP(TILL THE NEXT CH OR BH OR SD IS ENCOUNTERED)

													if (RecType.equals(BATCH_HEADER_IDENTIFIER) || RecType.equals(SALARY_STATEMENT_IDENTIFIER) || (record == null || record.trim().length() == 0)) {
														obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
														break;
													} else {
														continue;
													}

												} else {

													if ((UploadType.equals(UPLOADTYPE_REGULAR) && FormNo.equals(FORM_24Q) && (Integer.parseInt(CountOfSalaryDetailRec.trim()) > 0)) || (FormNo.equals(FORM_24Q)
															&& (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || (TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) && Integer.parseInt(CountOfSalaryDetailRec.trim()) > 0)))) {
														String LocalMode = null;
														do {
															record = br.readLine();

															LineCount++;
															if ((record == null || record.length() == 0) /*
																											 * && (Integer.parseInt(FinancialYr) < 201920)
																											 */)// Skip
																												// validations
																												// for
																												// Fin
																												// Year
																												// 2019-20
																												// onwards
																												// //
																												// Changes
																												// commented
																												// for
																												// 6.7
																												// on
																												// hold
																												// cr
															{
																obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Salary_Details_Records + tab + tab + tab + T_FV_2129_C + tab + T_FV_2129_M);
																break;
															}

															int localCaretCount = 0;
															int localCountField_DD = 1;
															String localSDNumber = "";

															StringTokenizer st_DD = new StringTokenizer(record, "^", true);

															LineNo = null;
															RecType = null;

															while (st_DD.hasMoreTokens()) {
																String val = st_DD.nextToken();
																NullField = false;
																FieldFound = false;
																if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
																	NullField = true;
																	FieldFound = true;
																}
																if (val.equals(FIELD_SEPERATOR)) {
																	Caret = true;
																	if (localCaretCount == 0 && localCountField_DD == 1) {
																		// LocalCountField_DD++;
																		LineNo = "";
																	}
																	localCaretCount++;
																} else {
																	Caret = false;
																	FieldFound = true;
																}

																if (localCountField_DD > 5) {
																	break;
																}
																if (FieldFound) {
																	switch (localCountField_DD) {
																	case 1:
																		LineNo = val;
																		break;
																	case 2:
																		RecType = val;
																		break;
																	case 4:
																		localSDNumber = val;
																		break;
																	case 5:
																		LocalMode = val;

																	} // Closing switch
																	localCountField_DD++;
																} // Closing if
															}

															if (localCaretCount != 2 && ((LineNo == null || LineNo.length() == 0) || (RecType == null || RecType.length() == 0))) {
																if (LineNo == null || LineNo.length() == 0)
																	obj_StringBuffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + tab + localSDNumber + tab + T_FV_4004_C + tab + T_FV_4004_M);
																else if ((RecType == null || RecType.length() == 0))
																	obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Salary_Detail_Record_Type + tab + tab + localSDNumber + tab + T_FV_4124_C + tab + T_FV_4124_M);
																else
																	obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + localSDNumber + tab + T_FV_4064_C + tab + T_FV_4064_M);
																continue;
															}
															if (localCaretCount < 5) {
																obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + localSDNumber + tab + T_FV_4064_C + tab + T_FV_4064_M);
																continue;
															}

															if ((errorInChallanRecord == false) && (Integer.parseInt(CountOfSalaryDetailRec.trim()) > 0) && !RecType.equals(BATCH_HEADER_IDENTIFIER) && !RecType.equals(SALARY_STATEMENT_IDENTIFIER)) {
																if (RecType.equals(CHALLAN_HEADER_IDENTIFIER)) {
																	obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Challan_Detail_Record_Number + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
																} else if (RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
																	if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY)
																			|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH))
																		obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + Deductee_Detail_Record_Number + tab + "-" + tab + tab + T_FV_3126_C + tab + T_FV_3126_M);
																	else
																		obj_StringBuffer
																				.append(lineNoOfChallanRec + tab + currentUploadType + tab + Deductee_Detail_Record_Number + tab + localCountChallan + tab + tab + T_FV_3126_C + tab + T_FV_3126_M);
																} else if (Integer.parseInt(FinancialYr) < 201920)// Skip
																													// validations
																													// for
																													// Fin
																													// Year
																													// 2019-20
																{
																	obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2126_C + tab + T_FV_2126_M);
																}
															}
														} while (!(RecType.equals(BATCH_HEADER_IDENTIFIER) || RecType.equals(SALARY_STATEMENT_IDENTIFIER)));

														if (RecType.equals(BATCH_HEADER_IDENTIFIER)) {

															batchRecFoundFlag = true;
															obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + Count_Of_Salary_Details_Records + tab + tab + countOfBatch + tab + tab + T_FV_2129_C + tab + T_FV_2129_M);
														}
													}
													break;
												}
											} // CLOSING IF LOOP(IF THERE IS AN ERROR IN CH)
											else if ((FileType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && Integer.parseInt(CountOfDeducteeDetail.trim()) == 0) {
												if (localCountChallan != countOfChallan) {
													record = br.readLine();
													LineCount++;
													if (record == null || record.trim().length() == 0) {
														obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
														break;
													}

													StringTokenizer st_CH2 = new StringTokenizer(record, FIELD_SEPERATOR, true);

													int localCaretCountCH12 = 0;
													int localCountField_CH12 = 1;
													String localCHNo = "-";

													while (st_CH2.hasMoreTokens()) {
														String val = st_CH2.nextToken();
														NullField = false;
														FieldFound = false;
														if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
															NullField = true;
															FieldFound = true;
														}
														if (val.equals(FIELD_SEPERATOR)) {
															Caret = true;
															if (localCountField_CH12 == 1 && localCaretCountCH12 == 0) {
																localCountField_CH12++;
																LineNo = val;
															}
															localCaretCountCH12++;
														} else {
															Caret = false;
															FieldFound = true;
														}
														if (localCountField_CH12 > 4) {
															break;
														}

														if (FieldFound) {
															switch (localCountField_CH12) {
															case 1:
																LineNo = val;
																break;
															case 2:
																RecType = val;
																break;
															case 4:
																localCHNo = val;

															} // Closing switch
															localCountField_CH12++;
														} // Closing if
													} // END while loop
													if (localCaretCountCH12 < 4) {

														if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH))

															obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + "-" + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);

														else

															obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + localCHNo + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);
														continue;
													} else if (RecType.equals(BATCH_HEADER_IDENTIFIER)) {
														obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
														break;
													} else if (!RecType.equals(CHALLAN_HEADER_IDENTIFIER)) {
														obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
														continue;
													} else
														continue;
												}
											}

											/*
											 * If transaction type is C2 or X then only batch and challan are expected and
											 * not the deductee. so we look for Next Challan in the file. If we Find
											 * Deductee record or Batch record or other Record type, we log Error and
											 * continue to look for Next Challan.
											 */
											if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)) {
												record = br.readLine();

												if (record == null || record.trim().length() == 0) {
													if (localCountChallan != countOfChallan) {
														obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
													}
													/*
													 * If we have already validated the last Challan of the Batch and The file has
													 * ended we DO NOT log Error.
													 */
													break;
												} else {
													LineCount++;
												}

												StringTokenizer st_CH3 = new StringTokenizer(record, FIELD_SEPERATOR, true);

												int localCaretCountBH1 = 0;
												int localCountField_BH1 = 1;
												while (st_CH3.hasMoreTokens()) {
													String val = st_CH3.nextToken();
													NullField = false;
													FieldFound = false;
													if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
														NullField = true;
														FieldFound = true;
													}
													if (val.equals(FIELD_SEPERATOR)) {
														Caret = true;
														if (localCountField_BH1 == 1 && localCaretCountBH1 == 0) {
															localCountField_BH1++;
															LineNo = val;
														}
														localCaretCountBH1++;
													} else {
														Caret = false;
														FieldFound = true;
													}
													if (localCountField_BH1 > 2) {
														break;
													}

													if (FieldFound) {
														switch (localCountField_BH1) {
														case 1:
															LineNo = val;
															break;
														case 2:
															RecType = val;
															break;

														} // Closing switch
														localCountField_BH1++;
													} // Closing if
												} // END while loop
												duplicateFileHeader = isDuplicateFileHeader(RecType, LineNo, obj_StringBuffer);

												if (duplicateFileHeader) {
													return;
												}
												if (localCountChallan == countOfChallan && RecType.equals(CHALLAN_HEADER_IDENTIFIER)) {
													obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
												} else if (!RecType.equals(BATCH_HEADER_IDENTIFIER) && !RecType.equals(CHALLAN_HEADER_IDENTIFIER)) {
													obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_4114_C + tab + T_FV_4114_M);
												} else if (RecType.equals(BATCH_HEADER_IDENTIFIER) && localCountChallan != countOfChallan && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)) {
													obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
													break;
												} else if ((localCountChallan == countOfChallan) && (i == countOfBatch)) {
													obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_2126_C + tab + T_FV_2126_M);
													break;
												}

												continue;
											} // CLOSING IF if
												// (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
											countOfDeductee = Integer.parseInt(CountOfDeducteeDetail.trim());

											/*
											 * Validate Deductee Records if Count of Deductee Detail Record is > 0. A
											 * Regular File can have Challan with 0(zero) number of Deductee Detail Record.
											 * If this case we DO NOT call validateDeducteeDetails Method and return back to
											 * Challan Loop
											 */
											if (countOfDeductee > 0) {
												long deducteeErrBuffLength1 = 0;
												long deducteeErrBuffLength2 = 0;
												ddRecValidatedFlag = true;
												deducteeErrBuffLength1 = obj_StringBuffer.errorBufferString.length();
												cal = new GregorianCalendar();
												System.out.println(" STARTING DEDUTEE VALIDATION FOR CHALLAN " + localCountChallan);
												for (int k = 1; k <= countOfDeductee; k++) {
													record = br.readLine();
													LineCount++;
													if (record == null || record.length() == 0) {
														if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH))
															obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + "-" + tab + tab + T_FV_3126_C + tab + T_FV_3126_M);

														else
															obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + localCountChallan + tab + tab + T_FV_3126_C + tab + T_FV_3126_M);

														break;
													}

													// reading the deductee detail, fields by field
													Obj_st = new StringTokenizer(record, FIELD_SEPERATOR, true);
													while (Obj_st.hasMoreTokens()) {
														String val = Obj_st.nextToken();
														NullField = false;
														FieldFound = false;
														if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
															NullField = true;
															FieldFound = true;
														}
														if (val.equals(FIELD_SEPERATOR))
															Caret = true;
														else {
															Caret = false;
															FieldFound = true;
														}
														if (FieldFound) {
															switch (CountField_DD) {
															case 1:
																LineNo = val;
																break;
															case 2:
																RecType = val;
																break;
															case 3:
																DD_BatchNo = val;
																break;

															}
															CountField_DD++;
															if (CountField_DD > 3)
																break;
														} // closing if
													} // Closing while
													CountField_DD = 1;
													duplicateFileHeader = isDuplicateFileHeader(RecType, LineNo, obj_StringBuffer);
													if (duplicateFileHeader) {
														return;
													}
													if (((RecType.equals(BATCH_HEADER_IDENTIFIER)) || RecType.equals(CHALLAN_HEADER_IDENTIFIER))) {
														obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3126_C + tab + T_FV_3126_M);
														continue;
													}

													if (RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
														DeducteeCount++;
														if (record == null || record.length() == 0) {
															break;
														}

														cal = new GregorianCalendar();
														long deducteeErrRecLengthBefore = obj_StringBuffer.errorBufferString.length();

														// System.out.println("Entering Perodic ValidateDeducteeDetails
														// method Deductee
														// Detail record No = "
														// + k
														// + "\t"
														// + cal.getTime()
														// + "\t\t CountChallan = "
														// + localCountChallan);

														validateDeducteeDetails(record, LineCount, BH_BatchNo, ChallanDetailRecordNo, TransactionType, Qperiod, FinancialYr, DateOfBankChallanNo, RRRDatePresentDate, transferVoucherNoProvided,
																bankChallanNoProvided, UploadType, obj_StringBuffer);

														cal = new GregorianCalendar();
														long deducteeErrRecLengthAfter = obj_StringBuffer.errorBufferString.length();

														// if format eror in deductee,then skip this deductee ,and goto
														// next deductee
														boolean errorInDedRec = false;

														if ((deducteeErrRecLengthAfter - deducteeErrRecLengthBefore) != 0) {
															errorInDedRec = true;
															continue;
														} else {
															errorInDedRec = false;
														}

													} // Closing if RecType is DD
													else {
														// Nahush 20 August 08
														if (Integer.parseInt(LineNo.trim()) != LineCount) {
															LineNo = "NA";
															obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + DEDUCTEE_RECORD_TYPE + tab + tab + tab + T_FV_4003_C + tab + T_FV_4003_M);
														}

														obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + DEDUCTEE_RECORD_TYPE + tab + CurrentchallanDetailRecordNo + tab + "NA" + tab + T_FV_4002_C + tab + T_FV_4002_M);
													}

												} // Closing For Loop of DD
												cal = new GregorianCalendar();

												/*
												 * Setting the FLAG deducteeLevlErrFlag to TRUE if NO ERROR is found while
												 * validating Deductee Records.
												 */
												deducteeErrBuffLength2 = obj_StringBuffer.errorBufferString.length();
												if ((deducteeErrBuffLength2 - deducteeErrBuffLength1) == 0) {
													deducteeLevlErrFlag = true;
												}
											}

										} // Closing If RecType is CH
										else {
											if (Integer.parseInt(LineNo.trim()) != LineCount) {
												LineNo = "NA";
												obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Challan_Record_Type + tab + tab + tab + T_FV_3002_C + tab + T_FV_3002_M);
											}

											obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Challan_Record_Type + tab + "NA" + tab + tab + T_FV_3001_C + tab + T_FV_3001_M);

											do {
												record = br.readLine();
												LineCount++;

												if (record == null) {
													if (!(localCountChallan <= countOfChallan)) {
														obj_StringBuffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
													}
													break;
												}
												StringTokenizer st_CH3 = new StringTokenizer(record, FIELD_SEPERATOR, true);

												int localCaretCountBH1 = 0;
												int localCountField_BH1 = 1;
												while (st_CH3.hasMoreTokens()) {
													String val = st_CH3.nextToken();
													NullField = false;
													FieldFound = false;
													if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
														NullField = true;
														FieldFound = true;
													}
													if (val.equals(FIELD_SEPERATOR)) {
														Caret = true;
														if (localCountField_BH1 == 1 && localCaretCountBH1 == 0) {
															localCountField_BH1++;
															LineNo = val;
														}
														localCaretCountBH1++;
													} else {
														Caret = false;
														FieldFound = true;
													}
													if (localCountField_BH1 > 2) {
														break;
													}

													if (FieldFound) {
														switch (localCountField_BH1) {
														case 1:
															LineNo = val;
															break;
														case 2:
															RecType = val;
															break;

														} // Closing switch
														localCountField_BH1++;
													} // Closing if
												} // END while loop

												duplicateFileHeader = isDuplicateFileHeader(RecType, LineNo, obj_StringBuffer);
												if (duplicateFileHeader) {
													return;
												}
											} while (!(RecType.equals(BATCH_HEADER_IDENTIFIER) || RecType.equals(CHALLAN_HEADER_IDENTIFIER)));

											continue; // break;
										} // CLOSING ELSE(IF THE NEXT LINE IS A CH)

										// checking whether the summation of Total Income Tax Deducted At Source =
										// TotalOfTDSAsPerDeducteeDetails

										// Log.tds_log.info("pval = "+pval+"\t\tnval = "+nval);
										/*
										 * 16 July Code Change ------- Provide Explanation Later ------ d4 =
										 * Math.round((double)(d4 * 100)) /100.0;
										 */

										double diffTotalIncomeTaxDeposited = pvalTotalIncomeTaxDeposited - nvalTotalIncomeTaxDeposited;
										sumOfTotalIncomeTaxDeposited = Math.round((double) (diffTotalIncomeTaxDeposited * 100)) / 100.0;

										// Log.tds_log.info("sumOfTotalIncomeTaxDeposited =
										// "+sumOfTotalIncomeTaxDeposited +"\t\t TotalTaxDepositedAsPerDeducteeAnex = "+
										// TotalTaxDepositedAsPerDeducteeAnex );
										if (!(obj_FieldValidation.isFloatNumber(TotalTaxDepositedAsPerDeducteeAnex))) {
											// System.out.println("Abhi"+sumOfTotalIncomeTaxDeposited+"
											// "+Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim()));
											if (sumOfTotalIncomeTaxDeposited != Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim())) {
												if (paperReturnFile) {
													byPassBooking = true;
													paperReturnRelax = true;
													obj_StringBuffer.appendPaperWarning(lineNoOfChallanRec + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3092_C + tab + T_FV_3092_M);
												} else if (Mode != null) { // Null check for mode
													if (isModeValid && !Mode.equals("F")) // added if mode ==f by shruti
														obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + Total_Tax_Deposit_Amount_as_per_deductee_annexure + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3092_C
																+ tab + T_FV_3092_M);
												}
											}
										}

										double diffpvalnvalValue = pval - nval;

										sumOfTotalIncomeTaxDeducted = Math.round((double) (diffpvalnvalValue * 100)) / 100.0;

										// if (sumOfTotalIncomeTaxDeducted != sumTotalTdsSurCess)
										if (!(obj_FieldValidation.isFloatNumber(SumTotalIncTaxDedAtSource))) {

											if (sumOfTotalIncomeTaxDeducted != Double.parseDouble(SumTotalIncTaxDedAtSource.trim())) {

												if (paperReturnFile) // &&
																		// (Double.parseDouble(SumTotalIncTaxDedAtSource.trim())
																		// == 0))
												{

													byPassBooking = true;
													paperReturnRelax = true;
													obj_StringBuffer.appendPaperWarning(lineNoOfChallanRec + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3091_C + tab + T_FV_3091_M);
												} else if (Mode != null) { // Null check for mode
													if (isModeValid && !Mode.equals("F")) // added if mode ==f by shruti
													{

														obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + Sum_Of_Total_Tax + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3091_C + tab + T_FV_3091_M);
													}
												}
											}
										}
										// added by faizan for fvu 4.5
										if (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
											if ((challanWiseTDSfield30 > SumTDSIncomeTaxDDfield14 + 10) || (challanWiseTDSfield30 < SumTDSIncomeTaxDDfield14 - 10))
												obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + "'TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3170_C + tab + T_FV_3170_M);

											if ((challanWiseTDSfield31 > SumTDSIncomeTaxDDfield15 + 10) || (challanWiseTDSfield31 < SumTDSIncomeTaxDDfield15 - 10))
												obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + "'TDS / TCS -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3171_C + tab + T_FV_3171_M);

											if ((challanWiseTDSfield32 > SumTDSIncomeTaxDDfield16 + 10) || (challanWiseTDSfield32 < SumTDSIncomeTaxDDfield16 - 10))
												obj_StringBuffer.append(lineNoOfChallanRec + tab + currentUploadType + tab + "'TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3172_C + tab + T_FV_3172_M);
										}

									} // Closing For Loop of CH

									receiptChallanDDNumber.append("^LD" + receiptChallanDetailRecNo + "=" + receiptLastDDNumber);
									receiptLastDDNumber = "-";

									/*
									 * If NO ERROR is found after Challan Record Validation, we set the Flag
									 * challanLevlErrFlag to TRUE.
									 */
									challanErrBuffLeng2 = obj_StringBuffer.errorBufferString.length();
									if ((challanErrBuffLeng2 - challanErrBuffLeng1) == 0) {
										challanLevlErrFlag = true;
									}

								}

								///////// Call to Salary Statement part START /////////

								if (batchRecFoundFlag) {
									/*
									 * Batch record found while looking for Salary Detail Record, therefore logg the
									 * error for Invalid salary detail count , DO NOT call SalaryDetailValidation
									 * method return back to Batch loop.
									 */
								} else if (((UploadType.equals(UPLOADTYPE_REGULAR) && FormNo.equals(FORM_24Q) && (Integer.parseInt(CountOfSalaryDetailRec.trim()) > 0))
										|| (FormNo.equals(FORM_24Q) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || (TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) && Integer.parseInt(CountOfSalaryDetailRec.trim()) > 0)
												|| (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && Integer.parseInt(CountOfSalaryDetailRec.trim()) > 0)))))
								/* && (Integer.parseInt(FinancialYr) < 201920) */ // Changes added for 6.7_2.163_2.1295
																					// by Kiran // Changes commented
																					// for 6.7 on hold cr
								{
									returnRecordType = null;
									System.out.println("Entering Salary Detail Validation");
									SalaryDetailValidation ss = new SalaryDetailValidation(this);
									// StringBuffer errorSalaryStatement = new StringBuffer();

									ss.salaryDetailValidator(record, UploadType, LineCount, RecType, BH_BatchNo, br, TransactionType, countOfBatch, Qperiod, FormNo, // CHANGE AMI
											FinancialYr, CountOfSalaryDetailRec, i, GrossTotalIncomeSD, RRRDatePresentDate, paperReturnFile, lineNoOfBatchRec, batchRecDataForPanStat, obj_FileGenerator, obj_StringBuffer, fileNamePrintedinStatRep,
											currentUploadType, PANForThisBatch, BatchUpdationIndicator);

									RecType = returnRecordType;

									// Setting the Record Type of the Last Record parrsed in salaryDetailValidator
									// Method
									LineCount = returnLineCount;
									// Setting the Line Count of the Last Record parrsed in salaryDetailValidator
									// Method
									record = returnRecord; // Setting the Record parrsed in salaryDetailValidator Method
									salaryDetailRecordFlag = true;

									/*
									 * Code Commented by Mayank 16-Sept 2005
									 */
									// statPANReport.append(ss.getStatisticFileSDRec());
									// Appending the PAN Report Stats to the Buffer

									// obj_StringBuffer.append(errorSalaryStatement);
									/////////////////////// metering ////////////////

									meteSDCount = meteSDCount + Integer.parseInt(CountOfSalaryDetailRec.trim());

									//////////////////// METERING //////////////////////////////

								} // checking if Upload Type is Cancelation
								else if (FormNo.equals(FORM_24Q) && (TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) && (Integer.parseInt(CountOfSalaryDetailRec.trim()) == 0)) {
									/*
									 * If Transaction Type 'Z' and Count of Salary Detail is 0 (Zero), we rest the
									 * RecType to NULL and set the zCorrectionZeroDDRecFlag True. The Flag is set to
									 * indicate that Next record must be BATCH RECORD
									 */
									RecType = "";
									zCorrectionZeroDDRecFlag = true;
								}
								///////////////// Call to Salary Statement part END ///////////////

							} // Check if TransactionType is not Batch Correction
						} // closing if RecType is BH
						else {
							if (!errorLoggedForInvalidBH) {
								obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + BATCH_RECORD_TYPE + tab + "-" + tab + "-" + tab + T_FV_2004_C + tab + T_FV_2004_M);
							} else {
								errorLoggedForInvalidBH = false;
							}

							do {
								record = br.readLine();
								LineCount++;
								if (record == null) {
									if (!(i <= (countOfBatch))) {
										obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
									}
									break;
								}
								StringTokenizer st_BH4 = new StringTokenizer(record, FIELD_SEPERATOR, true);

								int localCaretCountBH1 = 0;
								int localCountField_BH1 = 1;
								while (st_BH4.hasMoreTokens()) {
									String val = st_BH4.nextToken();
									NullField = false;
									FieldFound = false;
									if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
										NullField = true;
										FieldFound = true;
									}
									if (val.equals(FIELD_SEPERATOR)) {
										Caret = true;
										if (localCountField_BH1 == 1 && localCaretCountBH1 == 0) {
											localCountField_BH1++;
											LineNo = val;
										}
										localCaretCountBH1++;
									} else {
										Caret = false;
										FieldFound = true;
									}
									if (localCountField_BH1 > 2) {
										break;
									}

									if (FieldFound) {
										switch (localCountField_BH1) {
										case 1:
											LineNo = val;
											break;
										case 2:
											RecType = val;
											break;

										} // Closing switch
										localCountField_BH1++;
									} // Closing if
								} // END while loop

								duplicateFileHeader = isDuplicateFileHeader(RecType, LineNo, obj_StringBuffer);
								if (duplicateFileHeader)
									return;
							} while (!(RecType.equals(BATCH_HEADER_IDENTIFIER)));
							// CLOSING WHILE LOOP(IF THE NEXT LINE IS NOT BH)
							continue;
						} // CLOSING ELSE#if ((RecType.equals(BATCH_HEADER_IDENTIFIER)

						// #######################################################################################
						// ---------Code Added for validating every Batch For PAN Compliance ::
						// Manvendra Singh --14-Feb-2008
						int RequiredValidPanAtbatch = 0;

						// ----if file uploaded by TFC then at STM-- it would be checked for RRR date.
						// if (utilityLevel == 3 && TanTfcIdIndicator.equals(UPLOADED_BY_TFC))
						// {
						// if (tempRRRDateforBatch.before(newValidationStartDate))
						// {
						// performValidationAtbatchLevel = false;
						// }
						//
						// }

						if (totalPANtoValidate_in_batch == 0 && totalPANtoVaildate_in_batch_ignoring_remark == 0) {
							performValidationAtbatchLevel = false;
						}

						// System.out.println("totalPANtoVaildate_in_batch_ignoring_remark" +
						// totalPANtoVaildate_in_batch_ignoring_remark);

						// ------------Going to Perform validation --------------------
						if (performValidationAtbatchLevel) {

							// System.out.println(
							// "todays Date in batch : "
							// + CurrentDate.getTime()
							// + " totalPANtoVaildate_in_batch_ignoring_remark "
							// + " newValidationStartDate "
							// + newValidationStartDate.getTime()
							// + totalPANtoVaildate_in_batch_ignoring_remark
							// + " (CurrentDate.after(newValidationStartDate)"
							// + CurrentDate.after(newValidationStartDate)
							// + " CurrentDate.equals(newValidationStartDate)) "
							// + CurrentDate.equals(newValidationStartDate)
							// + " TransactionType "
							// + TransactionType
							// + " validPANtoValidate_in_batch_ignoring_remark "
							// + validPANtoValidate_in_batch_ignoring_remark);

							// Code Hashed By AMI For FVU 3.0
							// 95% PAN compliance For 24Q and 85% PAN compliance For 26Q and 27EQ is
							// relaxed.

							/*
							 * if (FileType.equals(FILETYPE_SALARY_ELECTRONIC)) { RequiredValidPanAtbatch =
							 * Math.round(((float) (totalPANtoVaildate_in_batch_ignoring_remark *
							 * Parameters.newsalaryPercentage)) / 100);
							 * //System.out.println("RequiredValidPanAtbatch"+RequiredValidPanAtbatch);
							 * //System.out.println("validPANtoValidate_in_batch_ignoring_remark"+
							 * validPANtoValidate_in_batch_ignoring_remark);
							 * 
							 * if (validPANtoValidate_in_batch_ignoring_remark < RequiredValidPanAtbatch) {
							 * obj_StringBuffer.append("NA" + tab + currentUploadType + tab + "NA" + tab +
							 * "-" + tab + "-" + tab + T_FV_4253_C + tab + T_FV_4253_M); }
							 * 
							 * } if (FileType.equals(FILETYPE_NONSALARY_ELECTRONIC) &&
							 * FormNo.equals(FORM_26Q)) { RequiredValidPanAtbatch = Math.round(((float)
							 * (totalPANtoValidate_in_batch * Parameters.newNonsalarypercentage)) / 100);
							 * //System.out.
							 * println("((float) (totalPANtoVaildate * Parameters.Nonsalarypercentage)) / 100  ==="
							 * + ((float) (totalPANtoVaildate * Parameters.Nonsalarypercentage)) / 100); if
							 * (validPANtovalidate_in_batch < RequiredValidPanAtbatch) {
							 * obj_StringBuffer.append("NA" + tab + currentUploadType + tab + "NA" + tab +
							 * "-" + tab + "-" + tab + T_FV_4254_C + tab + T_FV_4254_M); }
							 * 
							 * }
							 */

							// Code is uncommented For FVU 3.0 new changes

							if (FileType.equals(FILETYPE_TCS_ELECTRONIC)) {
								System.out.println("ignore remark:-" + totalPANtoVaildate_in_batch_ignoring_remark);
								System.out.println("valid pan:-" + validPANtoValidate_in_batch_ignoring_remark);
								RequiredValidPanAtbatch = Math.round(((float) (totalPANtoVaildate_in_batch_ignoring_remark * Parameters.newNonsalarypercentage)) / 100);
								if (validPANtoValidate_in_batch_ignoring_remark < RequiredValidPanAtbatch) {
									// Error code Changed For FVU 3.0 new changes
									// obj_StringBuffer.append("NA" + tab + currentUploadType + tab + "NA" + tab +
									// "-" + tab + "-" + tab + T_FV_4254_C + tab + T_FV_4254_M);
									obj_StringBuffer.append("NA" + tab + currentUploadType + tab + "NA" + tab + "-" + tab + "-" + tab + T_FV_4276_C + tab + T_FV_4276_M);
								}

							}

						} else {

						}
						// System.out.println(
						// "??????? validation not done because
						// totalPANtoVaildate_in_batch_ignoring_remark "
						// + "todays Date in batch : "
						// + CurrentDate.getTime()
						// + " newValidationStartDate "
						// + newValidationStartDate.getTime()
						// + totalPANtoVaildate_in_batch_ignoring_remark
						// + " (CurrentDate.after(newValidationStartDate)"
						// + CurrentDate.after(newValidationStartDate)
						// + " CurrentDate.equals(newValidationStartDate)) "
						// + CurrentDate.equals(newValidationStartDate)
						// + " TransactionType "
						// + TransactionType
						// + " validPANtoValidate_in_batch_ignoring_remark "
						// + validPANtoValidate_in_batch_ignoring_remark);
						//
						// #######################################################################################
						// Code added by sourabh stat for change in static report
						// System.out.println(" BIFERCATING CHALAN AND TV AND CIN
						// CHECKING"+cal.getTime());

						// System.out.println("statisticFileStrBuff"+statisticFileStrBuff.toString());

						try {
							// System.out.println("****************** In the If Of CIN Matching Block
							// ***************");

							if (countOfChallan == statChallanCount) {
								// System.out.println("came in pure challan"+statChallanCount);
								// System.out.println("came in pure challan for
								// amount"+obj_FieldValidation.changeNumberFormat(challanAmountAsPerChallan));

								typeOfChallan = "C";
								statisticFileStrBuff.append(String.valueOf(statChallanCount) + statDataDelemiter);
								statisticFileStrBuff.append(obj_FieldValidation.changeNumberFormat(challanAmountAsPerChallan) + statDataDelemiter);
								statisticFileStrBuff.append("0" + statDataDelemiter);
								statisticFileStrBuff.append("0" + statDataDelemiter);
								statisticFileStrBuff.append(typeOfChallan + statDataDelemiter);

							} else if (countOfChallan == statTransferVoucher) {
								// System.out.println("CAME IN TRV"+BatchLineNo+" TV
								// COUNT"+statTransferVoucher);
								typeOfChallan = "T";
								statisticFileStrBuff.append("0" + statDataDelemiter);
								statisticFileStrBuff.append("0" + statDataDelemiter);
								statisticFileStrBuff.append(String.valueOf(statTransferVoucher) + statDataDelemiter);
								statisticFileStrBuff.append(obj_FieldValidation.changeNumberFormat(transferAmountAsPerTV) + statDataDelemiter);
								statisticFileStrBuff.append(typeOfChallan + statDataDelemiter);

							} else if (countOfChallan == statChallanCount + statTransferVoucher) {
								// System.out.println("CAME IN BOTH"+BatchLineNo);
								typeOfChallan = "B";
								statisticFileStrBuff.append(String.valueOf(statChallanCount) + statDataDelemiter);
								statisticFileStrBuff.append(obj_FieldValidation.changeNumberFormat(challanAmountAsPerChallan) + statDataDelemiter);
								statisticFileStrBuff.append(String.valueOf(statTransferVoucher) + statDataDelemiter);
								statisticFileStrBuff.append(obj_FieldValidation.changeNumberFormat(transferAmountAsPerTV) + statDataDelemiter);
								statisticFileStrBuff.append(typeOfChallan + statDataDelemiter);

							} else {
								// System.out.println("CAME IN ELSE FOR BATCH NO"+BatchLineNo);
								statisticFileStrBuff.append("0" + statDataDelemiter);
								statisticFileStrBuff.append("0" + statDataDelemiter);
								statisticFileStrBuff.append("0" + statDataDelemiter);
								statisticFileStrBuff.append("0" + statDataDelemiter);
								statisticFileStrBuff.append("0" + statDataDelemiter);

							}
							// System.out.println(" CHALLAN COUNT"+statChallanCount+" AND TV COUNT FOR
							// "+statTransferVoucher+" AND BATCH COUNT"+countOfChallan);
							// Added by sourabh for CIN checking only for Standalone FVU

							if (obj_StringBuffer.errorBufferString.length() == 0 && utilityLevel == 0 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)
									|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {

								int matchChallanCount = 0;
								int unmatatchedChallanCount = 0;
								int cinArraySize = consolidatedHash.size(); // total challan present for cin match
								// Added for BIN match for FVU 4.6
								// int binArraySize = consolidatedHashBIN.size(); // total challan present for
								// BIN match
								// System.out.println("in the utility level zero"+utilityLevel);
								if (FileStatistics.getCinUploadFlag() == 1) {
									try {

										cinFr = new FileReader(FileStatistics.getCinFileName());// added by sourabh
										cinBr = new BufferedReader(cinFr);
										// Hash cinHash = new Hash();

										int recCount = 0;
										// boolean sameTan = true;
										final String dlm = "^";
										String readln;

										ArrayList CINConsolidateHashFromFile = new ArrayList();
										String header = "1qi5b63p";
										String footer = "9rtio7lb";
										// ArrayList CINHashBsrCode=new ArrayList();
										// ArrayList CINHashChallanNo=new ArrayList();
										// ArrayList CINHashPaymentDate=new ArrayList();
										// ArrayList CINAmt=new ArrayList();
										// ArrayList CINTan = new ArrayList();
										// Changed for MD5 Algorithm implementd by sourabh

										// String hashCodeTan =
										// cinHash.get20digitHashCode(cinHash.hashCode(TanOfDeductor,false));
										// String hashCodeTan = MD5.getHashString(TanOfDeductor);
										// String TanHash="";

										while ((readln = cinBr.readLine()) != null) {
											recCount++;
											if (recCount == 1) {
												// int k =0 ;
												// k = readln.lastIndexOf("^");

												// file level hash code need to check
												// added for FVU 5.0
												// String cinFilehashFromFile = "";
												// System.out.println("the first line is " + readln);
												// cinFilehashFromFile = readln.substring(k+1,readln.length());
												// System.out.println("the cinFilehashFromFile from form validator is" +
												// cinFilehashFromFile);
												// ended for FVU 5.0
											} else {

												StringTokenizer st = new StringTokenizer(readln, dlm, false);
												// String firsttan="";
												while (st.hasMoreElements()) {

													CINConsolidateHashFromFile.add(st.nextToken());

													// CINHashBsrCode.add(st.nextToken());
													// CINHashPaymentDate.add(st.nextToken());
													// CINHashChallanNo.add(st.nextToken());

													// if(firsttan.equals("")||firsttan.equals(st.nextToken()))
													// {
													// firsttan=firsttan.equals("")?st.nextToken():firsttan;
													// CINTan.add(firsttan);

													// }
													// else
													// {

													// sameTan = false;
													// }
													// //CINTan.add(st.nextToken());
													// CINAmt.add(st.nextToken());

												}
											}
										}
										int cinPresentInCINFile = CINConsolidateHashFromFile.size();

										// System.out.println("cinPresentInCINFile"+cinPresentInCINFile);

										// String hashCodeBsrCode="";
										// String hashCodePaymentDate="";
										// String hashCodeChallanNo="";

										// String hashCodeAmt="";
										String ConsolidatedHashFromReturn = "";
										// System.out.println("REACHING FOR LOOP");
										for (int cinLoop = 0; cinLoop < cinArraySize; cinLoop++) {

											// hashCodeBsrCode =
											// cinHash.get20digitHashCode(cinHash.hashCode(cinBsrCode.get(cinLoop).toString(),false));
											// hashCodePaymentDate =
											// cinHash.get20digitHashCode(cinHash.hashCode(cinOltasPayDate.get(cinLoop).toString(),false));
											// hashCodeChallanNo=
											// cinHash.get20digitHashCode(cinHash.hashCode(cinChallanSeqNo.get(cinLoop).toString(),false));
											// hashCodeAmt =
											// cinHash.get20digitHashCode(cinHash.hashCode(cinAmt.get(cinLoop).toString(),false));

											// Changed for MD5 Algorithm implementd by sourabh
											// hashCodeBsrCode = MD5.getHashString(cinBsrCode.get(cinLoop).toString());
											// hashCodePaymentDate =
											// MD5.getHashString(cinOltasPayDate.get(cinLoop).toString());
											// hashCodeChallanNo=
											// MD5.getHashString(cinChallanSeqNo.get(cinLoop).toString());
											// hashCodeAmt = MD5.getHashString(cinAmt.get(cinLoop).toString());
											ConsolidatedHashFromReturn = MD5.getHashString(header + consolidatedHash.get(cinLoop) + footer);
											// ConsolidatedHashFromReturn =
											// cinHash.get20digitHashCode(cinHash.hashCode((header+consolidatedHash.get(cinLoop)+footer),false));

											// System.out.println("bsr hash is ::"+hashCodeBsrCode+" payment hash
											// "+hashCodePaymentDate+" challan hash is :"+hashCodeChallanNo+" amount
											// hash
											// ::"+hashCodeAmt);

											int chkercount = 0;
											// String msg="";

											while (chkercount < cinPresentInCINFile) {
												// System.out.println(" tan from tds ::::::::"+hashCodeTan+"tan from
												// cin::::"+CINTan.get(chkercount).toString().trim()+" FOR TAN IS
												// :::::::
												// "+TanOfDeductor);

												// if(hashCodeTan.trim().equals(CINTan.get(chkercount).toString().trim())&&
												// sameTan == true)
												// {

												// if(!hashCodePaymentDate.trim().equals(CINHashPaymentDate.get(chkercount).toString().trim())||!hashCodeBsrCode.trim().equals(CINHashBsrCode.get(chkercount).toString().trim())||!hashCodeChallanNo.trim().equals(CINHashChallanNo.get(chkercount).toString().trim()))
												// {
												// WHOLE CIN NOT MATCH
												// System.out.println("CIN Not Present case date from cin file is
												// "+CINHashPaymentDate.get(chkercount).toString()+" and in tds return
												// is
												// "+hashCodePaymentDate+ "bsr cin " +
												// CINHashBsrCode.get(chkercount).toString()
												// + "bsr file " + hashCodeBsrCode.trim() + "chl no cin" +
												// CINHashChallanNo.get(chkercount).toString().trim() + "chl no file " +
												// hashCodeChallanNo.trim() + "for checker count"+chkercount);
												// if (chkercount == (cinPresentInCINFile - 1))
												// {
												// System.out.println("at 1 " + chkercount); //added by pushpendra
												// obj_StringBuffer.appendElectronicWarning(cinLineNo.get(cinLoop).toString()
												// +
												// tab + "Challan" + tab + cinBatchNo.get(cinLoop).toString() + tab +
												// cinChallanDetailRecordNo.get(cinLoop).toString() + tab + "NA" + tab +
												// cinDateOfChallan.get(cinLoop).toString() + tab +
												// cinChallanSeqNoView.get(cinLoop).toString() + tab +
												// cinBsrCode.get(cinLoop).toString() + tab + T_FV_3141_C + tab +
												// T_FV_3141_M);
												// }
												// }
												// else
												// {

												// if(hashCodeAmt.trim().equals(CINAmt.get(chkercount).toString().trim()))
												// {
												// System.out.println("amt from cin" +hashCodeAmt.trim() + "amt from
												// file" +
												// CINAmt.get(chkercount).toString().trim());
												// System.out.println(" Challan Match for tdscin::"+cinLoop+" and cin
												// from
												// cinfile"+chkercount);
												// matchChallanCount++;
												// break;
												// }
												// else
												// {
												// System.out.println(" Failed in amount");
												// System.out.println("amt from cin" +hashCodeAmt.trim() + "amt from
												// file" +
												// CINAmt.get(chkercount).toString().trim() + "for check count" +
												// chkercount);
												// obj_StringBuffer.appendElectronicWarning(cinLineNo.get(cinLoop).toString()
												// +
												// tab + "Challan" + tab + cinBatchNo.get(cinLoop).toString() + tab +
												// cinChallanDetailRecordNo.get(cinLoop).toString() + tab + "NA" + tab +
												// cinDateOfChallan.get(cinLoop).toString() + tab +
												// cinChallanSeqNoView.get(cinLoop).toString() + tab +
												// cinBsrCode.get(cinLoop).toString() + tab + T_FV_3146_C + tab +
												// T_FV_3146_M);
												// break;

												// }
												// }
												// }
												// else
												// {
												// obj_StringBuffer.appendElectronicWarning(cinLineNo.get(cinLoop).toString()
												// +
												// tab + "Challan" + tab + cinBatchNo.get(cinLoop).toString() + tab +
												// cinChallanDetailRecordNo.get(cinLoop).toString() + tab + "NA" + tab +
												// cinDateOfChallan.get(cinLoop).toString() + tab +
												// cinChallanSeqNoView.get(cinLoop).toString() + tab +
												// cinBsrCode.get(cinLoop).toString() + tab + T_FV_3140_C + tab +
												// T_FV_3140_M);
												// cinLoop = cinArraySize;
												// break;
												// }

												// System.out.println("INput to md5::" +
												// header+consolidatedHash.get(cinLoop)+footer);
												// System.out.println("Hash from TDS File::::" +
												// ConsolidatedHashFromReturn);
												// System.out.println("Hash form CSI file::::" +
												// CINConsolidateHashFromFile.get(chkercount).toString().trim());

												if (ConsolidatedHashFromReturn.trim().equals(CINConsolidateHashFromFile.get(chkercount).toString().trim())) {
													// System.out.println("matchChallanCount"+ matchChallanCount);
													matchChallanCount++;
													break;
												} else {
													if (chkercount == (cinPresentInCINFile - 1))
														obj_StringBuffer.appendElectronicWarning(cinLineNo.get(cinLoop).toString() + tab + "Challan" + tab + cinBatchNo.get(cinLoop).toString() + tab + cinChallanDetailRecordNo.get(cinLoop).toString()
																+ tab + "NA" + tab + cinDateOfChallan.get(cinLoop).toString() + tab + cinChallanSeqNoView.get(cinLoop).toString() + tab + cinBsrCode.get(cinLoop).toString() + tab + T_FV_3141_C + tab
																+ T_FV_3141_M);

												}
												chkercount++;

											} // End of While

										} // end of for loop
										unmatatchedChallanCount = cinArraySize - matchChallanCount;

										// Added For FVU 3.0 To add Unmatched Challan Count to Raw File
										// receiptUnmatchedChalanCnt = Integer.toString(unmatatchedChallanCount);

										// System.out.println("unmatatchedChallanCount"+unmatatchedChallanCount);
										// unmatchedChalanCntStrBuff.append(unmatatchedChallanCount +
										// statDataDelemiter);
										matchChlanCnt = true;
										unmtchChlnCnt = unmatatchedChallanCount;
										// System.out.println("Count Of matched challan::::"+matchChallanCount+"Count of
										// Unmatch Challan"+unmatatchedChallanCount);
										// System.out.println("Count of total challan"+cinArraySize);
										statisticFileStrBuff.append(matchChallanCount + statDataDelemiter);
										statisticFileStrBuff.append(unmatatchedChallanCount + statDataDelemiter);
										statisticFileStrBuff.append(cinArraySize + statDataDelemiter);
										cinFr.close();
										cinBr.close();
										cinBsrCode.clear();
										// cinChallanSeqNo.clear();
										cinChallanSeqNoView.clear();
										// cinOltasPayDate.clear();
										// cinAmt.clear();
										cinBatchNo.clear();
										cinChallanDetailRecordNo.clear();
										cinDateOfChallan.clear();
										cinLineNo.clear();
										consolidatedHash.clear();
									} // End of Try block

									catch (Exception e) {
										e.printStackTrace();
									}
								} // Closing of Cin File Uploaded
								else {

									statisticFileStrBuff.append(matchChallanCount + statDataDelemiter);
									statisticFileStrBuff.append(totalChallanforCINCheck + statDataDelemiter);
									statisticFileStrBuff.append(totalChallanforCINCheck + statDataDelemiter);

								}

							} else {

								statisticFileStrBuff.append("0" + statDataDelemiter);

								statisticFileStrBuff.append(totalChallanforCINCheck + statDataDelemiter);

								statisticFileStrBuff.append(totalChallanforCINCheck + statDataDelemiter);

							}
							System.out.println(" END OF :::BIFERCATING CHALAN AND TV AND CIN CHECKING" + cal.getTime());

						} catch (Exception e) {
							e.printStackTrace();
						}

						// Added By AMI For FVU 3.0

						// System.out.println("positionOfBtch"+positionOfBtch+"Flag for
						// deletion"+isMtchCntToBeUpdated+"matchChlanCnt"+matchChlanCnt);
						// System.out.println("*** Challan Buffer 1ST tIME
						// *****"+unmatchedChalanCntStrBuff.toString());
						// System.out.println("position 1"+unmatchedChalanCntStrBuff.charAt(0)+"Position
						// 2"+unmatchedChalanCntStrBuff.charAt(1));

						if (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)
								|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
							if (matchChlanCnt && isMtchCntToBeUpdated)
								unmatchedChalanCntStrBuff.append(Integer.toString(lineCountOfBtch) + statDataDelemiter + Integer.toString(unmtchChlnCnt) + statDataDelemiter);
							// else if(matchChlanCnt && !isMtchCntToBeUpdated)
							// unmatchedChalanCntStrBuff.append(Integer.toString(lineCountOfBtch)+statDataDelemiter+"NA"+
							// statDataDelemiter);
							// else if(!matchChlanCnt && isMtchCntToBeUpdated)
							else
								unmatchedChalanCntStrBuff.append(Integer.toString(lineCountOfBtch) + statDataDelemiter + "NA" + statDataDelemiter);
						}

						matchChlanCnt = false;
						isMtchCntToBeUpdated = false;
						isSameBtch = false;
						cntTaxDeductedAtHighRate = 0;

					} // closing For loop of BH

					// -------changed for validating the % of structurally valid PAN ---By Manvendra
					// ----------------------------------------------------------------------------
					int RequiredValidPan = 0;
					String temp_yearQtr = null;
					// Code in previous release from here moved at 0bject level instead of meathod
					// level
					// -------changed again to validate against RRRDate of batches-----------
					// Oct-2007 ---
					// -------------------------------------------------------------------------
					// if(utilityLevel == 2 )
					// {
					// Iterator iter = AllRRRdates.iterator();
					// while (iter.hasNext())
					// {
					// tempRRRdate = (Calendar) iter.next();
					// if(tempRRRdate.before(validationStartdate))
					// {
					// PerformValidation = false;
					// break;
					// }
					// }
					//
					// }

					if (utilityLevel == 3 && TanTfcIdIndicator.equals(UPLOADED_BY_TFC)) {
						if (tempRRRdate.before(validationStartdate) || tempRRRdate.after(newValidationStartDate) || tempRRRdate.equals(newValidationStartDate)) {
							PerformValidation = false;
						}
					} else if (CurrentDate.before(validationStartdate) || CurrentDate.equals(newValidationStartDate) || CurrentDate.after(newValidationStartDate)) {
						PerformValidation = false;
					}

					// -------------------------------------------------------
					temp_yearQtr = FinancialYr + Qperiod;

					if (totalPANtoVaildate == 0 && totalPANtoVaildate_ignoring_remark == 0) {
						PerformValidation = false;
					}

					if (PerformValidation && (TotalDeducteeInFile > Parameters.LeastCountofdeducteetovalidate) && obj_FieldValidation.NotInNonValidatonlist(temp_yearQtr.trim())) {

						// PercentageValidPan = temp_percentage ;

						if (FileType.equals(FILETYPE_SALARY_ELECTRONIC)) {
							RequiredValidPan = Math.round(((float) (totalPANtoVaildate_ignoring_remark * Parameters.salaryPercentage)) / 100);
							if (validPANtoValidate_ignoring_remark < RequiredValidPan) {
								obj_StringBuffer.append("NA" + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_4243_C + tab + T_FV_4243_M);
							}
						}
						if (FileType.equals(FILETYPE_NONSALARY_ELECTRONIC) && FormNo.equals("26Q")) {
							RequiredValidPan = Math.round(((float) (totalPANtoVaildate * Parameters.Nonsalarypercentage)) / 100);
							// System.out.println("((float) (totalPANtoVaildate *
							// Parameters.Nonsalarypercentage)) / 100 ===" + ((float) (totalPANtoVaildate *
							// Parameters.Nonsalarypercentage)) / 100);
							if (validPANtoValidate < RequiredValidPan) {
								obj_StringBuffer.append("NA" + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_4244_C + tab + T_FV_4244_M);
							}
						}
						if (FileType.equals(FILETYPE_TCS_ELECTRONIC)) {
							RequiredValidPan = Math.round(((float) (totalPANtoVaildate_ignoring_remark * Parameters.Nonsalarypercentage)) / 100);
							if (validPANtoValidate_ignoring_remark < RequiredValidPan) {
								obj_StringBuffer.append("NA" + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_4244_C + tab + T_FV_4244_M);
							}

						}

					} else {
						// System.out.println(
						// "Validation not done TotalDeducteeInFile::"
						// + TotalDeducteeInFile
						// + "CurrentDate.after(validationStartdate) "
						// + CurrentDate.after(validationStartdate)
						// + "NotInNonValidatonlist::"
						// + obj_FieldValidation.NotInNonValidatonlist(temp_yearQtr.trim())
						// + validPANtoValidate
						// + validPANtoValidate_ignoring_remark
						// + RequiredValidPan);
					}
					// ----------------------------------------------------------------------------

					// Appending the Data of Last Batch to the String Buffer
					if ((LastTanOfDeductor != null) && LastTanOfDeductor.trim().length() != 0 && !LastTanOfDeductor.trim().equals("^")) {

						receiptString.append("BH=" + (countOfBatch) + "^P1=" + receiptPanApplied + "^P2=" + receiptPanInvaild + "^P3=" + receiptPanNotAvbl + "^T=" + LastTanOfDeductor + "^AO=" + receiptTotalAmtPaidCrdtOriginalMode + "^AU="
								+ receiptTotalAmtPaidCrdtUpdateMode + "^AA=" + receiptTotalAmtPaidCrdtAddMode + "^DO=" + receiptTotalITDeductedAtSrcOrigMode + "^DU=" + receiptTotalITDeductedAtSrcUpdtMode + "^DA=" + receiptTotalITDeductedAtSrcAddMode
								+ "^DD=" + receiptTotalITDeductedAtSrcDelMode + "^TO=" + receiptTotofDepdAmtOrigMode + "^TU=" + receiptTotofDepdAmtUpdtMode + "^TA=" + receiptTotofDepdAmtAddMode + "^TD=" + receiptTotofDepdAmtDelMode + "^VP="
								+ statTotalValueofTurnover + "^DD=" + statTotalNoOfDDRec + "^SD=" + receiptSDCountForC5);

						if (utilityLevel == 0 || utilityLevel == 3) {
							receiptString.append("^LS=" + receiptLastSDNumber + receiptChallanDDNumber);
							// receiptString.append("~"); //Commented for FVU 3.0
						}
						// Commented for FVU 3.0
						/*
						 * else { receiptString.append("^~"); }
						 */
						if (utilityLevel == 1) {
							receiptString.append("^DH=" + receiptCntTaxDeductedAtHighRate); // No of deductee records
																							// where tax deducted at
																							// higher
																							// rate
							receiptString.append("^UC=" + receiptUnmatchedChalanCnt); // No of Unmatched Chllans Of CSI
																						// File
							if (FormNo.equals("24Q") && Qperiod.equals("Q4") && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || UploadType.equals(UPLOADTYPE_REGULAR))) {

								// receiptSalDelTotTaxableIncome = Double.toString(sumOfSalDelTotTaxableIncome);
							}

							receiptString.append("^NT=" + receiptSalDelTotTaxableIncome); // Net Taxable Income of SDs.
							receiptString.append("^~");
						} else {
							if (utilityLevel == 0 || utilityLevel == 3)
								receiptString.append("~");
							else
								receiptString.append("^~");
						}
					} else {
						receiptString.append("BH=" + (countOfBatch) + "^P1=" + receiptPanApplied + "^P2=" + receiptPanInvaild + "^P3=" + receiptPanNotAvbl + "^T=" + "-" + "^AO=" + receiptTotalAmtPaidCrdtOriginalMode + "^AU="
								+ receiptTotalAmtPaidCrdtUpdateMode + "^AA=" + receiptTotalAmtPaidCrdtAddMode + "^DO=" + receiptTotalITDeductedAtSrcOrigMode + "^DU=" + receiptTotalITDeductedAtSrcUpdtMode + "^DA=" + receiptTotalITDeductedAtSrcAddMode
								+ "^DD=" + receiptTotalITDeductedAtSrcDelMode + "^TO=" + receiptTotofDepdAmtOrigMode + "^TU=" + receiptTotofDepdAmtUpdtMode + "^TA=" + receiptTotofDepdAmtAddMode + "^TD=" + receiptTotofDepdAmtDelMode + "^VP="
								+ statTotalValueofTurnover + "^DD=" + statTotalNoOfDDRec + "^SD=" + receiptSDCountForC5);

						if (utilityLevel == 0 || utilityLevel == 3) {
							receiptString.append("^LS=" + receiptLastSDNumber + receiptChallanDDNumber);
							// receiptString.append("~"); //Commented for FVU 3.0
						}
						// Commented for FVU 3.0
						/*
						 * else { receiptString.append("^~"); }
						 */
						if (utilityLevel == 1) {
							receiptString.append("^DH=" + receiptCntTaxDeductedAtHighRate); // No of deductee records
																							// where tax deducted at
																							// higher
																							// rate
							receiptString.append("^UC=" + receiptUnmatchedChalanCnt); // No of Unmatched Chllans Of CSI
																						// File
							if (FormNo.equals("24Q") && Qperiod.equals("Q4") && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || UploadType.equals(UPLOADTYPE_REGULAR))) {
								// M08_B
								// receiptSalDelTotTaxableIncome = Double.toString(sumOfSalDelTotTaxableIncome);
								receiptSalDelTotTaxableIncome = sumOfSalDelTotTaxableIncome.toString();
								// M08_E
							}
							receiptString.append("^NT=" + receiptSalDelTotTaxableIncome); // Net Taxable Income of SDs.
							receiptString.append("^~");
						} else {
							if (utilityLevel == 0 || utilityLevel == 3)
								receiptString.append("~");
							else
								receiptString.append("^~");
						}
					}

					// System.out.println("receiptValidPAN"+receiptValidPAN);
					//
					// System.out.println("Receipt File"+receiptString.toString());

					// Appending the Data of Last Batch to the String Buffer

					// Added For FVU 3.0 Count of DD with Remark C
					if (!(receiptCntTaxDeductedAtHighRate.equals("-")))
						statCntTaxDeductedAtHighRate = receiptCntTaxDeductedAtHighRate;

					// System.out.println("statCntTaxDeductedAtHighRate"+statCntTaxDeductedAtHighRate);

					statisticFileStrBuff.append(statTotalNoOfDDRec + statDataDelemiter + receiptValidPAN + statDataDelemiter + statCntTaxDeductedAtHighRate + statDataDelemiter);

					statCntTaxDeductedAtHighRate = "0";

					// System.out.println("statisticFileStrBuff
					// ****************"+statisticFileStrBuff.toString());

					staisticsSalStrBuff.append(receiptSalValidPAN + statDataDelemiter + receiptSalPanApplied + statDataDelemiter + receiptSalPanNotAvbl + statDataDelemiter + receiptSalPanInvaild + statDataDelemiter + "\n");

					// Adding Data for Correction File Metering
					meteCorrectionFile = LineCount + "^" + tanOfFirstBatch;

					// ******************* Metering *****************//

					if (UploadType.equals(UPLOADTYPE_REGULAR) && (TanOfDeductor != null) && TanOfDeductor.trim().length() != 0 && !TanOfDeductor.trim().equals("^")) {
						meteTANList.addElement(TanOfDeductor);
					} else if (UploadType.equals(UPLOADTYPE_CORRECTION) && (LastTanOfDeductor != null) && LastTanOfDeductor.trim().length() != 0 && !LastTanOfDeductor.trim().equals("^")) {
						meteTANList.addElement(LastTanOfDeductor);
					} else
						meteTANList.addElement("TANNOTAVBL");

					meteOrigRRRNo.addElement(metORNo);

					if (meteDDCount != 0)
						meteDDNumber.addElement(Integer.toString(meteDDCount));
					else if ((meteDDCount == 0) && (meteSDCount != 0))
						meteDDNumber.addElement(Integer.toString(meteSDCount));
					else
						meteDDNumber.addElement("0");

					meteDDCount = 0;
					meteSDCount = 0;

					meteTransactionTypeList.addElement(TransactionType);
					meteChlnVector.add(meteChlnDetailRecNo);
					meteChlnDetailRecNo = new Vector();

					// ***************** Metering END*****************//

					// ***************** General File Information ***************** //
					generalFileInfoBuffer.append(rrrNoGFI + "^" + orgRRRNoGFI + "^" + rrrDateGFI + "^" + tanGFI + "^" + frmNoGFI + "^" + qtrGFI + "^" + finYrGFI + "^" + trnsTypeGFI + "^" + noOfChallansGFI + "^" + noOfDDGFI + "^" + noOfSDGFI + "^"
							+ fileTypeGFI + "^" + tanTfcIdGFI + "^" + LineCount);

					samScmLineCountOfFile = LineCount;

					// ***************** General File Information END***************** //

					try {
						if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
							samScmData.append(AdditionTotalAmountPaidCredited(receiptTotalAmtPaidCrdtUpdateMode, receiptTotalAmtPaidCrdtAddMode) + "^");
							samScmData.append(AdditionTotalTaxDeducted(receiptTotalITDeductedAtSrcUpdtMode, receiptTotalITDeductedAtSrcAddMode, receiptTotalITDeductedAtSrcDelMode) + "^");
							samScmData.append(AdditionTotalAmountDeposited(receiptTotofDepdAmtUpdtMode, receiptTotofDepdAmtAddMode, receiptTotofDepdAmtDelMode) + "^");
						} else {
							samScmData.append(receiptTotalAmtPaidCrdtOriginalMode + "^");
							samScmData.append(receiptTotalITDeductedAtSrcOrigMode + "^");
							samScmData.append(receiptTotofDepdAmtOrigMode + "^");
						}

						if (UploadType.equals(UPLOADTYPE_CORRECTION)) {
							totalOfLastTotalOfDepositAmountAsPerChallan = Math.round((double) (totalOfLastTotalOfDepositAmountAsPerChallan * 100)) / 100.0;
							String outputValue = obj_FieldValidation.changeNumberFormat(totalOfLastTotalOfDepositAmountAsPerChallan);
							samScmData.append(outputValue + "^");
						} else {
							samScmData.append("-" + "^");
						}

						if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
							samScmLastTotalIncomeTaxDeductedAtSource = Math.round((double) (samScmLastTotalIncomeTaxDeductedAtSource * 100)) / 100.0;
							String outputValue = obj_FieldValidation.changeNumberFormat(samScmLastTotalIncomeTaxDeductedAtSource);
							samScmData.append(outputValue + "^");
							// ///**********************
							samScmData.append(samScmRrrNum + "^");
							samScmData.append(samScmRrrDate + "^");
							// //**********************

						} else {

							samScmData.append("-" + "^");
							// ///**********************
							samScmData.append(samScmRrrNum + "^");
							samScmData.append(samScmRrrDate + "^");
							// //**********************

						}

					} catch (Exception e) {
						e.printStackTrace();
					}

					/*
					 * This is the END logic. We check if Extra ENTER or BLANK line is given in the
					 * File If found we Log Error.
					 */
					record = br.readLine();
					LineCount++;
					try {
						if (record != null) { // Newly added for exception FVU4.8
							System.out.println("Lines added at the end  =  " + record.length());
							if (record.trim().length() == 0)
								obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + "NA" + tab + tab + tab + T_FV_1019_C + tab + T_FV_1019_M);
						}
					} catch (Exception e) {
						e.printStackTrace();
					}

					/*
					 * If NO ERROR is found while Validating Last Challan and Last Batch of the file
					 * (when no Salary Detail Records are present) or If NO ERROR is found while
					 * Validating Last Salary Detail Record , Last Challan and Last Batch of the
					 * file or If NO ERROR is found while Validating Last Batch of the file for
					 * Batch Correction(C1), or If NO ERROR is found while Validating Last Batch of
					 * the file for Challan Cancellation or If NO ERROR is found while Validating
					 * Last Batch, Last Salary Detail Record of the file for C4 or Z We check if
					 * Extra Batch,Challan ,Deductee ,Salary Detail, or Section records are given at
					 * the END of File. If present we Log Error.
					 */

					if ((lastChallanErrorFlag && lastBatchErrorFlag && !salaryDetailRecordFlag) || (lastChallanErrorFlag && lastBatchErrorFlag && salaryDetailRecordFlag && lastSalaryDeducteeFlag)
							|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || (lastBatchErrorFlag && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION))
							|| (lastBatchErrorFlag && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY)) && salaryDetailRecordFlag && lastSalaryDeducteeFlag)
							|| (lastBatchErrorFlag && TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) && !salaryDetailRecordFlag)) {
						if (record == null || record.length() == 0) {
						} else {
							while (record != null && record.length() != 0) {
								int localCaretCounterEBH = 0;
								int localCountField_DD = 1;
								RecType = "";

								if (record == null || record.length() == 0) {
									break;
								}

								StringTokenizer st_DD = new StringTokenizer(record, "^", true);
								while (st_DD.hasMoreTokens()) {
									String val = st_DD.nextToken();
									NullField = false;
									FieldFound = false;
									if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
										NullField = true;
										FieldFound = true;
									}
									if (val.equals(FIELD_SEPERATOR)) {
										Caret = true;
										if (localCaretCounterEBH == 0 && localCountField_DD == 1) {
											localCountField_DD++;
											LineNo = "";
										}
										localCaretCounterEBH++;
									} else {
										Caret = false;
										FieldFound = true;
									}

									if (localCountField_DD > 2) {
										break;
									}
									if (FieldFound) {
										switch (localCountField_DD) {
										case 1:
											LineNo = val;
											break;
										case 2:
											RecType = val;
											break;

										} // Closing switch
										localCountField_DD++;
									} // Closing if
								} // Closing While

								if (localCountField_DD != 3) {
									try {
										int localLineNo = Integer.parseInt(LineNo.trim());
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_2126_C + tab + T_FV_2126_M);
									} catch (Exception e) {

										e.printStackTrace();

										obj_StringBuffer.append(LineCount + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_2126_C + tab + T_FV_2126_M);
									}
								} else if (RecType.equals(BATCH_HEADER_IDENTIFIER)) {
									obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
									break;
								} else if (RecType.equals(CHALLAN_HEADER_IDENTIFIER)) {
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
								} else if (RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + "NA" + tab + "NA" + tab + T_FV_3126_C + tab + T_FV_3126_M);
								} else if (RecType.equals(SALARY_STATEMENT_IDENTIFIER) /* && Integer.parseInt(FinancialYr) < 201920 */)// Skip
																																		// validations
																																		// for
																																		// Fin
																																		// Year
																																		// 2019-20
																																		// onwards//
																																		// Changes
																																		// commented
																																		// for
																																		// 6.7
																																		// on
																																		// hold
																																		// cr
								{
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Salary_Details_Records + tab + "NA" + tab + "NA" + tab + T_FV_2129_C + tab + T_FV_2129_M);
								} else if (RecType.equals(SECTION10_HEADER_IDENTIFIER) /* && Integer.parseInt(FinancialYr) < 201920 */)// Skip
																																		// validations
																																		// for
																																		// Fin
																																		// Year
																																		// 2019-20
																																		// onwards//
																																		// Changes
																																		// commented
																																		// for
																																		// 6.7
																																		// on
																																		// hold
																																		// cr
								{
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Section_Record_Number + tab + "NA" + tab + "NA" + tab + T_FV_6031_C + tab + T_FV_6031_M);
								}
								/*
								 * else if (RecType.equals(SECTION8889_HEADER_IDENTIFIER)) {
								 * obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab +
								 * "NA" + tab + T_FV_6032_C + tab + T_FV_6032_M); }
								 */
								else if (RecType.equals(SECTIONVIA_HEADER_IDENTIFIER) /* && Integer.parseInt(FinancialYr) < 201920 */)// Skip
																																		// validations
																																		// for
																																		// Fin
																																		// Year
																																		// 2019-20
																																		// onwards//
																																		// Changes
																																		// commented
																																		// for
																																		// 6.7
																																		// on
																																		// hold
																																		// cr
								{
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Section_C6A_Number + tab + "NA" + tab + "NA" + tab + T_FV_6033_C + tab + T_FV_6033_M);
								} else if (RecType.equals(SECTION16_HEADER_IDENTIFIER) /* && Integer.parseInt(FinancialYr) < 201920 */)// Skip
																																		// validations
																																		// for
																																		// Fin
																																		// Year
																																		// 2019-20
																																		// onwards//
																																		// Changes
																																		// commented
																																		// for
																																		// 6.7
																																		// on
																																		// hold
																																		// cr
								{
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Section_16 + tab + "NA" + tab + "NA" + tab + T_FV_6030_C + tab + T_FV_6030_M);
								} else /* if(Integer.parseInt(FinancialYr) < 201920) */// Skip validations for Fin Year
																						// 2019-20 onwards// Changes
																						// commented for 6.7 on hold cr
								{
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_2126_C + tab + T_FV_2126_M);
								}

								record = br.readLine();
								LineCount++;
							}
						}
					} else {
						/*
						 * If ERROR is found while Validating Last Challan and Last Batch of the file
						 * (when no Salary Detail Records are present) or If No ERROR is found while
						 * Validating Last Salary Detail Record , Last Challan and Last Batch of the
						 * file We check if Extra Batch, Challan ,Salary Detail are given at the END of
						 * File. If present we Log Error. Here we DON'T Check for Extra Deductee OR
						 * Section Records. Because if ERROR is found at any of the above given Record
						 * Type We Skip that record and the Underlying Dectee Record or Section Record.
						 *
						 */
						if (record == null || record.length() == 0) {
						} else {
							while (record != null && record.length() != 0) {
								int localCaretCounterEBH = 0;
								int localCountField_DD = 1;
								RecType = "";

								if (record == null || record.length() == 0) {
									break;
								}
								StringTokenizer st_DD = new StringTokenizer(record, "^", true);
								while (st_DD.hasMoreTokens()) {
									String val = st_DD.nextToken();
									NullField = false;
									FieldFound = false;
									if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
										NullField = true;
										FieldFound = true;
									}
									if (val.equals(FIELD_SEPERATOR)) {
										Caret = true;
										if (localCaretCounterEBH == 0 && localCountField_DD == 1) {
											localCountField_DD++;
											LineNo = "";
										}
										localCaretCounterEBH++;
									} else {
										Caret = false;
										FieldFound = true;
									}

									if (localCountField_DD > 2) {
										break;
									}
									if (FieldFound) {
										switch (localCountField_DD) {
										case 1:
											LineNo = val;
											break;
										case 2:
											RecType = val;
											break;

										} // Closing switch
										localCountField_DD++;
									} // Closing if
								} // Closing While

								if (localCountField_DD != 3) {
									try {
										int localLineNo = Integer.parseInt(LineNo.trim());
										obj_StringBuffer.append(BatchLineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2126_C + tab + T_FV_2126_M);
									} catch (Exception e) {
										e.printStackTrace();

										obj_StringBuffer.append(BatchLineNo + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_2126_C + tab + T_FV_2126_M);
									}
								} else if (RecType.equals(BATCH_HEADER_IDENTIFIER)) {
									obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
								} else if (RecType.equals(CHALLAN_HEADER_IDENTIFIER)) {
									obj_StringBuffer.append(BatchLineNo + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2097_C + tab + T_FV_2097_M);
								} else if (RecType.equals(SALARY_STATEMENT_IDENTIFIER) /* && Integer.parseInt(FinancialYr) < 201920 */)// Skip
																																		// validations
																																		// for
																																		// Fin
																																		// Year
																																		// 2019-20
																																		// onwards//
																																		// Changes
																																		// commented
																																		// for
																																		// 6.7
																																		// on
																																		// hold
																																		// cr
								{
									obj_StringBuffer.append(BatchLineNo + tab + currentUploadType + tab + Count_Of_Salary_Details_Records + tab + "NA" + tab + "NA" + tab + T_FV_2129_C + tab + T_FV_2129_M);
								} else if (!RecType.equals(DEDUCTEE_HEADER_IDENTIFIER) && !RecType.equals(SECTION10_HEADER_IDENTIFIER) /*
																																		 * && !RecType. equals( SECTION8889_HEADER_IDENTIFIER)
																																		 */
										&& !RecType.equals(SECTIONVIA_HEADER_IDENTIFIER) && !RecType.equals(SECTION16_HEADER_IDENTIFIER) /*
																																			 * && Integer.parseInt(FinancialYr) < 201920
																																			 */)// Skip
																																				// validations
																																				// for Fin
																																				// Year
																																				// 2019-20
																																				// onwards//
																																				// Changes
																																				// commented
																																				// for 6.7 on
																																				// hold cr
								{
									obj_StringBuffer.append(BatchLineNo + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_2126_C + tab + T_FV_2126_M);
								}
								record = br.readLine();
								LineCount++;
							}
						}
					}

				} else if (FileType.equals(FILETYPE_PAN_CORRECTION)) {
					System.out.println("Checking PAN Correction Batch record");
					countOfBatch = Integer.parseInt(NoBatches.trim());

					long panBatchError1 = 0; // To check if Format Error present at last Batch of File
					long panBatchError2 = 0; // To check if Format Error present at last Batch of File

					boolean panBatchErrorFlag = false; // Flag is set true if Error present at Last Batch of File

					for (int i = 1; i <= (countOfBatch); i++) { // begin of for countOfBatch
						if (!(RecType.equals(BATCH_HEADER_IDENTIFIER))) {
							while (!(RecType.equals(BATCH_HEADER_IDENTIFIER))) {
								record = br.readLine();

								LineCount++;

								if (record == null || record.length() == 0) {
									obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
									obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
									return;
								}

								CountField_DD = 1;
								int localCaretCounterPCD6 = 0;
								StringTokenizer st_BH = new StringTokenizer(record, FIELD_SEPERATOR, true);
								while (st_BH.hasMoreTokens()) {
									String val = st_BH.nextToken();
									NullField = false;
									FieldFound = false;
									if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
										NullField = true;
										FieldFound = true;
									}
									if (val.equals(FIELD_SEPERATOR)) {
										Caret = true;
										if (localCaretCounterPCD6 == 0 && CountField_DD == 1) {
											CountField_DD++;
											LineNo = val;
										}
										localCaretCounterPCD6++;
									} else {
										Caret = false;
										FieldFound = true;
									}
									if (FieldFound) {
										switch (CountField_DD) {
										case 1:
											LineNo = val;
											break;
										case 2:
											RecType = val;
											break;
										case 3:
											DD_BatchNo = val;
											break;

										}
										CountField_DD++;
										if (CountField_DD > 3)
											break;
									} // closing if
								} // Closing while

								duplicateFileHeader = isDuplicateFileHeader(LineNo, RecType, obj_StringBuffer);
								if (duplicateFileHeader) {
									return;
								}

								if (RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_4049_C + tab + T_FV_4049_M);
									// Incomplete
								}
								// RecType is not FH,BH,CH,DD but some special character.then increment batch
								// count
								if (!RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
									if (!RecType.equals(BATCH_HEADER_IDENTIFIER)) {
										BatchCount++;
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Batch_Record_Type + tab + "-" + tab + "-" + tab + T_FV_2004_C + tab + T_FV_2004_M);
										i++;
									}
								}
							}
						} // if (!(RecType.equals(BATCH_HEADER_IDENTIFIER)))

						// reading the fields of Batch Header field by field
						StringTokenizer Obj_st_bh = new StringTokenizer(record, FIELD_SEPERATOR, true);

						CountField_BH = 1;
						int localCaretCountBHPC = 0;
						while (Obj_st_bh.hasMoreTokens()) {
							String val = Obj_st_bh.nextToken();
							NullField = false;
							FieldFound = false;
							if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
								NullField = true;
								FieldFound = true;
							}
							if (val.equals(FIELD_SEPERATOR)) {
								Caret = true;
								if (localCaretCountBHPC == 0 && CountField_BH == 1) {
									CountField_BH++;
									LineNo = "";
								}
								localCaretCountBHPC++;
							} else {
								Caret = false;
								FieldFound = true;
							}

							if (FieldFound) {
								switch (CountField_BH) {
								case 1:
									LineNo = val;
									break;
								case 2:
									RecType = val;
									break;
								case 3:
									BH_BatchNo = val;
									break;
								case 4:
									CountOfDeducteeDetail = val;
									break;

								} // Closing switch
								CountField_BH++;
							} // Closing if
						} // Closing While

						int localBatchCount = i;
						if ((RecType.equals(BATCH_HEADER_IDENTIFIER))) {
							BatchCount++;

							if (countOfBatch == i) {
								panBatchError1 = obj_StringBuffer.errorBufferString.length();
							}

							long panBatchErrRecLengthBefore = obj_StringBuffer.errorBufferString.length();

							cal = new GregorianCalendar();
							System.out.println("Entering ValidateBatchHeaderForPANCorrection method " + cal.getTime());
							validateBatchHeaderForPANCorrection(record, LineCount, BatchCount, UploadType, TanDedtr, obj_StringBuffer);
							cal = new GregorianCalendar();
							System.out.println("Exiting ValidateBatchHeaderForPANCorrection method " + cal.getTime());

							long panBatchErrRecLengthAfter = obj_StringBuffer.errorBufferString.length();

							/*
							 * Flag is Set TRUE if Error is found while validating
							 */
							boolean errorInPanBatchRecord = false;
							if ((panBatchErrRecLengthAfter - panBatchErrRecLengthBefore) != 0) {
								errorInPanBatchRecord = true;
							} else {
								errorInPanBatchRecord = false;
							}
							if (countOfBatch == i) {
								panBatchError2 = obj_StringBuffer.errorBufferString.length();

								if ((panBatchError2 - panBatchError1) == 0) {
									panBatchErrorFlag = true;
								}
							}

							// if format error in the batch then exiting the batch nad goto next batch.

							if (!errorInPanBatchRecord) {

								do {
									record = br.readLine();
									LineCount++;
									if (record == null || record.length() == 0) {
										if (!(i <= (countOfBatch))) {
											obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + BATCH_RECORD_TYPE + tab + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
										}
										break;
									}

									duplicateFileHeader = isDuplicateFileHeader1(record, obj_StringBuffer);
									if (duplicateFileHeader) {
										fileStatus = 'F';
										return;
									}

									int localCaretCounterPDH1 = 0;
									int localCountField_BH = 1;
									StringTokenizer st_DD = new StringTokenizer(record, "^", true);
									while (st_DD.hasMoreTokens()) {
										String val = st_DD.nextToken();
										NullField = false;
										FieldFound = false;
										if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
											NullField = true;
											FieldFound = true;
										}
										if (val.equals(FIELD_SEPERATOR)) {
											Caret = true;
											if (localCaretCounterPDH1 == 0 && localCountField_BH == 1) {
												localCountField_BH++;
												LineNo = val;
											}
											localCaretCounterPDH1++;
										}

										else {
											Caret = false;
											FieldFound = true;
										}

										if (localCountField_BH > 2) {
											break;
										}
										if (FieldFound) {
											switch (localCountField_BH) {
											case 1:
												LineNo = val;
												break;
											case 2:
												RecType = val;
												break;

											} // Closing switch
											localCountField_BH++;
										} // Closing if
									}
								} while (!(RecType.equals(BATCH_HEADER_IDENTIFIER)));

								if (BatchCount > Integer.parseInt(NoBatches.trim())) {
									obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + BATCH_RECORD_TYPE + tab + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
								}
								continue;

							} // CLOSING IF(THERE IS ERROR ON BH)

							countOfDeductee = Integer.parseInt(CountOfDeducteeDetail.trim());
							int flag = 0;
							int localCountofDD = 0;
							int nextLocalCountofDD = 0;

							for (int k = 1; k <= countOfDeductee; k++) {
								record = br.readLine();
								LineCount++;
								localCountofDD = k;
								if (record == null || record.length() == 0) {
									flag = 1;
									localCountofDD = localCountofDD - 1;
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_4049_C + tab + T_FV_4049_M);
									break;
								}

								nextLocalCountofDD = k;
								// reading the deductee detail, fields by field
								CountField_DD = 1;

								int localCaretCountBHP22 = 0;
								Obj_st = new StringTokenizer(record, FIELD_SEPERATOR, true);
								while (Obj_st.hasMoreTokens()) {
									String val = Obj_st.nextToken();
									NullField = false;
									FieldFound = false;
									if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
										NullField = true;
										FieldFound = true;
									}
									if (val.equals(FIELD_SEPERATOR)) {
										Caret = true;
										if (localCaretCountBHP22 == 0 && CountField_DD == 1) {
											LineNo = val;
											CountField_DD++;
										}
										localCaretCountBHP22++;
									} else {
										Caret = false;
										FieldFound = true;
									}
									if (FieldFound) {
										switch (CountField_DD) {
										case 1:
											LineNo = val;
											break;
										case 2:
											RecType = val;
											break;
										case 3:
											DD_BatchNo = val;
											break;
										}
										CountField_DD++;
										if (CountField_DD > 3)
											break;
									} // closing if
								} // Closing while
								CountField_DD = 1;
								duplicateFileHeader = isDuplicateFileHeader(RecType, LineNo, obj_StringBuffer);
								if (duplicateFileHeader) {
									return;
								}

								if (RecType.equals(BATCH_HEADER_IDENTIFIER)) {
									flag = 1;
									obj_StringBuffer.append((LineCount - 1) + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_4049_C + tab + T_FV_4049_M);
									break;
								}
								if (RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
									DeducteeCount++;

									cal = new GregorianCalendar();
									System.out.println("Entering ValidateDeducteeDetailsforPan method " + cal.getTime());
									validateDeducteeDetailsforPan(record, LineCount, localBatchCount, ChallanDetailRecordNo, obj_StringBuffer);
									cal = new GregorianCalendar();
									System.out.println("Exiting ValidateDeducteeDetailsforPan method " + cal.getTime());

								} // Closing if RecType is DD
								else {
									// Nahush 20 August 08
									if (Integer.parseInt(LineNo.trim()) != LineCount) {
										LineNo = "NA";
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + DEDUCTEE_RECORD_TYPE + tab + tab + tab + T_FV_4003_C + tab + T_FV_4003_M);
									}

									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + DEDUCTEE_RECORD_TYPE + tab + tab + tab + T_FV_4002_C + tab + T_FV_4002_M);
								}
							} // Closing For Loop of DD

							if (localCountofDD < countOfDeductee) {
								if (flag != 1) {
									if (i < (countOfBatch)) {
										obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
									}

									if (nextLocalCountofDD != countOfDeductee) {
										obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_4049_C + tab + T_FV_4049_M);
										break;
									}
								}
							}

						} else {
							obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + BATCH_RECORD_TYPE + tab + "-" + tab + "-" + tab + T_FV_2004_C + tab + T_FV_2004_M);

							do {
								record = br.readLine();
								LineCount++;
								if (record == null || record.length() == 0)
									break;

								int localCaretCounterBHP = 0;
								int localCountField_BH = 1;
								StringTokenizer st_BH4 = new StringTokenizer(record, FIELD_SEPERATOR, true);
								while (st_BH4.hasMoreTokens()) {
									String val = st_BH4.nextToken();
									NullField = false;
									FieldFound = false;
									if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
										NullField = true;
										FieldFound = true;
									}
									if (val.equals(FIELD_SEPERATOR)) {
										Caret = true;
										if (localCaretCounterBHP == 0 && localCountField_BH == 1) {
											localCountField_BH++;
											LineNo = val;
										}
										localCaretCounterBHP++;
									} else {
										Caret = false;
										FieldFound = true;
									}

									if (localCountField_BH > 2) {
										break;
									}
									if (FieldFound) {
										switch (localCountField_BH) {
										case 1:
											LineNo = val;
											break;
										case 2:
											RecType = val;
											break;

										} // Closing switch
										localCountField_BH++;
									} // Closing if
								}
								duplicateFileHeader = isDuplicateFileHeader(RecType, LineNo, obj_StringBuffer);
								if (duplicateFileHeader) {
									return;
								}
							} while (!(RecType.equals(BATCH_HEADER_IDENTIFIER)));
							// ((RecType.equals(DEDUCTEE_HEADER_IDENTIFIER))); // CLOSING WHILE
							// LOOP(SEARCHINGTILL NEXT BH IS ENCOUNTERED)
							continue;
						} // CLOSING IF(THERE IS ERROR ON BH)
						flagForPanCorr = "true";
					}

					record = br.readLine();
					LineCount++;

					try {
						// Log.tds_log.info("Lines added at the end = " + record.length());
						if (record.trim().length() == 0)
							obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + "NA" + tab + tab + tab + T_FV_1019_C + tab + T_FV_1019_M);
					} catch (Exception e) {
						e.printStackTrace();
					}

					if (panBatchErrorFlag) {

						if (record == null || record.length() == 0) {
						} else {
							int localCaretCounterEBH = 0;
							int localCountField_DD = 1;
							RecType = "";
							StringTokenizer st_DD = new StringTokenizer(record, "^", true);
							while (st_DD.hasMoreTokens()) {
								String val = st_DD.nextToken();
								NullField = false;
								FieldFound = false;
								if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
									NullField = true;
									FieldFound = true;
								}
								if (val.equals(FIELD_SEPERATOR)) {
									Caret = true;
									if (localCaretCounterEBH == 0 && localCountField_DD == 1) {
										localCountField_DD++;
										LineNo = "";
									}
									localCaretCounterEBH++;
								} else {
									Caret = false;
									FieldFound = true;
								}

								if (localCountField_DD > 2) {
									break;
								}
								if (FieldFound) {
									switch (localCountField_DD) {
									case 1:
										LineNo = val;
										break;
									case 2:
										RecType = val;
										break;

									} // Closing switch
									localCountField_DD++;
								} // Closing if
							} // Closing While

							if (localCountField_DD != 3) {
								try {
									int localLineNo = Integer.parseInt(LineNo.trim());
									obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2126_C + tab + T_FV_2126_M);
								} catch (Exception e) {
									e.printStackTrace();

									obj_StringBuffer.append(LineCount + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2126_C + tab + T_FV_2126_M);
								}
							} else if (RecType.equals(BATCH_HEADER_IDENTIFIER)) {
								obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1018_C + tab + T_FV_1018_M);
							} else if (RecType.equals(DEDUCTEE_HEADER_IDENTIFIER)) {
								obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_4049_C + tab + T_FV_4049_M);
							} else /* if(Integer.parseInt(FinancialYr) < 201920) */// Skip validations for Fin Year
																					// 2019-20 onwards// Changes
																					// commented for 6.7 on hold cr
							{
								obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2126_C + tab + T_FV_2126_M);
							}

						}
					}
				} else {
					// Nahush 20 August 08
					if (Integer.parseInt(LineNo.trim()) != LineCount) {
						LineNo = "NA";
						obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + "Batch Line Number" + tab + tab + tab + T_FV_2002_C + tab + T_FV_2002_M);
					}
					obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + BATCH_RECORD_TYPE + tab + "-" + tab + "-" + tab + T_FV_2004_C + tab + T_FV_2004_M);
					obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
					return;
				}

			} else {
				// Nahush 20 August 08
				if (Integer.parseInt(LineNo.trim()) != LineCount) {
					LineNo = "NA";
					obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + FILE_RECORD_TYPE + tab + tab + tab + T_FV_1002_C + tab + T_FV_1002_M);
				}
				obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + FILE_RECORD_TYPE + tab + tab + tab + T_FV_1001_C + tab + T_FV_1001_M);
				obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
				return;
			} // if ((RecType.equals(FILE_HEADER_IDENTIFIER)))

			// Added By AMI For FVU 3.0
			if (obj_StringBuffer.errorBufferString.length() != 0) {
				int cntunmatchedChalnBufr = FormValidator.unmatchedChalanCntStrBuff.capacity();
				FormValidator.unmatchedChalanCntStrBuff.delete(0, cntunmatchedChalnBufr);
			}
			// End

			obj_FileGenerator.writeToFile(ERROR_FILE, obj_StringBuffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);

		} // Closing if Rectype is FH
		catch (Exception e1) {

			throw e1;
		} // CLOSING CATCH
		finally {
			try {
				fr.close();
				br.close();
			} catch (Exception e2) {

				throw e2;
			}
		}

		samData = new StringBuffer(this.getSamScmNoOfBatch() + "^" + this.getSamScmLineCountOfFile() + "^" + Parameters.fvuVersion[0] + "^" + "00000000000000000000" + "^" + Parameters.samVersion[0] + "^" + "00000000000000000000" + "^" + "\n"
				+ this.getReceiptString().toString() + "\n" + this.getStatisticFileStrBuff().toString() + "\n" + this.getSamScmData().toString());

	} // closing method readFile

	/****************
	 * Validate FileHeader method validates the fields of a File Header and returns
	 * a string buffer that contains the error in the File Header
	 *******************/

	private void validateFileHeader(String first, StringBufferTemp obj_StringBuffer) throws Exception {

		FieldValidation obj_FieldValidation = new FieldValidation();
		FileGenerator obj_FileGenerator = new FileGenerator();
		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;

		int i = 0;
		char ch;
		boolean error = false;
		boolean NullField = false;
		boolean append = true;
		boolean error_flag = false;
		String FileUploadType;
		try {

			// Validationg LineNo
			if (UploadType.equals("R"))
				FileUploadType = UPLOAD_TYPE_REGULAR;
			else
				FileUploadType = UPLOAD_TYPE_CORRECTION;

			if (LineNo.equals(FIELD_NULL) || LineNo.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append("NA" + tab + fileHeaderUploadType + tab + Line_Number + tab + tab + tab + T_FV_1003_C + tab + T_FV_1003_M);
				LineNo = "-";
			} else if (LineNo.length() <= 9) {
				if (obj_FieldValidation.isInt(LineNo))
					Str_Buffer.append("NA" + tab + fileHeaderUploadType + tab + Line_Number + tab + tab + tab + T_FV_1003_C + tab + T_FV_1003_M);
				else if (Integer.parseInt(LineNo.trim()) != LineCount)
					Str_Buffer.append("-" + tab + fileHeaderUploadType + tab + Line_Number + tab + tab + tab + T_FV_1002_C + tab + T_FV_1002_M);
			} else
				Str_Buffer.append("NA" + tab + fileHeaderUploadType + tab + Line_Number + tab + tab + tab + T_FV_1003_C + tab + T_FV_1003_M);

			// Validationg LineNo
			// Validating recordtype
			if (RecType.equals(FIELD_NULL) || RecType.equals(FIELD_SEPERATOR)) {
				// Nahush 20 August 08
				if (Integer.parseInt(LineNo.trim()) != LineCount) {
					LineNo = "NA";
					obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + FILE_RECORD_TYPE + tab + tab + tab + T_FV_1002_C + tab + T_FV_1002_M);
				}
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + FILE_RECORD_TYPE + tab + tab + tab + T_FV_1001_C + tab + T_FV_1001_M);
			} else if (!(RecType.equals(FILE_HEADER_IDENTIFIER))) {
				// Nahush 20 August 08
				if (Integer.parseInt(LineNo.trim()) != LineCount) {
					LineNo = "NA";
					obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + FILE_RECORD_TYPE + tab + tab + tab + T_FV_1002_C + tab + T_FV_1002_M);
				}
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + FILE_RECORD_TYPE + tab + tab + tab + T_FV_1001_C + tab + T_FV_1001_M);
			}
			// Validating recordtype
			// Validationg FileType
			if (FileType.equals(FIELD_NULL) || FileType.equals(FIELD_SEPERATOR))
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + FILE_TYPE + tab + tab + tab + T_FV_1004_C + tab + T_FV_1004_M);
			else if (FileType.equals(FILETYPE_SALARY_ELECTRONIC) || FileType.equals(FILETYPE_SALARY_DIGITAL) || FileType.equals(FILETYPE_NONSALARY_ELECTRONIC) || FileType.equals(FILETYPE_NONSALARY_DIGITAL) || FileType.equals(FILETYPE_TCS_DIGITAL)
					|| FileType.equals(FILETYPE_TCS_ELECTRONIC) // ||
																// FileType.equals(FILETYPE_PAN_CORRECTION)
																// /* Code
																// commented
																// on 15
																// March-PAN
																// Correction
																// disabled
																// */
			) {
				error = false;
				statisticFileStrBuff.append(FileType + statDataDelemiter);
				fileTypeGFI = FileType;
			} else
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + FILE_TYPE + tab + tab + tab + T_FV_1004_C + tab + T_FV_1004_M);
			// Validating FileType

			// Seting the Paper Based Return File FLAG to TRUE for NS9, SL9 or TC9
			if (FileType.equals(FILETYPE_SALARY_DIGITAL) || FileType.equals(FILETYPE_NONSALARY_DIGITAL) || FileType.equals(FILETYPE_TCS_DIGITAL)) {
				paperReturnFile = true;
				// Added by AMI to reject Paper Return For FVU 2.127 (New Field Addition)
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + FILE_TYPE + tab + tab + tab + T_FV_1035_C + tab + T_FV_1035_M);

			} else
				paperReturnFile = false;

			// Validating UploadType
			if (UploadType.equals(FIELD_NULL) || UploadType.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + "NA" + tab + UPLOAD_TYPE + tab + tab + tab + T_FV_1005_C + tab + T_FV_1005_M);
			else if (!(UploadType.equals(UPLOADTYPE_REGULAR)) && !(UploadType.equals(UPLOADTYPE_CORRECTION)))
				Str_Buffer.append(LineNo + tab + "NA" + tab + UPLOAD_TYPE + tab + tab + tab + T_FV_1005_C + tab + T_FV_1005_M);
			else {
				statisticFileStrBuff.append(UploadType + "\n");
			}

			// Validating UploadType
			// Validating FileCrDt
			if (FileCrDt.equals(FIELD_NULL) || FileCrDt.equals(FIELD_SEPERATOR))
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Creation Date" + tab + tab + tab + T_FV_1006_C + tab + T_FV_1006_M);
			else if (FileCrDt.length() == 8 && FileCrDt.trim().length() == 8) {
				if (obj_FieldValidation.isInt(FileCrDt))
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Creation Date" + tab + tab + tab + T_FV_1006_C + tab + T_FV_1006_M);
				else if (obj_FieldValidation.isDate(FileCrDt))
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Creation Date" + tab + tab + tab + T_FV_1006_C + tab + T_FV_1006_M);
				else if (obj_FieldValidation.isFutureDate(FileCrDt))
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Creation Date" + tab + tab + tab + T_FV_1006_C + tab + T_FV_1006_M);
			} else
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Creation Date" + tab + tab + tab + T_FV_1006_C + tab + T_FV_1006_M);

			// Validating FileCrDt
			// Validating FileSeqNo
			if (FileSeqNo.equals(FIELD_NULL) || FileSeqNo.equals(FIELD_SEPERATOR)) {
				if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR))
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Sequenece Number" + tab + tab + tab + T_FV_1015_C + tab + T_FV_1015_M);
			} else if (TanTfcIdIndicator.equals(UPLOADED_BY_TFC))
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Sequenece Number" + tab + tab + tab + T_FV_1016_C + tab + T_FV_1016_M);
			else if (FileSeqNo.length() <= 9) {
				if (obj_FieldValidation.isInt(FileSeqNo))
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Sequenece Number" + tab + tab + tab + T_FV_1007_C + tab + T_FV_1007_M);
				else if (Integer.parseInt(FileSeqNo.trim()) == 0)
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "File Sequenece Number" + tab + tab + tab + T_FV_1007_C + tab + T_FV_1007_M);
			} else
				Str_Buffer.append("1" + tab + fileHeaderUploadType + "File Sequenece Number" + tab + tab + tab + tab + T_FV_1007_C + tab + T_FV_1007_M);
			// Validating FileSeqNo

			// Validating TanTfcIdIndicator
			if (TanTfcIdIndicator.equals(FIELD_NULL) || TanTfcIdIndicator.equals(FIELD_SEPERATOR))
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "Uploader Type" + tab + tab + tab + T_FV_1009_C + tab + T_FV_1009_M);
			else if (!(TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR)) && !(TanTfcIdIndicator.equals(UPLOADED_BY_TFC)))
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "Uploader Type" + tab + tab + tab + T_FV_1009_C + tab + T_FV_1009_M);
			// Validating TanTfcId

			// Validating TanDedtr
			if (TanDedtr.equals(FIELD_NULL) || TanDedtr.equals(FIELD_SEPERATOR)) {

				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "TAN of Deductor/ Collector /TFC Id / Organization ID" + tab + tab + tab + T_FV_1010_C + tab + T_FV_1010_M);
			} else {
				// Start :: Added for fvu 5.0
				/*
				 * if(!TanFromCSIFile.equals(TanDedtr)) { Str_Buffer.append("1" + tab +
				 * fileHeaderUploadType + tab +
				 * "TAN of Deductor/ Collector /TFC Id / Organization ID" + tab + tab + tab +
				 * T_FV_6069_C + tab + T_FV_6069_M); System.out.
				 * println("Error :: Mismatch in TAN present in statement and .csi file imported, kindly provide valid TAN"
				 * ); }
				 */
				// End :: Added for fvu 5.0

				if (TanTfcIdIndicator.equals(UPLOADED_BY_TFC) && TanDedtr.length() != 5)
					error = true;
				else if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR) && ((TanDedtr.length() != 10) && (TanDedtr.length() != 6)))
					error = true;
				else if ((TanDedtr.trim().length() == 5) && (TanDedtr.length() == 5)) {
					if (obj_FieldValidation.isInt(TanDedtr))
						error = true;
					else if (Integer.parseInt(TanDedtr.trim()) == 0)
						error = true;
				} else if (TanDedtr.length() == 10)
					error = obj_FieldValidation.checkTan(TanDedtr);
				else if ((TanDedtr.length() == 6) && (TanDedtr.trim().length() == 6)) // Checking for Organization ID
					error = obj_FieldValidation.isAlphaNum(TanDedtr);
				else
					error = true;

				if (error)
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "TAN of Deductor/ Collector /TFC Id / Organization ID" + tab + tab + tab + T_FV_1010_C + tab + T_FV_1010_M);
				else if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR) /* && (TanDedtr.length() == 10) */
						&& (FileType.equals(FILETYPE_SALARY_DIGITAL) || FileType.equals(FILETYPE_NONSALARY_DIGITAL) || FileType.equals(FILETYPE_TCS_DIGITAL)))
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + FILE_TYPE + tab + tab + tab + T_FV_1023_C + tab + T_FV_1023_M);

				tanTfcIdGFI = TanDedtr;
				TanFromTxtFile = TanDedtr;
			}
			// Validating TanDedtr

			// Validating NoBatches
			if (NoBatches.equals(FIELD_NULL) || NoBatches.equals(FIELD_SEPERATOR))
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1011_C + tab + T_FV_1011_M);
			else if (NoBatches.length() <= 9) {
				if (obj_FieldValidation.isInt(NoBatches))
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1011_C + tab + T_FV_1011_M);
				else {
					if (Integer.parseInt(NoBatches.trim()) <= 0)
						Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1011_C + tab + T_FV_1011_M);
					else if (UploadType.equals(UPLOADTYPE_REGULAR) && (Integer.parseInt(NoBatches.trim()) != 1))
						Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1012_C + tab + T_FV_1012_M);
					else if (Integer.parseInt(NoBatches.trim()) > 10)
						Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1008_C + tab + T_FV_1008_M);
					else
						samScmNoOfBatch = NoBatches.trim();
				}
			} else
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + Total_No_of_Batches + tab + tab + tab + T_FV_1011_C + tab + T_FV_1011_M);

			// Validating NoBatches

			// CHANGE AMI

			// Validating RPUType
			if (!paperReturnFile) {
				if (RpuType.equals(FIELD_NULL) || RpuType.equals(FIELD_SEPERATOR) || RpuType.length() == 0) {
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "RPU Type" + tab + tab + tab + T_FV_1033_C + tab + T_FV_1033_M);
				} else if (RpuType.trim().length() == 0) {
					Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "RPU Type" + tab + tab + tab + T_FV_1034_C + tab + T_FV_1034_M);
				} else if (!RpuType.equals(FIELD_SEPERATOR) && RpuType.trim().length() != 0) {
					if (RpuType.length() <= 75) {
						if (obj_FieldValidation.checkSpChar(RpuType))
							Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "RPU Type" + tab + tab + tab + T_FV_1034_C + tab + T_FV_1034_M);
						else if (!(obj_FieldValidation.isInt(RpuType)))
							Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "RPU Type" + tab + tab + tab + T_FV_1034_C + tab + T_FV_1034_M);
						else if (obj_FieldValidation.isValidCharString(RpuType))
							Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "RPU Type" + tab + tab + tab + T_FV_1034_C + tab + T_FV_1034_M);
					} else
						Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "RPU Type" + tab + tab + tab + T_FV_1034_C + tab + T_FV_1034_M);
				}
			}
			// END

			// Validating Filler Field
			if (Filler == null) {
			} else {
				Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "Filler" + tab + tab + tab + T_FV_1017_C + tab + T_FV_1017_M);
			}

			if (FileHash.equals(FIELD_NULL) || FileHash.equals(FIELD_SEPERATOR)) {
				FileHash = "-";
			}

			if (FVUVer.equals(FIELD_NULL) || FVUVer.equals(FIELD_SEPERATOR)) {
				FVUVer = "-";
			}

			if (SAMHash.equals(FIELD_NULL) || SAMHash.equals(FIELD_SEPERATOR)) {
				SAMHash = "-";
			}

			if (SAMVer.equals(FIELD_NULL) || SAMVer.equals(FIELD_SEPERATOR)) {
				SAMVer = "-";
			}

		} // CLOSING try
		catch (Exception e) {

			throw e;
		} // CLOSING catch
		return;
	} // CLOSING METHOD ValidateFileHeader()

	// isValidRecType method validates the record Type nad return boolean value,
	// true if error else false
	private boolean isValidRecType(String LineNo, String RecType, String RecTypeIdentifier, StringBufferTemp obj_StringBuffer) {
		boolean NullField = false;
		boolean error = false;
		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;
		NullField = obj_FieldValidation.isFieldNull(RecType);
		if (NullField) {
			// Nahush 20 August 08
			if (Integer.parseInt(LineNo.trim()) != LineCount) {
				LineNo = "NA";
				obj_StringBuffer.append("1" + tab + fileHeaderUploadType + tab + FILE_RECORD_TYPE + tab + tab + tab + T_FV_1002_C + tab + T_FV_1002_M);
			}

			Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + FILE_RECORD_TYPE + tab + tab + T_FV_1001_C + tab + T_FV_1001_M);
		} else if (RecType.length() == 2) {
			if (obj_FieldValidation.isChar(RecType))
				error = true;
		}

		return (error);
	}

	private boolean isDuplicateFileHeader1(String record, StringBufferTemp obj_StringBuffer) throws IOException {
		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;
		FileGenerator obj_FileGenerator = new FileGenerator();
		StringTokenizer st_BH = new StringTokenizer(record, FIELD_SEPERATOR);

		boolean NullField = false;
		boolean FieldFound = false;
		boolean Caret = true;

		int caretCounterDupFileHeader = 0;
		int localCountField_FH = 1;
		StringTokenizer st_FH = new StringTokenizer(record, "^", true);
		while (st_FH.hasMoreTokens()) {
			String val = st_FH.nextToken();
			NullField = false;
			FieldFound = false;
			if ((val.equals(FIELD_SEPERATOR) && Caret) || val.length() == 0) {
				NullField = true;
				FieldFound = true;
			}
			if (val.equals(FIELD_SEPERATOR)) {
				Caret = true;
				caretCounterDupFileHeader++;
			} else {
				Caret = false;
				FieldFound = true;
			}

			if (localCountField_FH > 2) {
				break;
			}
			if (FieldFound) {
				switch (localCountField_FH) {
				case 1:
					LineNo = val;
					break;
				case 2:
					RecType = val;
					break;

				} // Closing switch
				localCountField_FH++;
			} // Closing if
		} // Closing While

		if ((RecType.equals(FILE_HEADER_IDENTIFIER))) {
			Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "NA" + tab + tab + tab + T_FV_1014_C + tab + T_FV_1014_M);
			obj_FileGenerator.writeToFile(ERROR_FILE, Str_Buffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
			return true;
		} // CLOSING IF if (RecType.equals(FILE_HEADER_IDENTIFIER)
		return false;
	} // CLOSING isDuplicateFileHeader METHOD

	private boolean isDuplicateFileHeader(String LineNo, String RecType, StringBufferTemp obj_StringBuffer) throws IOException {
		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;
		FileGenerator obj_FileGenerator = new FileGenerator();
		if ((RecType.equals(FILE_HEADER_IDENTIFIER))) {
			Str_Buffer.append("1" + tab + fileHeaderUploadType + tab + "NA" + tab + tab + tab + T_FV_1014_C + tab + T_FV_1014_M);
			obj_FileGenerator.writeToFile(ERROR_FILE, Str_Buffer.errorBufferString.toString(), 0, obj_StringBuffer.fileOpened);
			return true;
		} // CLOSING IF if (RecType.equals(FILE_HEADER_IDENTIFIER)
		return false;
	} // CLOSING isDuplicateFileHeader METHOD

	/************** Validation for batch header field wise *********************/

	private void validateBatchHeader(String batch, int LineCount, String UploadTypeBH, StringBufferTemp obj_StringBuffer) throws Exception {
		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;
		sumOfTotalIncomeTaxDeposited = 0;
		ChallanCount = 0;
		GrossTDSTotalAsPerChallan = null;
		GrossTotalIncomeSD = null;
		CountOfSalaryDetailRec = null;
		TransactionType = null;
		FormNo = null;
		DeductorType = null;
		LastDeductorType = null; // AMI
		FinancialYr = null;

		boolean error_flag = false;
		boolean NullField = false;
		boolean error = false;
		boolean differenceInYear = false;
		boolean nullTanOfDeductor = false;
		boolean Assessment_Financial = false;
		boolean Caret = true;
		boolean FieldFound = false;
		boolean bhChallanCountZero = false;
		int LCount = 0;

		try {
			int Count_BH_Fields = 1;
			String LineNo = null;
			String RecType = null;
			String BH_BatchNo = null;
			BatchUpdationIndicator = null;
			String PreviousRRRNo = null;
			String OriginalRRRNo = null;
			String CountOfDeducteeRec = null;
			String RRRNo = null;
			String RRRDate = null;
			LastTanOfDeductor = null;
			// Only for correction file value will be present only in C1 transaction
			// type.Incase os C2 if the batch updation indicator is 1 this field should be
			// provided
			TanOfDeductor = null;

			// Commented By AMI For FVU 3.0
			// String TanAck = null;
			// Added For FVU 3.0 instead of TanAck
			String receiptNumber = null;

			String PanOfDeductor = null;
			String AssessmentYr = null;
			String EmployerName = null;
			String EmployerAddr1 = null;
			String EmployerAddr2 = null;
			String EmployerAddr3 = null;
			String EmployerAddr4 = null;
			String EmployerAddr5 = null;
			String EmployerState = null;
			String EmployerPin = null;
			String EmployerBrnchDiv = null;
			String EmployerEmail = null;
			String EmployerSTD = null;
			String EmployerPhone = null;
			String EmployerAddrChange = null;
			String NameofPersonResponsilbleForSal = null;
			String DesignationofPersonResponsilbleForSal = null;
			String PersonResponsilbleAddr1 = null;
			String PersonResponsilbleAddr2 = null;
			String PersonResponsilbleAddr3 = null;
			String PersonResponsilbleAddr4 = null;
			String PersonResponsilbleAddr5 = null;
			String PersonResponsilbleState = null;
			String PersonResponsilblePin = null;
			String PersonResponsilbleEmailId1 = null;
			// Commented By AMI For FVU 3.0
			// String remark = null;
			String mobileNumber = null;
			boolean valueForMobileNo = false;
			boolean valueForStdCode = false;
			boolean valueForPhoneNo = false;
			boolean valueForEmailId = false;
			boolean validationToBePerform = true;

			boolean valueForMobileNoProvided = false;
			boolean valueForStdCodeProvided = false;
			boolean valueForPhoneNoProvided = false;
			boolean valueForResPersnStdCodeProvided = false;
			boolean valueForResPersnPhoneNoProvided = false;

			// By Abhishek for FVU 3.0
			boolean valueForResPersnStdCode = false;
			boolean valueForResPersnPhoneNo = false;

			String PersonResponsilbleSTDCode = null;
			String PersonResponsilbleTelePhone = null;
			String PersonResponsilbleAddrChange = null;
			// Commented For FVU 3.0
			// String TdsCircle = null;
			// TdsCircle field will be null for FVU 3.0 onwards and Unmatched Challan count
			// will be appended By FVU in this field.
			unMatchedChalanCnt = null;

			String ApprovalTaken = null;
			String ApprovalNo = null;
			// CHANGE AMI
			// LastDeductorType = null;
			boolean valueMinistry = true;
			boolean valueCheck = true;
			boolean valueFlag = true;
			String StateName = null;
			String PAOCode = null;
			String DDOCode = null;
			String MinistryName = null;
			String MinistryNameOther = null;
			String RegistrationId = null;

			String PAORegistrationNo = null;
			String DDORegistrationNo = null;
			String Str_DDO = null;
			// END
			String BatchHash = null;
			String GSTNNo = null; // FVU 5.6

			// Added for FVU 3.8 by Shalin

			String TANRegistrationNo = null; // after FVU 4.6 its PAN of responsible person
			String EmployerSTDAlt = null;
			String EmployerPhoneAlt = null;
			String EmployerEmailAlt = null;
			String PersonResponsilbleSTDCodeAlt = null;
			String PersonResponsilbleTelePhoneAlt = null;
			String PersonResponsilbleEmailIdAlt = null;

			// Added for FVU 4.6
			String PersonResponsilblePAN = null;

			FieldValidation obj_FieldValidation = new FieldValidation();
			FileGenerator obj_FileGenerator = new FileGenerator();
			int localCaretCounterBHQ = 0;
			StringTokenizer Obj_st = new StringTokenizer(batch, FIELD_SEPERATOR, true);
			while (Obj_st.hasMoreTokens()) {
				String val = Obj_st.nextToken();
				NullField = false;
				FieldFound = false;
				if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
					NullField = true;
					FieldFound = true;
				}
				if (val.equals(FIELD_SEPERATOR)) {
					Caret = true;
					if (localCaretCounterBHQ == 0 && Count_BH_Fields == 1) {
						// Count_BH_Fields++;
						LineNo = val;
					}
					localCaretCounterBHQ++;
				} else {
					Caret = false;
					FieldFound = true;
				}

				// if (Count_BH_Fields > 69) //CHANGE AMI
				if (Count_BH_Fields > 70) // FVU 5.6
				{
					break;
				}
				if (FieldFound) {
					switch (Count_BH_Fields) {

					case 1:
						LineNo = val;
						break;
					case 2:
						RecType = val;
						break;
					case 3:
						BH_BatchNo = val;
						break;
					case 4:
						CountOfChallanRec = val;
						break;
					case 5:
						FormNo = val;
						break;
					case 6:
						TransactionType = val;
						break;
					case 7:
						BatchUpdationIndicator = val;
						break;
					case 8:
						OriginalRRRNo = val;
						break;
					case 9:
						PreviousRRRNo = val;
						break;
					case 10:
						RRRNo = val;
						break;
					case 11:
						RRRDate = val;
						break;
					case 12:
						LastTanOfDeductor = val;
						break;
					case 13:
						TanOfDeductor = val;
						break;
					case 14:
						// Receipt Number will be provided in TanAck field For FVU 3.0
						receiptNumber = val;
						// TanAck = val;
						break;
					case 15:
						PanOfDeductor = val;
						break;
					case 16:
						AssessmentYr = val;
						break;
					case 17:
						FinancialYr = val;
						break;
					case 18:
						Qperiod = val;
						break;
					case 19:
						EmployerName = val;
						break;
					case 20:
						EmployerBrnchDiv = val;
						break;
					case 21:
						EmployerAddr1 = val;
						break;
					case 22:
						EmployerAddr2 = val;
						break;
					case 23:
						EmployerAddr3 = val;
						break;
					case 24:
						EmployerAddr4 = val;
						break;
					case 25:
						EmployerAddr5 = val;
						break;
					case 26:
						EmployerState = val;
						break;
					case 27:
						EmployerPin = val;
						break;
					case 28:
						EmployerEmail = val;
						break;
					case 29:
						EmployerSTD = val;
						break;
					case 30:
						EmployerPhone = val;
						break;
					case 31:
						EmployerAddrChange = val;
						break;
					case 32:
						DeductorType = val;
						break;
					case 33:
						NameofPersonResponsilbleForSal = val;
						break;
					case 34:
						DesignationofPersonResponsilbleForSal = val;
						break;
					case 35:
						PersonResponsilbleAddr1 = val;
						break;
					case 36:
						PersonResponsilbleAddr2 = val;
						break;
					case 37:
						PersonResponsilbleAddr3 = val;
						break;
					case 38:
						PersonResponsilbleAddr4 = val;
						break;
					case 39:
						PersonResponsilbleAddr5 = val;
						break;
					case 40:
						PersonResponsilbleState = val;
						break;
					case 41:
						PersonResponsilblePin = val;
						break;
					case 42:
						PersonResponsilbleEmailId1 = val;
						break;
					case 43:
						// Commented By AMI For FVU 3.0
						// remark = val;
						mobileNumber = val;
						break;
					case 44:
						PersonResponsilbleSTDCode = val;
						break;
					case 45:
						PersonResponsilbleTelePhone = val;
						break;
					case 46:
						PersonResponsilbleAddrChange = val;
						break;
					case 47:
						GrossTDSTotalAsPerChallan = val;
						break;
					case 48:
						// Commented For FVU 3.0 By AMI
						// TdsCircle = val;
						unMatchedChalanCnt = val;
						break;
					case 49:
						CountOfSalaryDetailRec = val;
						break;
					case 50:
						GrossTotalIncomeSD = val;
						break;
					case 51:
						ApprovalTaken = val;
						break;
					case 52:
						ApprovalNo = val;
						break;
					// CHANGE AMI
					case 53:
						LastDeductorType = val;
						break;
					case 54:
						StateName = val;
						break;
					case 55:
						PAOCode = val;
						break;
					case 56:
						DDOCode = val;
						break;
					case 57:
						MinistryName = val;
						break;
					case 58:
						MinistryNameOther = val;
						break;
					case 59:
						RegistrationId = val;
						break;
					case 60:
						PAORegistrationNo = val;
						break;
					case 61:
						DDORegistrationNo = val;
						break;
					// END

					// for FVU 3.8 by Shalin

					case 62:
						EmployerSTDAlt = val;
						break;
					case 63:
						EmployerPhoneAlt = val;
						break;
					case 64:
						EmployerEmailAlt = val;
						break;
					case 65:
						PersonResponsilbleSTDCodeAlt = val;
						break;
					case 66:
						PersonResponsilbleTelePhoneAlt = val;
						break;
					case 67:
						PersonResponsilbleEmailIdAlt = val;
						break;
					case 68:
						AIN = val;
						break;
					// Commented For FVU 5.6
					/*
					 * case 69 : BatchHash = val; break;
					 */
					case 69:
						GSTNNo = val;
						break;
					case 70:
						BatchHash = val;
						break;

					} // SWITCH
					Count_BH_Fields++;
				}
			} // WHILE

			// aDDED FOR fvu 4.6
			ain_chk = true;
			// if (localCaretCounterBHQ != 68) //CHANGE AMI
			if (localCaretCounterBHQ != 69) // FVU 5.6
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2001_C + tab + T_FV_2001_M);
				return;
			}

			// Validating LineNo

			if (LineNo.equals(FIELD_NULL) || LineNo.equals(FIELD_SEPERATOR) || LineNo.trim().length() == 0) {
				Str_Buffer.append("NA" + tab + currentUploadType + tab + "Batch Line Number" + tab + tab + tab + T_FV_2003_C + tab + T_FV_2003_M);
				LineNo = "NA";
				;
			} else if (LineNo.length() <= 9) {
				if (obj_FieldValidation.isInt(LineNo)) {
					Str_Buffer.append("NA" + tab + currentUploadType + tab + "Batch Line Number" + tab + tab + tab + T_FV_2003_C + tab + T_FV_2003_M);
					LineNo = "NA";
				} else if (Integer.parseInt(LineNo.trim()) != LineCount)
					Str_Buffer.append("NA" + tab + currentUploadType + tab + "Batch Line Number" + tab + tab + tab + T_FV_2002_C + tab + T_FV_2002_M);
				else
					lineNoOfBatchRec = LineNo;
			} else

			// Validating LineNo
			{
				Str_Buffer.append("NA" + tab + currentUploadType + tab + "Batch Line Number" + tab + tab + tab + T_FV_2003_C + tab + T_FV_2003_M);
				LineNo = "NA";
			}
			// Validating recordtype
			error = isValidRecType(LineNo, RecType, BATCH_HEADER_IDENTIFIER, Str_Buffer);
			if (error)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + BATCH_RECORD_TYPE + tab + tab + tab + T_FV_2004_C + tab + T_FV_2004_M);
			// Validating recordtype

			// Validating BatchNo
			batchRecDataForPanStat = new StringBuffer();
			if (BH_BatchNo.equals(FIELD_NULL) || BH_BatchNo.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + tab + tab + T_FV_2005_C + tab + T_FV_2005_M);
				BH_BatchNo = "NA";
			} else if (BH_BatchNo.length() <= 9) {
				if (obj_FieldValidation.isInt(BH_BatchNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + tab + tab + T_FV_2005_C + tab + T_FV_2005_M);
				else if (Integer.parseInt(BH_BatchNo.trim()) != BatchCount)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + tab + tab + T_FV_2005_C + tab + T_FV_2005_M);
				else
					batchRecDataForPanStat.append(Integer.parseInt(BH_BatchNo.trim()) + statDataDelemiter);
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + tab + tab + T_FV_2005_C + tab + T_FV_2005_M);
			// Validating BatchNo

			// Validating CountOfChallanRec
			boolean nullCountOfChallanRec = false;

			if (CountOfChallanRec.equals(FIELD_NULL) || CountOfChallanRec.equals(FIELD_SEPERATOR)) {
				nullCountOfChallanRec = true;
				if (UploadTypeBH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2063_C + tab + T_FV_2063_M);
				else
					statisticFileStrBuff.append("-" + statDataDelemiter);
			}

			else if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH)) {
				if (CountOfChallanRec.length() <= 9) {
					if (obj_FieldValidation.isInt(CountOfChallanRec))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2063_C + tab + T_FV_2063_M);
					else if (Integer.parseInt(CountOfChallanRec.trim()) == 0 && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2063_C + tab + T_FV_2063_M);
					else if (Integer.parseInt(CountOfChallanRec.trim()) == 0 && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
						bhChallanCountZero = true;
						// Adding data for Statistic File
						statisticFileStrBuff.append(Integer.parseInt(CountOfChallanRec.trim()) + statDataDelemiter);
						noOfChallansGFI = CountOfChallanRec;
					} else {
						// Adding data for Statistic File
						statisticFileStrBuff.append(Integer.parseInt(CountOfChallanRec.trim()) + statDataDelemiter);
						noOfChallansGFI = CountOfChallanRec;
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2063_C + tab + T_FV_2063_M);
			}
			// Validating CountOfChallanRec

			// Validating Form No
			if (FormNo.equals(FIELD_NULL) || FormNo.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Form Number" + tab + tab + tab + T_FV_2064_C + tab + T_FV_2064_M);
				return;
			} else {
				if ((FileType.equals(FILETYPE_SALARY_ELECTRONIC) || FileType.equals(FILETYPE_SALARY_DIGITAL)) && !FormNo.equals(FORM_24Q))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Form Number" + tab + tab + tab + T_FV_2100_C + tab + T_FV_2100_M);
				else if ((FileType.equals(FILETYPE_NONSALARY_ELECTRONIC) || FileType.equals(FILETYPE_NONSALARY_DIGITAL)) && !FormNo.equals(FORM_26Q) && !FormNo.equals(FORM_27Q))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Form Number" + tab + tab + tab + T_FV_2065_C + tab + T_FV_2065_M);
				else if ((FileType.equals(FILETYPE_TCS_ELECTRONIC) || FileType.equals(FILETYPE_TCS_DIGITAL)) && !FormNo.equals(FORM_27EQ))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Form Number" + tab + tab + tab + T_FV_2058_C + tab + T_FV_2058_M);
				else if (BatchCount == 1) // 13-07-2005 To check that all the Form Number in File are Same
				{
					formNoOfFirstBatch = FormNo;
				} else if ((formNoOfFirstBatch != null) && !formNoOfFirstBatch.equals(FormNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Form Number" + tab + tab + tab + T_FV_2158_C + tab + T_FV_2158_M);

				// Adding data for Statistic File
				statisticFileStrBuff.append(FormNo + statDataDelemiter);
				batchRecDataForPanStat.append(FormNo + statDataDelemiter);
				frmNoGFI = FormNo;
			}
			// Validating Form No

			// Validating Transaction Type
			// added by faizan for FVU 4.8

			boolean nullUploadType = false;
			if (UploadTypeBH.equals(UPLOADTYPE_REGULAR)) {
				nullUploadType = true;
				/*
				 * Code Modified To Allow Transaction Type R1 for Regular Paper returns uploaded
				 * by TFC after Applying Y1 Correction
				 */
				if (TransactionType.equals("R1") && paperReturnFile && TanTfcIdIndicator.equals(UPLOADED_BY_TFC)) {
					// Adding data for Statistic File
					statisticFileStrBuff.append(TransactionType + statDataDelemiter);
					batchRecDataForPanStat.append(TransactionType + statDataDelemiter);
					trnsTypeGFI = TransactionType;
				} else {
					if (!TransactionType.equals(FIELD_NULL) && !TransactionType.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + TRANSACTION_TYPE + tab + tab + tab + T_FV_2009_C + tab + T_FV_2009_M);
					else {
						statisticFileStrBuff.append("-" + statDataDelemiter);
						batchRecDataForPanStat.append("-" + statDataDelemiter);
						trnsTypeGFI = "R";
					}
					// Adding data for Statistic File
				}
			} else {
				if (TransactionType.equals(FIELD_NULL) || TransactionType.equals(FIELD_SEPERATOR)) {
					nullUploadType = true;
					if (UploadTypeBH.equals(UPLOADTYPE_CORRECTION))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + TRANSACTION_TYPE + tab + tab + tab + T_FV_2008_C + tab + T_FV_2008_M);
				} else {
					// added for FVU 4.9
					if (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
						if (!((DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATE_GOVERNMENT)) && (Integer.parseInt(FinancialYr) <= 201213))) // added for FVU 4.9

						{
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_6052_C + tab + T_FV_6052_M);
						}

					}
					// ended for FUV 4.9
					if (UploadTypeBH.equals(UPLOADTYPE_CORRECTION) && FormNo.equals(FORM_24Q)) {
						if (!(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH)) && !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)) && !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
								&& !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY)) && !(TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY)) && !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION))
								&& !(TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)) && !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) && !(TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
								&& !(TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + TRANSACTION_TYPE + tab + tab + tab + T_FV_2007_C + tab + T_FV_2007_M);
						else if ((TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)) && (Integer.parseInt(NoBatches.trim()) > 1))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2021_C + tab + T_FV_2021_M);
					}
					if (UploadTypeBH.equals(UPLOADTYPE_CORRECTION) && (FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q) || FormNo.equals(FORM_27EQ))) {
						if (!(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH)) && !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)) && !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
								&& !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)) && !(TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)) && !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
								&& !(TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && !(TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2130_C + tab + T_FV_2130_M);
						else if ((TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)) && (Integer.parseInt(NoBatches.trim()) > 1))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2021_C + tab + T_FV_2021_M);
					}

					/*
					 * Code added to Allow transaction type Y1 only for TFCs and Paper Return
					 */

					if (UploadTypeBH.equals(UPLOADTYPE_CORRECTION) && TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)) {
						if (!paperReturnFile)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2095_C + tab + T_FV_2095_M);
						else if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2098_C + tab + T_FV_2098_M);
					}

					// Adding data for Statistic File
					statisticFileStrBuff.append(TransactionType + statDataDelemiter);
					batchRecDataForPanStat.append(TransactionType + statDataDelemiter);
					trnsTypeGFI = TransactionType;
				}
			}

			// Validating Transaction Type
			// Validating If count of challan detail record is null for C1, C4 Y and X Type
			if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)) && nullCountOfChallanRec == false) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2131_C + tab + T_FV_2131_M);
			}

			if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)) && nullCountOfChallanRec == true) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Challan + tab + tab + tab + T_FV_2063_C + tab + T_FV_2063_M);
			}
			// Validating If count of challan detail record is null for C1, C4 , C5, C9, Y
			// and X Type

			// Validating BatchUpdationIndicator. --------- Must be NULL for REGULAR, C1,
			// C4, C5, Y, X, Z
			boolean batchUpdationIndicatorRequired = true;
			if (UploadTypeBH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)
					|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
				if (!BatchUpdationIndicator.equals(FIELD_NULL) && !BatchUpdationIndicator.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + BATCH_UPDATION_INDICATOR + tab + tab + tab + T_FV_2070_C + tab + T_FV_2070_M);
					valueFlag = false;
				}
			} else {
				if (BatchUpdationIndicator.equals(FIELD_NULL) || BatchUpdationIndicator.equals(FIELD_SEPERATOR)) {
					if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + BATCH_UPDATION_INDICATOR + tab + tab + tab + T_FV_2069_C + tab + T_FV_2069_M);
						batchUpdationIndicatorRequired = false;
					}

				} else {
					if (!(BatchUpdationIndicator.equals("0")) && !(BatchUpdationIndicator.equals("1")))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + BATCH_UPDATION_INDICATOR + tab + tab + tab + T_FV_2068_C + tab + T_FV_2068_M);
				}
			}
			// Validating BatchUpdationIndicator
			// Validating OriginalRRR no

			if (UploadTypeBH.equals(UPLOADTYPE_REGULAR)) {
				/*
				 * Code Modified To provide Orig RRR No for Transaction Type R1 for Regular
				 * Paper returns uploaded by TFC after Applying Y1 Correction
				 */
				if (TransactionType.equals("R1") && paperReturnFile && TanTfcIdIndicator.equals(UPLOADED_BY_TFC)) {
					if (OriginalRRRNo.equals(FIELD_NULL) || OriginalRRRNo.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + ORIGINAL_RRR_NO + tab + tab + tab + T_FV_2087_C + tab + T_FV_2087_M);
					else {
						if (OriginalRRRNo.length() == 15) {
							if (obj_FieldValidation.isInt(OriginalRRRNo))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2104_C + tab + T_FV_2104_M);
							else if (obj_FieldValidation.isValidRrrNumber(OriginalRRRNo))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2104_C + tab + T_FV_2104_M);
							else {
								metORNo = OriginalRRRNo;
								orgRRRNoGFI = OriginalRRRNo;
								samScmData.append(OriginalRRRNo + "^");
							}
						} else {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2104_C + tab + T_FV_2104_M);
						}
					}
				} else {
					if (!OriginalRRRNo.equals(FIELD_NULL) && !OriginalRRRNo.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + ORIGINAL_RRR_NO + tab + tab + tab + T_FV_2010_C + tab + T_FV_2010_M);
					else
						samScmData.append("-" + "^");
				}
			} else {
				if (OriginalRRRNo.equals(FIELD_NULL) || OriginalRRRNo.equals(FIELD_SEPERATOR)) {
					if (UploadType.equals(UPLOADTYPE_CORRECTION))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + ORIGINAL_RRR_NO + tab + tab + tab + T_FV_2013_C + tab + T_FV_2013_M);
					else
						samScmData.append("-" + "^");
				} else {
					if (OriginalRRRNo.length() == 15) {
						if (obj_FieldValidation.isInt(OriginalRRRNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + ORIGINAL_RRR_NO + tab + tab + tab + T_FV_2104_C + tab + T_FV_2104_M);
						else if (obj_FieldValidation.isValidRrrNumber(OriginalRRRNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + ORIGINAL_RRR_NO + tab + tab + tab + T_FV_2104_C + tab + T_FV_2104_M);
						else if (UploadType.equals(UPLOADTYPE_CORRECTION)) {
							if (OriginalRRRNo.equals(RRRNo))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + ORIGINAL_RRR_NO + tab + tab + tab + T_FV_2011_C + tab + T_FV_2011_M);
							else {
								if (BatchCount == 1) // 13-07-2005 To check that all the Original RRR No in File are
														// Same
								{
									origRRRNoOfFirstBatch = OriginalRRRNo;
								} else if ((origRRRNoOfFirstBatch != null) && !origRRRNoOfFirstBatch.equals(OriginalRRRNo))
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + ORIGINAL_RRR_NO + tab + tab + tab + T_FV_2162_C + tab + T_FV_2162_M);

								metORNo = OriginalRRRNo;
								orgRRRNoGFI = OriginalRRRNo;
								samScmData.append(OriginalRRRNo + "^");
								// origRRRNoOfFirstBatch
							}
						}
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + ORIGINAL_RRR_NO + tab + tab + tab + T_FV_2104_C + tab + T_FV_2104_M);
				}
			}
			// Validating OriginalRRR no

			// Validating Previous RRR no
			if (UploadTypeBH.equals(UPLOADTYPE_REGULAR)) {
				/*
				 * if (!PreviousRRRNo.equals(FIELD_NULL) &&
				 * !PreviousRRRNo.equals(FIELD_SEPERATOR)) Str_Buffer.append(LineNo + tab +
				 * currentUploadType + tab + "Previous RRR No" + tab + tab + tab + T_FV_2012_C +
				 * tab + T_FV_2012_M); else samScmData.append("-" + "^");
				 */

				if (PreviousRRRNo.equals(FIELD_NULL) || PreviousRRRNo.equals(FIELD_SEPERATOR))
					samScmData.append("-" + "^");
				else
					samScmData.append(PreviousRRRNo + "^");
			} else if (PreviousRRRNo.equals(FIELD_NULL) || PreviousRRRNo.equals(FIELD_SEPERATOR)) {
				if (UploadType.equals(UPLOADTYPE_CORRECTION))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Previous RRR No" + tab + tab + tab + T_FV_2015_C + tab + T_FV_2015_M);
				else
					samScmData.append("-" + "^");
			} else if (PreviousRRRNo.length() == 15) {
				if (obj_FieldValidation.isInt(PreviousRRRNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Previous RRR No" + tab + tab + tab + T_FV_2014_C + tab + T_FV_2014_M);
				else if (obj_FieldValidation.isValidRrrNumber(PreviousRRRNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Previous RRR No" + tab + tab + tab + T_FV_2014_C + tab + T_FV_2014_M);

				else if (PreviousRRRNo.equals(RRRNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Previous RRR No" + tab + tab + tab + T_FV_2016_C + tab + T_FV_2016_M);
				else {
					if (BatchCount == 1) // 13-07-2005 To check that all the Previous RRR No in File are Same
					{
						previousRRRNoOfFirstBatch = PreviousRRRNo;
					} else if ((previousRRRNoOfFirstBatch != null) && !previousRRRNoOfFirstBatch.equals(PreviousRRRNo))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Previous RRR No" + tab + tab + tab + T_FV_2163_C + tab + T_FV_2163_M);

					samScmData.append(PreviousRRRNo + "^");
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Previous RRR No" + tab + tab + tab + T_FV_2014_C + tab + T_FV_2014_M);

			// Validating Previous RRR no

			// Validating RRRNo
			boolean nullRRRNo = false;
			boolean errUnique = false;

			if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR)) {

				if (!RRRNo.equals(FIELD_NULL) && !RRRNo.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2020_C + tab + T_FV_2020_M);
			} else {
				if (RRRNo.equals(FIELD_NULL) || RRRNo.equals(FIELD_SEPERATOR)) {
					nullRRRNo = true;
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2019_C + tab + T_FV_2019_M);
				} else {
					if (RRRNo.length() == 15) {

						if (obj_FieldValidation.isInt(RRRNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
						else {
							if (obj_FieldValidation.isValidRrrNumber(RRRNo))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
							else {
								String Tan_in_RRR = RRRNo.substring(0, 5);

								if (!Tan_in_RRR.equals(TanDedtr)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
								} else if (RRRNumberHS.contains(RRRNo)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2137_C + tab + T_FV_2137_M);
								}
								/*
								 * code added to check that for Transaction type R1 Original RRR No. and RRR No.
								 * should not be same Also the Eightth Digit of RRR Number should be 9
								 */
								else if (TransactionType.equals("R1") && paperReturnFile && TanTfcIdIndicator.equals(UPLOADED_BY_TFC)) {
									if (OriginalRRRNo.equals(RRRNo)) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2136_C + tab + T_FV_2136_M);
									} else if (obj_FieldValidation.eightthDigitOfRRRNum(RRRNo)) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
									} else {
										RRRNumberHS.add(RRRNo);
										rrrNoGFI = RRRNo;
									}
								}
								// code added to check that for Transaction type Y1 Eightth Digit of RRR Number
								// should be 9
								else if (TransactionType.equals("Y1") && paperReturnFile && TanTfcIdIndicator.equals(UPLOADED_BY_TFC)) {
									if (obj_FieldValidation.eightthDigitOfRRRNum(RRRNo)) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
									} else {
										RRRNumberHS.add(RRRNo);
										rrrNoGFI = RRRNo;
									}
								}
								/*
								 * code added to check that for Transaction type Y Eightth Digit of RRR Number
								 * should be 8 and Ninth Digit should be 9
								 */
								else if (TransactionType.equals("Y") && paperReturnFile && TanTfcIdIndicator.equals(UPLOADED_BY_TFC)) {
									if (obj_FieldValidation.eightthNinethDigitOfRRRNum(RRRNo)) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
									} else {
										RRRNumberHS.add(RRRNo);
										rrrNoGFI = RRRNo;
									}
								} else {
									RRRNumberHS.add(RRRNo);
									rrrNoGFI = RRRNo;
								}
							}
						}
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
					samScmRrrNum = RRRNo;
					//////// *********
					// samScmData.append(RRRNo + "^");
					////// *********
				}
			}
			// Validating RRRNo
			// Validating RRRDate
			if (RRRDate.equals(FIELD_NULL) || RRRDate.equals(FIELD_SEPERATOR)) {
				if (TanTfcIdIndicator.equals(UPLOADED_BY_TFC))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2103_C + tab + T_FV_2103_M);
				else
					RRRDatePresentDate = Calendar.getInstance();
			} else {
				if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2023_C + tab + T_FV_2023_M);
				} else if (RRRDate.length() == 8) {
					if (obj_FieldValidation.isInt(RRRDate))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
					else if (obj_FieldValidation.isDate(RRRDate))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
					else if (obj_FieldValidation.isFutureDate(RRRDate))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
					else {
						RRRDatePresentDate = new GregorianCalendar(Integer.parseInt(RRRDate.substring(4, 8)), Integer.parseInt(RRRDate.substring(2, 4)) - 1, Integer.parseInt(RRRDate.substring(0, 2)));

						rrrDateGFI = RRRDate;

						// Added by Manvendra to add PAN validations on the basis of RRR dates........
						// ------------------------------------------
						// AllRRRdates.add(RRRDatePresentDate);
						tempRRRdate = RRRDatePresentDate; // Because all RRR dates in file are same....

						// --------- Code added for batchwise validation for PAN compliance .. Manvendra
						// Singh :: 15-Feb-2008
						tempRRRDateforBatch = RRRDatePresentDate;

						// ------------------------------------------
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
				samScmRrrDate = RRRDate;
				//

				//////// *********
				// samScmData.append(RRRDate + "^");
				//////// *********
			}
			// Validating RRRDate

			// Validating LastTanOfDeductor
			boolean isLastTanOfDeductorNull = false;
			if (LastTanOfDeductor.equals(FIELD_NULL) || LastTanOfDeductor.equals(FIELD_SEPERATOR)) {
				if (UploadTypeBH.equals(UPLOADTYPE_CORRECTION))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2026_C + tab + T_FV_2026_M);

				isLastTanOfDeductorNull = true;
			} else {
				if (UploadTypeBH.equals(UPLOADTYPE_REGULAR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2025_C + tab + T_FV_2025_M);
				else {
					if (LastTanOfDeductor.length() == 10 && LastTanOfDeductor.trim().length() == 10) {
						if (obj_FieldValidation.checkTan(LastTanOfDeductor))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2024_C + tab + T_FV_2024_M);
						else if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR) && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && (TanDedtr.length() == 10) && !LastTanOfDeductor.equals(TanDedtr)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2017_C + tab + T_FV_2017_M);
						} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
							if (BatchCount == 1) {
								tanOfFirstBatch = LastTanOfDeductor;
							} else if ((tanOfFirstBatch != null) && !tanOfFirstBatch.equals(LastTanOfDeductor))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2157_C + tab + T_FV_2157_M);

							// Adding data for Statistic File
							statisticFileStrBuff.append("-^" + LastTanOfDeductor + statDataDelemiter);
							batchRecDataForPanStat.append("-^" + LastTanOfDeductor + statDataDelemiter);
							tanGFI = LastTanOfDeductor;
						} else if ((tanOfFirstBatch != null) && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && !tanOfFirstBatch.equals(LastTanOfDeductor))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2157_C + tab + T_FV_2157_M);

					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2024_C + tab + T_FV_2024_M);
				}
			}
			// Validating LastTanOfDeductor

			// Validating TanOfDeductor
			if (TanOfDeductor.equals(FIELD_NULL) || TanOfDeductor.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2028_C + tab + T_FV_2028_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2073_C + tab + T_FV_2073_M);
			else if (TanOfDeductor.length() == 10 && TanOfDeductor.trim().length() == 10) {
				if (obj_FieldValidation.checkTan(TanOfDeductor))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2027_C + tab + T_FV_2027_M);
				else if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && (TanDedtr.length() == 10) && !TanOfDeductor.equals(TanDedtr))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2112_C + tab + T_FV_2112_M);
				// ADDED BY FAIZAN for fvu 4.8
				else if (obj_FieldValidation.checkTanForbh(TanOfDeductor))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Of Deductor / Employer / Collector" + tab + tab + tab + T_FV_6051_C + tab + T_FV_6051_M);
				// ended for fvu 4.8
				else if (UploadTypeBH.equals(UPLOADTYPE_CORRECTION) && !isLastTanOfDeductorNull && !TanOfDeductor.equals(LastTanOfDeductor))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2059_C + tab + T_FV_2059_M);
				else if (BatchCount == 1) // 13-07-2005 To check that all the TAN in File are Same
				{
					if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && !TanOfDeductor.equals(LastTanOfDeductor))
						tanOfFirstBatch = LastTanOfDeductor;
					else
						tanOfFirstBatch = TanOfDeductor;
				} else if ((tanOfFirstBatch != null) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && !tanOfFirstBatch.equals(TanOfDeductor))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2156_C + tab + T_FV_2156_M);

				// Adding data for Statistic File
				statisticFileStrBuff.append(TanOfDeductor + statDataDelemiter);
				batchRecDataForPanStat.append(TanOfDeductor + statDataDelemiter);
				tanGFI = TanOfDeductor;

				if (LastTanOfDeductor.equals(FIELD_NULL) || LastTanOfDeductor.equals(FIELD_SEPERATOR)) {
					statisticFileStrBuff.append("-" + statDataDelemiter);
					batchRecDataForPanStat.append("-" + statDataDelemiter);
				} else {
					statisticFileStrBuff.append(LastTanOfDeductor + statDataDelemiter);
					batchRecDataForPanStat.append(LastTanOfDeductor + statDataDelemiter);
				}

			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2027_C + tab + T_FV_2027_M);
			// Validating TanOfDeductor

			// Commented by AMI for FVU 3.0

			/*
			 * //Validating TanAck It is a Filler field. No data must be provided if
			 * (!TanAck.equals(FIELD_NULL) && !TanAck.equals(FIELD_SEPERATOR))
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filer-1" + tab +
			 * tab + tab + T_FV_2029_C + tab + T_FV_2029_M); //Validating TanAck
			 */

			// Validation for Receipt Number For FVU 3.0
			if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR) || UploadType.equals(UPLOADTYPE_CORRECTION)) {
				if (!receiptNumber.equals(FIELD_NULL) && !receiptNumber.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt Number" + tab + tab + tab + T_FV_2215_C + tab + T_FV_2215_M);
			} else {
				if ((receiptNumber.equals(FIELD_NULL) || receiptNumber.equals(FIELD_SEPERATOR)) && UploadType.equals(UPLOADTYPE_REGULAR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt Number" + tab + tab + tab + T_FV_2207_C + tab + T_FV_2207_M);
				else if (!receiptNumber.equals(FIELD_NULL) && !receiptNumber.equals(FIELD_SEPERATOR)) {
					if (receiptNumber.trim().length() == 8 && receiptNumber.length() == 8) {

						if (obj_FieldValidation.isAlpha(receiptNumber)) {

							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt Number" + tab + tab + tab + T_FV_2200_C + tab + T_FV_2200_M);
						}
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt Number" + tab + tab + tab + T_FV_2200_C + tab + T_FV_2200_M);
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt Number" + tab + tab + tab + T_FV_2200_C + tab + T_FV_2200_M);
			}
			// Validation for Receipt Number

			// Validating PanOfDeductor --------- Must be NULL for C4, C5, Y, Y1, X, Z OR If
			// Batch Updation Indicator is '0'

			// ---------------Added by Nahush for validating Deductor PAN against PAN of
			// deductee.
			PANForThisBatch = PanOfDeductor;
			// ---------------
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PanOfDeductor.equals(FIELD_NULL) && !PanOfDeductor.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of Deductor / Employer" + tab + tab + tab + T_FV_2141_C + tab + T_FV_2141_M);
				else {
					statisticFileStrBuff.append("-" + statDataDelemiter);
					batchRecDataForPanStat.append("-" + statDataDelemiter);
				}
				// Adding data for Statistic File
			}
			// CHANGE AMI
			else if ((PanOfDeductor.equals(FIELD_NULL) || PanOfDeductor.equals(FIELD_SEPERATOR)) && !paperReturnFile
					&& (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || BatchUpdationIndicator.equals("1")) && valueFlag) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of Deductor / Employer" + tab + tab + tab + T_FV_2164_C + tab + T_FV_2164_M);
			}
			// END
			else if (PanOfDeductor.equals(FIELD_NULL) || PanOfDeductor.equals(FIELD_SEPERATOR)) {
				statisticFileStrBuff.append("-" + statDataDelemiter);
				batchRecDataForPanStat.append("-" + statDataDelemiter);
				// Adding data for Statistic File
			} else if ((PanOfDeductor.length() > 10) && (PanOfDeductor.trim().length() > 10)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of Deductor / Employer" + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
			}

			else if (!(PanOfDeductor.equals(PAN_NOT_REQUIRED)) && valueFlag) {

				if ((PanOfDeductor.length() == 10) && (PanOfDeductor.trim().length() == 10)) {
					// END

					if (obj_FieldValidation.checkPan(PanOfDeductor)) {
						if (paperReturnFile) {
							if (obj_FieldValidation.isAlphaNum(PanOfDeductor)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of Deductor / Employer" + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
							} else {
								statisticFileStrBuff.append(PanOfDeductor + statDataDelemiter);
								batchRecDataForPanStat.append(PanOfDeductor + statDataDelemiter);
								paperReturnRelax = true;
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
							}
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of Deductor / Employer" + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
					} else {
						statisticFileStrBuff.append(PanOfDeductor + statDataDelemiter);
						batchRecDataForPanStat.append(PanOfDeductor + statDataDelemiter);
					}
					// Adding data for Statistic File
				} else {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of Deductor / Employer" + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
				}
			} else if (PanOfDeductor.equals(PAN_NOT_REQUIRED)) {
				statisticFileStrBuff.append(PanOfDeductor + statDataDelemiter);
				batchRecDataForPanStat.append(PanOfDeductor + statDataDelemiter);
			} else if (paperReturnFile) {
				if (obj_FieldValidation.isAlphaNum(PanOfDeductor)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of Deductor / Employer" + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
				} else {
					paperReturnRelax = true;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
					statisticFileStrBuff.append(PanOfDeductor + statDataDelemiter);
					batchRecDataForPanStat.append(PanOfDeductor + statDataDelemiter);
				}
			}

			else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of Deductor / Employer" + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);

			// Validating PanOfDeductor

			// Validating AssessmentYr
			if (AssessmentYr.equals(FIELD_NULL) || AssessmentYr.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2032_C + tab + T_FV_2032_M);
			} else if (AssessmentYr.length() == 6 && AssessmentYr.trim().length() == 6) {
				if (obj_FieldValidation.isInt(AssessmentYr))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2032_C + tab + T_FV_2032_M);
				else {
					differenceInYear = obj_FieldValidation.isDifferenceInYearOne(AssessmentYr);
					if (differenceInYear)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2032_C + tab + T_FV_2032_M);
					else if (BatchCount == 1) // 13-07-2005 To check that all the TAN in File are Same
					{
						assessmentYearOfFirstBatch = AssessmentYr;
					} else if ((assessmentYearOfFirstBatch != null) && !assessmentYearOfFirstBatch.equals(AssessmentYr))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2159_C + tab + T_FV_2159_M);
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2032_C + tab + T_FV_2032_M);

			// Adding data for Statistic File
			statisticFileStrBuff.append(AssessmentYr + statDataDelemiter);
			batchRecDataForPanStat.append(AssessmentYr + statDataDelemiter);

			// Validating AssessmentYr

			// Validating FinancialYr
			if (FinancialYr.equals(FIELD_NULL) || FinancialYr.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year" + tab + tab + tab + T_FV_2033_C + tab + T_FV_2033_M);
			} else if (FinancialYr.length() == 6 && FinancialYr.trim().length() == 6) {
				if (obj_FieldValidation.isInt(FinancialYr))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year" + tab + tab + tab + T_FV_2033_C + tab + T_FV_2033_M);
				else {
					differenceInYear = obj_FieldValidation.isDifferenceInYearOne(FinancialYr);
					if (differenceInYear)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year" + tab + tab + tab + T_FV_2033_C + tab + T_FV_2033_M);
					else {
						Assessment_Financial = obj_FieldValidation.isAssmentYrFinancialYr(AssessmentYr, FinancialYr);
						if (Assessment_Financial)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year" + tab + tab + tab + T_FV_2034_C + tab + T_FV_2034_M);
						// Added by Abhishek (200506 hashed for including 201011)
						// else if (Integer.parseInt(FinancialYr.trim()) < 200506)
						// Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year" +
						// tab + tab + tab + T_FV_2044_C + tab + T_FV_2044_M);
						else if (Integer.parseInt(FinancialYr.trim()) < 201011)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year" + tab + tab + tab + T_FV_2211_C + tab + T_FV_2211_M);
						// End
						else if (BatchCount == 1) // 13-07-2005 To check that all the TAN in File are Same
						{
							financialYearOfFirstBatch = FinancialYr;

							/*
							 * if(UploadType.equals(UPLOADTYPE_CORRECTION) &&
							 * Integer.parseInt(financialYearOfFirstBatch)==201314) //for FVU 3.8 by Shalin
							 * { Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year"
							 * + tab + tab + tab + T_FV_2230_C + tab + T_FV_2230_M); }
							 */
							if (Integer.parseInt(financialYearOfFirstBatch) == 200506 || Integer.parseInt(financialYearOfFirstBatch) == 200607) // for
																																				// FVU
																																				// 3.8
																																				// by
																																				// Shalin
							{
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year" + tab + tab + tab + T_FV_2228_C + tab + T_FV_2228_M);
							}
							if (Integer.parseInt(financialYearOfFirstBatch) >= 201213) {
								isFinYrGrtr = true;
							} else {
								isFinYrGrtr = false;
							}
							if (Integer.parseInt(financialYearOfFirstBatch) >= 201314) // for FVU 3.8 by Shalin
							{
								isFinYrGrtrthn = true;
							} else {
								isFinYrGrtrthn = false;
							}

						} else if ((financialYearOfFirstBatch != null) && !financialYearOfFirstBatch.equals(FinancialYr))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "FinancialYr" + tab + tab + tab + T_FV_2160_C + tab + T_FV_2160_M);
					}
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Financial Year" + tab + tab + tab + T_FV_2033_C + tab + T_FV_2033_M);

			// Adding data for Statistic File
			statisticFileStrBuff.append(FinancialYr + statDataDelemiter);
			batchRecDataForPanStat.append(FinancialYr + statDataDelemiter);
			finYrGFI = FinancialYr;

			// Validating FinancialYr

			System.out.println("isFinYrGrtrthn:- " + isFinYrGrtrthn);

			// Commented for FVU 4.6
			/*
			 * if (isFinYrGrtrthn && UploadTypeBH.equals(UPLOADTYPE_REGULAR)) //for FVU 3.8
			 * by Shalin { TANRegistrationNo=RegistrationId; RegistrationId=""; } else
			 * if(isFinYrGrtrthn && UploadTypeBH.equals(UPLOADTYPE_CORRECTION) &&
			 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) ||
			 * ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) &&
			 * BatchUpdationIndicator.equals("1")) )) { TANRegistrationNo=RegistrationId;
			 * RegistrationId="";
			 * 
			 * 
			 * }
			 */
			// Added for FVU 4.6
			PersonResponsilblePAN = RegistrationId;
			RegistrationId = "";

			// Start Validating TAN Registration No. for FVU 3.8 by Shalin
			// commented for FVU 4.6
			/*
			 * if(isFinYrGrtrthn && ( UploadTypeBH.equals(UPLOADTYPE_REGULAR) ||
			 * (UploadTypeBH.equals(UPLOADTYPE_CORRECTION) &&
			 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) ||
			 * ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) &&
			 * BatchUpdationIndicator.equals("1")) )))) {
			 * if(UploadTypeBH.equals(UPLOADTYPE_CORRECTION) &&
			 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) ||
			 * TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) ||
			 * TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) )) { if
			 * (!TANRegistrationNo.equals(FIELD_NULL) &&
			 * !TANRegistrationNo.equals(FIELD_SEPERATOR)) Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "TAN Registration Number" + tab + tab + tab +
			 * T_FV_2227_C + tab + T_FV_2227_M); }
			 * 
			 * else if (!TANRegistrationNo.equals(FIELD_NULL) &&
			 * !TANRegistrationNo.equals(FIELD_SEPERATOR)) { if (TANRegistrationNo.length()
			 * != 12) Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "TAN Registration Number" + tab + tab + tab + T_FV_2219_C + tab +
			 * T_FV_2219_M); else if (!TANRegistrationNo.substring(0,1).equals("T"))
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "TAN Registration Number" + tab + tab + tab + T_FV_2219_C + tab +
			 * T_FV_2219_M); else if
			 * (!obj_FieldValidation.isNumber(TANRegistrationNo.substring(1,5)))
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "TAN Registration Number" + tab + tab + tab + T_FV_2219_C + tab +
			 * T_FV_2219_M); else if
			 * (obj_FieldValidation.isAlphaNum(TANRegistrationNo.substring(5,11)))
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "TAN Registration Number" + tab + tab + tab + T_FV_2219_C + tab +
			 * T_FV_2219_M); else if
			 * (obj_FieldValidation.isChar(TANRegistrationNo.substring(11,12)))
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "TAN Registration Number" + tab + tab + tab + T_FV_2219_C + tab +
			 * T_FV_2219_M); } }
			 */

			// End Validating TAN Registration Number for FVU 3.8 by Shalin
			// Validating Pan of responsible person for FVU 4.6
			System.out.println(" PersonResponsilblePAN :: " + PersonResponsilblePAN);
			System.out.println("PersonResponsilblePAN.trim().length() ::" + PersonResponsilblePAN.trim().length());
			if (!PersonResponsilblePAN.equals(FIELD_NULL) && !PersonResponsilblePAN.equals(FIELD_SEPERATOR)) {
				if (PersonResponsilblePAN.trim().length() != 10) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of person responsible for dedcuting tax" + tab + tab + tab + T_FV_2235_C + tab + T_FV_2235_M);
				} else if (PersonResponsilblePAN.equals(PAN_NOT_AVAILABLE) || PersonResponsilblePAN.equals(PAN_APPLIED) || PersonResponsilblePAN.equals(PAN_INVALID))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of person responsible for dedcuting tax" + tab + tab + tab + T_FV_2235_C + tab + T_FV_2235_M);
				else if (PersonResponsilblePAN.length() == 10 && PersonResponsilblePAN.trim().length() == 10) {
					if (obj_FieldValidation.checkPan(PersonResponsilblePAN))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of person responsible for dedcuting tax" + tab + tab + tab + T_FV_2235_C + tab + T_FV_2235_M);
					else if (obj_FieldValidation.checkPanForthDigit24Q(PersonResponsilblePAN)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of person responsible for dedcuting tax" + tab + tab + tab + T_FV_2235_C + tab + T_FV_2235_M);
					}

				}
			} else {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN of person responsible for dedcuting tax" + tab + tab + tab + T_FV_2235_C + tab + T_FV_2235_M);
			}

			// End of Validating Pan of responsible person

			// Validating Batch Period --------- Must be NULL for C1, C2, C3, C5, Y, X
			boolean invalidSalaryDetailFlag = false;
			if (Qperiod.equals(FIELD_NULL) || Qperiod.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Period" + tab + tab + tab + T_FV_2132_C + tab + T_FV_2132_M);
			} else if (!(Qperiod.equals("Q1")) && !(Qperiod.equals("Q2")) && !(Qperiod.equals("Q3")) && !(Qperiod.equals("Q4")))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Period" + tab + tab + tab + T_FV_2132_C + tab + T_FV_2132_M);
			else if ((Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3")) && FormNo.equals(FORM_24Q)) {
				invalidSalaryDetailFlag = true;
				// Str_Buffer.append(LineNo + tab + currentUploadType + tab + tab + tab +
				// T_FV_2142_C + tab + T_FV_2142_M);
			}
			/*
			 * else if (Qperiod.equals("Q4") && FormNo.equals(FORM_24Q) && paperReturnFile)
			 * { Str_Buffer.append(LineNo + tab + currentUploadType + tab + tab + tab +
			 * T_FV_2143_C + tab + T_FV_2143_M); }
			 */
			// Changes commented for 6.7 on hold cr start
			// Skip validations for Fin Year 2019-20 onwards START
			/*
			 * if(!invalidSalaryDetailFlag && Qperiod.equals("Q4") &&
			 * FormNo.equals(FORM_24Q) && Integer.parseInt(FinancialYr) >= 201920) {
			 * obj_StringBuffer.append(LineNo + tab + currentUploadType + tab +
			 * BATCH_RECORD_TYPE + tab + "-" + tab + "-" + tab + T_FV_9000_C + tab +
			 * T_FV_9000_M); }
			 */
			// Skip validations for Fin Year 2019-20 onwards END
			// Changes commented for 6.7 on hold cr end

			// changed below two else if condition to if for period validation shruti FVU
			// 5.4
			if (BatchCount == 1) // 13-07-2005 To check that all the TAN in File are Same
			{
				quarterOfFirstBatch = Qperiod;
			}
			if ((quarterOfFirstBatch != null) && !quarterOfFirstBatch.equals(Qperiod))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Period" + tab + tab + tab + T_FV_2161_C + tab + T_FV_2161_M);

			// Adding data for Statistic File
			statisticFileStrBuff.append(Qperiod + statDataDelemiter);
			batchRecDataForPanStat.append(Qperiod + statDataDelemiter);
			qtrGFI = Qperiod;
			// Validating Batch Period

			// Validating EmployerName

			if (EmployerName.equals(FIELD_NULL) || EmployerName.equals(FIELD_SEPERATOR) || EmployerName.trim().length() == 0) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employer / Deductor / Collector" + tab + tab + tab + T_FV_2101_C + tab + T_FV_2101_M);
			}

			else if (EmployerName.length() > 75)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employer / Deductor / Collector" + tab + tab + tab + T_FV_2035_C + tab + T_FV_2035_M);
			else if (obj_FieldValidation.isValidCharString(EmployerName))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employer / Deductor / Collector" + tab + tab + tab + T_FV_2035_C + tab + T_FV_2035_M);
			// added for FVU 5.0 : nik 1

			else if (!(obj_FieldValidation.checkNonSpecialCharacter(EmployerName)) && Integer.parseInt(FinancialYr) >= 200708)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employer / Deductor / Collector" + tab + tab + tab + T_FV_6053_C + tab + T_FV_6053_M);

			// ended for FVU 5.0 : nik

			else if (!(obj_FieldValidation.isValidNameString(EmployerName))) // Added by FVU 5.5
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employer / Deductor / Collector" + tab + tab + tab + T_FV_2236_C + tab + T_FV_2236_M);
			else {
				// System.out.println("i am in enelnlenlemp namer");
				statisticFileStrBuff.append(EmployerName.trim() + statDataDelemiter);
				batchRecDataForPanStat.append(EmployerName.trim() + statDataDelemiter + FileType);
			}
			// Priya added for FVU 5.0
			if (Integer.parseInt(BH_BatchNo) == 1)
				TanNameFromTxtFile = EmployerName;
			// Adding data for Statistic File

			// Validating EmployerName

			// Validating EmployerBrnchDiv --------- Must be NULL for C4, C5, C9, Y, X, Z OR
			// If Batch Updation Indicator is '0'

			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)))

			{
				if (!EmployerBrnchDiv.equals(FIELD_NULL) && !EmployerBrnchDiv.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector Branch/ Division" + tab + tab + tab + T_FV_2146_C + tab + T_FV_2146_M);
			}

			// added for FVU 5.0 : nik 2

			else if (!(obj_FieldValidation.checkNonSpecialCharacter(EmployerBrnchDiv)) && batchUpdationIndicatorRequired && Integer.parseInt(FinancialYr) >= 200708)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector Branch/ Division" + tab + tab + tab + T_FV_6054_C + tab + T_FV_6054_M);

			// ended for FVU 5.0 : nik
			// Added for FVU 5.0 :: 2.1278
			else if (EmployerBrnchDiv.equals(FIELD_NULL) || EmployerBrnchDiv.equals(FIELD_SEPERATOR) && batchUpdationIndicatorRequired) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector Branch/ Division" + tab + tab + tab + T_FV_6054_C + tab + T_FV_6054_M);
			}
			// End
			else if (!EmployerBrnchDiv.equals(FIELD_NULL) && !EmployerBrnchDiv.equals(FIELD_SEPERATOR)) {
				if (EmployerBrnchDiv.length() > 75)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector Branch/ Division" + tab + tab + tab + T_FV_2145_C + tab + T_FV_2145_M);
				else if (obj_FieldValidation.isValidCharString(EmployerBrnchDiv))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector Branch/ Division" + tab + tab + tab + T_FV_2145_C + tab + T_FV_2145_M);

			}

			// Validating EmployerBrnchDiv

			// Validating EmployerAddr1 --------- Must be NULL for C4, C5, C9, Y, X, Z OR If
			// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerAddr1.equals(FIELD_NULL) && !EmployerAddr1.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address1" + tab + tab + tab + T_FV_2102_C + tab + T_FV_2102_M);
				else
					samScmData.append("-" + "^");
			}
			// added for FVU 5.0 : nik 3

			else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(EmployerAddr1)) && Integer.parseInt(FinancialYr) >= 200708 && batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address1" + tab + tab + tab + T_FV_6055_C + tab + T_FV_6055_M);

			else if ((EmployerAddr1.equals(FIELD_NULL) || EmployerAddr1.equals(FIELD_SEPERATOR) || EmployerAddr1.trim().length() == 0) && batchUpdationIndicatorRequired) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address1" + tab + tab + tab + T_FV_2081_C + tab + T_FV_2081_M);
			} else if (EmployerAddr1.length() > 25) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address1" + tab + tab + tab + T_FV_2036_C + tab + T_FV_2036_M);
			} else if (obj_FieldValidation.isValidCharString_new(EmployerAddr1))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address1" + tab + tab + tab + T_FV_2036_C + tab + T_FV_2036_M);

			// ended for FVU 5.0 : nik
			else
				samScmData.append(EmployerAddr1 + "^");
			// Validating EmployerAddr1
			// Validating EmployerAddr2 --------- Must be NULL for C4, C5, C9, Y, X, Z OR If
			// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerAddr2.equals(FIELD_NULL) && !EmployerAddr2.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address2" + tab + tab + tab + T_FV_2105_C + tab + T_FV_2105_M);
				else
					samScmData.append("-" + "^");
			} else if (EmployerAddr2.equals(FIELD_NULL) || EmployerAddr2.equals(FIELD_SEPERATOR)) {
				samScmData.append("-" + "^");
			} else if (EmployerAddr2.length() > 25) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address2" + tab + tab + tab + T_FV_2037_C + tab + T_FV_2037_M);
			} else if (obj_FieldValidation.isValidCharString_new(EmployerAddr2))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address2" + tab + tab + tab + T_FV_2037_C + tab + T_FV_2037_M);
			// added for FVU 5.0 : nik 4
			else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(EmployerAddr2)) && Integer.parseInt(FinancialYr) >= 200708)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address2" + tab + tab + tab + T_FV_6056_C + tab + T_FV_6056_M);

			// ended for FVU 5.0 : nik
			else
				samScmData.append(EmployerAddr2 + "^");
			// Validating EmployerAddr2
			// Validating EmployerAddr3 --------- Must be NULL for C4, C5, Y, X, Z OR If
			// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerAddr3.equals(FIELD_NULL) && !EmployerAddr3.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address3" + tab + tab + tab + T_FV_2106_C + tab + T_FV_2106_M);
				else
					samScmData.append("-" + "^");
			} else if (EmployerAddr3.equals(FIELD_NULL) || EmployerAddr3.equals(FIELD_SEPERATOR)) {
				samScmData.append("-" + "^");
			} else if (EmployerAddr3.length() > 25) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address3" + tab + tab + tab + T_FV_2038_C + tab + T_FV_2038_M);
			} else if (obj_FieldValidation.isValidCharString_new(EmployerAddr3))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address3" + tab + tab + tab + T_FV_2038_C + tab + T_FV_2038_M);
			// added for FVU 5.0 nik 5

			else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(EmployerAddr3)) && Integer.parseInt(FinancialYr) >= 200708)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address3" + tab + tab + tab + T_FV_6057_C + tab + T_FV_6057_M);

			// ended for FVU 5.0 nik
			else
				samScmData.append(EmployerAddr3 + "^");
			// Validating EmployerAddr3
			// Validating EmployerAddr4 --------- Must be NULL for C4, C5, Y, X, Z OR If
			// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerAddr4.equals(FIELD_NULL) && !EmployerAddr4.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address 4" + tab + tab + tab + T_FV_2107_C + tab + T_FV_2107_M);
				else
					samScmData.append("-" + "^");
			} else if (EmployerAddr4.equals(FIELD_NULL) || EmployerAddr4.equals(FIELD_SEPERATOR)) {
				samScmData.append("-" + "^");
			} else if (EmployerAddr4.length() > 25) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address 4" + tab + tab + tab + T_FV_2039_C + tab + T_FV_2039_M);
			} else if (obj_FieldValidation.isValidCharString_new(EmployerAddr4))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address 4" + tab + tab + tab + T_FV_2039_C + tab + T_FV_2039_M);
			// added for FVU 5.0 nik 6

			else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(EmployerAddr4)) && Integer.parseInt(FinancialYr) >= 200708)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address 4" + tab + tab + tab + T_FV_6058_C + tab + T_FV_6058_M);

			// ended for FVU 5.0 nik
			else
				samScmData.append(EmployerAddr4 + "^");
			// Validating EmployerAddr4
			// Validating EmployerAddr5 --------- Must be NULL for C4, C5, Y, X, Z OR If
			// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerAddr5.equals(FIELD_NULL) && !EmployerAddr5.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address 5" + tab + tab + tab + T_FV_2108_C + tab + T_FV_2108_M);
				else
					samScmData.append("-" + "^");
			} else if (EmployerAddr5.equals(FIELD_NULL) || EmployerAddr5.equals(FIELD_SEPERATOR)) {
				samScmData.append("-" + "^");
			} else if (EmployerAddr5.length() > 25) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address 5" + tab + tab + tab + T_FV_2040_C + tab + T_FV_2040_M);
			} else if (obj_FieldValidation.isValidCharString_new(EmployerAddr5))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address 5" + tab + tab + tab + T_FV_2040_C + tab + T_FV_2040_M);
			// added for FVU 5.0 nik 7

			else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(EmployerAddr5)) && Integer.parseInt(FinancialYr) >= 200708)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer / Deductor / Collector Address 5" + tab + tab + tab + T_FV_6059_C + tab + T_FV_6059_M);

			// ended for FVU 5.0 nik
			else
				samScmData.append(EmployerAddr5 + "^");
			// Validating EmployerAddr5
			
			// Validating EmployerState --------- Must be NULL for C4, C5, Y, Y1, X, Z OR If
			// Batch Updation Indicator is '0'
			//CR #65617 START
			if(batchUpdationIndicatorRequired && !EmployerState.equals(FIELD_NULL) && !EmployerState.equals(FIELD_SEPERATOR) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))) {
				if (obj_FieldValidation.isInt(EmployerState))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
			}
			//CR #65617 END
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)
			// || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) //commented for
			// FVU 5.6
			// || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
			// || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)
					|| TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY)
			// || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) //commented for FVU
			// 5.6
			// || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) //commented for
			// FVU 5.6
			)) {
				if (!EmployerState.equals(FIELD_NULL) && !EmployerState.equals(FIELD_SEPERATOR)
						&& !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) // added tras type c2,c3
																																																						// for FVU 5.6

					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2109_C + tab + T_FV_2109_M);

				else
					samScmData.append("-" + "^");
				
				
				//Added for State code issue - Vinita Redmine 74898 // Obs no 05 FVU 7.1 09 Mar 2021 - Vinita
				
				if ( !(EmployerState.equals(FIELD_NULL) || EmployerState.equals(FIELD_SEPERATOR)) && EmployerState.length() <= 2 && batchUpdationIndicatorRequired) {
					if (obj_FieldValidation.isInt(EmployerState))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
					else if (!paperReturnFile) {
						if (!(Integer.parseInt(EmployerState.trim()) > 0 && Integer.parseInt(EmployerState.trim()) < 38 && Integer.parseInt(EmployerState.trim()) != 8)) // Changed for FVU 4.3
																																										//Changed for FVU 6.4 ladakh // //Changes for FVU 7.0 - Vinita (08 code removed)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
						else
							samScmData.append(EmployerState + "^");
					} else if (paperReturnFile) {
						if (EmployerState.equals("00")) {
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
							samScmData.append(EmployerState + "^");
						} else if (!(Integer.parseInt(EmployerState.trim()) > 0 && Integer.parseInt(EmployerState.trim()) < 38 && Integer.parseInt(EmployerState.trim()) != 8) && batchUpdationIndicatorRequired) // Changed for FVU 4.3
																																																				//Changed for FVU 6.4 ladakh //Changes for FVU 7.0 - Vinita (08 code removed)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
						else
							samScmData.append(EmployerState + "^");
					}
				}
				
				// Redmine 74898 
				
				
			}
			// else if ((EmployerState == null || EmployerState.equals(FIELD_NULL) ||
			// EmployerState.equals(FIELD_SEPERATOR))&& batchUpdationIndicatorRequired)
			// {
			// Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer /
			// Deductor / Collector State" + tab + tab + tab + T_FV_2082_C + tab +
			// T_FV_2082_M);
			// }
			else if (EmployerState.length() <= 2 && batchUpdationIndicatorRequired) {
				if (obj_FieldValidation.isInt(EmployerState))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
				else if (!paperReturnFile) {
					if (!(Integer.parseInt(EmployerState.trim()) > 0 && Integer.parseInt(EmployerState.trim()) < 38 && Integer.parseInt(EmployerState.trim()) != 8)) // Changed for FVU 4.3
																																									//Changed for FVU 6.4 ladakh // //Changes for FVU 7.0 - Vinita (08 code removed)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
					else
						samScmData.append(EmployerState + "^");
				} else if (paperReturnFile) {
					if (EmployerState.equals("00")) {
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
						samScmData.append(EmployerState + "^");
					} else if (!(Integer.parseInt(EmployerState.trim()) > 0 && Integer.parseInt(EmployerState.trim()) < 38 && Integer.parseInt(EmployerState.trim()) != 8) && batchUpdationIndicatorRequired) // Changed for FVU 4.3
																																																			//Changed for FVU 6.4 ladakh //Changes for FVU 7.0 - Vinita (08 code removed)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);
					else
						samScmData.append(EmployerState + "^");
				}
			} else if (batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2041_C + tab + T_FV_2041_M);

			if ((EmployerState == null || EmployerState.trim().equals(FIELD_NULL) || EmployerState.equals(FIELD_SEPERATOR)) && batchUpdationIndicatorRequired) // removed else if for
																																								// fvu 5.6
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector State" + tab + tab + tab + T_FV_2082_C + tab + T_FV_2082_M);
			}
			// Validating EmployerState
			// Validating EmployerPin --------- Must be NULL for C4, C5, Y, Y1, X, Z OR If
			// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerPin.equals(FIELD_NULL) && !EmployerPin.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector PIN" + tab + tab + tab + T_FV_2110_C + tab + T_FV_2110_M);
				else
					samScmData.append("-" + "^");
			} else if ((EmployerPin.equals(FIELD_NULL) || EmployerPin.equals(FIELD_SEPERATOR)) && batchUpdationIndicatorRequired) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector PIN" + tab + tab + tab + T_FV_2083_C + tab + T_FV_2083_M);
			} else if (EmployerPin.length() == 6 && EmployerPin.trim().length() == 6) {
				if ((obj_FieldValidation.isInt(EmployerPin) || Integer.parseInt(EmployerPin) < 110001) && batchUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector PIN" + tab + tab + tab + T_FV_2042_C + tab + T_FV_2042_M);
				else
					samScmData.append(EmployerPin + "^");
			} else if (batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer  / Deductor / Collector PIN" + tab + tab + tab + T_FV_2042_C + tab + T_FV_2042_M);
			// Validating EmployerPin
			// validating EmployerEmail --------- Must be NULL for C4, C5, Y, X, Z OR If
			// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerEmail.equals(FIELD_NULL) && !EmployerEmail.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id of deductor/collector" + tab + tab + tab + T_FV_2078_C + tab + T_FV_2078_M);
			} else if (!EmployerEmail.equals(FIELD_NULL) && !EmployerEmail.equals(FIELD_SEPERATOR)) {
				if (EmployerEmail.length() <= 75) {
					// Changes For FVU 3.0
					if (EmployerEmail.length() != EmployerEmail.trim().length())
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id of deductor/collector" + tab + tab + tab + T_FV_2144_C + tab + T_FV_2144_M);
					else if (obj_FieldValidation.isValidEmail(EmployerEmail)) {
						if (paperReturnFile) {
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2144_C + tab + T_FV_2144_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id of deductor/collector" + tab + tab + tab + T_FV_2144_C + tab + T_FV_2144_M);
					}
					// Added For FVU 3.0
					else
						valueForEmailId = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id of deductor/collector" + tab + tab + tab + T_FV_2144_C + tab + T_FV_2144_M);
			} // validating EmployeeEmail
				// validating EmployerSTD --------- Must be NULL for C4, C5, Y, Y1, X, Z OR If
				// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerSTD.equals(FIELD_NULL) && !EmployerSTD.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of deductor/collector" + tab + tab + tab + T_FV_2148_C + tab + T_FV_2148_M);
			} else if (!EmployerSTD.equals(FIELD_NULL) && !EmployerSTD.equals(FIELD_SEPERATOR)) {
				// Added For FVU 3.0
				valueForStdCodeProvided = true;
				if (EmployerSTD.length() <= 5) {
					// Changes For FVU 3.0
					if (EmployerSTD.length() != EmployerSTD.trim().length())
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of deductor/collector" + tab + tab + tab + T_FV_2147_C + tab + T_FV_2147_M);
					else if (obj_FieldValidation.isInt(EmployerSTD))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of deductor/collector" + tab + tab + tab + T_FV_2147_C + tab + T_FV_2147_M);
					// Added For FVU 3.0
					else if (Integer.parseInt(EmployerSTD) == 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of deductor/collector" + tab + tab + tab + T_FV_2147_C + tab + T_FV_2147_M);
					else
						valueForStdCode = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of deductor/collector" + tab + tab + tab + T_FV_2147_C + tab + T_FV_2147_M);
			} // validating EmployerSTD
				// validating EmployerPhone --------- Must be NULL for C4, C5, Y, X, Z OR If
				// Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!EmployerPhone.equals(FIELD_NULL) && !EmployerPhone.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of deductor/collector" + tab + tab + tab + T_FV_2150_C + tab + T_FV_2150_M);
			} else if (!EmployerPhone.equals(FIELD_NULL) && !EmployerPhone.equals(FIELD_SEPERATOR)) {
				// Added For FVU 3.0
				valueForPhoneNoProvided = true;

				if (EmployerPhone.length() <= 10) {
					if (EmployerPhone.length() != EmployerPhone.trim().length())
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of deductor/collector" + tab + tab + tab + T_FV_2149_C + tab + T_FV_2149_M);
					else if (obj_FieldValidation.isInt(EmployerPhone))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of deductor/collector" + tab + tab + tab + T_FV_2149_C + tab + T_FV_2149_M);
					// Added For FVU 3.0
					else if (Long.parseLong(EmployerPhone) == 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of deductor/collector" + tab + tab + tab + T_FV_2149_C + tab + T_FV_2149_M);
					else
						valueForPhoneNo = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of deductor/collector" + tab + tab + tab + T_FV_2149_C + tab + T_FV_2149_M);
			} // validating EmployerPhone
				// *******************
				// Validating EmployerAddrChange --------- Must be NULL for C4, C5, Y, X, Z OR
				// If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || paperReturnFile)) {
				if (!EmployerAddrChange.equals(FIELD_NULL) && !EmployerAddrChange.equals(FIELD_SEPERATOR)) {
					if (paperReturnFile) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Employer/Deductor/Collector since last Return" + tab + tab + tab + T_FV_2071_C + tab + T_FV_2071_M);
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Employer/Deductor/Collector since last Return" + tab + tab + tab + T_FV_2111_C + tab + T_FV_2111_M);
					}
				}
			} else if ((EmployerAddrChange.equals(FIELD_NULL) || EmployerAddrChange.equals(FIELD_SEPERATOR)) && batchUpdationIndicatorRequired) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Employer/Deductor/Collector since last Return" + tab + tab + tab + T_FV_2084_C + tab + T_FV_2084_M);
			} else if (((EmployerAddrChange.length() != 1) || (EmployerAddrChange.trim().length() != 1) || !(Character.isLetter(EmployerAddrChange.charAt(0))) || !(Character.isUpperCase(EmployerAddrChange.charAt(0))))
					&& batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Employer/Deductor/Collector since last Return" + tab + tab + tab + T_FV_2043_C + tab + T_FV_2043_M);
			else if (!(EmployerAddrChange.equals("Y")) && !(EmployerAddrChange.equals("N")) && batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Employer/Deductor/Collector since last Return" + tab + tab + tab + T_FV_2043_C + tab + T_FV_2043_M);
			// Validating EmployerAddrChange
			// Validating DeductorType
			if (DeductorType.equals(FIELD_NULL) || DeductorType.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductor  / Collector Type" + tab + tab + tab + T_FV_2077_C + tab + T_FV_2077_M);
				valueCheck = false;
			}
			// CHANGE AMI
			else if (!DeductorType.equals(CENTRAL_GOVERNMENT) && !DeductorType.equals(STATE_GOVERNMENT) && !DeductorType.equals(STATUTORY_BODY_CG) && !DeductorType.equals(STATUTORY_BODY_SG) && !DeductorType.equals(AUTONOMOUS_BODY_CG)
					&& !DeductorType.equals(AUTONOMOUS_BODY_SG) && !DeductorType.equals(LOCAL_AUTHORITY_CG) && !DeductorType.equals(LOCAL_AUTHORITY_SG) && !DeductorType.equals(COMPANY89) && !DeductorType.equals(BRANCH_DIV_COMPANY)
					&& !DeductorType.equals(ASSOCIATION_OF_PERSON) && !DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON) && !DeductorType.equals(BODY_OF_INDIVIDUALS) && !DeductorType.equals(INDIVIDUAL) && !DeductorType.equals(FIRM)
					&& !DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductor  / Collector Type" + tab + tab + tab + T_FV_2076_C + tab + T_FV_2076_M);
				valueCheck = false;
			}

			else
				samScmData.append(DeductorType + "^");

			// Validating DeductorType

			// Validating LastDeductorType

			// System.out.println("Last --- "+LastDeductorType+"Last length---
			// "+LastDeductorType.length());

			if (UploadType.equals(UPLOADTYPE_REGULAR) && !paperReturnFile && (!(LastDeductorType.equals(FIELD_NULL) || LastDeductorType.equals(FIELD_SEPERATOR)))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Deductor  / Collector Type" + tab + tab + tab + T_FV_2165_C + tab + T_FV_2165_M);
			}
			// Validating LastDeductorType --------- Must be NULL for C4, C5, Y, X, Z OR If
			// Batch Updation Indicator is '0'
			else if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || paperReturnFile)) {
				if (!LastDeductorType.equals(FIELD_NULL) && !LastDeductorType.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Deductor  / Collector Type" + tab + tab + tab + T_FV_2166_C + tab + T_FV_2166_M);
					valueCheck = false;
				}
			}

			if ((BatchUpdationIndicator.equals("1") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH)) && valueFlag) {
				if ((LastDeductorType.equals(FIELD_NULL) || LastDeductorType.equals(FIELD_SEPERATOR)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Deductor  / Collector Type" + tab + tab + tab + T_FV_2194_C + tab + T_FV_2194_M);

				else if (!LastDeductorType.equals(FIELD_NULL) && !LastDeductorType.equals(FIELD_SEPERATOR) && LastDeductorType.trim().length() != 0) {
					if (!LastDeductorType.equals(CENTRAL_GOVERNMENT) && !LastDeductorType.equals(STATE_GOVERNMENT) && !LastDeductorType.equals(STATUTORY_BODY_CG) && !LastDeductorType.equals(STATUTORY_BODY_SG)
							&& !LastDeductorType.equals(AUTONOMOUS_BODY_CG) && !LastDeductorType.equals(AUTONOMOUS_BODY_SG) && !LastDeductorType.equals(LOCAL_AUTHORITY_CG) && !LastDeductorType.equals(LOCAL_AUTHORITY_SG)
							&& !LastDeductorType.equals(COMPANY89) && !LastDeductorType.equals(BRANCH_DIV_COMPANY) && !LastDeductorType.equals(ASSOCIATION_OF_PERSON) && !LastDeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON)
							&& !LastDeductorType.equals(BODY_OF_INDIVIDUALS) && !LastDeductorType.equals(INDIVIDUAL) && !LastDeductorType.equals(FIRM) && !LastDeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Deductor  / Collector Type" + tab + tab + tab + T_FV_2195_C + tab + T_FV_2195_M);
						valueCheck = false;
					}
				} else {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Deductor  / Collector Type" + tab + tab + tab + T_FV_2195_C + tab + T_FV_2195_M);
					valueCheck = false;
				}

				if (valueCheck) {
					if (LastDeductorType.equals(CENTRAL_GOVERNMENT) || LastDeductorType.equals(STATE_GOVERNMENT)) {
						if (!DeductorType.equals(CENTRAL_GOVERNMENT) && !DeductorType.equals(STATE_GOVERNMENT)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductor  / Collector Type" + tab + tab + tab + T_FV_2076_C + tab + T_FV_2076_M);
							valueCheck = false;
						}
					} else if (LastDeductorType.equals(STATUTORY_BODY_CG) || LastDeductorType.equals(STATUTORY_BODY_SG) || LastDeductorType.equals(AUTONOMOUS_BODY_CG) || LastDeductorType.equals(AUTONOMOUS_BODY_SG)
							|| LastDeductorType.equals(LOCAL_AUTHORITY_CG) || LastDeductorType.equals(LOCAL_AUTHORITY_SG) || LastDeductorType.equals(COMPANY89) || LastDeductorType.equals(BRANCH_DIV_COMPANY)
							|| LastDeductorType.equals(ASSOCIATION_OF_PERSON) || LastDeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON) || LastDeductorType.equals(BODY_OF_INDIVIDUALS) || LastDeductorType.equals(INDIVIDUAL)
							|| LastDeductorType.equals(FIRM) || LastDeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) {
						if (!DeductorType.equals(STATUTORY_BODY_CG) && !DeductorType.equals(STATUTORY_BODY_SG) && !DeductorType.equals(AUTONOMOUS_BODY_CG) && !DeductorType.equals(AUTONOMOUS_BODY_SG) && !DeductorType.equals(LOCAL_AUTHORITY_CG)
								&& !DeductorType.equals(LOCAL_AUTHORITY_SG) && !DeductorType.equals(COMPANY89) && !DeductorType.equals(BRANCH_DIV_COMPANY) && !DeductorType.equals(ASSOCIATION_OF_PERSON)
								&& !DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON) && !DeductorType.equals(BODY_OF_INDIVIDUALS) && !DeductorType.equals(INDIVIDUAL) && !DeductorType.equals(FIRM)
								&& !DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductor  / Collector Type" + tab + tab + tab + T_FV_2076_C + tab + T_FV_2076_M);
							valueCheck = false;
						}
					}
				}

			}
			// END
			// Validating LastDeductorType

			// Validating NameofPersonResponsilbleForSal --------- Must be NULL for C4, C5,
			// Y, X, Z OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!NameofPersonResponsilbleForSal.equals(FIELD_NULL) && !NameofPersonResponsilbleForSal.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2113_C + tab + T_FV_2113_M);
			}

			else if (!(obj_FieldValidation.checkNonSpecialCharacter(NameofPersonResponsilbleForSal)) && batchUpdationIndicatorRequired && Integer.parseInt(FinancialYr) >= 200708)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_6060_C + tab + T_FV_6060_M);

			// ended for FVU 5.0 nik
			else if ((NameofPersonResponsilbleForSal.equals(FIELD_NULL) || NameofPersonResponsilbleForSal.equals(FIELD_SEPERATOR)) && batchUpdationIndicatorRequired) {
				if (paperReturnFile) {
					paperReturnRelax = true;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2079_C + tab + T_FV_2079_M);
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2079_C + tab + T_FV_2079_M);
			} else if (NameofPersonResponsilbleForSal.length() <= 75 && NameofPersonResponsilbleForSal.trim().length() != 0 && batchUpdationIndicatorRequired) {
				if (obj_FieldValidation.isValidCharString(NameofPersonResponsilbleForSal))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2079_C + tab + T_FV_2079_M);

				else if (!(obj_FieldValidation.isValidNameString(NameofPersonResponsilbleForSal))) // added by shruti
																									// for FVU 5.5
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2236_C + tab + T_FV_2236_M);
			} else if (batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2079_C + tab + T_FV_2079_M);

			// Validating NameofPersonResponsilbleForSal
			// Validating DesignationofPersonResponsilbleForSal --------- Must be NULL for
			// C4, C5, Y, X, Z OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!DesignationofPersonResponsilbleForSal.equals(FIELD_NULL) && !DesignationofPersonResponsilbleForSal.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Designation of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2114_C + tab + T_FV_2114_M);
			}

			else if (!(obj_FieldValidation.checkNonSpecialCharacter(DesignationofPersonResponsilbleForSal)) && batchUpdationIndicatorRequired && Integer.parseInt(FinancialYr) >= 200708)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Designation of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_6061_C + tab + T_FV_6061_M);

			else if ((DesignationofPersonResponsilbleForSal.equals(FIELD_NULL) || DesignationofPersonResponsilbleForSal.equals(FIELD_SEPERATOR) || DesignationofPersonResponsilbleForSal.trim().length() == 0)) {
				if (paperReturnFile) {
					paperReturnRelax = true;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2045_C + tab + T_FV_2045_M);
				} else if (batchUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Designation of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2045_C + tab + T_FV_2045_M);
			} else if (DesignationofPersonResponsilbleForSal.length() > 20 && batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Designation of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2045_C + tab + T_FV_2045_M);
			else if (DesignationofPersonResponsilbleForSal.trim().length() == 0) {
				if (paperReturnFile) {
					paperReturnRelax = true;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2045_C + tab + T_FV_2045_M);
				} else if (batchUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Designation of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2045_C + tab + T_FV_2045_M);
			} else if (obj_FieldValidation.isValidCharString(DesignationofPersonResponsilbleForSal) && batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Designation of Person responsible for paying salary / Deduction / Collection" + tab + tab + tab + T_FV_2045_C + tab + T_FV_2045_M);
			// added for FVU 5.0 nik 9

			// ended for FVU 5.0 nik
			// Validating DesignationofPersonResponsilbleForSal
			// Validating PersonResponsilbleAddr1 --------- Must be NULL for C4, C5, Y, X, Z
			// OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleAddr1.equals(FIELD_NULL) && !PersonResponsilbleAddr1.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Address1" + tab + tab + tab + T_FV_2115_C + tab + T_FV_2115_M);
			}
			// added for FVU 5.0 nik 10

			else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(PersonResponsilbleAddr1)) && Integer.parseInt(FinancialYr) >= 200708 && batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address1" + tab + tab + tab + T_FV_6062_C + tab + T_FV_6062_M);

			else if ((PersonResponsilbleAddr1.equals(FIELD_NULL) || PersonResponsilbleAddr1.equals(FIELD_SEPERATOR) || PersonResponsilbleAddr1.trim().length() == 0)) {
				if (paperReturnFile) {
					paperReturnRelax = true;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2080_C + tab + T_FV_2080_M);
				}

				else if (batchUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address1" + tab + tab + tab + T_FV_2080_C + tab + T_FV_2080_M);

			} else if (PersonResponsilbleAddr1.length() > 25)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address1" + tab + tab + tab + T_FV_2046_C + tab + T_FV_2046_M);
			else if (obj_FieldValidation.isValidCharString_new(PersonResponsilbleAddr1))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address1" + tab + tab + tab + T_FV_2046_C + tab + T_FV_2046_M);

			// ended for FVU 5.0 nik
			// Validating PersonResponsilbleAddr1
			// Validating PersonResponsilbleAddr2 --------- Must be NULL for C4, C5, Y, X, Z
			// OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleAddr2.equals(FIELD_NULL) && !PersonResponsilbleAddr2.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address2" + tab + tab + tab + T_FV_2116_C + tab + T_FV_2116_M);
			} else if (!PersonResponsilbleAddr2.equals(FIELD_NULL) && !PersonResponsilbleAddr2.equals(FIELD_SEPERATOR)) {
				if (PersonResponsilbleAddr2.length() > 25)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address2" + tab + tab + tab + T_FV_2047_C + tab + T_FV_2047_M);
				else if (obj_FieldValidation.isValidCharString_new(PersonResponsilbleAddr2))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address2" + tab + tab + tab + T_FV_2047_C + tab + T_FV_2047_M);
				// added for FVU 5.0 nik 11

				else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(PersonResponsilbleAddr2)) && Integer.parseInt(FinancialYr) >= 200708)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address2" + tab + tab + tab + T_FV_6063_C + tab + T_FV_6063_M);

				// ended for FVU 5.0 nik
			}

			// Validating PersonResponsilbleAddr2
			// Validating PersonResponsilbleAddr3 --------- Must be NULL for C4, C5, Y, X, Z
			// OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleAddr3.equals(FIELD_NULL) && !PersonResponsilbleAddr3.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address3" + tab + tab + tab + T_FV_2117_C + tab + T_FV_2117_M);
			} else if (!PersonResponsilbleAddr3.equals(FIELD_NULL) && !PersonResponsilbleAddr3.equals(FIELD_SEPERATOR)) {
				if (PersonResponsilbleAddr3.length() > 25)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address3" + tab + tab + tab + T_FV_2048_C + tab + T_FV_2048_M);
				else if (obj_FieldValidation.isValidCharString_new(PersonResponsilbleAddr3))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address3" + tab + tab + tab + T_FV_2048_C + tab + T_FV_2048_M);
				// added for FVU 5.0 nik 12

				else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(PersonResponsilbleAddr3)) && Integer.parseInt(FinancialYr) >= 200708)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address3" + tab + tab + tab + T_FV_6064_C + tab + T_FV_6064_M);

				// ended for FVU 5.0 nik
			}

			// Validating PersonResponsilbleAddr3
			// Validating PersonResponsilbleAddr4 --------- Must be NULL for C4, C5, Y, X, Z
			// OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleAddr4.equals(FIELD_NULL) && !PersonResponsilbleAddr4.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address4" + tab + tab + tab + T_FV_2118_C + tab + T_FV_2118_M);
			} else if (!PersonResponsilbleAddr4.equals(FIELD_NULL) && !PersonResponsilbleAddr4.equals(FIELD_SEPERATOR)) {
				if (PersonResponsilbleAddr4.length() > 25)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address4" + tab + tab + tab + T_FV_2049_C + tab + T_FV_2049_M);
				else if (obj_FieldValidation.isValidCharString_new(PersonResponsilbleAddr4))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address4" + tab + tab + tab + T_FV_2049_C + tab + T_FV_2049_M);
				// added for FVU 5.0 nik 13

				else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(PersonResponsilbleAddr4)) && Integer.parseInt(FinancialYr) >= 200708)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address4" + tab + tab + tab + T_FV_6065_C + tab + T_FV_6065_M);

				// ended for FVU 5.0 nik
			}

			// Validating PersonResponsilbleAddr4
			// Validating PersonResponsilbleAddr5 --------- Must be NULL for C4, C5, Y, X, Z
			// OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleAddr5.equals(FIELD_NULL) && !PersonResponsilbleAddr5.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address5" + tab + tab + tab + T_FV_2119_C + tab + T_FV_2119_M);
			} else if (!PersonResponsilbleAddr5.equals(FIELD_NULL) && !PersonResponsilbleAddr5.equals(FIELD_SEPERATOR)) {
				if (PersonResponsilbleAddr5.length() > 25)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address5" + tab + tab + tab + T_FV_2050_C + tab + T_FV_2050_M);
				else if (obj_FieldValidation.isValidCharString_new(PersonResponsilbleAddr5))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address5" + tab + tab + tab + T_FV_2050_C + tab + T_FV_2050_M);
				// added for FVU 5.0 nik 14

				else if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(PersonResponsilbleAddr5)) && Integer.parseInt(FinancialYr) >= 200708)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's  Address5" + tab + tab + tab + T_FV_6066_C + tab + T_FV_6066_M);

				// ended for FVU 5.0 nik
			}

			// Validating PersonResponsilbleAddr5
			// Validating PersonResponsilbleState --------- Must be NULL for C4, C5, Y, X, Z
			// OR If Batch Updation Indicator is '0'
			//CR #65617 START
			if(batchUpdationIndicatorRequired && !PersonResponsilbleState.equals(FIELD_NULL) && !PersonResponsilbleState.equals(FIELD_SEPERATOR) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))) {
				if (obj_FieldValidation.isInt(PersonResponsilbleState))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
			}
			//CR #65617 END
			
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleState.equals(FIELD_NULL) && !PersonResponsilbleState.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2120_C + tab + T_FV_2120_M);
			
			// Redmine no #74898 Bug Fix  // Obs no 05 FVU 7.1 09 Mar 2021 - Vinita
				if ( !(PersonResponsilbleState.equals(FIELD_NULL) || PersonResponsilbleState.equals(FIELD_SEPERATOR)) && PersonResponsilbleState.length() <= 2) {
					if (obj_FieldValidation.isInt(PersonResponsilbleState) && batchUpdationIndicatorRequired)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
					else if (!paperReturnFile && batchUpdationIndicatorRequired) {
						if (!(Integer.parseInt(PersonResponsilbleState.trim()) > 0 && Integer.parseInt(PersonResponsilbleState.trim()) < 38 && Integer.parseInt(PersonResponsilbleState.trim()) != 8) && (Integer.parseInt(PersonResponsilbleState.trim()) != 99)) // Changed for FVU 4.3//Changed
																																																			// for FVU 6.4 ladakh //Changes for FVU 7.0 - Vinita (08 code removed)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
					} else if (paperReturnFile) {
						if (PersonResponsilbleState.equals("00")) {
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
						} else if (!(Integer.parseInt(PersonResponsilbleState.trim()) > 0 && Integer.parseInt(PersonResponsilbleState.trim()) < 38 && Integer.parseInt(PersonResponsilbleState.trim()) != 8) && (Integer.parseInt(PersonResponsilbleState.trim()) != 99) && batchUpdationIndicatorRequired) // Changed
																																																													// for FVU
																																																													// 4.3//Changed for FVU 6.4 ladakh //Changes for FVU 7.0 - Vinita (08 code removed)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
					}
				}
			// Redmine no #74898 Bug Fix
			
			} else if ((PersonResponsilbleState.equals(FIELD_NULL) || PersonResponsilbleState.equals(FIELD_SEPERATOR)) && batchUpdationIndicatorRequired) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2086_C + tab + T_FV_2086_M);
			} else if (PersonResponsilbleState.length() <= 2) {
				if (obj_FieldValidation.isInt(PersonResponsilbleState) && batchUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
				else if (!paperReturnFile && batchUpdationIndicatorRequired) {
					if (!(Integer.parseInt(PersonResponsilbleState.trim()) > 0 && Integer.parseInt(PersonResponsilbleState.trim()) < 38 && Integer.parseInt(PersonResponsilbleState.trim()) != 8) && (Integer.parseInt(PersonResponsilbleState.trim()) != 99)) // Changed for FVU 4.3//Changed
																																																		// for FVU 6.4 ladakh //Changes for FVU 7.0 - Vinita (08 code removed)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
				} else if (paperReturnFile) {
					if (PersonResponsilbleState.equals("00")) {
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
					} else if (!(Integer.parseInt(PersonResponsilbleState.trim()) > 0 && Integer.parseInt(PersonResponsilbleState.trim()) < 38 && Integer.parseInt(PersonResponsilbleState.trim()) != 8) && (Integer.parseInt(PersonResponsilbleState.trim()) != 99) && batchUpdationIndicatorRequired) // Changed
																																																												// for FVU
																																																												// 4.3//Changed for FVU 6.4 ladakh //Changes for FVU 7.0 - Vinita (08 code removed)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
				}
			} else if (batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's State" + tab + tab + tab + T_FV_2051_C + tab + T_FV_2051_M);
			// Validating PersonResponsilbleState
			// Validating PersonResponsilblePin --------- Must be NULL for C4, C5, Y, X, Z
			// OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilblePin.equals(FIELD_NULL) && !PersonResponsilblePin.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's PIN" + tab + tab + tab + T_FV_2121_C + tab + T_FV_2121_M);
			} else if (PersonResponsilblePin.equals(FIELD_NULL) || PersonResponsilblePin.equals(FIELD_SEPERATOR)) {
				if (paperReturnFile) {
					paperReturnRelax = true;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2088_C + tab + T_FV_2088_M);
				} else if (batchUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's PIN" + tab + tab + tab + T_FV_2088_C + tab + T_FV_2088_M);
			} else if (PersonResponsilblePin.length() == 6 && PersonResponsilblePin.trim().length() == 6) {
				if (obj_FieldValidation.isInt(PersonResponsilblePin)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's PIN" + tab + tab + tab + T_FV_2052_C + tab + T_FV_2052_M);
				} else if (Integer.parseInt(PersonResponsilblePin) < 110001) {
					if (paperReturnFile && Integer.parseInt(PersonResponsilblePin) < 110001 && Integer.parseInt(PersonResponsilblePin) >= 000000) {
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2052_C + tab + T_FV_2052_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's PIN" + tab + tab + tab + T_FV_2052_C + tab + T_FV_2052_M);
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's PIN" + tab + tab + tab + T_FV_2052_C + tab + T_FV_2052_M);
			// Validating PersonResponsilblePin
			// validating PersonResponsilbleEmailId1 --------- Must be NULL for C4, C5, Y,
			// X, Z OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleEmailId1.equals(FIELD_NULL) && !PersonResponsilbleEmailId1.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id of responsible person" + tab + tab + tab + T_FV_2122_C + tab + T_FV_2122_M);
			} else if (!PersonResponsilbleEmailId1.equals(FIELD_NULL) && !PersonResponsilbleEmailId1.equals(FIELD_SEPERATOR)) {
				if (PersonResponsilbleEmailId1.length() <= 75) {
					// Changes For FVU 3.0
					if (PersonResponsilbleEmailId1.length() != PersonResponsilbleEmailId1.trim().length())
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id of responsible person" + tab + tab + tab + T_FV_2053_C + tab + T_FV_2053_M);

					else if (obj_FieldValidation.isValidEmail(PersonResponsilbleEmailId1)) {
						if (paperReturnFile) {
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2053_C + tab + T_FV_2053_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id of responsible person" + tab + tab + tab + T_FV_2053_C + tab + T_FV_2053_M);
					} else if (!valueForEmailId)
						valueForEmailId = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id of responsible person" + tab + tab + tab + T_FV_2053_C + tab + T_FV_2053_M);
			}
			// added for FVU 5.0 nik 15
			else if ((PersonResponsilbleEmailId1.equals(FIELD_NULL) || PersonResponsilbleEmailId1.equals(FIELD_SEPERATOR)) && (EmployerEmail.equals(FIELD_NULL) || EmployerEmail.equals(FIELD_SEPERATOR))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "E-mail id for Deductor or responsible person" + tab + tab + tab + T_FV_6067_C + tab + T_FV_6067_M);
			}
			// ended for FVU 5.0 nik
			// validating PersonResponsilbleEmailId1
			/*
			 * Validations for Remark Field is commented By AMI For FVU 3.0 // validating
			 * remark --------- Must be NULL for C4, C5, Y, X, Z OR If Batch Updation
			 * Indicator is '0' if ((BatchUpdationIndicator.equals("0") ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) ||
			 * TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) ||
			 * TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) ) { if
			 * (!remark.equals(FIELD_NULL) && !remark.equals(FIELD_SEPERATOR))
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remark" + tab +
			 * tab + tab + T_FV_2123_C + tab + T_FV_2123_M); } else if
			 * (!remark.equals(FIELD_NULL) && !remark.equals(FIELD_SEPERATOR)) { if
			 * (remark.length() <= 75) { if (obj_FieldValidation.isValidCharString(remark))
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remark" + tab +
			 * tab + tab + T_FV_2054_C + tab + T_FV_2054_M); } else Str_Buffer.append(LineNo
			 * + tab + currentUploadType + tab + "Remark" + tab + tab + tab + T_FV_2054_C +
			 * tab + T_FV_2054_M); } // validating remark
			 */
			// Validations For mobileNumber For FVU 3.0
			// Mobile Number --------- Must be NULL for C4, C5, Y, X, Z OR If Batch Updation
			// Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)))

			{
				if (!mobileNumber.equals(FIELD_NULL) && !mobileNumber.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_2201_C + tab + T_FV_2201_M);
			}
			// M05_B added and later commented by Dhanya as the requirement is changed.
			/*
			 * else if ( (DeductorType.equals(STATE_GOVERNMENT)||
			 * DeductorType.equals(CENTRAL_GOVERNMENT)) && (!mobileNumber.equals(FIELD_NULL)
			 * && !mobileNumber.equals(FIELD_SEPERATOR))) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab +
			 * tab + T_FV_2216_C + tab + T_FV_2216_M); }
			 */
			// M05_B
			// Mobile No should be provided for deductor type OTHER THAN 'STATE' and
			// 'CENTRAL Govt' .
			else if (!DeductorType.equals(STATE_GOVERNMENT) && !DeductorType.equals(CENTRAL_GOVERNMENT) && (mobileNumber.equals(FIELD_NULL) || mobileNumber.equals(FIELD_SEPERATOR))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_2217_C + tab + T_FV_2217_M);
			}
			// M05_E
			else if (!mobileNumber.equals(FIELD_NULL) && !mobileNumber.equals(FIELD_SEPERATOR)) {
				// Added For FVU 3.0
				valueForMobileNoProvided = true;
				int count = 0;
				// Added By amit for FVU 4.5 To check whether the mobile number contains all
				// same digit 1111111111
				if (mobileNumber.trim().length() == 10) {
					for (int i = 1; i < 10; i++) {
						String val = Integer.toString(i);
						for (int j = 0; j < 9; j++) {
							val = val + Integer.toString(i);

						}
						if (mobileNumber.trim().equals(val)) {

							count++;
							break;
						}

					}

					if (obj_FieldValidation.isInt(mobileNumber))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_2202_C + tab + T_FV_2202_M);
					// Added By amit for hanlde space for fvu 4.5
					else if (!(mobileNumber.trim().length() == mobileNumber.length())) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_2202_C + tab + T_FV_2202_M);
					}

					else if (count == 1) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_2202_C + tab + T_FV_2202_M);

					}

					// Amit end for fvu 4.5
					// Added For FVU 3.0
					else if (mobileNumber.charAt(0) == '0')
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_2202_C + tab + T_FV_2202_M);
					else if (mobileNumber.trim() == "000000000" || mobileNumber.trim() == "9999999999") // Changed by
																										// Abhishek from
																										// int to long
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_2202_C + tab + T_FV_2202_M);
					else
						valueForMobileNo = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_2202_C + tab + T_FV_2202_M);
			}
			// added for FVU 5.0 nik 16
			else if (UploadType.equals(UPLOADTYPE_REGULAR) && (mobileNumber.equals(FIELD_NULL) || mobileNumber.equals(FIELD_SEPERATOR))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Mobile Number" + tab + tab + tab + T_FV_6068_C + tab + T_FV_6068_M);
			}
			// ended for FVU 5.0 nik
			// mobileNumber Validations END

			// validating PersonResponsilbleSTDCode --------- Must be NULL for C4, C5, Y, X,
			// Z OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleSTDCode.equals(FIELD_NULL) && !PersonResponsilbleSTDCode.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of responsible person" + tab + tab + tab + T_FV_2124_C + tab + T_FV_2124_M);
			} else if (!PersonResponsilbleSTDCode.equals(FIELD_NULL) && !PersonResponsilbleSTDCode.equals(FIELD_SEPERATOR)) {
				// Added For FVU 3.0

				valueForResPersnStdCodeProvided = true;

				if (PersonResponsilbleSTDCode.length() <= 5) {
					// Changes For FVU 3.0
					if (PersonResponsilbleSTDCode.length() != PersonResponsilbleSTDCode.trim().length())
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of responsible person" + tab + tab + tab + T_FV_2055_C + tab + T_FV_2055_M);
					else if (obj_FieldValidation.isInt(PersonResponsilbleSTDCode))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of responsible person" + tab + tab + tab + T_FV_2055_C + tab + T_FV_2055_M);
					// Added For FVU 3.0
					else if (Integer.parseInt(PersonResponsilbleSTDCode) == 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of responsible person" + tab + tab + tab + T_FV_2055_C + tab + T_FV_2055_M);
					else if (!valueForResPersnStdCode)
						valueForResPersnStdCode = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of responsible person" + tab + tab + tab + T_FV_2055_C + tab + T_FV_2055_M);
			} // validating PersonResponsilbleSTDCode
				// validating PersonResponsilbleTelePhoneNo --------- Must be NULL for C4, C5,
				// Y, X, Z OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!PersonResponsilbleTelePhone.equals(FIELD_NULL) && !PersonResponsilbleTelePhone.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of responsible person." + tab + tab + tab + T_FV_2074_C + tab + T_FV_2074_M);
			} else if (!PersonResponsilbleTelePhone.equals(FIELD_NULL) && !PersonResponsilbleTelePhone.equals(FIELD_SEPERATOR)) {
				// Added For FVU 3.0
				valueForResPersnPhoneNoProvided = true;

				if (PersonResponsilbleTelePhone.length() <= 10) {
					// Changes For FVU 3.0
					if (PersonResponsilbleTelePhone.length() != PersonResponsilbleTelePhone.trim().length())
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of responsible person." + tab + tab + tab + T_FV_2056_C + tab + T_FV_2056_M);
					else if (obj_FieldValidation.isInt(PersonResponsilbleTelePhone))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of responsible person." + tab + tab + tab + T_FV_2056_C + tab + T_FV_2056_M);
					// Added For FVU 3.0
					else if (Long.parseLong(PersonResponsilbleTelePhone) == 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of responsible person." + tab + tab + tab + T_FV_2056_C + tab + T_FV_2056_M);
					else if (!valueForResPersnPhoneNo)
						valueForResPersnPhoneNo = true;

				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of responsible person." + tab + tab + tab + T_FV_2056_C + tab + T_FV_2056_M);
			} // validating PersonResponsilbleTelePhoneNo

			// Validations Added For FVU 3.0
			// Either Employer's Phone Number with STD code or Person Responsible's Phone
			// Number with STD code or Mobile Number should be provided.
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)))
				validationToBePerform = false;

			if (validationToBePerform) {
				// if(!(valueForMobileNo || (valueForStdCode && valueForPhoneNo) ||
				// (valueForResPersnStdCode && valueForResPersnPhoneNo)))
				// Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Contact Number" +
				// tab + tab + tab + T_FV_2203_C + tab + T_FV_2203_M);
				if (!valueForMobileNoProvided && !valueForPhoneNoProvided && !valueForResPersnPhoneNoProvided && !valueForResPersnStdCodeProvided && !valueForStdCodeProvided)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Contact Number" + tab + tab + tab + T_FV_2203_C + tab + T_FV_2203_M);
				// Added by Abhishek for provided ph num if std code is provided or vice versa
				if (valueForResPersnStdCode == true && (PersonResponsilbleTelePhone.trim().equals(FIELD_NULL) || PersonResponsilbleTelePhone.trim().equals(FIELD_SEPERATOR)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of responsible person." + tab + tab + tab + T_FV_2209_C + tab + T_FV_2209_M);
				else if (valueForResPersnPhoneNo == true && (PersonResponsilbleSTDCode.equals(FIELD_NULL) || PersonResponsilbleSTDCode.equals(FIELD_SEPERATOR)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code  of responsible person." + tab + tab + tab + T_FV_2210_C + tab + T_FV_2210_M);

				if (valueForStdCode == true && (EmployerPhone.trim().equals(FIELD_NULL) || EmployerPhone.trim().equals(FIELD_SEPERATOR)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Telephone no. of deductor/collector." + tab + tab + tab + T_FV_2212_C + tab + T_FV_2212_M);
				else if (valueForPhoneNo == true && (EmployerSTD.trim().equals(FIELD_NULL) || EmployerSTD.trim().equals(FIELD_SEPERATOR)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "STD code of deductor/collector." + tab + tab + tab + T_FV_2213_C + tab + T_FV_2213_M);
				// End by Abhishek

				// Email Id of Person Responsible or Employer should be provided.
				if (!valueForEmailId)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Email ID" + tab + tab + tab + T_FV_2204_C + tab + T_FV_2204_M);
			}
			// Validating PersonResponsilbleAddrChange --------- Must be NULL for C4, C5, Y,
			// X, Z OR If Batch Updation Indicator is '0'
			if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
					|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
					|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || paperReturnFile)) {
				if (!PersonResponsilbleAddrChange.equals(FIELD_NULL) && !PersonResponsilbleAddrChange.equals(FIELD_SEPERATOR)) {
					if (paperReturnFile) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Responsible person since last Return" + tab + tab + tab + T_FV_2072_C + tab + T_FV_2072_M);
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Responsible person since last Return" + tab + tab + tab + T_FV_2075_C + tab + T_FV_2075_M);
					}
				}
			} else if ((PersonResponsilbleAddrChange.equals(FIELD_NULL) || PersonResponsilbleAddrChange.equals(FIELD_SEPERATOR)) && batchUpdationIndicatorRequired) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Responsible person since last Return" + tab + tab + tab + T_FV_2094_C + tab + T_FV_2094_M);
			} else if (((PersonResponsilbleAddrChange.length() != 1) || (PersonResponsilbleAddrChange.trim().length() != 1) || !(Character.isLetter(PersonResponsilbleAddrChange.charAt(0)))
					|| !(Character.isUpperCase(PersonResponsilbleAddrChange.charAt(0)))) && batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Responsible person since last Return" + tab + tab + tab + T_FV_2057_C + tab + T_FV_2057_M);
			else if (!(PersonResponsilbleAddrChange.equals("Y")) && !(PersonResponsilbleAddrChange.equals("N")) && batchUpdationIndicatorRequired)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Change of Address of Responsible person since last Return" + tab + tab + tab + T_FV_2057_C + tab + T_FV_2057_M);
			// Validating PersonResponsilbleAddrChange
			// Validating GrossTDSTotalAsPerChallan
			if (GrossTDSTotalAsPerChallan.equals(FIELD_NULL) || GrossTDSTotalAsPerChallan.equals(FIELD_SEPERATOR)) {
				if (UploadTypeBH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)
						|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Total of Deposit Amount as per Challan" + tab + tab + tab + T_FV_2096_C + tab + T_FV_2096_M);
				else
					statisticFileStrBuff.append("-" + statDataDelemiter); // Adding data for Statistic File
			} else {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
						|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Total of Deposit Amount as per Challan" + tab + tab + tab + T_FV_2134_C + tab + T_FV_2134_M);
				// added by faizan for FVU 4.5
				else if (GrossTDSTotalAsPerChallan.length() != GrossTDSTotalAsPerChallan.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Total of Deposit Amount as per Challan" + tab + tab + tab + T_FV_2096_C + tab + T_FV_2096_M);

				}
				// ended by faizan
				else if (GrossTDSTotalAsPerChallan.length() <= 15) {
					if (obj_FieldValidation.isDecimalNumber(GrossTDSTotalAsPerChallan))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Total of Deposit Amount as per Challan" + tab + tab + tab + T_FV_2096_C + tab + T_FV_2096_M);
					else if (!GrossTDSTotalAsPerChallan.trim().endsWith(".00")) {
						if (paperReturnFile) {
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2096_C + tab + T_FV_2096_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Total of Deposit Amount as per Challan" + tab + tab + tab + T_FV_2096_C + tab + T_FV_2096_M);
					} else
						statisticFileStrBuff.append(obj_FieldValidation.changeNumberFormat(Double.parseDouble(GrossTDSTotalAsPerChallan.trim())) + statDataDelemiter);
					// Adding data for Statistic File
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Total of Deposit Amount as per Challan" + tab + tab + tab + T_FV_2096_C + tab + T_FV_2096_M);
			} // Validating GrossTDSTotalAsPerChallan
				// Commented By AMI For FVU 3.0
				// Validating TdsCircle --------- Must be NULL for C4, C5, Y, X, Z OR If Batch
				// Updation Indicator is '0'
			/*
			 * if (TdsCircle.equals(FIELD_NULL) || TdsCircle.equals(FIELD_SEPERATOR)) { }
			 * else { if (!FormNo.equals(FORM_24Q)) Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab +
			 * "TDS Circle where annual return / statement under section 206 is to be filed"
			 * + tab + tab + tab + T_FV_2128_C + tab + T_FV_2128_M); else if (
			 * (BatchUpdationIndicator.equals("0") ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) ||
			 * TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) ||
			 * TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) ) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "TDS Circle where annual return / statement under section 206 is to be filed"
			 * + tab + tab + tab + T_FV_2125_C + tab + T_FV_2125_M); } else if
			 * (TdsCircle.length() > 50) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab +
			 * "TDS Circle where annual return / statement under section 206 is to be filed"
			 * + tab + tab + tab + T_FV_2031_C + tab + T_FV_2031_M); } else if
			 * (obj_FieldValidation.isValidCharString(TdsCircle)) Str_Buffer.append(LineNo +
			 * tab + currentUploadType + tab +
			 * "TDS Circle where annual return / statement under section 206 is to be filed"
			 * + tab + tab + tab + T_FV_2031_C + tab + T_FV_2031_M); } // Validating
			 * TdsCircle
			 */

			// Added For FVU 3.0 Raw File Unmatched ChallanCount
			if (unMatchedChalanCnt.equals(FIELD_NULL) || unMatchedChalanCnt.equals(FIELD_SEPERATOR)) {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
					receiptUnmatchedChalanCnt = "NA";
				else
					receiptUnmatchedChalanCnt = "-";
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH)) // Added for FVU 4.2
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Unmatched Challan Count" + tab + tab + tab + T_FV_2205_C + tab + T_FV_2205_M);
			} else
				receiptUnmatchedChalanCnt = unMatchedChalanCnt;

			// Validating CountOfSalaryDetailRec
			boolean CountOfSalaryDetailRecFlag = false;
			if (CountOfSalaryDetailRec.equals(FIELD_NULL) || CountOfSalaryDetailRec.equals(FIELD_SEPERATOR)) {
				if ((FormNo.equals(FORM_24Q) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY)))
						|| (UploadTypeBH.equals(UPLOADTYPE_REGULAR) && FormNo.equals(FORM_24Q)) && (FileType.equals(FILETYPE_SALARY_DIGITAL) || FileType.equals(FILETYPE_SALARY_ELECTRONIC)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Count of Salary Details  Records" + tab + tab + tab + T_FV_2127_C + tab + T_FV_2127_M);
				else
					statisticFileStrBuff.append("-" + statDataDelemiter); // Adding data for Statistic File
			} else {
				if (!FormNo.equals(FORM_24Q))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Count of Salary Details  Records" + tab + tab + tab + T_FV_2140_C + tab + T_FV_2140_M);
				else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)
						|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)
						|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && (FileType.equals(FILETYPE_SALARY_DIGITAL) && FileType.equals(FILETYPE_SALARY_ELECTRONIC))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Count of Salary Details  Records" + tab + tab + tab + T_FV_2135_C + tab + T_FV_2135_M);
				} else if (CountOfSalaryDetailRec.length() <= 9 && (FileType.equals(FILETYPE_SALARY_DIGITAL) || FileType.equals(FILETYPE_SALARY_ELECTRONIC))) {
					if (obj_FieldValidation.isInt(CountOfSalaryDetailRec)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Count of Salary Details  Records" + tab + tab + tab + T_FV_2127_C + tab + T_FV_2127_M);
					} // Following Check added-- Not to allow 24Q , Q1,Q2,Q3 returns in which SD count
						// is greater than zero
					else if (invalidSalaryDetailFlag && Long.parseLong(CountOfSalaryDetailRec.trim()) != 0) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Count of Salary Details Records" + tab + tab + tab + T_FV_2142_C + tab + T_FV_2142_M);
					} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && bhChallanCountZero) {
						if (Long.parseLong(CountOfSalaryDetailRec.trim()) < 1) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Count of Salary Details  Records" + tab + tab + tab + T_FV_2151_C + tab + T_FV_2151_M);
						} else
							CountOfSalaryDetailRecFlag = true;
					} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY)) {
						if (Long.parseLong(CountOfSalaryDetailRec.trim()) < 1) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Count of Salary Details  Records" + tab + tab + tab + T_FV_2138_C + tab + T_FV_2138_M);
						} else
							CountOfSalaryDetailRecFlag = true;
					} // Following Check added-- Not to allow 24Q , Q4 returns in which SD count is
						// zero and return in non nil
					else if (FormNo.equals(FORM_24Q) && Qperiod.equals("Q4") && UploadTypeBH.equals(UPLOADTYPE_REGULAR) && Double.parseDouble(GrossTDSTotalAsPerChallan.trim()) != 0) {
						if (Long.parseLong(CountOfSalaryDetailRec.trim()) < 1) {
							if (paperReturnFile) {
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + tab + tab + T_FV_2133_C + tab + T_FV_2133_M);
								paperReturnRelax = true;
							} else
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2133_C + tab + T_FV_2133_M);
						} else
							CountOfSalaryDetailRecFlag = true;
					} else
						CountOfSalaryDetailRecFlag = true; // Adding data for Statistic File
					if (CountOfSalaryDetailRecFlag) {
						statisticFileStrBuff.append(Long.toString(Long.parseLong(CountOfSalaryDetailRec.trim())) + statDataDelemiter);
						receiptSDCountForC5 = Long.toString(Long.parseLong(CountOfSalaryDetailRec.trim()));
						noOfSDGFI = Long.toString(Long.parseLong(CountOfSalaryDetailRec.trim()));
					}

				} else {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Count of Salary Details  Records" + tab + tab + tab + T_FV_2127_C + tab + T_FV_2127_M);
				}
			} // Validating CountOfSalaryDetailRec
				// Validating GrossTotalIncomeSD
			if (GrossTotalIncomeSD.equals(FIELD_NULL) || GrossTotalIncomeSD.equals(FIELD_SEPERATOR)) {
				if ((FormNo.equals(FORM_24Q) && Qperiod.equals("Q4") && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY)))
						|| (UploadTypeBH.equals(UPLOADTYPE_REGULAR) && FormNo.equals(FORM_24Q) && Qperiod.equals("Q4")) && (FileType.equals(FILETYPE_SALARY_DIGITAL) || FileType.equals(FILETYPE_SALARY_ELECTRONIC)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Gross Total Income as per Salary Detail" + tab + tab + tab + T_FV_2089_C + tab + T_FV_2089_M);
				else
					statisticFileStrBuff.append("-" + statDataDelemiter);
			} else {
				// added by faizan for fvu 4.5
				if (!(FormNo.equals(FORM_24Q) && Qperiod.equals("Q4"))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Gross Total Income as per Salary Detail" + tab + tab + tab + T_FV_2090_C + tab + T_FV_2090_M);
				} else if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) && !UploadTypeBH.equals(UPLOADTYPE_REGULAR)) {
					if (!(GrossTotalIncomeSD.equals(FIELD_NULL) || GrossTotalIncomeSD.equals(FIELD_SEPERATOR)))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Gross Total Income as per Salary Detail" + tab + tab + tab + T_FV_2091_C + tab + T_FV_2091_M);
				}
				// ended by faizan
				else if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC)
						|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)
						|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && (FileType.equals(FILETYPE_SALARY_DIGITAL) && FileType.equals(FILETYPE_SALARY_ELECTRONIC)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Gross Total Income as per Salary Detail" + tab + tab + tab + T_FV_2091_C + tab + T_FV_2091_M);
				// Added By amit for fvu 4.5
				else if (GrossTotalIncomeSD.length() != GrossTotalIncomeSD.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Gross Total Income as per Salary Detail" + tab + tab + tab + T_FV_2089_C + tab + T_FV_2089_M);

				}

				// Amit end fro fvu 4.5
				else if (GrossTotalIncomeSD.length() <= 15 && (FileType.equals(FILETYPE_SALARY_DIGITAL) || FileType.equals(FILETYPE_SALARY_ELECTRONIC))) {
					if (obj_FieldValidation.isDecimalNumber(GrossTotalIncomeSD))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Gross Total Income as per Salary Detail" + tab + tab + tab + T_FV_2089_C + tab + T_FV_2089_M);
					else if (CountOfSalaryDetailRecFlag) {
						if ((Long.parseLong(CountOfSalaryDetailRec.trim()) == 0) && (Double.parseDouble(GrossTotalIncomeSD.trim()) != 0)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Gross Total Income as per Salary Detail" + tab + tab + tab + T_FV_2093_C + tab + T_FV_2093_M);
						} else
							statisticFileStrBuff.append(obj_FieldValidation.changeNumberFormat(Double.parseDouble(GrossTotalIncomeSD.trim())) + statDataDelemiter);
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Total of - Gross Total Income as per Salary Detail" + tab + tab + tab + T_FV_2089_C + tab + T_FV_2089_M);
			} // Validating GrossTotalIncomeSD
				// Validating ApprovalTaken
			if (ApprovalTaken.equals(FIELD_NULL) || ApprovalTaken.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "AO Approval " + tab + tab + tab + T_FV_2152_C + tab + T_FV_2152_M);
			} else if (!ApprovalTaken.equals(APPROVAL_YES) && !ApprovalTaken.equals(APPROVAL_NO)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "AO Approval " + tab + tab + tab + T_FV_2152_C + tab + T_FV_2152_M);
			}
			// added by faizan for fvu 4.5
			else if (!ApprovalTaken.equals(APPROVAL_NO)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "AO Approval " + tab + tab + tab + T_FV_2152_C + tab + T_FV_2152_M);
			}
			// ended by faizan
			else
				samScmData.append(ApprovalTaken + "^"); // Validating ApprovalTaken
			// Validating ApprovalNo
			/*
			 * if (ApprovalNo.equals(FIELD_NULL) || ApprovalNo.equals(FIELD_SEPERATOR)) { if
			 * (ApprovalTaken.equals(APPROVAL_YES)) Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "AO Approval Number " + tab + tab + tab +
			 * T_FV_2153_C + tab + T_FV_2153_M); else samScmData.append("-" + "^"); } else
			 * if ((ApprovalNo.trim().length() == 0) || (ApprovalNo.length() > 15)) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "AO Approval Number " + tab + tab + tab + T_FV_2154_C + tab + T_FV_2154_M); }
			 * else if (ApprovalTaken.equals(APPROVAL_NO)) { Str_Buffer.append(LineNo + tab
			 * + currentUploadType + tab + "AO Approval Number " + tab + tab + tab +
			 * T_FV_2155_C + tab + T_FV_2155_M); } else samScmData.append(ApprovalNo + "^");
			 */
			// Validating ApprovalNo
			// }
			// CHANGE AMI
			// Added for FVU 4.0
			// Validating ApprovalNo(flag for previous rrr)

			if (ApprovalNo.equals(FIELD_NULL) || ApprovalNo.equals(FIELD_SEPERATOR)) {
				if (UploadType.equals(UPLOADTYPE_REGULAR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Has regular statement filed earlier" + tab + tab + tab + T_FV_2231_C + tab + T_FV_2231_M);
			} else {
				if (!UploadType.equals(UPLOADTYPE_REGULAR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Has regular statement filed earlier" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
				} else if (ApprovalNo.trim().length() != 1) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Has regular statement filed earlier" + tab + tab + tab + T_FV_2231_C + tab + T_FV_2231_M);
				} else if (!(ApprovalNo.trim().length() == ApprovalNo.length())) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Has regular statement filed earlier" + tab + tab + tab + T_FV_2231_C + tab + T_FV_2231_M);
				} else if (!ApprovalNo.trim().equals("Y") && !ApprovalNo.trim().equals("N")) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Has regular statement filed earlier" + tab + tab + tab + T_FV_2231_C + tab + T_FV_2231_M);
				} else if (ApprovalNo.trim().equals("N") && !PreviousRRRNo.equals(FIELD_NULL) && !PreviousRRRNo.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt No. of earlier regular statement filed" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
				} else if (ApprovalNo.trim().equals("Y") && (PreviousRRRNo.equals(FIELD_NULL) || PreviousRRRNo.equals(FIELD_SEPERATOR))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt No. of earlier regular statement filed" + tab + tab + tab + T_FV_2232_C + tab + T_FV_2232_M);
				} else if (ApprovalNo.trim().equals("Y") && !PreviousRRRNo.equals(FIELD_NULL) && !PreviousRRRNo.equals(FIELD_SEPERATOR)) {
					if (PreviousRRRNo.length() == 15) {
						if (obj_FieldValidation.isInt(PreviousRRRNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt No. of earlier regular statement filed" + tab + tab + tab + T_FV_2232_C + tab + T_FV_2232_M);
						else if (obj_FieldValidation.isValidRrrNumber(PreviousRRRNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt No. of earlier regular statement filed" + tab + tab + tab + T_FV_2232_C + tab + T_FV_2232_M);

					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Receipt No. of earlier regular statement filed" + tab + tab + tab + T_FV_2232_C + tab + T_FV_2232_M);
					}
				}
			}
			
			// Validating for flag for previous rrr
			// Validating for Deductor type K,M,P,T,J,B,Q,F
			if (valueCheck) {
				if (DeductorType.equals(COMPANY89) || DeductorType.equals(BRANCH_DIV_COMPANY) || DeductorType.equals(ASSOCIATION_OF_PERSON) || DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON) || DeductorType.equals(BODY_OF_INDIVIDUALS)
						|| DeductorType.equals(INDIVIDUAL) || DeductorType.equals(FIRM) || DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) {
					valueCheck = false;

					if (!(StateName.equals(FIELD_NULL) || StateName.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2167_C + tab + T_FV_2167_M);
					}
					if (!(PAOCode.equals(FIELD_NULL) || PAOCode.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Code" + tab + tab + tab + T_FV_2170_C + tab + T_FV_2170_M);
					}
					if (!(DDOCode.equals(FIELD_NULL) || DDOCode.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Code" + tab + tab + tab + T_FV_2173_C + tab + T_FV_2173_M);
					}
					if (!(MinistryName.equals(FIELD_NULL) || MinistryName.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2176_C + tab + T_FV_2176_M);
					}
					if (!(MinistryNameOther.equals(FIELD_NULL) || MinistryNameOther.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Others" + tab + tab + tab + T_FV_2179_C + tab + T_FV_2179_M);
					}
					if (!(PAORegistrationNo.equals(FIELD_NULL) || PAORegistrationNo.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Registration No" + tab + tab + tab + T_FV_2183_C + tab + T_FV_2183_M);
					}
					if (!(DDORegistrationNo.equals(FIELD_NULL) || DDORegistrationNo.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Registration No" + tab + tab + tab + T_FV_2185_C + tab + T_FV_2185_M);
					}
					if (!(RegistrationId.equals(FIELD_NULL) || RegistrationId.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Registration Number" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
					}
				}
			}
			
			

			// Validating for Deductor type K,M,P,T,J,B,Q,F

			if (!paperReturnFile && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))) {
				if (valueCheck) {
					if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
							|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || paperReturnFile)) {
						if (!StateName.equals(FIELD_NULL) && !StateName.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2187_C + tab + T_FV_2187_M);
						}
						if (!PAOCode.equals(FIELD_NULL) && !PAOCode.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Code" + tab + tab + tab + T_FV_2188_C + tab + T_FV_2188_M);
						}
						if (!DDOCode.equals(FIELD_NULL) && !DDOCode.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Code" + tab + tab + tab + T_FV_2189_C + tab + T_FV_2189_M);
						}
						if (!MinistryName.equals(FIELD_NULL) && !MinistryName.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2190_C + tab + T_FV_2190_M);
						}
						if (!MinistryNameOther.equals(FIELD_NULL) && !MinistryNameOther.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Other" + tab + tab + tab + T_FV_2191_C + tab + T_FV_2191_M);
						}
						if (!PAORegistrationNo.equals(FIELD_NULL) && !PAORegistrationNo.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Registration No" + tab + tab + tab + T_FV_2192_C + tab + T_FV_2192_M);
						}
						if (!DDORegistrationNo.equals(FIELD_NULL) && !DDORegistrationNo.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Registration No" + tab + tab + tab + T_FV_2193_C + tab + T_FV_2193_M);
						}
						if (!RegistrationId.equals(FIELD_NULL) && !RegistrationId.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Registration Number" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
						}
						valueCheck = false;
					}
				}

				// Validating StateName
				// System.out.println("valueCheck"+valueCheck);
				
				//Added for State code issue - Vinita Redmine 74898 // Obs no 05 FVU 7.1 09 Mar 2021 - Vinita
				if (BatchUpdationIndicator.equals("0") && !(StateName.equals(FIELD_NULL) || StateName.equals(FIELD_SEPERATOR)) && StateName.length() <= 2) {
					if (obj_FieldValidation.isInt(StateName))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2169_C + tab + T_FV_2169_M);
					else if (!(Integer.parseInt(StateName.trim()) > 0 && Integer.parseInt(StateName.trim()) < 38 && Integer.parseInt(StateName.trim()) != 8)) // Changed for FVU
																													// 4.3//Changed for FVU 6.4 ladakh //Changes for FVU 7.0 - Vinita (08 code removed)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2169_C + tab + T_FV_2169_M);
				}
				
				//Added for State code issue - Vinita Redmine 74898

				if (valueCheck) {
					if (StateName.trim().length() == 0 && (DeductorType.equals(STATE_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_SG))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2169_C + tab + T_FV_2169_M);
					} else if (!(StateName.equals(FIELD_NULL) || StateName.equals(FIELD_SEPERATOR))
							&& (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(LOCAL_AUTHORITY_CG))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2167_C + tab + T_FV_2167_M);
					} else if ((DeductorType.equals(STATE_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_SG))
							&& (StateName.equals(FIELD_NULL) || StateName.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2168_C + tab + T_FV_2168_M);
					} else if (!StateName.equals(FIELD_NULL) && !StateName.equals(FIELD_SEPERATOR) && StateName.trim().length() != 0 && valueCheck) {
						if (StateName.length() <= 2) {
							if (obj_FieldValidation.isInt(StateName))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2169_C + tab + T_FV_2169_M);
							else if (!(Integer.parseInt(StateName.trim()) > 0 && Integer.parseInt(StateName.trim()) < 38 && Integer.parseInt(StateName.trim()) != 8)) // Changed for FVU
																															// 4.3//Changed for FVU 6.4 ladakh //Changes for FVU 7.0 - Vinita (08 code removed)
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2169_C + tab + T_FV_2169_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "State Name" + tab + tab + tab + T_FV_2169_C + tab + T_FV_2169_M);
					}

					// Validating StateName

					// Validating PAOCODE

					// else if(paperReturnFile && (!StateName.equals(FIELD_NULL) ||
					// !StateName.equals(FIELD_SEPERATOR)))
					// Str_Buffer.append("State Name should not be provided for Paper Returns");

					if ((PAOCode.trim().length() == 0) && (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATE_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG)
							|| DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG) || DeductorType.equals(LOCAL_AUTHORITY_SG))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Code" + tab + tab + tab + T_FV_2172_C + tab + T_FV_2172_M);
					} else if (DeductorType.equals(CENTRAL_GOVERNMENT) && (PAOCode.equals(FIELD_NULL) || PAOCode.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Code" + tab + tab + tab + T_FV_2171_C + tab + T_FV_2171_M);
					} else if (!PAOCode.equals(FIELD_NULL) && !PAOCode.equals(FIELD_SEPERATOR) && PAOCode.trim().length() != 0 && valueCheck) {
						if (PAOCode.length() <= 20) {
							if (PAOCode.trim().length() != PAOCode.length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Code" + tab + tab + tab + T_FV_2172_C + tab + T_FV_2172_M);
							else if (!(obj_FieldValidation.isInt(PAOCode))) {
								if (obj_FieldValidation.checkZero(PAOCode))
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Code" + tab + tab + tab + T_FV_2172_C + tab + T_FV_2172_M);
							} else if (obj_FieldValidation.isAlphaNum(PAOCode))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Code" + tab + tab + tab + T_FV_2172_C + tab + T_FV_2172_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Code" + tab + tab + tab + T_FV_2172_C + tab + T_FV_2172_M);
					}
					// Validating PAOCode

					// Validating DDOCode

					if ((DDOCode.trim().length() == 0) && (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATE_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG)
							|| DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG) || DeductorType.equals(LOCAL_AUTHORITY_SG))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Code" + tab + tab + tab + T_FV_2175_C + tab + T_FV_2175_M);
					} else if (DeductorType.equals(CENTRAL_GOVERNMENT) && (DDOCode.equals(FIELD_NULL) || DDOCode.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Code" + tab + tab + tab + T_FV_2174_C + tab + T_FV_2174_M);
					} else if (!DDOCode.equals(FIELD_NULL) && !DDOCode.equals(FIELD_SEPERATOR) && DDOCode.trim().length() != 0 && valueCheck) {
						if (DDOCode.length() <= 20) {
							if (DDOCode.trim().length() != DDOCode.length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Code" + tab + tab + tab + T_FV_2175_C + tab + T_FV_2175_M);
							else if (!(obj_FieldValidation.isInt(DDOCode))) {
								if (obj_FieldValidation.checkZero(DDOCode))
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Code" + tab + tab + tab + T_FV_2175_C + tab + T_FV_2175_M);
							} else if (obj_FieldValidation.isAlphaNum(DDOCode))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Code" + tab + tab + tab + T_FV_2175_C + tab + T_FV_2175_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Code" + tab + tab + tab + T_FV_2175_C + tab + T_FV_2175_M);
					}
					// Validating DDOCode

					// VAlidating Ministry Name

					if ((MinistryName.trim().length() == 0) && (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_CG)
							|| DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG) || DeductorType.equals(LOCAL_AUTHORITY_SG))) {
						valueMinistry = false;
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2178_C + tab + T_FV_2178_M);
					} else if ((DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_CG)) && (MinistryName.equals(FIELD_NULL) || MinistryName.equals(FIELD_SEPERATOR))) {
						valueMinistry = false;
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2177_C + tab + T_FV_2177_M);
					} else if (DeductorType.equals(STATE_GOVERNMENT) && (!(MinistryName.equals(FIELD_NULL) || MinistryName.equals(FIELD_SEPERATOR)))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2176_C + tab + T_FV_2176_M);
					} else if (!MinistryName.equals(FIELD_NULL) && !MinistryName.equals(FIELD_SEPERATOR) && MinistryName.trim().length() != 0 && valueCheck) {
						if (MinistryName.length() >= 1 && MinistryName.length() <= 3) {
							if (MinistryName.trim().length() != MinistryName.length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2178_C + tab + T_FV_2178_M);
							else if (obj_FieldValidation.isInt(MinistryName))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2178_C + tab + T_FV_2178_M);
							else if (!(Integer.parseInt(MinistryName.trim()) > 0 && Integer.parseInt(MinistryName.trim()) < 58) && (Integer.parseInt(MinistryName.trim()) != 99))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2178_C + tab + T_FV_2178_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2178_C + tab + T_FV_2178_M);
					}
					// Validating Ministry Name

					// Validating MinistryNameOther
					if (DeductorType.equals(STATE_GOVERNMENT) && (!(MinistryNameOther.equals(FIELD_NULL) || MinistryNameOther.equals(FIELD_SEPERATOR))))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Others" + tab + tab + tab + T_FV_2179_C + tab + T_FV_2179_M);

					if (MinistryName.equals("99")) {
						if (MinistryNameOther.equals(FIELD_NULL) || MinistryNameOther.equals(FIELD_SEPERATOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Others" + tab + tab + tab + T_FV_2180_C + tab + T_FV_2180_M);
						else if (MinistryNameOther.trim().length() == 0)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Others" + tab + tab + tab + T_FV_2181_C + tab + T_FV_2181_M);
						else if (!MinistryNameOther.equals(FIELD_NULL) && !MinistryNameOther.equals(FIELD_SEPERATOR) && MinistryNameOther.trim().length() != 0 && valueCheck) {
							if (MinistryNameOther.length() <= 150) {
								if (!(obj_FieldValidation.isInt(MinistryNameOther)))
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Others" + tab + tab + tab + T_FV_2181_C + tab + T_FV_2181_M);
								else if (obj_FieldValidation.isAlphaNumSpace(MinistryNameOther))
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Others" + tab + tab + tab + T_FV_2181_C + tab + T_FV_2181_M);
							} else
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Others" + tab + tab + tab + T_FV_2181_C + tab + T_FV_2181_M);
						}
					} else if (valueMinistry && (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_CG)
							|| DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG) || DeductorType.equals(LOCAL_AUTHORITY_SG))) {
						if ((MinistryName.equals(FIELD_NULL) || MinistryName.equals(FIELD_SEPERATOR)) && (!(MinistryNameOther.equals(FIELD_NULL) || MinistryNameOther.equals(FIELD_SEPERATOR))))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name" + tab + tab + tab + T_FV_2196_C + tab + T_FV_2196_M);
						else if (!MinistryName.equals("99") && valueMinistry) {
							if (!(MinistryNameOther.equals(FIELD_NULL) || MinistryNameOther.equals(FIELD_SEPERATOR)))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Ministry Name-Others" + tab + tab + tab + T_FV_2179_C + tab + T_FV_2179_M);
						}
					}
					// Validating MinistryNameOther

					// Validating Registeration ID

					if (!(RegistrationId.equals(FIELD_NULL) || RegistrationId.equals(FIELD_SEPERATOR)))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN Registration Number" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);

					// Validating Registeration ID

					// Validating PAO registration no.
					if ((PAORegistrationNo.trim().length() == 0) && (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATE_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG)
							|| DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG) || DeductorType.equals(LOCAL_AUTHORITY_SG))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Registration No" + tab + tab + tab + T_FV_2184_C + tab + T_FV_2184_M);
					} else if (!PAORegistrationNo.equals(FIELD_NULL) && !PAORegistrationNo.equals(FIELD_SEPERATOR) && PAORegistrationNo.trim().length() != 0 && valueCheck) {
						if ((PAORegistrationNo.length() == 7) && (PAORegistrationNo.trim().length() == 7)) {
							if (obj_FieldValidation.isInt(PAORegistrationNo)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Registration No" + tab + tab + tab + T_FV_2184_C + tab + T_FV_2184_M);
							} else if (obj_FieldValidation.isValidRrrNumber(PAORegistrationNo)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Registration No" + tab + tab + tab + T_FV_2184_C + tab + T_FV_2184_M);
							}
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAO Registration No" + tab + tab + tab + T_FV_2184_C + tab + T_FV_2184_M);
					}

					// Validating PAO Registration No.

					// Validating DDO Registration No.
					if ((DDORegistrationNo.trim().length() == 0) && (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATE_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG)
							|| DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG) || DeductorType.equals(LOCAL_AUTHORITY_SG))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Registration No" + tab + tab + tab + T_FV_2186_C + tab + T_FV_2186_M);
					} else if (!DDORegistrationNo.equals(FIELD_NULL) && !DDORegistrationNo.equals(FIELD_SEPERATOR) && DDORegistrationNo.trim().length() != 0 && valueCheck) {
						if ((DDORegistrationNo.length() == 10) && (DDORegistrationNo.trim().length() == 10)) {
							if (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(LOCAL_AUTHORITY_CG)) {
								Str_DDO = "CGV";
								if (obj_FieldValidation.checkDDORegistrationNo(DDORegistrationNo, Str_DDO))
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Registration No" + tab + tab + tab + T_FV_2186_C + tab + T_FV_2186_M);
							} else if (DeductorType.equals(STATE_GOVERNMENT) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_SG)) {
								Str_DDO = "SGV";
								if (obj_FieldValidation.checkDDORegistrationNo(DDORegistrationNo, Str_DDO))
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Registration No" + tab + tab + tab + T_FV_2186_C + tab + T_FV_2186_M);
							} else
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Registration No" + tab + tab + tab + T_FV_2186_C + tab + T_FV_2186_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "DDO Registration No" + tab + tab + tab + T_FV_2186_C + tab + T_FV_2186_M);
					}

					// Validating DDO Registration No.

					// END
				}
				// Added for FVU 3.8 by Shalin --- START

				if (isFinYrGrtrthn) {

					// validating EmployerEmailAlt --------- Must be NULL for C4, C5, Y, X, Z OR If
					// Batch Updation Indicator is '0'
					if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
							|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
						if (!EmployerEmailAlt.equals(FIELD_NULL) && !EmployerEmailAlt.equals(FIELD_SEPERATOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Email ID (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
					} else if (!EmployerEmailAlt.equals(FIELD_NULL) && !EmployerEmailAlt.equals(FIELD_SEPERATOR)) {
						if (EmployerEmailAlt.length() <= 75) {

							if (EmployerEmailAlt.length() != EmployerEmailAlt.trim().length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Email ID (Alternate)" + tab + tab + tab + T_FV_2220_C + tab + T_FV_2220_M);
							else if (obj_FieldValidation.isValidEmail(EmployerEmailAlt)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Email ID (Alternate)" + tab + tab + tab + T_FV_2220_C + tab + T_FV_2220_M);
							}
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Email ID (Alternate)" + tab + tab + tab + T_FV_2220_C + tab + T_FV_2220_M);
					} // validating EmployeeEmailAlt

					// validating EmployerSTDAlt --------- Must be NULL for C4, C5, Y, Y1, X, Z OR
					// If Batch Updation Indicator is '0'
					if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
							|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
						if (!EmployerSTDAlt.equals(FIELD_NULL) && !EmployerSTDAlt.equals(FIELD_SEPERATOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer STD code (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
					} else if (!EmployerPhoneAlt.equals(FIELD_NULL) && !EmployerPhoneAlt.equals(FIELD_SEPERATOR) && (EmployerSTDAlt.equals(FIELD_NULL) || EmployerSTDAlt.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer STD code (Alternate)" + tab + tab + tab + T_FV_2221_C + tab + T_FV_2221_M);
					} else if (!EmployerSTDAlt.equals(FIELD_NULL) && !EmployerSTDAlt.equals(FIELD_SEPERATOR)) {

						if (EmployerSTDAlt.length() <= 5) {

							if (EmployerSTDAlt.length() != EmployerSTDAlt.trim().length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer STD code (Alternate)" + tab + tab + tab + T_FV_2221_C + tab + T_FV_2221_M);
							else if (obj_FieldValidation.isInt(EmployerSTDAlt))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer STD code (Alternate)" + tab + tab + tab + T_FV_2221_C + tab + T_FV_2221_M);
							else if (Integer.parseInt(EmployerSTDAlt) == 0)
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer STD code (Alternate)" + tab + tab + tab + T_FV_2221_C + tab + T_FV_2221_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer STD code (Alternate)" + tab + tab + tab + T_FV_2221_C + tab + T_FV_2221_M);
					} // validating EmployerSTDAlt

					// validating EmployerPhoneAlt --------- Must be NULL for C4, C5, Y, X, Z OR If
					// Batch Updation Indicator is '0'
					if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
							|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
						if (!EmployerPhoneAlt.equals(FIELD_NULL) && !EmployerPhoneAlt.equals(FIELD_SEPERATOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
					}

					else if (!EmployerSTDAlt.equals(FIELD_NULL) && !EmployerSTDAlt.equals(FIELD_SEPERATOR) && (EmployerPhoneAlt.equals(FIELD_NULL) || EmployerPhoneAlt.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2222_C + tab + T_FV_2222_M);
					} else if (!EmployerPhoneAlt.equals(FIELD_NULL) && !EmployerPhoneAlt.equals(FIELD_SEPERATOR)) {

						if (EmployerPhoneAlt.length() <= 10) {
							if (EmployerPhoneAlt.length() != EmployerPhoneAlt.trim().length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2222_C + tab + T_FV_2222_M);
							else if (obj_FieldValidation.isInt(EmployerPhoneAlt))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2222_C + tab + T_FV_2222_M);
							else if (Long.parseLong(EmployerPhoneAlt) == 0)
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2222_C + tab + T_FV_2222_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2222_C + tab + T_FV_2222_M);
					} // validating EmployerPhoneAlt

					// validating PersonResponsilbleSTDCode --------- Must be NULL for C4, C5, Y, X,
					// Z OR If Batch Updation Indicator is '0'
					if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
							|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
						if (!PersonResponsilbleSTDCodeAlt.equals(FIELD_NULL) && !PersonResponsilbleSTDCodeAlt.equals(FIELD_SEPERATOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's STD Code (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
					}

					else if (!PersonResponsilbleTelePhoneAlt.equals(FIELD_NULL) && !PersonResponsilbleTelePhoneAlt.equals(FIELD_SEPERATOR) && (PersonResponsilbleSTDCodeAlt.equals(FIELD_NULL) || PersonResponsilbleSTDCodeAlt.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's STD Code (Alternate)" + tab + tab + tab + T_FV_2223_C + tab + T_FV_2223_M);
					}

					else if (!PersonResponsilbleSTDCodeAlt.equals(FIELD_NULL) && !PersonResponsilbleSTDCodeAlt.equals(FIELD_SEPERATOR)) {

						if (PersonResponsilbleSTDCodeAlt.length() <= 5) {

							if (PersonResponsilbleSTDCodeAlt.length() != PersonResponsilbleSTDCodeAlt.trim().length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's STD Code (Alternate)" + tab + tab + tab + T_FV_2223_C + tab + T_FV_2223_M);
							else if (obj_FieldValidation.isInt(PersonResponsilbleSTDCodeAlt))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's STD Code (Alternate)" + tab + tab + tab + T_FV_2223_C + tab + T_FV_2223_M);

							else if (Integer.parseInt(PersonResponsilbleSTDCodeAlt) == 0)
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's STD Code (Alternate)" + tab + tab + tab + T_FV_2223_C + tab + T_FV_2223_M);

						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's STD Code (Alternate)" + tab + tab + tab + T_FV_2223_C + tab + T_FV_2223_M);
					} // validating PersonResponsilbleSTDCodeAlt

					// validating PersonResponsilbleTelePhoneAlt --------- Must be NULL for C4, C5,
					// Y, X, Z OR If Batch Updation Indicator is '0'

					if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
							|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
						if (!PersonResponsilbleTelePhoneAlt.equals(FIELD_NULL) && !PersonResponsilbleTelePhoneAlt.equals(FIELD_SEPERATOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
					}

					else if (!PersonResponsilbleSTDCodeAlt.equals(FIELD_NULL) && !PersonResponsilbleSTDCodeAlt.equals(FIELD_SEPERATOR) && (PersonResponsilbleTelePhoneAlt.equals(FIELD_NULL) || PersonResponsilbleTelePhoneAlt.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2224_C + tab + T_FV_2224_M);
					}

					else if (!PersonResponsilbleTelePhoneAlt.equals(FIELD_NULL) && !PersonResponsilbleTelePhoneAlt.equals(FIELD_SEPERATOR)) {
						if (PersonResponsilbleTelePhoneAlt.length() <= 10) {

							if (PersonResponsilbleTelePhoneAlt.length() != PersonResponsilbleTelePhoneAlt.trim().length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2224_C + tab + T_FV_2224_M);
							else if (obj_FieldValidation.isInt(PersonResponsilbleTelePhoneAlt))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2224_C + tab + T_FV_2224_M);

							else if (Long.parseLong(PersonResponsilbleTelePhoneAlt) == 0)
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2224_C + tab + T_FV_2224_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2224_C + tab + T_FV_2224_M);
					} // validating PersonResponsilbleTelePhoneAlt

					// validating PersonResponsilbleEmailIdAlt --------- Must be NULL for C4, C5, Y,
					// X, Z OR If Batch Updation Indicator is '0'
					if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
							|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
						if (!PersonResponsilbleEmailIdAlt.equals(FIELD_NULL) && !PersonResponsilbleEmailIdAlt.equals(FIELD_SEPERATOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Email ID (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
					} else if (!PersonResponsilbleEmailIdAlt.equals(FIELD_NULL) && !PersonResponsilbleEmailIdAlt.equals(FIELD_SEPERATOR)) {
						if (PersonResponsilbleEmailIdAlt.length() <= 75) {
							if (PersonResponsilbleEmailIdAlt.length() != PersonResponsilbleEmailIdAlt.trim().length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Email ID (Alternate)" + tab + tab + tab + T_FV_2225_C + tab + T_FV_2225_M);

							else if (obj_FieldValidation.isValidEmail(PersonResponsilbleEmailIdAlt)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Email ID (Alternate)" + tab + tab + tab + T_FV_2225_C + tab + T_FV_2225_M);
							}
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Email ID (Alternate)" + tab + tab + tab + T_FV_2225_C + tab + T_FV_2225_M);
					} // validating PersonResponsilbleEmailIdAlt

					// validating AIN --------- Must be NULL for C4, C5, Y, X, Z OR If Batch
					// Updation Indicator is '0'

					if ((BatchUpdationIndicator.equals("0") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)
							|| TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC) || TransactionType.equals(TRANSACTIONTYPE_REPLACE_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
						if (!AIN.equals(FIELD_NULL) && !AIN.equals(FIELD_SEPERATOR))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Account Office Identification Number (AIN) " + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
					} else if (!AIN.equals(FIELD_NULL) && !AIN.equals(FIELD_SEPERATOR)) {
						if (AIN.length() == 7) {
							if (AIN.length() != AIN.trim().length())
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Account Office Identification Number (AIN) " + tab + tab + tab + T_FV_2226_C + tab + T_FV_2226_M);
							else if (!obj_FieldValidation.isNumber(AIN)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Account Office Identification Number (AIN) " + tab + tab + tab + T_FV_2226_C + tab + T_FV_2226_M);
							} else if (obj_FieldValidation.isMod7Ain(AIN)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Account Office Identification Number (AIN) " + tab + tab + tab + T_FV_2226_C + tab + T_FV_2226_M);
							} else if (!(DeductorType.equals("A") || DeductorType.equals("S"))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Account Office Identification Number (AIN) " + tab + tab + tab + T_FV_2234_C + tab + T_FV_2234_M);
							}
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Account Office Identification Number (AIN) " + tab + tab + tab + T_FV_2226_C + tab + T_FV_2226_M);
					}
					// added by Shalin for FVU 4.4
					// commented by nik start for FVU 4.6
					/*
					 * else if(AIN.equals(FIELD_NULL) || AIN.equals(FIELD_SEPERATOR)) {
					 * if((FormNo.equals(FORM_24Q) || FormNo.equals(FORM_26Q)) &&
					 * (DeductorType.equals(CENTRAL_GOVERNMENT) ||
					 * DeductorType.equals(STATE_GOVERNMENT))) {
					 * if(UploadType.equals(UPLOADTYPE_REGULAR) ||
					 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) ||
					 * ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) ||
					 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) &&
					 * BatchUpdationIndicator.equals("1"))) Str_Buffer.append(LineNo + tab +
					 * currentUploadType + tab + "Account Office Identification Number (AIN) " + tab
					 * + tab + tab + T_FV_2233_C + tab + T_FV_2233_M); } }
					 */

					// validating AIN

				}

				else {
					if (!EmployerEmailAlt.equals(FIELD_NULL) && !EmployerEmailAlt.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Email ID (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);

					if (!EmployerSTDAlt.equals(FIELD_NULL) && !EmployerSTDAlt.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer STD code (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);

					if (!EmployerPhoneAlt.equals(FIELD_NULL) && !EmployerPhoneAlt.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employer Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);

					if (!PersonResponsilbleSTDCodeAlt.equals(FIELD_NULL) && !PersonResponsilbleSTDCodeAlt.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's STD Code (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);

					if (!PersonResponsilbleTelePhoneAlt.equals(FIELD_NULL) && !PersonResponsilbleTelePhoneAlt.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Tel-Phone No. (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);

					if (!PersonResponsilbleEmailIdAlt.equals(FIELD_NULL) && !PersonResponsilbleEmailIdAlt.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Responsible Person's Email ID (Alternate)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);

					if (!AIN.equals(FIELD_NULL) && !AIN.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Account Office Identification Number (AIN)" + tab + tab + tab + T_FV_2227_C + tab + T_FV_2227_M);
				}

				// Added for fvu 3.8 by Shalin --- END
			}

			// validate GSTN no
			if (!GSTNNo.equals(FIELD_NULL) && !GSTNNo.equals(FIELD_SEPERATOR)) {
				if (GSTNNo.length() != 15) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Goods and Services Tax Number (GSTN)" + tab + tab + tab + T_FV_2237_C + tab + T_FV_2237_M);

				} else if (!obj_FieldValidation.isAlphanumeric(GSTNNo)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Goods and Services Tax Number (GSTN)" + tab + tab + tab + T_FV_2237_C + tab + T_FV_2237_M);

				} else if (!(UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)
						|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
						|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH_TFC))) {

					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Goods and Services Tax Number (GSTN)" + tab + tab + tab + T_FV_2237_C + tab + T_FV_2237_M);
				}
			}

			// Validate GSTN no.

			// Validating Date of Filling for FVU 3.7 added by Shalin

			if (!(FormNo.equals(FIELD_NULL) || FormNo.equals(FIELD_SEPERATOR) || Qperiod.equals(FIELD_NULL) || Qperiod.equals(FIELD_SEPERATOR) || FinancialYr.equals(FIELD_NULL) || FinancialYr.equals(FIELD_SEPERATOR) || FinancialYr.length() != 6
					|| FinancialYr.trim().length() != 6 || obj_FieldValidation.isInt(FinancialYr))) {
				boolean isFillingDateValid = obj_FieldValidation.isFillingDateValid(FormNo, Qperiod, FinancialYr);
				//version Commented FVU 7.2
				if (!isFillingDateValid)

					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Period" + tab + tab + tab + T_FV_2218_C + tab + T_FV_2218_M);
				
			}

			// Validating Date of Filling for FVU 3.7 added by Shalin
		} catch (Exception e) {

			throw e;
		}
		return;
	}

	/**************************
	 * Validation for Challan Header
	 **********************************/
	private void validateChallanHeader(String challan, int LineCount, String BH_BatchNo, String FileType, String FormNo, String QPeriod, int validChallanCount, String GrossTDSTotalAsPerChallan, String CountOfChallanRec, Calendar RRRDatePresentDate,
			String UploadTypeCH, StringBufferTemp obj_StringBuffer, int utilityLevel, String fileExtention) // File Extention Added For FVU 3.0
			throws Exception {

		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;
		boolean error_flag = false;
		boolean NullField = false;
		boolean FieldFound = false;
		boolean Caret = false;
		boolean error = false;
		boolean nullInterest = false;
		boolean nullOthers = false;
		int LCount = 0;
		int iChallanDetailRecordNo = 0;
		BankChallanNo = null;
		BankBranchCode = null;
		DateOfBankChallanNo = null;
		TotalOfDepositAmountAsPerChallan = null;
		TotalTaxDepositedAsPerDeducteeAnex = null;
		SumTotalIncTaxDedAtSource = null;
		sumTotalTdsSurCess = 0;
		double sumTotal = 0;
		double iTDSIncomeTaxC = 0;
		double iTDSSurchargeC = 0;
		double iInterestC = 0;
		double iTDSCessC = 0;
		double iOthersC = 0;
		double iTotalOfTDSAsPerDeducteeDetails = 0;
		double iTotalOfDepositAmountAsPerChallan = 0;
		DeducteeCount = 0;
		pval = 0;
		nval = 0;
		pvalTotalIncomeTaxDeposited = 0;
		nvalTotalIncomeTaxDeposited = 0;
		System.out.println("Validating Challan For Batch Number" + BatchLineNo);
		try {

			String LineNo = null;
			String RecType = null;
			String CH_BatchNo = null;
			String ChallanDetailRecordNo = null;
			String StatementFromDate = null;
			String StatementToDate = null;
			String ChallanUpdationIndicator = null;
			String CountOfDeducteeDetail = null;
			String LastBankChallanNo = null;
			String LastTransferVoucherNo = null;
			String TransferVoucherNo = null;
			String LastBankBranchCode = null;
			String LastDateOfBankChallanNo = null;
			String MajorHeadCode = null;
			// Filler Fields in File Format
			String MinorHeadCode = null;
			// Filler Fields in File Format
			String Section = null;
			String OltasIncomeTax = null;
			String OltasSurcharge = null;
			String OltasCess = null;
			String OltasInterest = null;
			String OltasOthers = null;
			String LastTotalOfDepositAmountAsPerChallan = null;
			String TDSInterest = null;
			String TDSOthers = null;
			String Remark = null;
			String TDSIncomeTaxC = null;
			String TDSSurchargeC = null;
			String TDSCessC = null;
			// String SumTotalIncTaxDedAtSource = null;
			String ChequeDDNo = null;
			String ByBookCash = null;
			String StmtToDate = null;
			// Filler Fields in File Format
			String StmtFromDate = null;
			// Filler Fields in File Format
			String ChallanHash = null;

			// Added for FVU 3.8 by Shalin

			String LateFee = null;
			String MinorHeadCodeChaln = null;

			boolean CountOfDeducteeDetailFlag = false;
			// Is set to true if no error in Count Of Deductee Detail
			boolean fieldfound = false;
			int Count_CH_Field = 1;
			boolean valueDate = true;
			// Added By AMI For FVU 3.0
			boolean bankDatePresent = true;

			FieldValidation obj_FieldValidation = new FieldValidation();
			FileGenerator obj_FileGenerator = new FileGenerator();
			int localCaretCounterCH12 = 0;
			StringTokenizer Obj_st = new StringTokenizer(challan, FIELD_SEPERATOR, true);
			while (Obj_st.hasMoreTokens()) {
				String val = Obj_st.nextToken();
				NullField = false;
				FieldFound = false;
				if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
					NullField = true;
					FieldFound = true;
				}
				if (val.equals(FIELD_SEPERATOR)) {
					Caret = true;
					if ((Count_CH_Field == 1) && (localCaretCounterCH12 == 0)) {
						Count_CH_Field++;
						LineNo = "-";
					}
					localCaretCounterCH12++;
				} else {
					Caret = false;
					FieldFound = true;
				}

				if (Count_CH_Field > 41) {
					break;
				}
				if (FieldFound) {
					switch (Count_CH_Field) {
					case 1:
						LineNo = val;
						break;
					case 2:
						RecType = val;
						break;
					case 3:
						CH_BatchNo = val;
						break;
					case 4:
						ChallanDetailRecordNo = val;
						break;
					case 5:
						CountOfDeducteeDetail = val;
						break;
					case 6:
						NillChallanIndicator = val;
						break;
					case 7:
						ChallanUpdationIndicator = val;
						break;
					case 8:
						Period = val;
						break;
					case 9:
						StmtFromDate = val;
						break;
					case 10:
						StmtToDate = val;
						break;
					case 11:
						LastBankChallanNo = val;
						break;
					case 12:
						BankChallanNo = val;
						break;
					case 13:
						LastTransferVoucherNo = val;
						break;
					case 14:
						TransferVoucherNo = val;
						break;
					case 15:
						LastBankBranchCode = val;
						break;
					case 16:
						BankBranchCode = val;
						break;
					case 17:
						LastDateOfBankChallanNo = val;
						break;
					case 18:
						DateOfBankChallanNo = val;
						break;
					case 19:
						MajorHeadCode = val;
						break;
					case 20:
						MinorHeadCode = val;
						break;
					case 21:
						Section = val;
						break;
					case 22:
						OltasIncomeTax = val;
						break;
					case 23:
						OltasSurcharge = val;
						break;
					case 24:
						OltasCess = val;
						break;
					case 25:
						OltasInterest = val;
						break;
					case 26:
						OltasOthers = val;
						break;
					case 27:
						TotalOfDepositAmountAsPerChallan = val;
						break;
					case 28:
						LastTotalOfDepositAmountAsPerChallan = val;
						break;
					case 29:
						TotalTaxDepositedAsPerDeducteeAnex = val;
						break;
					case 30:
						TDSIncomeTaxC = val;
						break;
					case 31:
						TDSSurchargeC = val;
						break;
					case 32:
						TDSCessC = val;
						break;
					case 33:
						SumTotalIncTaxDedAtSource = val;
						break;
					case 34:
						TDSInterest = val;
						break;
					case 35:
						TDSOthers = val;
						break;
					case 36:
						ChequeDDNo = val;
						break;
					case 37:
						ByBookCash = val;
						break;
					case 38:
						Remark = val;
						break;
					case 39:
						LateFee = val;
						break;
					case 40:
						MinorHeadCodeChaln = val;
						break;
					case 41:
						ChallanHash = val;
						break;
					} // SWITCH
					Count_CH_Field++;
				}
			} // WHILE

			// ###### Code added to check for Sections at DD level when challan updation
			// indicator
			// is not provided in case of C3 Manvendra Singh :: 19-Feb-2008
			ChallanUpdationIndicatorForcurrentchallan = ChallanUpdationIndicator;
			// ##############################

			// ------------ Added by Nahush

			if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)) {
				CurrentchallanDetailRecordNo = "Null";
			}

			else {
				CurrentchallanDetailRecordNo = ChallanDetailRecordNo;
			}

			// ------------

			// Added By AMI For FVU 3.0
			// Validating Unmatched Challan Count Of Btch Field

			// isSameBtch = true;

			if (!isSameBtch) {
				isSameBtch = true;

				int lineNoForBtch = Integer.parseInt(LineNo); // to be changed
				lineNoForBtch = lineNoForBtch - 1;

				if (utilityLevel == 0 && fileExtention.equalsIgnoreCase("txt")) {
					if (!(unMatchedChalanCnt.equals(FIELD_NULL) || unMatchedChalanCnt.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(Integer.toString(lineNoForBtch) + tab + currentUploadType + tab + "Unmatched Chalan Count" + tab + tab + tab + T_FV_2205_C + tab + T_FV_2205_M);
					}
				} else if (unMatchedChalanCnt.equals(FIELD_NULL) || unMatchedChalanCnt.equals(FIELD_SEPERATOR)) {
					if (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Integer.parseInt(ChallanUpdationIndicator) == 1)
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) // Must be NULL for C4, C5, Y,
																							// X, Z OR If Cha Updation
																							// Indicator is '0'
						Str_Buffer.append(Integer.toString(lineNoForBtch) + tab + currentUploadType + tab + "Unmatched Chalan Count" + tab + tab + tab + T_FV_2208_C + tab + T_FV_2208_M);
				} else if (unMatchedChalanCnt.trim().length() <= 9) {
					if (unMatchedChalanCnt.trim().equals("NA")) {
					} else if (obj_FieldValidation.isInt(unMatchedChalanCnt))
						Str_Buffer.append(Integer.toString(lineNoForBtch) + tab + currentUploadType + tab + "Unmatched Chalan Count" + tab + tab + tab + T_FV_2206_C + tab + T_FV_2206_M);
					// else
					// Str_Buffer.append(Integer.toString(lineNoForBtch) + tab + currentUploadType +
					// tab + "Unmatched Chalan Count" + tab + tab + tab + T_FV_2206_C + tab +
					// T_FV_2206_M);
				} else
					Str_Buffer.append(Integer.toString(lineNoForBtch) + tab + currentUploadType + tab + "Unmatched Chalan Count" + tab + tab + tab + T_FV_2206_C + tab + T_FV_2206_M);

			}
			// Validating Unmatched Challan Count

			if (localCaretCounterCH12 != 40) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + "NA" + tab + tab + T_FV_3000_C + tab + T_FV_3000_M);
				return;
			} // Validating LineNo 1
			if (LineNo.equals(FIELD_NULL) || LineNo.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3003_C + tab + T_FV_3003_M);
				LineNo = "-";
			} else if (LineNo.length() <= 9) {
				if (obj_FieldValidation.isInt(LineNo))
					Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3003_C + tab + T_FV_3003_M);
				else {
					LCount = Integer.parseInt(LineNo.trim());
					if (LCount != LineCount)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3002_C + tab + T_FV_3002_M);
					else
						lineNoOfChallanRec = LineNo;
				}
			} else
				Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3003_C + tab + T_FV_3003_M);
			// Validating LineNo
			// Validating recordtype 2
			error = isValidRecType(LineNo, RecType, CHALLAN_HEADER_IDENTIFIER, Str_Buffer);
			if (error) {
				if (Integer.parseInt(LineNo.trim()) != LineCount) {
					LineNo = "NA";
					obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + Challan_Record_Type + tab + tab + tab + T_FV_3002_C + tab + T_FV_3002_M);
				}

				Str_Buffer.append(LineNo + tab + currentUploadType + tab + Challan_Record_Type + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3001_C + tab + T_FV_3001_M);
			}
			// Validating recordtype
			// Validating BatchNo 3
			if (CH_BatchNo.equals(FIELD_NULL) || CH_BatchNo.equals(FIELD_SEPERATOR)) {
				if (ChallanDetailRecordNo.equals(FIELD_NULL) || ChallanDetailRecordNo.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + "NA" + tab + tab + T_FV_3004_C + tab + T_FV_3004_M);
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3004_C + tab + T_FV_3004_M);
				CH_BatchNo = "NA";
			} else if (CH_BatchNo.length() <= 9) {
				if (obj_FieldValidation.isInt(CH_BatchNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3004_C + tab + T_FV_3004_M);
				else if (Integer.parseInt(CH_BatchNo.trim()) != Integer.parseInt(BH_BatchNo.trim()))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3004_C + tab + T_FV_3004_M);
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3004_C + tab + T_FV_3004_M);
			// Validating BatchNo
			// Validating ChallanDetailRecordNo 4
			if (ChallanDetailRecordNo.equals(FIELD_NULL) || ChallanDetailRecordNo.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + "NA" + tab + tab + T_FV_3009_C + tab + T_FV_3009_M);
				ChallanDetailRecordNo = "NA";
				CurrentchallanDetailRecordNo = "NA";
			} else if (ChallanDetailRecordNo.length() <= 9) {
				if (obj_FieldValidation.isInt(ChallanDetailRecordNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3009_C + tab + T_FV_3009_M);
				else {
					iChallanDetailRecordNo = Integer.parseInt(ChallanDetailRecordNo.trim());
					receiptChallanDetailRecNo = Integer.parseInt(ChallanDetailRecordNo.trim());
					if (UploadTypeCH.equals(UPLOADTYPE_REGULAR)) {
						if (iChallanDetailRecordNo != ChallanCount)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3009_C + tab + T_FV_3009_M);
						else {
							meteChlnDetailRecNo.addElement(ChallanDetailRecordNo.trim());
						}
					} else {
						if (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
							if (Integer.parseInt(ChallanDetailRecordNo.trim()) < 2)
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3030_C + tab + T_FV_3030_M);
							else if ((prevChallanRecCount != 0) && ((prevChallanRecCount + 1) != Integer.parseInt(ChallanDetailRecordNo.trim())))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3009_C + tab + T_FV_3009_M);
						} else if (Integer.parseInt(ChallanDetailRecordNo.trim()) < 1) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3009_C + tab + T_FV_3009_M);
						} else if (prevChallanRecCount >= Integer.parseInt(ChallanDetailRecordNo.trim())) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + CurrentchallanDetailRecordNo + tab + "Challan-Detail Record Number" + tab + tab + T_FV_3077_C + tab + T_FV_3077_M);
						} else {
							meteChlnDetailRecNo.addElement(ChallanDetailRecordNo.trim());
						}
						prevChallanRecCount = Integer.parseInt(ChallanDetailRecordNo.trim());
					}
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3009_C + tab + T_FV_3009_M);
			// Validating ChallanDetailRecordNo
			// Validating CountOfDeducteeDetail 5
			if (CountOfDeducteeDetail.equals(FIELD_NULL) || CountOfDeducteeDetail.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3015_C + tab + T_FV_3015_M);
			} else {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3074_C + tab + T_FV_3074_M);
				else if (CountOfDeducteeDetail.length() <= 9) {
					if (obj_FieldValidation.isInt(CountOfDeducteeDetail))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3014_C + tab + T_FV_3014_M);
					else if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) && (Long.parseLong(CountOfDeducteeDetail.trim()) < 1))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3014_C + tab + T_FV_3014_M);
					else {
						if (statTotalNoOfDDRec.equals("-")) {
							statTotalNoOfDDRec = Integer.toString(Integer.parseInt(CountOfDeducteeDetail.trim()));
							noOfDDGFI = Integer.toString(Integer.parseInt(CountOfDeducteeDetail.trim()));
						} else {
							statTotalNoOfDDRec = Integer.toString(Integer.parseInt(statTotalNoOfDDRec.trim()) + Integer.parseInt(CountOfDeducteeDetail.trim()));
							noOfDDGFI = Integer.toString(Integer.parseInt(noOfDDGFI.trim()) + Integer.parseInt(CountOfDeducteeDetail.trim()));
						}

						CountOfDeducteeDetailFlag = true;
						meteDDCount = meteDDCount + Integer.parseInt(CountOfDeducteeDetail.trim());
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3014_C + tab + T_FV_3014_M);
			}

			// Validating CountOfDeducteeDetail
			// Validating NillChallanIndicator 6
			if (NillChallanIndicator.equals(FIELD_NULL) || NillChallanIndicator.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NIL Challan Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3010_C + tab + T_FV_3010_M);
			else if (!(NillChallanIndicator.equals("Y")) && !(NillChallanIndicator.equals("N")))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NIL Challan Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3010_C + tab + T_FV_3010_M);

			// Added for FVU 4.0
			// Changed for FVU 4.6
			if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) && NillChallanIndicator.equals("Y") && !CountOfDeducteeDetail.equals(FIELD_NULL) && !CountOfDeducteeDetail.equals(FIELD_SEPERATOR)) {
				if (CountOfDeducteeDetail.trim().equals("0") && !(FormNo.equals(FORM_24Q) && QPeriod.equals("Q4"))) // Changed
																													// for
																													// FVU
																													// 4.2
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NIL Challan Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3165_C + tab + T_FV_3165_M);
			} else if (NillChallanIndicator.equals("Y") && (CountOfDeducteeDetail.equals(FIELD_NULL) || CountOfDeducteeDetail.equals(FIELD_SEPERATOR))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NIL Challan Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3165_C + tab + T_FV_3165_M);
			}

			// Validating NillChallanIndicator
			// Validating ChallanUpdationIncicator 7

			boolean ChallanUpdationIndicatorRequired = true;
			if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
				if (!ChallanUpdationIndicator.equals(FIELD_NULL) && !ChallanUpdationIndicator.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan Updation Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3008_C + tab + T_FV_3008_M);
					ChallanUpdationIndicatorRequired = false;
				}
			} else {

				if (ChallanUpdationIndicator.equals(FIELD_NULL) || ChallanUpdationIndicator.equals(FIELD_SEPERATOR)) {
					if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan Updation Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3006_C + tab + T_FV_3006_M);
				} else {
					if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan Updation Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3008_C + tab + T_FV_3008_M);
						ChallanUpdationIndicatorRequired = false;
					} else if (!(ChallanUpdationIndicator.equals("0")) && !(ChallanUpdationIndicator.equals("1")))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan Updation Indicator" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3007_C + tab + T_FV_3007_M);
				}
			} // Validating ChallanUpdationIncicator
				// Validating Period 8
			if (!Period.equals(FIELD_NULL) && !Period.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 2" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3016_C + tab + T_FV_3016_M);
			// Validating Period
			// Validating Stmt From date 9
			if (!StmtFromDate.equals(FIELD_NULL) && !StmtFromDate.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 3" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3117_C + tab + T_FV_3117_M);
			// Validating Stmt From date
			// Validating Stmt To date 10
			if (!StmtToDate.equals(FIELD_NULL) && !StmtToDate.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 4" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3118_C + tab + T_FV_3118_M);
			// Validating Stmt To date
			// Validating LastBankChallanNo 11
			boolean validLstBnkChlnNoProvided = false;
			boolean lastBnkChlnNoNotProvided = false;
			if (LastBankChallanNo.equals(FIELD_NULL) || LastBankChallanNo.equals(FIELD_SEPERATOR)) {
				if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) { /*
																													 * In case of Challan adittion and Nil Challan Last Bank Challan Number is not
																													 * provided
																													 */
				} else {
					if ((DeductorType.equals(STATUTORY_BODY_CG) || // New Deductor Type Added For "OTHERS" by AMI
							DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG) || DeductorType.equals(LOCAL_AUTHORITY_SG)
							|| DeductorType.equals(COMPANY89) || DeductorType.equals(BRANCH_DIV_COMPANY) || DeductorType.equals(ASSOCIATION_OF_PERSON) || DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON) || DeductorType.equals(BODY_OF_INDIVIDUALS)
							|| DeductorType.equals(INDIVIDUAL) || DeductorType.equals(FIRM) || DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) && UploadTypeCH.equals(UPLOADTYPE_CORRECTION) && NillChallanIndicator.equals("N"))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3019_C + tab + T_FV_3019_M);
					else
						lastBnkChlnNoNotProvided = true;
				}
			} else {
				if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3018_C + tab + T_FV_3018_M);
				else if (LastBankChallanNo.length() <= 9) {
					if (obj_FieldValidation.isInt(LastBankChallanNo))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3017_C + tab + T_FV_3017_M);
					else if (Integer.parseInt(LastBankChallanNo.trim()) > 99999)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3017_C + tab + T_FV_3017_M);
					else
						validLstBnkChlnNoProvided = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3017_C + tab + T_FV_3017_M);
			} // Validating LastBankChallanNo
				// Validating BankChallanNo 12
			bankChallanNoProvided = false;
			boolean validBankChlNoProvided = false;
			boolean bankChlNoNotProvided = false;
			if (BankChallanNo.equals(FIELD_NULL) || BankChallanNo.equals(FIELD_SEPERATOR)) {
				if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				} else if (DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG)
						|| DeductorType.equals(LOCAL_AUTHORITY_SG) || DeductorType.equals(COMPANY89) || DeductorType.equals(BRANCH_DIV_COMPANY) || DeductorType.equals(ASSOCIATION_OF_PERSON) || DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON)
						|| DeductorType.equals(BODY_OF_INDIVIDUALS) || DeductorType.equals(INDIVIDUAL) || DeductorType.equals(FIRM) || DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) // New Deductor Type Added For "OTHERS" by
																																															// AMI
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3022_C + tab + T_FV_3022_M);
				else
					bankChlNoNotProvided = true;
			} else {
				if ((ByBookCash.equalsIgnoreCase("Y") && (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) && !NillChallanIndicator.equals("Y")) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3153_C + tab + T_FV_3153_M);// change for
																																														// mandatory
																																														// BIN
				} else if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3056_C + tab + T_FV_3056_M);
				// Added By amit for fvu 4.5 to handle space
				else if (!(BankChallanNo.trim().length() == BankChallanNo.length())) {
					bankChallanNoProvided = true;
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
				}

				// Amit end forfvu 4.5
				else if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
					if (BankChallanNo.trim().length() <= 5) {
						if (obj_FieldValidation.isInt(BankChallanNo)) {
							bankChallanNoProvided = true;
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
						}

						// commented for fvu 4.5
						/*
						 * else if (Integer.parseInt(BankChallanNo.trim()) > 99999) {
						 * 
						 * if (paperReturnFile &&
						 * (BankChallanNo.trim().equals(paperRetBankChalnDefValue))) {
						 * Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab +
						 * ChallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
						 * byPassBooking = true; paperReturnRelax = true; validBankChlNoProvided = true;
						 * bankChallanNoProvided = true; } else { //
						 * System.out.println("In the bank chalan num check more thn 5 digits");
						 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No"
						 * + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3021_C + tab +
						 * T_FV_3021_M); bankChallanNoProvided = true; } }
						 */
						else if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || (ChallanUpdationIndicator.equals("0") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))) {
							if (validLstBnkChlnNoProvided && (Integer.parseInt(LastBankChallanNo.trim()) != Integer.parseInt(BankChallanNo.trim()))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3096_C + tab + T_FV_3096_M);
							} else {
								validBankChlNoProvided = true;
								bankChallanNoProvided = true;
							}
						} else {
							validBankChlNoProvided = true;
							bankChallanNoProvided = true;
						}
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
						bankChallanNoProvided = true;
					}
				}
				// Commented For FVU 3.0 By AMI ; Reverted by Abhinandan for FVU 3.0 as per the
				// requirement of ganeshan
				else if (!(UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
					if (BankChallanNo.length() <= 9) {
						if (obj_FieldValidation.isInt(BankChallanNo)) {
							bankChallanNoProvided = true;
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
						} else if (Integer.parseInt(BankChallanNo.trim()) > 99999) {

							if (paperReturnFile && (BankChallanNo.trim().equals(paperRetBankChalnDefValue))) {
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
								byPassBooking = true;
								paperReturnRelax = true;
								validBankChlNoProvided = true;
								bankChallanNoProvided = true;
							} else {
								// System.out.println("In the bank chalan num check more thn 5 digits");
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
								bankChallanNoProvided = true;
							}
						} else if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || (ChallanUpdationIndicator.equals("0") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))) {
							if (validLstBnkChlnNoProvided && (Integer.parseInt(LastBankChallanNo.trim()) != Integer.parseInt(BankChallanNo.trim()))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3096_C + tab + T_FV_3096_M);
							} else {
								validBankChlNoProvided = true;
								bankChallanNoProvided = true;
							}
						} else {
							validBankChlNoProvided = true;
							bankChallanNoProvided = true;
						}
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
						bankChallanNoProvided = true;
					}
				} else {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank Challan No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3021_C + tab + T_FV_3021_M);
					bankChallanNoProvided = true;
				} // Validating BankChallanNo
			}
			// Validating LastTransferVoucherNo 13
			boolean validLastTrnsfrVouchNoProvided = false;
			boolean lastTransferVoucherNoNotProvided = false;
			if (LastTransferVoucherNo.equals(FIELD_NULL) || LastTransferVoucherNo.equals(FIELD_SEPERATOR)) {
				if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) { /*
																													 * In case of Challan adittion and Nil Challan Last transfer Voucher Number is
																													 * not provided
																													 */
				} else
					lastTransferVoucherNoNotProvided = true;
			} else {
				if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Transfer Voucher No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3025_C + tab + T_FV_3025_M);
				else if (DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG)
						|| DeductorType.equals(LOCAL_AUTHORITY_SG) || DeductorType.equals(COMPANY89) || DeductorType.equals(BRANCH_DIV_COMPANY) || DeductorType.equals(ASSOCIATION_OF_PERSON) || DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON)
						|| DeductorType.equals(BODY_OF_INDIVIDUALS) || DeductorType.equals(INDIVIDUAL) || DeductorType.equals(FIRM) || DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) // New Deductor Type Added For "OTHERS" by
																																															// AMI
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Transfer Voucher No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3057_C + tab + T_FV_3057_M);
				else if (validLstBnkChlnNoProvided)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Transfer Voucher No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3055_C + tab + T_FV_3055_M);
				else if ((validBankChlNoProvided && ChallanUpdationIndicator.equals("0")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Transfer Voucher No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3123_C + tab + T_FV_3123_M);
				else {
					if (LastTransferVoucherNo.length() <= 9) {
						if (obj_FieldValidation.isInt(LastTransferVoucherNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Transfer Voucher No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3028_C + tab + T_FV_3028_M);
						else
							validLastTrnsfrVouchNoProvided = true;
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Transfer Voucher No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3028_C + tab + T_FV_3028_M);
				}
			} // Validating LastTransferVoucherNo
				// Validating TransferVoucherNo 14
			transferVoucherNoProvided = false;
			if (TransferVoucherNo.equals(FIELD_NULL) || TransferVoucherNo.equals(FIELD_SEPERATOR)) {
				if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				} else if (((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || ChallanUpdationIndicator.equals("0")) && validLastTrnsfrVouchNoProvided)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3060_C + tab + T_FV_3060_M);
				}

				// M02_B Added on 28/01/2011 If Last TV is present, Then TV has to be present
				// for Correction
				else if ((!LastTransferVoucherNo.equals(FIELD_NULL) && !LastTransferVoucherNo.equals(FIELD_SEPERATOR)) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3024_C + tab + T_FV_3024_M);
					// $$$$$$
				}
				// M02_E
				// changed for FVU 4.6
				else if (isFinYrGrtrthn && (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && (ByBookCash.equalsIgnoreCase("Y")) && !NillChallanIndicator.equals("Y")) // for BIN
				{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3156_C + tab + T_FV_3156_M);
				}

			} else {
				if (ByBookCash.equalsIgnoreCase("Y") && (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && !NillChallanIndicator.equals("Y")) {
					if (!obj_FieldValidation.ValidateBinMandatoryTV(TransferVoucherNo)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3155_C + tab + T_FV_3155_M);
					}
					int itv = -1;
					try {

						itv = Integer.parseInt(TransferVoucherNo);

					} catch (Exception e) {

					}
					System.out.println("Value of TV::" + itv);
					if (itv == 0) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3155_C + tab + T_FV_3155_M);
					}
				} else if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3059_C + tab + T_FV_3059_M);
				else if (DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG)
						|| DeductorType.equals(LOCAL_AUTHORITY_SG) || DeductorType.equals(COMPANY89) || DeductorType.equals(BRANCH_DIV_COMPANY) || DeductorType.equals(ASSOCIATION_OF_PERSON) || DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON)
						|| DeductorType.equals(BODY_OF_INDIVIDUALS) || DeductorType.equals(INDIVIDUAL) || DeductorType.equals(FIRM) || DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) // New Deductor Type Added For "OTHERS" by
																																															// AMI
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3067_C + tab + T_FV_3067_M);
				else if (validBankChlNoProvided)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3065_C + tab + T_FV_3065_M);
				else if ((validLstBnkChlnNoProvided && ChallanUpdationIndicator.equals("0")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3125_C + tab + T_FV_3125_M);
				else if (TransferVoucherNo.length() <= 9) {

					// M02_B Added by Dhanya on 28/01/2011 as zeros are not allowed in TV field
					int iTVNo = 1;
					try {

						iTVNo = Integer.parseInt(TransferVoucherNo);

					} catch (Exception e) {

					}
					// M02_E

					// M02_B Added by Dhanya on 28/01/2011 as zeros are not allowed in TV field
					// Modified by manas as zeros are allowed for c2,c3,c5
					if (iTVNo == 0 && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3024_C + tab + T_FV_3024_M);
					}
					// M02_E

					else if (obj_FieldValidation.isInt(TransferVoucherNo))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3024_C + tab + T_FV_3024_M);
					else if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || (ChallanUpdationIndicator.equals("0") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))) {
						if (!LastTransferVoucherNo.equals(TransferVoucherNo)) {
							// DBT The msg shown is changed( and the change is reverted); previous msg was
							// T_FV_3060_M ; changed by Dhanya on 24/12/2010
							// Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher
							// No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3152_C + tab +
							// T_FV_3152_M);
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3060_C + tab + T_FV_3060_M);
						} else
							transferVoucherNoProvided = true;
					} else
						transferVoucherNoProvided = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Transfer Voucher/DDO Serial No " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3024_C + tab + T_FV_3024_M);
			} // Validating TransferVoucherNo
				// Validating LastBankBranchCode 15

			/*
			 * int a = 0; a = Integer.parseInt(TransferVoucherNo);
			 * System.out.println("sdfsdfsdfs "+TransferVoucherNo);
			 * if(Integer.parseInt(TransferVoucherNo)>0) {
			 * System.out.println("--------------------------------------------------- yes "
			 * +a); } else {
			 * System.out.println("--------------------------------------------------- No "
			 * +a); }
			 */

			if (LastBankBranchCode.equals(FIELD_NULL) || LastBankBranchCode.equals(FIELD_SEPERATOR)) {
				if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) { /* Nil Challan Do Not have Last Bank Branch Code */
				} else if ((DeductorType.equals(STATUTORY_BODY_CG) || // New Deductor Type Added For "OTHERS" by AMI
						DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG) || DeductorType.equals(LOCAL_AUTHORITY_SG)
						|| DeductorType.equals(COMPANY89) || DeductorType.equals(BRANCH_DIV_COMPANY) || DeductorType.equals(ASSOCIATION_OF_PERSON) || DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON) || DeductorType.equals(BODY_OF_INDIVIDUALS)
						|| DeductorType.equals(INDIVIDUAL) || DeductorType.equals(FIRM) || DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST)) && UploadTypeCH.equals(UPLOADTYPE_CORRECTION) && NillChallanIndicator.equals("N"))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3061_C + tab + T_FV_3061_M);
				else if (validLstBnkChlnNoProvided)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3121_C + tab + T_FV_3121_M);
			} else {
				if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3032_C + tab + T_FV_3032_M);

				// M02_B
				// Commeneted for change M02
				// else if (lastBnkChlnNoNotProvided)
				// Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch
				// Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3127_C + tab +
				// T_FV_3127_M);

				else if (lastBnkChlnNoNotProvided) {
					// TV
					if (ByBookCash.equalsIgnoreCase("Y") && UploadTypeCH.equals(UPLOADTYPE_CORRECTION) && !NillChallanIndicator.equals("Y")) {
						if (LastBankBranchCode.length() == 7 && LastBankBranchCode.trim().length() == 7) {
							if (obj_FieldValidation.isAlphaNum(LastBankBranchCode))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3031_C + tab + T_FV_3031_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3031_C + tab + T_FV_3031_M);
					} else // Challan
					{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3127_C + tab + T_FV_3127_M);
					}
				}
				// M02_E

				else if (validLastTrnsfrVouchNoProvided)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3058_C + tab + T_FV_3058_M);
				else if ((transferVoucherNoProvided && ChallanUpdationIndicator.equals("0")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3124_C + tab + T_FV_3124_M);
				else if (LastBankBranchCode.length() == 7 && LastBankBranchCode.trim().length() == 7) {
					if (obj_FieldValidation.isInt(LastBankBranchCode))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3031_C + tab + T_FV_3031_M);
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3031_C + tab + T_FV_3031_M);
			} // Validating LastBankBranchCode
				// Validating BankBranchCode 16
			if (BankBranchCode.equals(FIELD_NULL) || BankBranchCode.equals(FIELD_SEPERATOR)) {
				// changed for FVU 4.6
				if (isFinYrGrtrthn && ByBookCash.equalsIgnoreCase("Y") && (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && !NillChallanIndicator.equals("Y")) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3154_C + tab + T_FV_3154_M);
				}

				else if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					// Added By AMI For FVU 3.0 on 14th Oct,2010
					if (DateOfBankChallanNo.equals(FIELD_NULL) || DateOfBankChallanNo.equals(FIELD_SEPERATOR)) {
						if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
					}
				} else if (DeductorType.equals(STATUTORY_BODY_CG) || DeductorType.equals(STATUTORY_BODY_SG) || DeductorType.equals(AUTONOMOUS_BODY_CG) || DeductorType.equals(AUTONOMOUS_BODY_SG) || DeductorType.equals(LOCAL_AUTHORITY_CG)
						|| DeductorType.equals(LOCAL_AUTHORITY_SG) || DeductorType.equals(COMPANY89) || DeductorType.equals(BRANCH_DIV_COMPANY) || DeductorType.equals(ASSOCIATION_OF_PERSON) || DeductorType.equals(ARTIFICIAL_JURIDICAL_PERSON)
						|| DeductorType.equals(BODY_OF_INDIVIDUALS) || DeductorType.equals(INDIVIDUAL) || DeductorType.equals(FIRM) || DeductorType.equals(ASSOCIATION_OF_PERSON_TRUST))// New Deductor Type Added For "OTHERS" by
																																														// AMI
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3036_C + tab + T_FV_3036_M);
				else if (validBankChlNoProvided)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3073_C + tab + T_FV_3073_M);

				// M02_B Added on 28/01/2011 If Last BSR is present, Then BSR has to be present
				// for Correction
				else if ((!LastBankBranchCode.equals(FIELD_NULL) && !LastBankBranchCode.equals(FIELD_SEPERATOR)) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3035_C + tab + T_FV_3035_M);
					// $$$$$$
				}
				// M02_E

				// Added By AMI For FVU 3.0 on 14th Oct,2010
				else {
					if (DateOfBankChallanNo.equals(FIELD_NULL) || DateOfBankChallanNo.equals(FIELD_SEPERATOR)) {
						if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No2'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
					}
				}
			} else {

				if (ByBookCash.equalsIgnoreCase("Y") && (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && !NillChallanIndicator.equals("Y")) {
					if (obj_FieldValidation.isInt(BankBranchCode)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3154_C + tab + T_FV_3154_M);
					}
					// added by abhishek for BIN mandatory field check on 01/06/2012
					else if (BankBranchCode.length() == 7 && BankBranchCode.trim().length() == 7) {
						if (obj_FieldValidation.isMod7(BankBranchCode))

							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3149_C + tab + T_FV_3149_M);
					}
				}

				if (NillChallanIndicator.equals("Y") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3063_C + tab + T_FV_3063_M);
				else if (bankChlNoNotProvided && !ByBookCash.equals("Y")) // Added By AMI For FVU 3.0
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3122_C + tab + T_FV_3122_M);
				else {

					if (BankBranchCode.length() == 7 && BankBranchCode.trim().length() == 7) {
						if (paperReturnFile) {
							if (BankBranchCode.equals(paperRetBankBSRDefValue)) {
								byPassBooking = true;
								paperReturnRelax = true;
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3035_C + tab + T_FV_3035_M);
							}
						}
						// Added By AMI For FVU 3.0
						if (ByBookCash.equals("Y") && bankChlNoNotProvided) {
							if (obj_FieldValidation.isAlphaNum(BankBranchCode))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3035_C + tab + T_FV_3035_M);

							// CR 2446
							else if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || (ChallanUpdationIndicator.equals("0") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))) {
								if (!LastBankBranchCode.equals(BankBranchCode)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3151_C + tab + T_FV_3151_M);
								}

							}
						} // END
						else if (obj_FieldValidation.isInt(BankBranchCode)) {
							// System.out.println("Getting rejecte 1 ::::::::::::");
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3035_C + tab + T_FV_3035_M);
						} else if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || (ChallanUpdationIndicator.equals("0") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))) {
							if (!LastBankBranchCode.equals(BankBranchCode)) {
								// DBT The msg shown over here should be T_FV_3151_M ; previous T_FV_3160_M
								// changed by Dhanya on 24/12/2010
								// Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch
								// Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab
								// + T_FV_3151_C + tab + T_FV_3151_M);
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3062_C + tab + T_FV_3062_M);
							}
						}
						// 19-feb-2009 added for BSR check --- Nahush

						if (!paperReturnFile) {
							// CHANGE AMI
							if (BankBranchCode.equals("0000000")
									&& (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || ChallanUpdationIndicator.equals("1") || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {

								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3149_C + tab + T_FV_3149_M);
							} else {
								// END
								bsrPresent = checkBSR(BankBranchCode);

								// Added By AMI For FVU 3.0

								// System.out.println("**********Checking the BSR Code ***************");

								if (DateOfBankChallanNo.equals(FIELD_NULL) || DateOfBankChallanNo.equals(FIELD_SEPERATOR)) {
									if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
										bankDatePresent = false;
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
									}
								} else if (DateOfBankChallanNo.length() == 8 && DateOfBankChallanNo.trim().length() == 8) {
									if (obj_FieldValidation.isInt(DateOfBankChallanNo) && obj_FieldValidation.isDate(DateOfBankChallanNo))
										bankDatePresent = false;
								} else
									bankDatePresent = false;
								// END

								if (bankDatePresent) // Condition added to Check whether DateOfBankChallanNo is present
														// or not
								{
									// em.out.println("************ In the validations of DateOfBankChallanNo
									// *********");
									dateOfChallan = DateOfBankChallanNo.substring(0, 2) + "/" + DateOfBankChallanNo.substring(2, 4) + "/" + DateOfBankChallanNo.substring(4, 8);
								}

								if (!bsrPresent && bankDatePresent) // Condition added to Check whether
																	// DateOfBankChallanNo is present or not
								{

									// Added By AMI For FVU 3.0
									if (!ByBookCash.equals("Y")) {
										Str_Buffer.appendElectronicWarning(
												LineNo + tab + "Challan" + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + "NA" + tab + dateOfChallan + tab + BankChallanNo + tab + BankBranchCode + tab + T_FV_3139_C + tab + T_FV_3139_M);
										bsrCount = 0;

										// for(int i=0;i< bsrList.size();i++)
										// {
										// if(BankBranchCode.equals(bsrList.get(i).toString()))
										// bsrCount=bsrCount+1;
										// }

										// if (bsrCount == 0)
										bsrList.add(BankBranchCode + FIELD_SEPERATOR + BH_BatchNo);
									}

								}
							}

						}
					}

					else {
						// System.out.println("Getting rejecte 2 ::::::::::::");
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Bank-Branch Code/Form 24G receipt No. " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3035_C + tab + T_FV_3035_M);
					}
				}
			} // Validating BankBranchCode
				// Validating Last Date Of Bank Challan No/ Transfer Voucher number 17
			boolean validLastDate = false;
			if (LastDateOfBankChallanNo.equals(FIELD_NULL) || LastDateOfBankChallanNo.equals(FIELD_SEPERATOR)) {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)
						|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3039_C + tab + T_FV_3039_M);
			} else {
				if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3038_C + tab + T_FV_3038_M);
				else {
					if (LastDateOfBankChallanNo.length() == 8 && LastDateOfBankChallanNo.trim().length() == 8) {
						if (obj_FieldValidation.isInt(LastDateOfBankChallanNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3037_C + tab + T_FV_3037_M);
						else if (obj_FieldValidation.isDate(LastDateOfBankChallanNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3037_C + tab + T_FV_3037_M);
						else if (obj_FieldValidation.isFutureDate(LastDateOfBankChallanNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3037_C + tab + T_FV_3037_M);
						else if (obj_FieldValidation.isDateGreaterThenRRRDatePresentDate(LastDateOfBankChallanNo, RRRDatePresentDate))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3037_C + tab + T_FV_3037_M);
						else
							validLastDate = true;
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3037_C + tab + T_FV_3037_M);
				}
			} // Validating LastDateOfBankChallanNo
				// Validating Date Of Bank Challan No/ Transfer Voucher number 18

			// Changes Done By AMI For FVU 3.0
			if (!DateOfBankChallanNo.equals(FIELD_NULL) && !DateOfBankChallanNo.equals(FIELD_SEPERATOR)) {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3119_C + tab + T_FV_3119_M);
				else if (DateOfBankChallanNo.length() == 8 && DateOfBankChallanNo.trim().length() == 8) {
					// System.out.println("DateOfBankChallanNo"+DateOfBankChallanNo);
					if (obj_FieldValidation.isInt(DateOfBankChallanNo)) {
						valueDate = false; // Added By AMI
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
					} else if (obj_FieldValidation.isDate(DateOfBankChallanNo)) {
						// System.out.println("STEP1 \n");
						valueDate = false; // Added By AMI
						if (paperReturnFile) {
							if (DateOfBankChallanNo.equals(paperRetDateBankChalnDefValue)) {
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
								byPassBooking = true;
								paperReturnRelax = true;
							} else
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
					} else if (obj_FieldValidation.isFutureDate(DateOfBankChallanNo)) {
						// System.out.println("STEP2 \n");
						valueDate = false; // Added By AMI
						if (paperReturnFile) {
							byPassBooking = true;
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
						}

						else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);

					}
					// Commented for FVU 4.0
					/*
					 * else if (obj_FieldValidation.isDateAfterFinYear(DateOfBankChallanNo,
					 * FinancialYr)) { //System.out.println("STEP3 \n"); if (paperReturnFile) {
					 * byPassBooking = true; paperReturnRelax = true;
					 * Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab +
					 * ChallanDetailRecordNo + tab + tab + T_FV_3076_C + tab + T_FV_3076_M); } else
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * "Date of 'Bank Challan No / Transfer Voucher No'" + tab +
					 * CurrentchallanDetailRecordNo + tab + tab + T_FV_3076_C + tab + T_FV_3076_M);
					 * 
					 * 
					 * }
					 */
					else if (obj_FieldValidation.isDateGreaterThenRRRDatePresentDate(DateOfBankChallanNo, RRRDatePresentDate)) {
						// System.out.println("STEP4 \n");
						if (paperReturnFile) {
							byPassBooking = true;
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);

					}
					// Added by Abhishek on 01/06/2012 for validation on bin mandatory fields
					else if (ByBookCash.equalsIgnoreCase("Y") && (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && !NillChallanIndicator.equals("Y")) {
						if (obj_FieldValidation.isLastDayOfMnth(DateOfBankChallanNo)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3157_C + tab + T_FV_3157_M);
						}
					} else if (validLastDate == true) {
						// System.out.println("STEP5 \n");
						// valueDate = false;
						if ((ChallanUpdationIndicator.equals("0") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) {
							valueDate = false; // Added By AMI
							if (!DateOfBankChallanNo.equals(LastDateOfBankChallanNo))
								// SONU
								// Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank
								// Challan No / Transfer Voucher No'" + tab + tab + tab + T_FV_3064_C + tab +
								// T_FV_3064_M);
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3064_C + tab + T_FV_3064_M);
						}

					}

					// CHANGE AMI DHANYA COMMENT REMOVE
					if (NillChallanIndicator.equals("Y") && !paperReturnFile && valueDate
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || ChallanUpdationIndicator.equals("1") || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
						// version Commented FVU 7.2
						if (obj_FieldValidation.isDateLastDateOfQuarter(DateOfBankChallanNo, FinancialYr, Qperiod)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3150_C + tab + T_FV_3150_M);
						}
					}
					// END
					// Added for FVU 4.0
					if (!NillChallanIndicator.equals("Y") && !ByBookCash.equalsIgnoreCase("Y") && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)
							|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {

						if (obj_FieldValidation.isDateAfterPrevFinYear(DateOfBankChallanNo, FinancialYr)) {

							if (paperReturnFile) {
								byPassBooking = true;
								paperReturnRelax = true;
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3166_C + tab + T_FV_3166_M);
							} else
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3166_C + tab + T_FV_3166_M);

						}
					} else {

						if (obj_FieldValidation.isDateAfterFinYear(DateOfBankChallanNo, FinancialYr)) {
							// System.out.println("STEP3 \n");
							if (paperReturnFile) {
								byPassBooking = true;
								paperReturnRelax = true;
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3076_C + tab + T_FV_3076_M);
							} else
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3076_C + tab + T_FV_3076_M);

						}
					}

				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of 'Bank Challan No / Transfer Voucher No'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3040_C + tab + T_FV_3040_M);
			} // Validating DateOfBankChallanNo
				// Validating MajorHeadCode 19
			if (!MajorHeadCode.equals(FIELD_NULL) && !MajorHeadCode.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 5 " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3011_C + tab + T_FV_3011_M);
			} // Validating MajorSectionCode
				// Validating MinorSectionCode 20
			if (!MinorHeadCode.equals(FIELD_NULL) && !MinorHeadCode.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 6 " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3042_C + tab + T_FV_3042_M);
			} // Validating MinorSectionCode

			// Validating Section 21

			if (isFinYrGrtrthn) // for FVU 3.8 by Shalin
			{
				if (!Section.equals(FIELD_NULL) && !Section.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + tab + tab + T_FV_3160_C + tab + T_FV_3160_M);
			} else {

				if (Section.equals(FIELD_NULL) || Section.equals(FIELD_SEPERATOR)) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3043_C + tab + T_FV_3043_M);
					}

					// M01_B
					// Commeneted for M01_B, as section should be there for C3 irrespective of ch
					// updation indicator

					/*
					 * else if ((!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) &&
					 * !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) &&
					 * !ChallanUpdationIndicator.equals("0"))) Str_Buffer.append(LineNo + tab +
					 * currentUploadType + tab + "Section / Collection Code" + tab +
					 * CurrentchallanDetailRecordNo + tab + tab + T_FV_3043_C + tab + T_FV_3043_M);
					 */
					else if ((!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3043_C + tab + T_FV_3043_M);
					// M01_E

				} else {

					// M01_B

					// Commeneted for M01_B, as section should be there for C3 irrespective of ch
					// updation indicator
					/*
					 * if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) ||
					 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) ||
					 * (ChallanUpdationIndicator.equals("0") &&
					 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab
					 * + T_FV_3052_C + tab + T_FV_3052_M);
					 */

					if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)

					)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3052_C + tab + T_FV_3052_M);
					// M01_E

					else if (Section.length() <= 3) {
						if (FormNo.equals(FORM_24Q)) {
							if (!(Section.equals("92A")) && !(Section.equals("92B")))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3043_C + tab + T_FV_3043_M);
						} else if (FormNo.equals(FORM_26Q)) {
							if (!(Section.equals("193")) && !(Section.equals("94A")) && !(Section.equals("94B")) && !(Section.equals("4BB")) && !(Section.equals("94C")) && !(Section.equals("94D")) && !(Section.equals("4EE"))
									&& !(Section.equals("94F")) && !(Section.equals("94G")) && !(Section.equals("94H")) && !(Section.equals("94I")) && !(Section.equals("94J")) && !(Section.equals("94L")) && !(Section.equals("194")))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3043_C + tab + T_FV_3043_M);
						} else if (FormNo.equals(FORM_27Q)) {
							if (!(Section.equals("94E")) && !(Section.equals("195")) && !(Section.equals("96A")) && !(Section.equals("96B")) && !(Section.equals("96C")) && !(Section.equals("96D"))
									&& !(Section.equals("4LB") && Integer.parseInt(FinancialYr) >= 201112) && !(Section.equals("4LC") && Integer.parseInt(FinancialYr) >= 201213) && !(Section.equals("4LD") && Integer.parseInt(FinancialYr) >= 201314)) // Modified
																																																															// on
																																																															// 13/08/2012
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3043_C + tab + T_FV_3043_M);

							// Added for FVU 4.0
							if (!DeductorType.equals("K") && !DeductorType.equals("M") && Section.equals("4LC")) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3167_C + tab + T_FV_3167_M);
							}
						} else if (FormNo.equals(FORM_27EQ)) {
							if (!(Section.equals("A")) && !(Section.equals("B")) && !(Section.equals("C")) && !(Section.equals("D")) && !(Section.equals("E")) && !(Section.equals("F")) && !(Section.equals("G")) && !(Section.equals("H"))
									&& !(Section.equals("I")) && !(Section.equals("J") && Integer.parseInt(FinancialYr) >= 201213) && !(Section.equals("K") && Integer.parseInt(FinancialYr) >= 201213)) // Modified on
																																																			// 13/08/2012

								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3043_C + tab + T_FV_3043_M);

							// added by Shalin for FVU 4.4
							else if ((Section.equals("J") || Section.equals("K")) && Integer.parseInt(FinancialYr) == 201213 && Qperiod.equals("Q1")) {
								if (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code1" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_4301_C + tab + T_FV_4301_M);
							}

						}

					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section / Collection Code" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3043_C + tab + T_FV_3043_M);
				} // Validating Section
					// ######## Added for validating remark1 field . Manvendra :: 15-Feb-2008
				sectionForThisChallan = Section;
			}

			// Validate OLTAS-INCOME TAX ----- 22

			boolean errorOltasIncomeTax = false;
			if (OltasIncomeTax.equals(FIELD_NULL) || OltasIncomeTax.equals(FIELD_SEPERATOR)) {
				if ((!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !ChallanUpdationIndicator.equals("0")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas  TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3020_C + tab + T_FV_3020_M);
			} else if (OltasIncomeTax.length() <= 15) {
				if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || ChallanUpdationIndicator.equals("0")) && ChallanUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas  TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3027_C + tab + T_FV_3027_M);
				else if (obj_FieldValidation.isDecimalNumber(OltasIncomeTax))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas  TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3020_C + tab + T_FV_3020_M);
				// Added By amit for 4.5
				else if (OltasIncomeTax.length() != OltasIncomeTax.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas  TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3020_C + tab + T_FV_3020_M);

				}
				// Amit end for Fvu 4.5
				else if (!OltasIncomeTax.trim().endsWith(".00")) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3020_C + tab + T_FV_3020_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas  TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3020_C + tab + T_FV_3020_M);
				} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(OltasIncomeTax.trim()) != 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas  TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3033_C + tab + T_FV_3033_M);
				else
					errorOltasIncomeTax = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas  TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3020_C + tab + T_FV_3020_M);
			// Validate OLTAS-INCOME TAX
			// Validate OLTAS-SURCHARGE ----23
			boolean errorOltasSurcharge = false;
			if (OltasSurcharge.equals(FIELD_NULL) || OltasSurcharge.equals(FIELD_SEPERATOR)) {
				if ((!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !ChallanUpdationIndicator.equals("0")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS  -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3034_C + tab + T_FV_3034_M);
			} else if (OltasSurcharge.length() <= 15) {
				if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || ChallanUpdationIndicator.equals("0")) && ChallanUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS  -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3093_C + tab + T_FV_3093_M);

				else if (obj_FieldValidation.isDecimalNumber(OltasSurcharge))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS  -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3034_C + tab + T_FV_3034_M);
				// Added By amit for 4.5
				if (OltasSurcharge.length() != OltasSurcharge.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS  -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3034_C + tab + T_FV_3034_M);
				}

				// Amit end for Fvu 4.5
				else if (!OltasSurcharge.trim().endsWith(".00")) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3034_C + tab + T_FV_3034_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS  -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3034_C + tab + T_FV_3034_M);
				} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(OltasSurcharge.trim()) != 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS  -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3094_C + tab + T_FV_3094_M);
				else
					errorOltasSurcharge = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS  -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3034_C + tab + T_FV_3034_M);
			// Validate OLTAS-SURCHARGE
			// Validate OLTAS-CESS ------------ 24
			boolean errorOltasCess = false;
			if (OltasCess.equals(FIELD_NULL) || OltasCess.equals(FIELD_SEPERATOR)) {
				if ((!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !ChallanUpdationIndicator.equals("0")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3095_C + tab + T_FV_3095_M);
			}
			// Added By amit for fvu 4.5
			else if (OltasCess.length() != OltasCess.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3095_C + tab + T_FV_3095_M);
			}
			// Amit end for fvu 4.5
			else if (OltasCess.length() <= 15) {
				if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || ChallanUpdationIndicator.equals("0")) && ChallanUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3106_C + tab + T_FV_3106_M);
				else if (obj_FieldValidation.isDecimalNumber(OltasCess))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3095_C + tab + T_FV_3095_M);
				else if (!OltasCess.trim().endsWith(".00")) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3095_C + tab + T_FV_3095_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3095_C + tab + T_FV_3095_M);
				} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(OltasCess.trim()) != 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3107_C + tab + T_FV_3107_M);
				else
					errorOltasCess = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Oltas TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3095_C + tab + T_FV_3095_M);
			// Validate OLTAS-CESS
			// Validate OLTAS-INTEREST ---- 25
			boolean errorOltasInterest = false;
			if (OltasInterest.equals(FIELD_NULL) || OltasInterest.equals(FIELD_SEPERATOR)) {
				if ((!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !ChallanUpdationIndicator.equals("0")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3108_C + tab + T_FV_3108_M);
			}
			// Added By amit for 4.5
			else if (OltasInterest.length() != OltasInterest.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3108_C + tab + T_FV_3108_M);
			}

			// Amit end for Fvu 4.5
			else if (OltasInterest.length() <= 15) {
				if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || ChallanUpdationIndicator.equals("0")) && ChallanUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3109_C + tab + T_FV_3109_M);
				else if (obj_FieldValidation.isDecimalNumber(OltasInterest))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3108_C + tab + T_FV_3108_M);
				else if (!OltasInterest.trim().endsWith(".00")) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3108_C + tab + T_FV_3108_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3108_C + tab + T_FV_3108_M);
				} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(OltasInterest.trim()) != 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3110_C + tab + T_FV_3110_M);
				else
					errorOltasInterest = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3108_C + tab + T_FV_3108_M);
			// Validate OLTAS-INTEREST
			// Validate OLTAS-OTHERS ------- 26
			boolean errrorOltasOthers = false;
			if (OltasOthers.equals(FIELD_NULL) || OltasOthers.equals(FIELD_SEPERATOR)) {
				if ((!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !ChallanUpdationIndicator.equals("0")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3111_C + tab + T_FV_3111_M);
			}
			// Added By amit for 4.5
			else if (OltasOthers.length() != OltasOthers.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3111_C + tab + T_FV_3111_M);
			}

			// Amit end for Fvu 4.5
			else if (OltasOthers.length() <= 15) {
				if ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || ChallanUpdationIndicator.equals("0")) && ChallanUpdationIndicatorRequired)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3112_C + tab + T_FV_3112_M);

				else if (obj_FieldValidation.isDecimalNumber(OltasOthers))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3111_C + tab + T_FV_3111_M);
				else if (!OltasOthers.trim().endsWith(".00")) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3111_C + tab + T_FV_3111_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3111_C + tab + T_FV_3111_M);
				} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(OltasOthers.trim()) != 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3113_C + tab + T_FV_3113_M);
				else
					errrorOltasOthers = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Oltas TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3111_C + tab + T_FV_3111_M);
			// Validate OLTAS-OTHERS

			// Added for FVU 3.8 by Shalin --- START

			// Validating LateFee 39

			boolean errorLateFee = false;
			if (isFinYrGrtr && (UploadType.equals(UPLOADTYPE_REGULAR) || (UploadType.equals(UPLOADTYPE_CORRECTION)
					&& (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (ChallanUpdationIndicator.equals("1") || ChallanUpdationIndicator.equals("0"))) // Changed
																																																										// by
																																																										// Shalin
																																																										// for
																																																										// FVu
																																																										// 4.1
							|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))) {

				if (LateFee.equals(FIELD_NULL) || LateFee.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Fee'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3158_C + tab + T_FV_3158_M);
				}
				// Added By amit for 4.5

				else if (LateFee.length() != LateFee.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Fee'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3158_C + tab + T_FV_3158_M);
				}

				// Amit end for Fvu 4.5
				else if (LateFee.length() <= 15) {

					if (obj_FieldValidation.isDecimalNumber(LateFee))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Fee'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3158_C + tab + T_FV_3158_M);
					else if (!LateFee.trim().endsWith(".00")) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Fee'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3158_C + tab + T_FV_3158_M);
					} else if (!(Double.parseDouble(LateFee) >= 0.00)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Fee'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3158_C + tab + T_FV_3158_M);
					} else
						errorLateFee = true;
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Fee'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3158_C + tab + T_FV_3158_M);
			} else {
				if (!LateFee.equals(FIELD_NULL) && !LateFee.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Fee " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3162_C + tab + T_FV_3162_M);

			}

			// Validating LateFee

			// Added for fvu 3.8 by Shalin --- END

			// Validating TotalOfDepositAmountAsPerChallan 27

			boolean errrorTotalOfDepositAmountAsPerChallan = false;
			if (TotalOfDepositAmountAsPerChallan.equals(FIELD_NULL) || TotalOfDepositAmountAsPerChallan.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3120_C + tab + T_FV_3120_M);
			// Added By amit for 4.5

			else if (TotalOfDepositAmountAsPerChallan.length() != TotalOfDepositAmountAsPerChallan.trim().length()) {

				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
			}

			// Amit end for Fvu 4.5
			else if (TotalOfDepositAmountAsPerChallan.length() <= 15) {
				if (!paperReturnFile) {

					if (obj_FieldValidation.isDecimalNumber(TotalOfDepositAmountAsPerChallan))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
					else if (!TotalOfDepositAmountAsPerChallan.trim().endsWith(".00")) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
					} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim()) != 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3081_C + tab + T_FV_3081_M);
					else if (NillChallanIndicator.equals("N") && Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim()) <= 0) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
					} else {
						iTotalOfDepositAmountAsPerChallan = Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim());
						sumOfTotalOfDepositAmountAsPerChallan = sumOfTotalOfDepositAmountAsPerChallan + Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim());
						errrorTotalOfDepositAmountAsPerChallan = true;
						if (errorOltasIncomeTax && errorOltasSurcharge && errorOltasCess && errorOltasInterest && errrorOltasOthers) {
							if (isFinYrGrtr) // Added for FVU 3.8 by Shalin
							{
								if (errorLateFee) {
									if (Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim()) != Double.parseDouble(OltasIncomeTax.trim()) + Double.parseDouble(OltasSurcharge.trim()) + Double.parseDouble(OltasCess.trim())
											+ Double.parseDouble(OltasInterest.trim()) + Double.parseDouble(LateFee.trim()) + Double.parseDouble(OltasOthers.trim())) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3114_C + tab + T_FV_3114_M);
									}
								}
							} else {
								if (Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim()) != Double.parseDouble(OltasIncomeTax.trim()) + Double.parseDouble(OltasSurcharge.trim()) + Double.parseDouble(OltasCess.trim())
										+ Double.parseDouble(OltasInterest.trim()) + Double.parseDouble(OltasOthers.trim())) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3114_C + tab + T_FV_3114_M);
								}
							}
						}
					}
				} else if (paperReturnFile) {
					if (obj_FieldValidation.isDecimalNumber(TotalOfDepositAmountAsPerChallan))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
					else {
						if (!TotalOfDepositAmountAsPerChallan.trim().endsWith(".00")) {
							byPassBooking = true;
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + ChallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
						} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim()) != 0)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3081_C + tab + T_FV_3081_M);
						else if (NillChallanIndicator.equals("N") && Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim()) == 0) {
							byPassBooking = true;
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + ChallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
						}
						iTotalOfDepositAmountAsPerChallan = Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim());
						sumOfTotalOfDepositAmountAsPerChallan = sumOfTotalOfDepositAmountAsPerChallan + Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim());
						errrorTotalOfDepositAmountAsPerChallan = true;
						if (errorOltasIncomeTax && errorOltasSurcharge && errorOltasCess && errorOltasInterest && errrorOltasOthers) {

							if (isFinYrGrtr) // Added for FVU 3.8 by Shalin
							{
								if (errorLateFee) {
									if (Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim()) != Double.parseDouble(OltasIncomeTax.trim()) + Double.parseDouble(OltasSurcharge.trim()) + Double.parseDouble(OltasCess.trim())
											+ Double.parseDouble(OltasInterest.trim()) + Double.parseDouble(LateFee.trim()) + Double.parseDouble(OltasOthers.trim())) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3114_C + tab + T_FV_3114_M);
									}
								}
							} else {
								if (Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim())

								!= Double.parseDouble(OltasIncomeTax.trim()) + Double.parseDouble(OltasSurcharge.trim()) + Double.parseDouble(OltasCess.trim()) + Double.parseDouble(OltasInterest.trim()) + Double.parseDouble(OltasOthers.trim())) {
									if (paperReturnFile) {
										byPassBooking = true;
										paperReturnRelax = true;
										Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3114_C + tab + T_FV_3114_M);
									} else
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3114_C + tab + T_FV_3114_M);
								}
							}
						}
					}
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3047_C + tab + T_FV_3047_M);
			// Validating TotalOfDepositAmountAsPerChallan
			// Validating LastTotalOfDepositAmountAsPerChallan 28
			if (LastTotalOfDepositAmountAsPerChallan.equals(FIELD_NULL) || LastTotalOfDepositAmountAsPerChallan.equals(FIELD_SEPERATOR)) {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)
						|| TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3046_C + tab + T_FV_3046_M);
			} else {
				if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3045_C + tab + T_FV_3045_M);
				else {
					if (LastTotalOfDepositAmountAsPerChallan.length() <= 15) {
						if (obj_FieldValidation.isDecimalNumber(LastTotalOfDepositAmountAsPerChallan))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3044_C + tab + T_FV_3044_M);
						// added by faizan for FVU 4.5
						else if (LastTotalOfDepositAmountAsPerChallan.length() != LastTotalOfDepositAmountAsPerChallan.trim().length()) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3044_C + tab + T_FV_3044_M);
						}
						// ended by faizan
						else if (!LastTotalOfDepositAmountAsPerChallan.trim().endsWith(".00"))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3044_C + tab + T_FV_3044_M);
						else if (NillChallanIndicator.equals("Y") && Double.parseDouble(LastTotalOfDepositAmountAsPerChallan.trim()) != 0)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3080_C + tab + T_FV_3080_M);
						else if (NillChallanIndicator.equals("N") && Double.parseDouble(LastTotalOfDepositAmountAsPerChallan.trim()) <= 0) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3044_C + tab + T_FV_3044_M);
						} else if (errrorTotalOfDepositAmountAsPerChallan && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && (((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || ChallanUpdationIndicator.equals("0"))))) {
							if (Double.parseDouble(LastTotalOfDepositAmountAsPerChallan.trim()) != Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim())) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3072_C + tab + T_FV_3072_M);
							}

							totalOfLastTotalOfDepositAmountAsPerChallan = totalOfLastTotalOfDepositAmountAsPerChallan + Double.parseDouble(LastTotalOfDepositAmountAsPerChallan.trim());
						} else
							totalOfLastTotalOfDepositAmountAsPerChallan = totalOfLastTotalOfDepositAmountAsPerChallan + Double.parseDouble(LastTotalOfDepositAmountAsPerChallan.trim());
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3044_C + tab + T_FV_3044_M);
				}
			} // Validating LastTotalOfDepositAmountAsPerChallan
				// Validating TotalTaxDepositedAsPerDeducteeAnex 29
			boolean errorTotalTaxDepositedAsPerDeducteeAnex = false;
			if (TotalTaxDepositedAsPerDeducteeAnex.equals(FIELD_NULL) || TotalTaxDepositedAsPerDeducteeAnex.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3069_C + tab + T_FV_3069_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3075_C + tab + T_FV_3075_M);
			// Added By amit for 4.5
			else if (TotalTaxDepositedAsPerDeducteeAnex.length() != TotalTaxDepositedAsPerDeducteeAnex.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3069_C + tab + T_FV_3069_M);
			}
			// Amit end for Fvu 4.5
			else if (TotalTaxDepositedAsPerDeducteeAnex.length() > 15)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3069_C + tab + T_FV_3069_M);
			else if (UploadTypeCH.equals(UPLOADTYPE_REGULAR)) {
				if (obj_FieldValidation.isDecimalNumber(TotalTaxDepositedAsPerDeducteeAnex))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3069_C + tab + T_FV_3069_M);
				else if (NillChallanIndicator.equals("Y") && Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim()) != 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3079_C + tab + T_FV_3079_M);
				else if (CountOfDeducteeDetailFlag && (Integer.parseInt(CountOfDeducteeDetail.trim()) == 0) && (Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim()) != 0))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3103_C + tab + T_FV_3103_M);
				else
					errorTotalTaxDepositedAsPerDeducteeAnex = true;
			} else if (obj_FieldValidation.isFloatNumber(TotalTaxDepositedAsPerDeducteeAnex))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3069_C + tab + T_FV_3069_M);
			else if (NillChallanIndicator.equals("Y") && Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim()) != 0)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3079_C + tab + T_FV_3079_M);
			else if (CountOfDeducteeDetailFlag && (Integer.parseInt(CountOfDeducteeDetail.trim()) == 0) && (Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim()) != 0))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3103_C + tab + T_FV_3103_M);
			else if (errrorTotalOfDepositAmountAsPerChallan) {
				if (NillChallanIndicator.equals("N")) {
					if (Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim()) > Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim())) {
						if (paperReturnFile) {
							byPassBooking = true;
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3068_C + tab + T_FV_3068_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposit Amount as per deductee annexure " + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3068_C + tab + T_FV_3068_M);
					} else
						errorTotalTaxDepositedAsPerDeducteeAnex = true;
				}
			} // Validating TotalTaxDepositedAsPerDeducteeAnex
				// Validating TDSIncomeTaxC 30
			boolean errorTDSIncomeTaxC = false;
			if (TDSIncomeTaxC.equals(FIELD_NULL) || TDSIncomeTaxC.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3078_C + tab + T_FV_3078_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3083_C + tab + T_FV_3083_M);
			// Added By amit for 4.5
			else if (TDSIncomeTaxC.length() != TDSIncomeTaxC.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3078_C + tab + T_FV_3078_M);
			}
			// Amit end for Fvu 4.5
			else if (TDSIncomeTaxC.length() > 15)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3078_C + tab + T_FV_3078_M);
			else if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
				if (obj_FieldValidation.isDecimalNumber(TDSIncomeTaxC))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3078_C + tab + T_FV_3078_M);
				else if (CountOfDeducteeDetailFlag) {
					if ((Integer.parseInt(CountOfDeducteeDetail.trim()) == 0) && (Double.parseDouble(TDSIncomeTaxC.trim()) != 0)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3087_C + tab + T_FV_3087_M);
					} else
						errorTDSIncomeTaxC = true;
				} else
					errorTDSIncomeTaxC = true;
			} else if (obj_FieldValidation.isFloatNumber(TDSIncomeTaxC))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3078_C + tab + T_FV_3078_M);
			else
				errorTDSIncomeTaxC = true;
			// Validating TDSIncomeTaxC
			// Validating TDSSurchargeC 31
			boolean errorTDSSurchargeC = false;
			if (TDSSurchargeC.equals(FIELD_NULL) || TDSSurchargeC.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3097_C + tab + T_FV_3097_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
				// || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3099_C + tab + T_FV_3099_M);
			// Added By amit for 4.5
			else if (TDSSurchargeC.length() != TDSSurchargeC.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3097_C + tab + T_FV_3097_M);
			}
			// Amit end for Fvu 4.5
			else if (TDSSurchargeC.length() > 15)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3097_C + tab + T_FV_3097_M);
			else if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
				if (obj_FieldValidation.isDecimalNumber(TDSSurchargeC))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3097_C + tab + T_FV_3097_M);
				else if (CountOfDeducteeDetailFlag) {
					if ((Integer.parseInt(CountOfDeducteeDetail.trim()) == 0) && (Double.parseDouble(TDSSurchargeC.trim()) != 0)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3098_C + tab + T_FV_3098_M);
					} else
						errorTDSSurchargeC = true;
				} else
					errorTDSSurchargeC = true;
			} else if (obj_FieldValidation.isFloatNumber(TDSSurchargeC))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS -Surcharge '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3097_C + tab + T_FV_3097_M);
			else
				errorTDSSurchargeC = true;
			// Validating TDSSurchargeC
			// Validating TDSCessC 32
			boolean errorTDSCessC = false;
			if (TDSCessC.equals(FIELD_NULL) || TDSCessC.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3100_C + tab + T_FV_3100_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3102_C + tab + T_FV_3102_M);
			// Added By amit for 4.5
			else if (TDSCessC.length() != TDSCessC.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS - Cess '" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3100_C + tab + T_FV_3100_M);
			}
			// Amit end for Fvu 4.5
			else if (TDSCessC.length() > 15)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3100_C + tab + T_FV_3100_M);
			else if (UploadTypeCH.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
				if (obj_FieldValidation.isDecimalNumber(TDSCessC))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3100_C + tab + T_FV_3100_M);
				else if (CountOfDeducteeDetailFlag) {
					if ((Integer.parseInt(CountOfDeducteeDetail.trim()) == 0) && (Double.parseDouble(TDSCessC.trim()) != 0)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3101_C + tab + T_FV_3101_M);
					} else
						errorTDSCessC = true;
				} else
					errorTDSCessC = true;
			} else if (obj_FieldValidation.isFloatNumber(TDSCessC))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'TDS / TCS - Cess'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3100_C + tab + T_FV_3100_M);
			else
				errorTDSCessC = true;
			// Validating TDSCessC
			// validating SumTotalIncTaxDedAtSource 33
			boolean isValidSumTotalIncTaxDedAtSource = false;
			if (SumTotalIncTaxDedAtSource.equals(FIELD_NULL) || SumTotalIncTaxDedAtSource.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Sum of 'Total Income Tax Deducted at Source'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3041_C + tab + T_FV_3041_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Sum of 'Total Income Tax Deducted at Source'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3050_C + tab + T_FV_3050_M);
			// Added By amit for 4.5
			else if (SumTotalIncTaxDedAtSource.length() != SumTotalIncTaxDedAtSource.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Sum of 'Total Income Tax Deducted at Source'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3041_C + tab + T_FV_3041_M);
			}
			// Amit end for Fvu 4.5
			else if (SumTotalIncTaxDedAtSource.length() > 15)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Sum of 'Total Income Tax Deducted at Source'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3041_C + tab + T_FV_3041_M);
			else if (obj_FieldValidation.isFloatNumber(SumTotalIncTaxDedAtSource))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Sum of 'Total Income Tax Deducted at Source'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3041_C + tab + T_FV_3041_M);
			else
				isValidSumTotalIncTaxDedAtSource = true;
			// validating SumTotalIncTaxDedAtSource
			// Validating Interest 34
			boolean errorIntrest = false;
			if (TDSInterest.equals(FIELD_NULL) || TDSInterest.equals(FIELD_SEPERATOR)) {
				nullInterest = true;
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS/ TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3049_C + tab + T_FV_3049_M);
			} else {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					errorIntrest = true;
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS/ TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3086_C + tab + T_FV_3086_M);
				}
				// Added By amit for 4.5
				else if (TDSInterest.length() != TDSInterest.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS/ TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3049_C + tab + T_FV_3049_M);
				}
				// Amit end for Fvu 4.5
				else if (TDSInterest.length() <= 15) {
					if (obj_FieldValidation.isDecimalNumber(TDSInterest)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS/ TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3049_C + tab + T_FV_3049_M);
						errorIntrest = true;
					} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(TDSInterest.trim()) != 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS/ TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3082_C + tab + T_FV_3082_M);
					else if (NillChallanIndicator.equals("N") && Double.parseDouble(TDSInterest.trim()) < 0) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS/ TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3049_C + tab + T_FV_3049_M);
						errorIntrest = true;
					}
				} else {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS/ TCS - Interest Amount" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3049_C + tab + T_FV_3049_M);
					errorIntrest = true;
				}
			} // Validating Interest
				// Validating others 35
			boolean errorOthers = false;
			if (TDSOthers.equals(FIELD_NULL) || TDSOthers.equals(FIELD_SEPERATOR)) {
				nullOthers = true;
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3051_C + tab + T_FV_3051_M);
			} else {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					errorOthers = true;
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3088_C + tab + T_FV_3088_M);
				}
				// Added By amit for 4.5
				else if (TDSOthers.length() != TDSOthers.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3051_C + tab + T_FV_3051_M);
				}
				// Amit end for Fvu 4.5
				else if (TDSOthers.length() <= 15) {
					if (obj_FieldValidation.isDecimalNumber(TDSOthers)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3051_C + tab + T_FV_3051_M);
						errorOthers = true;
					} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(TDSOthers.trim()) != 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3084_C + tab + T_FV_3084_M);
					else if (NillChallanIndicator.equals("N") && Double.parseDouble(TDSOthers.trim()) < 0) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3051_C + tab + T_FV_3051_M);
						errorOthers = true;
					}
				} else {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS - Others (amount)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3051_C + tab + T_FV_3051_M);
					errorOthers = true;
				}
			} // Validating others

			// Validating ChequeDDNo 36
			if (isFinYrGrtrthn) {
				if (!ChequeDDNo.equals(FIELD_NULL) && !ChequeDDNo.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Cheque / DD No." + tab + tab + tab + T_FV_3161_C + tab + T_FV_3161_M);
			} else {
				if (ChequeDDNo.equals(FIELD_NULL) || ChequeDDNo.equals(FIELD_SEPERATOR)) {
					if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !NillChallanIndicator.equals("Y") && validBankChlNoProvided
							&& !ChallanUpdationIndicator.equals("0")) {
						if (paperReturnFile && validBankChlNoProvided) {
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3115_C + tab + T_FV_3115_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Cheque / DD No. (if any)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3115_C + tab + T_FV_3115_M);
					}
				} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || NillChallanIndicator.equals("Y")
						|| (NillChallanIndicator.equals("N") && (transferVoucherNoProvided == false) && (bankChallanNoProvided == false))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Cheque / DD No. (if any)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3116_C + tab + T_FV_3116_M);
				} else if ((ChallanUpdationIndicator.equals("0") || transferVoucherNoProvided))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Cheque / DD No. (if any)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3116_C + tab + T_FV_3116_M);
				else if (ChequeDDNo.length() <= 15) {
					if (obj_FieldValidation.isInt(ChequeDDNo))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Cheque / DD No. (if any)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3115_C + tab + T_FV_3115_M);
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Cheque / DD No. (if any)" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3115_C + tab + T_FV_3115_M);
				// Validating ChequeDDNo
			}

			// Validating ByBookCash 37

			if (ByBookCash.equals(FIELD_NULL) || ByBookCash.equals(FIELD_SEPERATOR)) {
				if (NillChallanIndicator.equals("N") && transferVoucherNoProvided && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
				} else if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) // &&
																																						// (!paperReturnFile)
						&& NillChallanIndicator.equals("N") && (transferVoucherNoProvided == false) && (bankChallanNoProvided == false) && !ByBookCash.equals("Y")) {
					if (paperReturnFile) {
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
					}
				}
				// Added By AMI For FVU 3.0
				else if (bankChallanNoProvided)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
				// END

				// Added by Abhishek for FVU 3.1 on 04/03/2011
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && NillChallanIndicator.equals("N")) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
				}

				// end by Abhishek
			}

			// M07_B
			// else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) ||
			// TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) Commented by Dhanya
			// (for M07)on 28/01/2011 as BokkEntry Value is allowed for C5.
			else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION)) // M07_E
			{

				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3105_C + tab + T_FV_3105_M);
			} else if ((ByBookCash.length() > 1) || obj_FieldValidation.isChar(ByBookCash) || (ByBookCash.trim().length() == 0) || !(Character.isLetter(ByBookCash.charAt(0))) || !(Character.isUpperCase(ByBookCash.charAt(0))))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);

			// added by nik start for FVU 4.6

			else if (ByBookCash.equals(APPROVAL_YES) && (UploadType.equals(UPLOADTYPE_REGULAR) || (UploadType.equals(UPLOADTYPE_CORRECTION) && BatchUpdationIndicator.equals("1"))) && (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_26Q))
					&& isFinYrGrtrthn) {

				if (AIN.equals(FIELD_NULL) || AIN.equals(FIELD_SEPERATOR) && ain_chk) {
					ain_chk = false;
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Account Office Identification Number (AIN) " + tab + tab + tab + T_FV_2233_C + tab + T_FV_2233_M);
				}

			}
			// ended by nik end for FVU 4.6
			// added for FVU 5.0 nik for Point 2
			else if (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && (DeductorType.equals(CENTRAL_GOVERNMENT) || DeductorType.equals(STATE_GOVERNMENT)) && (Integer.parseInt(FinancialYr) <= 201213) && !(APPROVAL_YES.equals(ByBookCash))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_6052_C + tab + T_FV_6052_M);
			}
			// ended for FVU 5.0 nik
			else {

				if (!ByBookCash.equals("Y") && !ByBookCash.equals("N"))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);

				// M07_B
				// For all the following condition checks for BookEntry, one more condition [ &&
				// !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) ] is added on
				// 28/01/2011 by Dhanya as C5 correction will not have values in BSR,TV and
				// Challan field and at the same time, it can have values in Book Entry field.

				else if (NillChallanIndicator.equals("N") && transferVoucherNoProvided && !ByBookCash.equals("Y") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {

					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
				} else if (NillChallanIndicator.equals("N") && (transferVoucherNoProvided == false) && (bankChallanNoProvided == false) && !ByBookCash.equals("Y") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
				} else if (NillChallanIndicator.equals("N") && validBankChlNoProvided && !ByBookCash.equals("N") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
					} else {

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3104_C + tab + T_FV_3104_M);
					}
				}
				if (NillChallanIndicator.equals("Y") && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "By Book entry / Cash" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3164_C + tab + T_FV_3164_M);
				}

				// M07_E

			} // Validating ByBookCash
				// Validating Remark 38

			// added by faizan for FVU 4.5
			if (!(Remark.equals(FIELD_NULL) || Remark.equals(FIELD_SEPERATOR)))
			// ended by faizan
			// if (Remark.equals(FIELD_NULL) || Remark.equals(FIELD_SEPERATOR))
			{
				if (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)
						|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3090_C + tab + T_FV_3090_M);

			}
			// commented for fvu 4.5 by Shalin
			/*
			 * else if ( TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CANCELLATION) ||
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) ||
			 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
			 * ChallanUpdationIndicator.equals("0"))) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Remarks" + tab + CurrentchallanDetailRecordNo +
			 * tab + tab + T_FV_3090_C + tab + T_FV_3090_M); }
			 */
			else if (Remark.length() > 14) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3054_C + tab + T_FV_3054_M);
			} else if (obj_FieldValidation.isValidCharString(Remark))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3054_C + tab + T_FV_3054_M);
			// Validating Remark

			// Added for FVU 3.8 by Shalin --- START

			// Validating MinorHeadCodeChaln 40

			if (isFinYrGrtrthn && (UploadType.equals(UPLOADTYPE_REGULAR) || (UploadType.equals(UPLOADTYPE_CORRECTION) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)
					|| (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && ChallanUpdationIndicator.equals("1")) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))) {

				if (NillChallanIndicator.equals("N") && ByBookCash.equals("N")) {
					if (MinorHeadCodeChaln.equals(FIELD_NULL) || MinorHeadCodeChaln.equals(FIELD_SEPERATOR)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Minor Head of Challan'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3159_C + tab + T_FV_3159_M);
					} else if (MinorHeadCodeChaln.length() <= 3) {
						if (ChallanUpdationIndicator.equals("0")) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Minor Head of Challan'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3162_C + tab + T_FV_3162_M);
						} else if (!(MinorHeadCodeChaln.trim().equals("200") || MinorHeadCodeChaln.trim().equals("400"))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Minor Head of Challan'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3159_C + tab + T_FV_3159_M);
						}

					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Minor Head of Challan'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3159_C + tab + T_FV_3159_M);
				} else if (NillChallanIndicator.equals("Y") || ByBookCash.equals("Y")) {
					if (!MinorHeadCodeChaln.equals(FIELD_NULL) && !MinorHeadCodeChaln.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Minor Head of Challan'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3162_C + tab + T_FV_3162_M);
				}
			} else {
				if (!MinorHeadCodeChaln.equals(FIELD_NULL) && !MinorHeadCodeChaln.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Minor Head of Challan" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3162_C + tab + T_FV_3162_M);
			}

			// Validating MinorHeadCodeChaln
			// Added for fvu 3.8 by Shalin --- END

			// checking whether Sum of 'Total Income Tax Deducted at Source' = TDS
			// Amount+Surcharge + Cess + Interest + Others
			if (errorTDSIncomeTaxC) {
				iTDSIncomeTaxC = Double.parseDouble(TDSIncomeTaxC.trim());
				// Added by faizan for fvu 4.5
				challanWiseTDSfield30 = Double.parseDouble(TDSIncomeTaxC.trim());
			}
			if (errorTDSSurchargeC) {
				iTDSSurchargeC = Double.parseDouble(TDSSurchargeC.trim());
				// Added by faizan for fvu 4.5
				challanWiseTDSfield31 = iTDSSurchargeC;
			}
			if (errorTDSCessC) {
				iTDSCessC = Double.parseDouble(TDSCessC.trim());
				// Added by faizan for fvu 4.5
				challanWiseTDSfield32 = iTDSCessC;
			}
			if (nullInterest || errorIntrest == true)
				iInterestC = 0;
			else if (errorIntrest == false)
				iInterestC = Double.parseDouble(TDSInterest.trim());
			if (nullOthers || errorOthers == true)
				iOthersC = 0;
			else if (errorOthers == false)
				iOthersC = Double.parseDouble(TDSOthers.trim());
			// d4 = Math.round((double)(d4 * 100)) /100.0;
			sumTotal = iTDSIncomeTaxC + iTDSSurchargeC + iTDSCessC;
			// 16 July 05. Code changed -------------
			sumTotal = Math.round((double) (sumTotal * 100)) / 100.0;
			sumTotalTdsSurCess = sumTotal;
			if (errorTotalTaxDepositedAsPerDeducteeAnex && errrorTotalOfDepositAmountAsPerChallan) {
				// 16 July 05. Code changed -------------
				double interestOtherDepAmt = 0;
				// Added by Shalin for FVU 4.1
				if ((ByBookCash.equals(FIELD_NULL) || ByBookCash.equals(FIELD_SEPERATOR) || ByBookCash.equals("N")) && errorLateFee)
					interestOtherDepAmt = iInterestC + iOthersC + Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim()) + Double.parseDouble(LateFee);
				else
					interestOtherDepAmt = iInterestC + iOthersC + Double.parseDouble(TotalTaxDepositedAsPerDeducteeAnex.trim());
				interestOtherDepAmt = Math.round((double) (interestOtherDepAmt * 100)) / 100.0;
				if (interestOtherDepAmt > Double.parseDouble(TotalOfDepositAmountAsPerChallan.trim())) {
					if (paperReturnFile) {
						paperReturnRelax = true;
						byPassBooking = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3066_C + tab + T_FV_3066_M);
					} else if (errorLateFee)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3169_C + tab + T_FV_3169_M);
					else if (ByBookCash.equals("Y"))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3168_C + tab + T_FV_3168_M);
					else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total of Deposit Amount as per Challan/Transfer Voucher Number" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3066_C + tab + T_FV_3066_M);
				} // 16 July 05. Code changed -------------
			}

			if (isValidSumTotalIncTaxDedAtSource && !paperReturnFile) { // Log.tds_log.info("sumTotal = "+sumTotal+"\t\t
																		// SumTotalIncTaxDedAtSource =
																		// "+SumTotalIncTaxDedAtSource);
				if (sumTotal != Double.parseDouble(SumTotalIncTaxDedAtSource.trim()))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Sum of 'Total Income Tax Deducted at Source'" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_3048_C + tab + T_FV_3048_M);
			} else if (isValidSumTotalIncTaxDedAtSource && paperReturnFile) {
				if (sumTotal != Double.parseDouble(SumTotalIncTaxDedAtSource.trim())) {
					paperReturnRelax = true;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + tab + T_FV_3048_C + tab + T_FV_3048_M);
				}
			} // checking whether Amount of Tax deducted =TDS Amount+Surcharge +Interest +
				// Penalty + Others
			if (!(obj_FieldValidation.isDecimalNumber(GrossTDSTotalAsPerChallan)) && obj_FieldValidation.isNumber(CountOfChallanRec)) {
				if (validChallanCount == Integer.parseInt(CountOfChallanRec.trim()) && (Double.parseDouble(GrossTDSTotalAsPerChallan.trim()) != sumOfTotalOfDepositAmountAsPerChallan)) {
					// Log.tds_log.info("sumOfTotalOfDepositAmountAsPerChallan = " +
					// sumOfTotalOfDepositAmountAsPerChallan + "\t\tGrossTDSTotalAsPerChallan = " +
					// GrossTDSTotalAsPerChallan);
					Str_Buffer.append(lineNoOfBatchRec + tab + currentUploadType + tab + "Sum of Total of Deposit Amount as per Challan" + tab + tab + tab + T_FV_3070_C + tab + T_FV_3070_M);
				}
			} // return (Str_Buffer);
				// Added For Mandatory CSI File

			if (!cinMandatory && Parameters.csiMandatory) {
				// edited for FVU 5.0
				// System.out.println("Upload Type"+UploadType);
				// System.out.println("Parameters.csiMandatory"+Parameters.csiMandatory);
				// System.out.println("NillChallanIndicator"+NillChallanIndicator);
				// System.out.println("TransactionType"+TransactionType);
				// System.out.println("CIN File Name"+FileStatistics.getCinFileName());
				// System.out.println("ByBookCash"+ByBookCash);
				// System.out.println("Challan Updation Indicator"+ChallanUpdationIndicator);
				// ended for FVU 5.0

				if (Parameters.csiMandatory && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)) && NillChallanIndicator.equals("N")
						&& (FileStatistics.getCinFileName() == null || FileStatistics.getCinFileName().equals("")) && ByBookCash.equals("N")) {
					cinMandatory = true;
					// forCSIfile =true;
					// System.out.println("i am in ttttttttttttttt CSI Mandatory");
				}
				if (Parameters.csiMandatory && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && ChallanUpdationIndicator.equals("1")) && NillChallanIndicator.equals("N")
						&& (FileStatistics.getCinFileName() == null || FileStatistics.getCinFileName().equals("")) && ByBookCash.equals("N")) {
					cinMandatory = true;
					// forCSIfile =true;
					// System.out.println("i am in ttttfffffff CSI Mandatory");
				}

				// added for CSI mandatory
				if (Parameters.csiMandatory && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN)) && NillChallanIndicator.equals("N")
						&& ByBookCash.equals("N")) {
					// cinMandatory=true;
					forCSIfile = true;
					// System.out.println("forCSIMandatory");
				}
				if (Parameters.csiMandatory && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && ChallanUpdationIndicator.equals("1")) && NillChallanIndicator.equals("N") && ByBookCash.equals("N")) {
					// cinMandatory=true;
					forCSIfile = true;
					// System.out.println("CSI Mandatory");
				}
				// ended for CSI mandatory

			}
			// added by sourabh
			try {

				if (utilityLevel == 0 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && ChallanUpdationIndicator.equals("1"))
						|| TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && (ByBookCash.equals("N") || validBankChlNoProvided == true || NillChallanIndicator.equals("Y")) && validBankChlNoProvided) {
					try {

						// System.out.println("**********Adding CIN FROM CHALLAN
						// :::::::::::::"+TransactionType.toString());
						// System.out.println("Bank Branch
						// Code:::"+BankBranchCode+"DateOfBAnkChallanNo:::"+DateOfBankChallanNo+"
						// CHALLAN NUMBER::::::"+String.valueOf(Integer.parseInt(BankChallanNo))+"TAN OF
						// DEDUCTOR:::"+TanOfDeductor+"AMOUNT:::"+obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalOfDepositAmountAsPerChallan)));

						// Added By AMI For FVU 3.0
						if (!isMtchCntToBeUpdated)
							isMtchCntToBeUpdated = true;

						consolidatedHash.add(BankBranchCode + DateOfBankChallanNo + String.valueOf(Integer.parseInt(BankChallanNo)) + TanOfDeductor + obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalOfDepositAmountAsPerChallan)));
						// System.out.println("CONSOLIDATED CODE FROM
						// ArrayList"+consolidatedHash.toString());

						cinBsrCode.add(BankBranchCode); // Bsr code
						// cinChallanSeqNo.add(String.valueOf(Integer.parseInt(BankChallanNo))); challan
						// number
						cinChallanSeqNoView.add(BankChallanNo);
						// cinOltasPayDate.add(DateOfBankChallanNo); //payment date
						// cinAmt.add(obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalOfDepositAmountAsPerChallan)));
						// // Amt
						cinBatchNo.add(BH_BatchNo);
						cinChallanDetailRecordNo.add(ChallanDetailRecordNo);
						cinDateOfChallan.add(dateOfChallan);
						cinLineNo.add(LineNo);
						totalChallanforCINCheck++;
					} catch (Exception e) {
						e.printStackTrace();
					}
				}
				// Added for FVU 4.6 BIN matching
				/*
				 * else if(utilityLevel == 0
				 * &&(UploadType.equals(UPLOADTYPE_REGULAR)||TransactionType.equals(
				 * TRANSACTIONTYPE_CORRECTION_CHALLAN)||(TransactionType.equals(
				 * TRANSACTIONTYPE_CORRECTION_DEDUCTEE)&&ChallanUpdationIndicator.equals("1"))||
				 * TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))&&(ByBookCash.equals
				 * ("Y")||validBankChlNoProvided==true||NillChallanIndicator.equals("Y"))&&
				 * validBankChlNoProvided) { try{
				 * 
				 * // System.out.println("**********Adding CIN FROM CHALLAN :::::::::::::"
				 * +TransactionType.toString());
				 * //System.out.println("Bank Branch Code:::"+BankBranchCode+
				 * "DateOfBAnkChallanNo:::"+DateOfBankChallanNo+" CHALLAN NUMBER::::::"+String.
				 * valueOf(Integer.parseInt(BankChallanNo))+"TAN OF DEDUCTOR:::"+TanOfDeductor+
				 * "AMOUNT:::"+obj_FieldValidation.changeNumberFormat(Double.parseDouble(
				 * TotalOfDepositAmountAsPerChallan)));
				 * 
				 * //Added By AMI For FVU 3.0 if(!isMtchCntToBeUpdated) isMtchCntToBeUpdated =
				 * true;
				 * 
				 * 
				 * consolidatedHashBIN.add(BankBranchCode+DateOfBankChallanNo+String.valueOf(
				 * Integer.parseInt(TransferVoucherNo))+TanOfDeductor+obj_FieldValidation.
				 * changeNumberFormat(Double.parseDouble(TotalOfDepositAmountAsPerChallan)));
				 * //System.out.println("CONSOLIDATED CODE FROM ArrayList"+consolidatedHash.
				 * toString());
				 * 
				 * binBsrCode.add(BankBranchCode); //Bsr code
				 * //cinChallanSeqNo.add(String.valueOf(Integer.parseInt(BankChallanNo)));
				 * challan number binChallanSeqNoView.add(TransferVoucherNo);
				 * //cinOltasPayDate.add(DateOfBankChallanNo); //payment date
				 * //cinAmt.add(obj_FieldValidation.changeNumberFormat(Double.parseDouble(
				 * TotalOfDepositAmountAsPerChallan))); // Amt binBatchNo.add(BH_BatchNo);
				 * binChallanDetailRecordNo.add(ChallanDetailRecordNo);
				 * binDateOfChallan.add(dateOfChallan); binLineNo.add(LineNo);
				 * totalChallanforCINCheck++; } catch(Exception e) { e.printStackTrace(); }
				 * 
				 * }
				 */
				// Added by sourabh for new Static report.

				if ((transferVoucherNoProvided == true && !TransferVoucherNo.equals("") && !TransferVoucherNo.equals(FIELD_SEPERATOR)) || ByBookCash.equals("Y")) {

					statTransferVoucher++;
					transferAmountAsPerTV = transferAmountAsPerTV + Double.parseDouble(TotalOfDepositAmountAsPerChallan);

				}

				else if (ByBookCash.trim().equals("N") || validBankChlNoProvided == true || NillChallanIndicator.trim().equals("Y") || NillChallanIndicator.trim().equals("N")) {

					statChallanCount++;
					challanAmountAsPerChallan = challanAmountAsPerChallan + Double.parseDouble(TotalOfDepositAmountAsPerChallan);
				}
				// Added for FVU 5.0 ..to bypass tanTanTanname validation

				/*
				 * if ( (UploadType.equals(UPLOADTYPE_REGULAR) && (ByBookCash.equals("") ||
				 * ByBookCash.equals(FIELD_SEPERATOR))) ||
				 * (UploadType.equals(UPLOADTYPE_REGULAR) && ByBookCash.equals("Y")) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH)) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * ChallanUpdationIndicator.equals("0")) || (
				 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY)) || (
				 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) &&
				 * (ByBookCash.equals("")|| ByBookCash.equals(FIELD_SEPERATOR))) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) &&
				 * ByBookCash.equals("Y")) ||
				 * 
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) &&
				 * ByBookCash.equals("Y") && (ByBookCash.equals("")||
				 * ByBookCash.equals(FIELD_SEPERATOR)) ) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) &&
				 * (ByBookCash.equals(FIELD_NULL) || ByBookCash.equals(FIELD_SEPERATOR) )) ||
				 * 
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (
				 * ByBookCash.equals(FIELD_NULL) || ByBookCash.equals(FIELD_SEPERATOR) ) &&
				 * ChallanUpdationIndicator.equals("1"))||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * ByBookCash.equals("Y") && ChallanUpdationIndicator.equals("1")) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * ByBookCash.equals("N") && ChallanUpdationIndicator.equals("0")) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * ByBookCash.equals("Y") && ChallanUpdationIndicator.equals("0")) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (
				 * ByBookCash.equals(FIELD_NULL) || ByBookCash.equals(FIELD_SEPERATOR) ) &&
				 * ChallanUpdationIndicator.equals("0")) ) { bypassTanTanNameValidate= true; }
				 */
				// ** end
				// System.out.println(" After if loop bypassTanTanNameValidate ::" +
				// bypassTanTanNameValidate);
			} catch (Exception e) {
				/*
				 * if ( (UploadType.equals(UPLOADTYPE_REGULAR) && (ByBookCash.equals("") ||
				 * ByBookCash.equals(FIELD_SEPERATOR))) ||
				 * (UploadType.equals(UPLOADTYPE_REGULAR) && ByBookCash.equals("Y")) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH)) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * ChallanUpdationIndicator.equals("0")) || (
				 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY)) || (
				 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) &&
				 * (ByBookCash.equals("")|| ByBookCash.equals(FIELD_SEPERATOR))) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) &&
				 * ByBookCash.equals("Y")) ||
				 * 
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) &&
				 * ByBookCash.equals("Y") && (ByBookCash.equals("")||
				 * ByBookCash.equals(FIELD_SEPERATOR))) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) &&
				 * (ByBookCash.equals(FIELD_NULL) || ByBookCash.equals(FIELD_SEPERATOR) )) ||
				 * 
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (
				 * ByBookCash.equals(FIELD_NULL) || ByBookCash.equals(FIELD_SEPERATOR) ) &&
				 * ChallanUpdationIndicator.equals("1"))||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * ByBookCash.equals("Y") && ChallanUpdationIndicator.equals("1")) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * ByBookCash.equals("N") && ChallanUpdationIndicator.equals("0")) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * ByBookCash.equals("Y") && ChallanUpdationIndicator.equals("0")) ||
				 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (
				 * ByBookCash.equals(FIELD_NULL) || ByBookCash.equals(FIELD_SEPERATOR) ) &&
				 * ChallanUpdationIndicator.equals("0")) ) { bypassTanTanNameValidate= true; }
				 */

				e.printStackTrace();

			}

		} catch (Exception e) {

			throw e;
		}
		return;
	} // method
		// START OF DEDUCTEE DETAILS VALIDATION

	private void validateDeducteeDetails(String deductee, int LineCount, String BH_BatchNo, String ChallanDetailRecordNo, String TransactionType, String Qperiod, String FinancialYr, String DateOfBankChallanNo, Calendar RRRDatePresentDate,
			boolean transferVoucherNoProvided, boolean bankChallanNoProvided, String UploadTypeDD, StringBufferTemp obj_StringBuffer

	) throws Exception {

		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;
		boolean error_flag = false;
		boolean NullField = false;
		boolean error = false;
		boolean FieldFound = false;
		boolean Caret = false;
		boolean nullEmployeePan = false;
		int LCount = 0;
		int iDeducteeDetailRecNo = 0;
		int wrongDate = 0;
		boolean inPeriodAndFinancialYr = false;
		double iTotalIncomeTaxDeductedAtSource = 0;
		double iLastTotalIncomeTaxDeductedAtSource = 0;
		double iTDSIncomeTaxDD = 0;
		double iTDSSurchargeDD = 0;
		double iCessDD = 0;
		double sumOfIncomeTaxSurcharge = 0;
		double iLastTotalTaxDeposited = 0;
		int SumOfTDSAndSurcharge = 0;
		Mode = null;

		try {
			String LineNo = null;
			String RecType = null;
			String DD_BatchNo = null;
			String ChallanRecordNo = null;
			String DeducteeDetailRecNo = null;
			String EmployeeSerialNo = null;
			String DeducteeCode = null;
			String LastEmployeePan = null;
			String EmployeePan = null;
			String LastEmployeePanRefNo = null;
			String EmployeePanRefNo = null;
			String EmployeeName = null;
			String TDSIncomeTaxDD = null;
			String TDSSurchargeDD = null;
			String TDSCessDD = null;
			String TotalIncomeTaxDeductedAtSource = null;
			String LastTotalIncomeTaxDeductedAtSource = null;
			String TotalValueofPurchase = null;
			String TotalTaxDeposited = null;
			String LastTotalTaxDeposited = null;
			String AmountOfPayment = null;
			String DateOnWhichAmountPaid = null;
			String RateAtWhichTaxDeducted = null;
			String GrossingUpIndicator = null;
			String DateOnWhichTaxDeducted = null;
			String DateOfDeposit = null;
			String BookCashEntry = null;
			String DateOfFurnishingTaxDeductionCertificate = null;
			String Remark1 = null;
			String Remark2 = null;
			String NonResident = null;
			String Remark3 = null;
			String PermanentResidentEstablishment = null;
			String DeducteeHash = null;

			// Added for FVU 3.8 by Shalin

			String SectionCode = null;
			String CertNumAo = null;
			String DedRefNum = null;
			String TdsRate = null;
			String NatureOfRemittance = null;
			String AckNoForm15CA = null;
			String RemittanceCountry = null;

			// Added for FVU 5.2 by priya

			String DeducteeEmailId = null;
			String DeducteeContactNo = null;
			String DeducteeAddress = null;
			String TaxIdentificationNo = null;
			// Changes added for 6.6_2.162_2.1294 by Puja
			String amtOfCashWithIn194N = null;
			String filler9 = null;
			String filler10 = null;
			String filler11 = null;
			String CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N = null;
			String CashWithdrawalAmtInExcessOf1CrForSec194N = null;
			String filler12 = null;
			String filler13 = null;
			
			//Changes added for FVU 7.0 by Vinita
			String whthrPaymtLiablTds = null;
			String challanNumber = null;
			String datePaymtTds = null;
			
			// Added By AMI
			boolean value_Pan = true;
			// Added by Abhishek for FVU 3.0
			boolean valueForPanRefNo = false;
			// Added by Abhishek for FVU 3.1
			int flgForThreshold = 0;

			int Count_DD_field = 1;
			FieldValidation obj_FieldValidation = new FieldValidation();
			FileGenerator obj_FileGenerator = new FileGenerator();
			StringTokenizer Obj_st = new StringTokenizer(deductee, FIELD_SEPERATOR, true);
			int localCaretCounter_Q12 = 0;
			while (Obj_st.hasMoreTokens()) {
				String val = Obj_st.nextToken();

				NullField = false;
				FieldFound = false;
				if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
					NullField = true;
					FieldFound = true;
				}
				if (val.equals(FIELD_SEPERATOR)) {
					Caret = true;
					if (Count_DD_field == 1 && localCaretCounter_Q12 == 0) {
						Count_DD_field++;
						LineNo = val;
					}
					localCaretCounter_Q12++;
				} else {
					Caret = false;
					FieldFound = true;
				}
				// Commented for FVu 5.2
				/*
				 * if (Count_DD_field > 39) { break; }
				 */

				// Added for FVU 5.2
				// Changes added for 6.6_2.162_2.1294 by Puja
				if (Count_DD_field > 48) {
					break;
				}

				if (FieldFound) {
					switch (Count_DD_field) {
					case 1:
						LineNo = val;
						break;
					case 2:
						RecType = val;
						break;
					case 3:
						DD_BatchNo = val;
						break;
					case 4:
						ChallanRecordNo = val;
						break;
					case 5:
						DeducteeDetailRecNo = val;
						break;
					case 6:
						Mode = val;
						break;
					case 7:
						EmployeeSerialNo = val;
						break;
					case 8:
						DeducteeCode = val;
						break;
					case 9:
						LastEmployeePan = val;
						break;
					case 10:
						EmployeePan = val;
						break;
					case 11:
						LastEmployeePanRefNo = val;
						break;
					case 12:
						EmployeePanRefNo = val;
						break;
					case 13:
						EmployeeName = val;
						break;
					case 14:
						TDSIncomeTaxDD = val;
						break;
					case 15:
						TDSSurchargeDD = val;
						break;
					case 16:
						TDSCessDD = val;
						break;
					case 17:
						TotalIncomeTaxDeductedAtSource = val;
						break;
					case 18:
						LastTotalIncomeTaxDeductedAtSource = val;
					case 19:
						TotalTaxDeposited = val;
						break;
					case 20:
						LastTotalTaxDeposited = val;
						break;
					case 21:
						TotalValueofPurchase = val;
						break;
					case 22:
						AmountOfPayment = val;
						break;
					case 23:
						DateOnWhichAmountPaid = val;
						break;
					case 24:
						DateOnWhichTaxDeducted = val;
						break;
					case 25:
						DateOfDeposit = val;
						break;
					case 26:
						RateAtWhichTaxDeducted = val;
						break;
					case 27:
						GrossingUpIndicator = val;
						break;
					case 28:
						BookCashEntry = val;
						break;
					case 29:
						DateOfFurnishingTaxDeductionCertificate = val;
						break;
					case 30:
						Remark1 = val;
						break;
					case 31:
						// Remark2 = val;
						if (FormNo.equals(FORM_27EQ))
							NonResident = val; // FVU 5.7
						else
							Remark2 = val;
						break;
					case 32:
						// Remark3 = val;
						if (FormNo.equals(FORM_27EQ))
							PermanentResidentEstablishment = val; // FVU 2.1285
						else
							Remark3 = val;
						break;

					// Added for FVU 3.8 by Shalin
					case 33:
						SectionCode = val;
						break;
					case 34:
						CertNumAo = val;
						break;
					case 35:
						if(FormNo.equals(FORM_27EQ)){ // FVU 7.0
							whthrPaymtLiablTds = val;
							TdsRate = "";
						}
						else{
							TdsRate = val;
						}	
						break;
					case 36:
						if(FormNo.equals(FORM_27EQ)){ // FVU 7.0
							challanNumber = val;
							NatureOfRemittance = "";
						}	
						else{
							NatureOfRemittance = val;
						}
						break;
					case 37:
						if(FormNo.equals(FORM_27EQ)){ // FVU 7.0
							datePaymtTds = val;
							AckNoForm15CA = "";
						}	
						else{
							AckNoForm15CA = val;
						}	
						break;
					case 38:
						RemittanceCountry = val;
						break;
					/*
					 * case 39 : DeducteeHash = val; break;
					 */

					// Added for FVU 5.2 Priya
					case 39:
						DeducteeEmailId = val;
						break;

					case 40:
						DeducteeContactNo = val;
						break;

					case 41:
						DeducteeAddress = val;
						break;

					case 42:
						TaxIdentificationNo = val;
						break;
					// Changes added for 6.6_2.162_2.1294 by Puja
					case 43:
						if (FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q))
							amtOfCashWithIn194N = val;
						else
							filler9 = val;
						break;
					case 44://Changes for CR#65617
						if (FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q))
							CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N = val;
						else
							filler10 = val;
						break;
					case 45://Changes for CR#65617
						if (FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q))
							CashWithdrawalAmtInExcessOf1CrForSec194N = val;
						else
							filler11 = val;
						break;
					case 46:
						filler12 = val;
						break;
					case 47:
						filler13 = val;
						break;
					case 48:
						DeducteeHash = val;
						break;

					} // SWITCH
					Count_DD_field++;
				}
			} // WHILE

			// Added for valdating Amount paid for structurally valid PAN--- Manvendra ::
			// 15-Feb-2008
			boolean isStructurallyValidPan = false;
			// Variable added to check the validity of B -Manvendra Singh :: 18-Feb-2008
			boolean isValid_B = true;
			// #################################
			boolean parseableTotalDeduction = false; // 22-Feb-2008 ---FVU 2.113
			// ################################################3

			// Added for FVU 3.8 by Shalin

			if (FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q) || FormNo.equals(FORM_27EQ)) {
				DedRefNum = EmployeePanRefNo;
				EmployeePanRefNo = "";

			} else {
				DedRefNum = "";
			}

			// -------------- Added by Nahush

			if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) || TransactionType.equals(TRANSACTIONTYPE_CANCELLATION_BATCH)) {
				CurrentDeducteeDetailRecNo = "Null";
			}

			else {
				CurrentDeducteeDetailRecNo = DeducteeDetailRecNo;
			}

			// -----------------------

			// Validating LineNo 1
			// commented for FVu 5.2
			/*
			 * if (localCaretCounter_Q12 != 38) { //Incomplete
			 * 
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +"NA" + tab +
			 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4001_C + tab + T_FV_4001_M); return; }
			 */
			// Added for fvu 5.2 by priya

			// Changes added for 6.6_2.162_2.1294 by Puja
			if (localCaretCounter_Q12 != 47) { // Incomplete
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4001_C + tab + T_FV_4001_M);
				return;
			}

			if (LineNo.equals(FIELD_NULL) || LineNo.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4004_C + tab + T_FV_4004_M);
				LineNo = "-";
			} else if (LineNo.length() <= 9) {
				if (obj_FieldValidation.isInt(LineNo))
					Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4004_C + tab + T_FV_4004_M);
				else if (Integer.parseInt(LineNo.trim()) != LineCount)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4003_C + tab + T_FV_4003_M);
			} else
				Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4004_C + tab + T_FV_4004_M);
			// Validating LineNo
			// Validating recordtype 2
			error = isValidRecType(LineNo, RecType, DEDUCTEE_HEADER_IDENTIFIER, Str_Buffer);
			if (error) {
				// Nahush 20 August 08
				if (Integer.parseInt(LineNo.trim()) != LineCount) {
					LineNo = "NA";
					obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + DEDUCTEE_RECORD_TYPE + tab + tab + tab + T_FV_4003_C + tab + T_FV_4003_M);
				}

				Str_Buffer.append(LineNo + tab + currentUploadType + tab + DEDUCTEE_RECORD_TYPE + tab + tab + tab + T_FV_4002_C + tab + T_FV_4002_M);
			}
			// Validating recordtype
			// Validating BatchNo 3
			validatingBatchNo(BH_BatchNo, Str_Buffer, LineNo, DD_BatchNo, obj_FieldValidation);
			// Validating BatchNo

			// Validating ChallanRecordNo 4
			validateChallanRecordNo(ChallanDetailRecordNo, Str_Buffer, LineNo, ChallanRecordNo, obj_FieldValidation);
			// Validating ChallanRecordNo
			// Validating DeducteeDetailRecNo 5
			DeducteeDetailRecNo = validateDeducteeDetailRecNo(TransactionType, UploadTypeDD, Str_Buffer, LineNo, DeducteeDetailRecNo, obj_FieldValidation); // Validating DeducteeDetailRecNo

			// Added by Shalin for FVU 3.8
			// Validating SectionCode

			validateSectionCode(TransactionType, Qperiod, FinancialYr, Str_Buffer, LineNo, EmployeePan, TotalIncomeTaxDeductedAtSource, AmountOfPayment, DateOnWhichAmountPaid, Remark1, SectionCode, obj_FieldValidation, RateAtWhichTaxDeducted,
					DateOnWhichTaxDeducted, amtOfCashWithIn194N, DeducteeEmailId,DeducteeContactNo,DeducteeAddress,TaxIdentificationNo,NatureOfRemittance); // Changes added for 6.8_2.164_2.1296 by puja_funPoint3 // 5 params added for FVU 7.2 by Vinita
			

			// Validating SectionCode
			// Validating Mode 6

			validateMode(TransactionType, UploadTypeDD, Str_Buffer, LineNo, DeducteeDetailRecNo, obj_FieldValidation);
			// Validating Mode
			// Validating EmployeeSerialNo 7

			validateEmployeeSerialNo(TransactionType, Qperiod, UploadTypeDD, Str_Buffer, LineNo, EmployeeSerialNo, EmployeePan, obj_FieldValidation);
			// Validating EmployeeSerialNo
			// Validating DeducteeCode 8
			validateDeducteeCode(BH_BatchNo, ChallanDetailRecordNo, TransactionType, Str_Buffer, LineNo, DeducteeDetailRecNo, DeducteeCode);
			// Validating DeducteeCode
			// Validating LastEmployeePan 9
			boolean validLastEmpPANStructure = validateLastEmployeePan(TransactionType, UploadTypeDD, Str_Buffer, LineNo, LastEmployeePan, EmployeePan, obj_FieldValidation);
			// Validating LastEmployeePan

			// Validating EmployeePan 10
			// --------------------------------------------------------------------------
			// ----------------------------------------------------------------------------
			nullEmployeePan = false;
			if (EmployeePan.equals(FIELD_NULL) || EmployeePan.equals(FIELD_SEPERATOR) || (EmployeePan.trim().length() == 0)) {
				if (paperReturnFile) {
					byPassBooking = true;
					paperReturnRelax = true;
					receiptPanInvaild++;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4009_C + tab + T_FV_4009_M);
					if (batchNumberOfRecord == 0) {
						batchNumberOfRecord = Integer.parseInt(BH_BatchNo.trim());
						Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatFileHeader());
						Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatTableStructureStart(batchRecDataForPanStat.toString()));
						batchRecDataForPanStat = new StringBuffer();
						// Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab +
						// CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
						// T_FV_4009_C + tab + T_FV_4009_M);
						Str_Buffer.appendPANStat("<TR>");
						Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
						Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=125>" + DeducteeDetailRecNo + "</TD>");
						Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + "" + "</TD>");
						Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + "PAN not Provided" + "</TD>");
						Str_Buffer.appendPANStat("</TR>");
					} else if (batchNumberOfRecord == Integer.parseInt(BH_BatchNo.trim())) {
						Str_Buffer.appendPANStat("<TR>");
						Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
						Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=125>" + DeducteeDetailRecNo + "</TD>");
						Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + "" + "</TD>");
						Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + "PAN not Provided" + "</TD>");
						Str_Buffer.appendPANStat("</TR>");
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4009_C + tab + T_FV_4009_M);
			} else {
				nullEmployeePan = true;

				if (!FormNo.equals(FORM_27Q) && Mode.equals("F") && !LastEmployeePan.equals(EmployeePan) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))) { // Added by shruti FVU 5.4

					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4344_C + tab + T_FV_4344_M);

				}

				if (Mode.equals("D") && !LastEmployeePan.equals(EmployeePan)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4184_C + tab + T_FV_4184_M);
				} // else if (paperReturnFile && EmployeePan.length() < 10)
					// {
					// panStatFlag = 1;
					// }
				else if (EmployeePan.length() > 10)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4009_C + tab + T_FV_4009_M);
				else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && obj_FieldValidation.checkPan(EmployeePan))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4009_C + tab + T_FV_4009_M);
				else if (!EmployeePan.equals(PAN_NOT_AVAILABLE) && !EmployeePan.equals(PAN_APPLIED) && !EmployeePan.equals(PAN_INVALID)) {
					if (EmployeePan.length() == 10 && EmployeePan.trim().length() == 10) {

						if (obj_FieldValidation.checkPan(EmployeePan)) {
							if (paperReturnFile) {
								if (obj_FieldValidation.isAlphaNum(EmployeePan)) {
									Str_Buffer.append(LineNo + tab + "Employee / Party  PAN" + tab + currentUploadType + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
								} else {
									byPassBooking = true;
									paperReturnRelax = true;
									Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4009_C + tab + T_FV_4009_M);
									receiptPanInvaild++;
									/*
									 * code added on 08-May-2006 to make an entry of Structurally invalid PAN in PAN
									 * stat buffer file.
									 */
									if (batchNumberOfRecord == 0) {
										batchNumberOfRecord = Integer.parseInt(BH_BatchNo.trim());
										Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatFileHeader());
										Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatTableStructureStart(batchRecDataForPanStat.toString()));
										batchRecDataForPanStat = new StringBuffer();
										// Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab +
										// CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
										// T_FV_4009_C + tab + T_FV_4009_M);
										Str_Buffer.appendPANStat("<TR>");
										Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
										Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=125>" + DeducteeDetailRecNo + "</TD>");
										Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + EmployeePan + "</TD>");
										Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + "Structurally Invalid Pan" + "</TD>");
										Str_Buffer.appendPANStat("</TR>");
									} else if (batchNumberOfRecord == Integer.parseInt(BH_BatchNo.trim())) {
										Str_Buffer.appendPANStat("<TR>");
										Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
										Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=125>" + DeducteeDetailRecNo + "</TD>");
										Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + EmployeePan + "</TD>");
										Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + "Structurally Invalid Pan" + "</TD>");
										Str_Buffer.appendPANStat("</TR>");
									}
								}
							} else
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4009_C + tab + T_FV_4009_M);
						} else if (validLastEmpPANStructure && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && !LastEmployeePan.equals(EmployeePan))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4216_C + tab + T_FV_4216_M);
						else {
							value_Pan = false;
							receiptValidPAN++;
							isStructurallyValidPan = true;
							// -------changed for validating the % of structurally valid PAN ---By Manvendra
							// ------- execution comes here means PAN is structurally valid
							// ----------------------------------------------------------------------------

							if (isFinYrGrtr) {
								if (!isFinYrGrtrthn && !(Mode.equals("D") || Mode.equals("U")) && !sectionForThisChallan.equals("K")) {
									validPANtoValidate_in_batch_ignoring_remark++;
									validPANtoValidate_ignoring_remark++;
									if (!Remark1.equals("B")) {
										validPANtoValidate++;
										validPANtovalidate_in_batch++;
									}
									// System.out.println(" Mode is " + Mode + "Remark is " + Remark1 + " valid pan
									// to validate " + validPANtoValidate);
								}
								if (isFinYrGrtrthn && !(Mode.equals("D") || Mode.equals("U")) && !sectionForThisDD.equals("K")) {
									validPANtoValidate_in_batch_ignoring_remark++;
									validPANtoValidate_ignoring_remark++;
									if (!Remark1.equals("B")) {
										validPANtoValidate++;
										validPANtovalidate_in_batch++;
									}
									// System.out.println(" Mode is " + Mode + "Remark is " + Remark1 + " valid pan
									// to validate " + validPANtoValidate);
								}
							}

							else {
								if (!(Mode.equals("D") || Mode.equals("U"))) {
									validPANtoValidate_in_batch_ignoring_remark++;
									validPANtoValidate_ignoring_remark++;
									if (!Remark1.equals("B")) {
										validPANtoValidate++;
										validPANtovalidate_in_batch++;
									}
									// System.out.println(" Mode is " + Mode + "Remark is " + Remark1 + " valid pan
									// to validate " + validPANtoValidate);
								}
							}
							// ----------------------------------------------------------------------------

						}
						// CHANGE AMI
						if (FormNo.equals(FORM_24Q) && !paperReturnFile
								&& (UploadType.equals(UPLOADTYPE_REGULAR) || Mode.equals("A") || Mode.equals("U") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
							if (obj_FieldValidation.checkPanForthDigit24Q(EmployeePan)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4263_C + tab + T_FV_4263_M);
							} else {
								if (value_Pan) {
									receiptValidPAN++;
									isStructurallyValidPan = true;
									// -------changed for validating the % of structurally valid PAN ---By Manvendra
									// ------- execution comes here means PAN is structurally valid
									// ----------------------------------------------------------------------------

									if (!(Mode.equals("D") || Mode.equals("U"))) {
										validPANtoValidate_in_batch_ignoring_remark++;
										validPANtoValidate_ignoring_remark++;

										if (!Remark1.equals("B")) {
											validPANtoValidate++;
											validPANtovalidate_in_batch++;
										}

									}
								}
							}
						}
						// END
					} else {
						if (paperReturnFile) {
							if (obj_FieldValidation.isAlphaNum(EmployeePan)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + tab + tab + T_FV_2030_C + tab + T_FV_2030_M);
							} else {
								byPassBooking = true;
								paperReturnRelax = true;
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4009_C + tab + T_FV_4009_M);
								receiptPanInvaild++;
								/*
								 * code added on 08-May-2006 to make an entry of Structurally invalid PAN in PAN
								 * stat buffer file.
								 */
								if (batchNumberOfRecord == 0) {
									batchNumberOfRecord = Integer.parseInt(BH_BatchNo.trim());
									Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatFileHeader());
									Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatTableStructureStart(batchRecDataForPanStat.toString()));
									batchRecDataForPanStat = new StringBuffer();
									// Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab +
									// CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
									// T_FV_4009_C + tab + T_FV_4009_M);
									Str_Buffer.appendPANStat("<TR>");
									Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
									Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=125>" + DeducteeDetailRecNo + "</TD>");
									Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + EmployeePan + "</TD>");
									Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + "Structurally Invalid Pan" + "</TD>");
									Str_Buffer.appendPANStat("</TR>");
								} else if (batchNumberOfRecord == Integer.parseInt(BH_BatchNo.trim())) {
									Str_Buffer.appendPANStat("<TR>");
									Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
									Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=125>" + DeducteeDetailRecNo + "</TD>");
									Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + EmployeePan + "</TD>");
									Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + "Structurally Invalid Pan" + "</TD>");
									Str_Buffer.appendPANStat("</TR>");
								}
							}
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4009_C + tab + T_FV_4009_M);
					}
				} else {
					if (validLastEmpPANStructure && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4216_C + tab + T_FV_4216_M);
					else {
						// used to generate provisional receipt
						// adding PANINVALID/PANAPPLIED/PANNOTAVL count to respective Vector for
						// respective BATCH Record
						String tempPanSt = null;
						if (EmployeePan.equals(PAN_NOT_AVAILABLE)) {
							receiptPanNotAvbl++;
							tempPanSt = "PAN not available";
						} else if (EmployeePan.equals(PAN_APPLIED)) {
							receiptPanApplied++;
							tempPanSt = "PAN applied";
						} else if (EmployeePan.equals(PAN_INVALID)) {
							receiptPanInvaild++;
							tempPanSt = "Invalid PAN";
						} /* HTML Code is appended to the Buffer with the respective Values */
						if (generateTdsPANStatBuffer && Str_Buffer.getErrorCount() == 0) {
							if (batchNumberOfRecord == 0) {
								batchNumberOfRecord = Integer.parseInt(BH_BatchNo.trim());
								Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatFileHeader());
								Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatTableStructureStart(batchRecDataForPanStat.toString()));
								batchRecDataForPanStat = new StringBuffer();
								Str_Buffer.appendPANStat("<TR>");
								Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
								Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=125>" + DeducteeDetailRecNo + "</TD>");
								Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + EmployeePan + "</TD>");
								Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + tempPanSt + "</TD>");
								Str_Buffer.appendPANStat("</TR>");
							} else if (batchNumberOfRecord == Integer.parseInt(BH_BatchNo.trim())) {
								Str_Buffer.appendPANStat("<TR>");
								Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
								Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=125>" + DeducteeDetailRecNo + "</TD>");
								Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + EmployeePan + "</TD>");
								Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + tempPanSt + "</TD>");
								Str_Buffer.appendPANStat("</TR>");
							} else {
								batchNumberOfRecord = Integer.parseInt(BH_BatchNo.trim());
								Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatTableStructureEnd(fileNamePrintedinStatRep));
								Str_Buffer.appendPANStat(obj_FileGenerator.createPANStatTableStructureStart(batchRecDataForPanStat.toString()));
								batchRecDataForPanStat = new StringBuffer();
								Str_Buffer.appendPANStat("<TR>");
								Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=75> " + LineNo + "</TD>");
								Str_Buffer.appendPANStat("<TD  valign=top style='text-align:right' width=120>" + DeducteeDetailRecNo + "</TD>");
								Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=188> " + EmployeePan + "</TD>");
								Str_Buffer.appendPANStat("<TD  ALIGN=LEFT width=180>" + tempPanSt + "</TD>");
								Str_Buffer.appendPANStat("</TR>");
							}
						}
					}
				}

				// -------changed for validating the % of structurally valid PAN ---By Manvendra
				// ----------------------------------------------------------------------------
				if (isFinYrGrtr) {
					if (!isFinYrGrtrthn && !(Mode.equals("D") || Mode.equals("U")) && !sectionForThisChallan.equals("K")) {
						totalPANtoVaildate_in_batch_ignoring_remark++;
						totalPANtoVaildate_ignoring_remark++;
						if (!Remark1.equals("B")) {
							totalPANtoVaildate++;
							totalPANtoValidate_in_batch++;
						}

						// System.out.println(" Mode is::" + Mode + " Remark is ::" + Remark1 + " Total
						// Pan To validate::" + totalPANtoVaildate + "deductee record No::" +
						// DeducteeDetailRecNo);
					}
					if (isFinYrGrtrthn && !(Mode.equals("D") || Mode.equals("U")) && !sectionForThisDD.equals("K")) {
						totalPANtoVaildate_in_batch_ignoring_remark++;
						totalPANtoVaildate_ignoring_remark++;
						if (!Remark1.equals("B")) {
							totalPANtoVaildate++;
							totalPANtoValidate_in_batch++;
						}

						// System.out.println(" Mode is::" + Mode + " Remark is ::" + Remark1 + " Total
						// Pan To validate::" + totalPANtoVaildate + "deductee record No::" +
						// DeducteeDetailRecNo);
					}
				}

				else {
					if (!(Mode.equals("D") || Mode.equals("U"))) {
						totalPANtoVaildate_in_batch_ignoring_remark++;
						totalPANtoVaildate_ignoring_remark++;
						if (!Remark1.equals("B")) {
							totalPANtoVaildate++;
							totalPANtoValidate_in_batch++;
						}

						// System.out.println(" Mode is::" + Mode + " Remark is ::" + Remark1 + " Total
						// Pan To validate::" + totalPANtoVaildate + "deductee record No::" +
						// DeducteeDetailRecNo);
					}
				}
				// ----------------------------------------------------------------------------

				// ---------------Added by Nahush for validating Deductor PAN against PAN of
				// deductee.

				if (!(EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && PANForThisBatch.equals(EmployeePan)
						&& (UploadType.equals("R") || (UploadType.equals("C") && BatchUpdationIndicator.equals("1")))) {
					if (paperReturnFile) {
						Str_Buffer.appendPaperWarning(LineNo + tab + "Deductee" + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_4261_C + tab + T_FV_4261_M);
					}

					else {
						Str_Buffer.appendElectronicWarning(LineNo + tab + "Deductee" + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_4261_C + tab + T_FV_4261_M);
					}
				}

			} // Validating EmployeePan

			// added by Priyanka for fvu 4.7 for point 2 // shifted code to method during FVY 7.2

			validateEmployeePan(TransactionType, Str_Buffer, LineNo,
					DD_BatchNo, ChallanRecordNo, DeducteeDetailRecNo,
					LastEmployeePan, EmployeePan);

			// Validating LastEmployeePanRefNo 11
			validateLastEmployeePanRefNo(TransactionType, UploadTypeDD, Str_Buffer, LineNo, LastEmployeePanRefNo, obj_FieldValidation); // Validating
																																		// LastEmployeePanRefNo

			// Validating EmployeePanRefNo 12
			validateEmployeePanRefNo(TransactionType, Str_Buffer, LineNo, LastEmployeePanRefNo, EmployeePanRefNo, obj_FieldValidation);
			// Validating EmployeePanRefNo
			// Added by ABhishek for checking pan ref num against last pan ref num

			// M04_B
			/*
			 * commented by Dhanya on 03/02/2011 as for FVU3.1, PAN Ref No validations
			 * should be as that of FVU 2.128
			 * 
			 * if(valueForPanRefNo== true && (LastEmployeePanRefNo.trim().equals(FIELD_NULL)
			 * || LastEmployeePanRefNo.trim().equals(FIELD_SEPERATOR)) &&
			 * UploadType.equals(UPLOADTYPE_CORRECTION)) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Employee/Party PAN Ref. No." + tab +
			 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4275_C + tab + T_FV_4275_M); } M04_E
			 */

			// END
			// Validating EmployeeName 13
			validateEmployeeName(BH_BatchNo, ChallanDetailRecordNo, TransactionType, Str_Buffer, LineNo, DeducteeDetailRecNo, EmployeeName, obj_FieldValidation);
			// Validating EmployeeName
			// Validating TDSIncomeTax 14
			boolean errorTDSIncomeTaxDD = false;
			if (TDSIncomeTaxDD.equals(FIELD_NULL) || TDSIncomeTaxDD.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4036_C + tab + T_FV_4036_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4112_C + tab + T_FV_4112_M);
			}
			// Added By amit for 4.5

			else if (TDSIncomeTaxDD.length() != TDSIncomeTaxDD.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4036_C + tab + T_FV_4036_M);
			}

			// Amit end for Fvu 4.5
			else if (TDSIncomeTaxDD.length() <= 15) {
				if (obj_FieldValidation.isDecimalNumber(TDSIncomeTaxDD))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4036_C + tab + T_FV_4036_M);
				else if (Double.parseDouble(TDSIncomeTaxDD.trim()) < 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4036_C + tab + T_FV_4036_M);
				// ######################################################
				// -- Code Added to check For IncomeTax when remark1 is B --- Manvendra ::
				// 15-Feb-2008

				else if (Remark1.equals("B") && Double.parseDouble(TDSIncomeTaxDD.trim()) != 0 && !paperReturnFile && FormNo.equals(FORM_26Q) && !Mode.equals("D") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)
						&& ChallanUpdationIndicatorForcurrentchallan.equals("0") && (!SectionCode.equals("94J")) // added
																													// for
																													// FVU
																													// 5.6
						&& performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4247_C + tab + T_FV_4247_M);
					isValid_B = false;
				} else if (!isFinYrGrtrthn && Remark1.equals("B") && Double.parseDouble(TDSIncomeTaxDD.trim()) != 0 && !paperReturnFile && !Mode.equals("D")
						&& (sectionForThisChallan.equals("194") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("193")) && performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4247_C + tab + T_FV_4247_M);
					isValid_B = false;
				} else if (isFinYrGrtrthn && Remark1.equals("B") && Double.parseDouble(TDSIncomeTaxDD.trim()) != 0 && !paperReturnFile && !Mode.equals("D")
						&& (sectionForThisDD.equals("194") || sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94A") || sectionForThisDD.equals("193") || sectionForThisDD.equals("94D")) // added "94D" for FVU 5.5
						&& performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4247_C + tab + T_FV_4247_M);
					isValid_B = false;
				}

				// ######################################################
				else
					errorTDSIncomeTaxDD = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4036_C + tab + T_FV_4036_M);
			// Validating TDSIncomeTax
			// Validating TDSSurcharge 15
			boolean errorTDSSurchargeDD = false;
			if (TDSSurchargeDD.equals(FIELD_NULL) || TDSSurchargeDD.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4037_C + tab + T_FV_4037_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4113_C + tab + T_FV_4113_M);
			}
			// Added By amit for 4.5
			else if (TDSSurchargeDD.length() != TDSSurchargeDD.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4037_C + tab + T_FV_4037_M);
			}
			// Amit end for Fvu 4.5
			else if (TDSSurchargeDD.length() <= 15) {
				if (obj_FieldValidation.isDecimalNumber(TDSSurchargeDD))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4037_C + tab + T_FV_4037_M);
				else if (Double.parseDouble(TDSSurchargeDD.trim()) < 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4037_C + tab + T_FV_4037_M);
				// ######################################################
				// -- Code Added to check For surcharge when remark1 is B --- Manvendra ::
				// 15-Feb-2008
				else if (Remark1.equals("B") && Double.parseDouble(TDSSurchargeDD.trim()) != 0 && !paperReturnFile && !Mode.equals("D") && FormNo.equals(FORM_26Q) && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)
						&& ChallanUpdationIndicatorForcurrentchallan.equals("0") && (!SectionCode.equals("94J")) // added
																													// for
																													// FVU
																													// 5.6
						&& performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4248_C + tab + T_FV_4248_M);
					isValid_B = false;
				} else if (!isFinYrGrtrthn && Remark1.equals("B") && Double.parseDouble(TDSSurchargeDD.trim()) != 0 && !paperReturnFile && !Mode.equals("D")
						&& (sectionForThisChallan.equals("194") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("193")) && performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4248_C + tab + T_FV_4248_M);
					isValid_B = false;
				} else if (isFinYrGrtrthn && Remark1.equals("B") && Double.parseDouble(TDSSurchargeDD.trim()) != 0 && !paperReturnFile && !Mode.equals("D")
						&& (sectionForThisDD.equals("194") || sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94A") || sectionForThisDD.equals("193") || sectionForThisDD.equals("94D")) // added "94D" for FVU 5.5
						&& performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4248_C + tab + T_FV_4248_M);
					isValid_B = false;
				}

				// ######################################################
				else
					errorTDSSurchargeDD = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4037_C + tab + T_FV_4037_M);
			// Validating TDSSurcharge
			// Validating Cess 16
			boolean errorCessDD = false;
			if (TDSCessDD.equals(FIELD_NULL) || TDSCessDD.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4038_C + tab + T_FV_4038_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4117_C + tab + T_FV_4117_M);
			}
			// Added By amit for 4.5
			else if (TDSCessDD.length() != TDSCessDD.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4038_C + tab + T_FV_4038_M);
			}
			// Amit end for Fvu 4.5
			else if (TDSCessDD.length() <= 15) {
				if (obj_FieldValidation.isDecimalNumber(TDSCessDD))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4038_C + tab + T_FV_4038_M);
				else if (Double.parseDouble(TDSCessDD.trim()) < 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4038_C + tab + T_FV_4038_M);
				// ----------------####################################
				// -- Code Added to check For Cess when remark1 is B --- Manvendra ::
				// 15-Feb-2008
				else if (Remark1.equals("B") && Double.parseDouble(TDSCessDD.trim()) != 0 && !paperReturnFile && FormNo.equals(FORM_26Q) && !Mode.equals("D") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)
						&& ChallanUpdationIndicatorForcurrentchallan.equals("0") && (!SectionCode.equals("94J")) // added
																													// for
																													// FVU
																													// 5.6
						&& performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4249_C + tab + T_FV_4249_M);
					isValid_B = false;
				} else if (!isFinYrGrtrthn && Remark1.equals("B") && Double.parseDouble(TDSCessDD.trim()) != 0 && !paperReturnFile && !Mode.equals("D")
						&& (sectionForThisChallan.equals("194") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("193")) && performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4249_C + tab + T_FV_4249_M);
					isValid_B = false;
				} else if (isFinYrGrtrthn && Remark1.equals("B") && Double.parseDouble(TDSCessDD.trim()) != 0 && !paperReturnFile && !Mode.equals("D")
						&& (sectionForThisDD.equals("194") || sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94A") || sectionForThisDD.equals("193") || sectionForThisDD.equals("94D")) // added "94D" for FVU 5.5
						&& performDDvalidation) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4249_C + tab + T_FV_4249_M);
					isValid_B = false;
				}

				// ####################################
				else
					errorCessDD = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS / TCS -Cess" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4038_C + tab + T_FV_4038_M);
			// Validating Cess
			// Validating LastTotalIncomeTaxDeductedAtSource 18
			boolean validLastTotalIncomeTaxDeductedAtSource = false;
			if (LastTotalIncomeTaxDeductedAtSource.equals(FIELD_NULL) || LastTotalIncomeTaxDeductedAtSource.equals(FIELD_SEPERATOR)) {
				if (Mode.equals("D") || Mode.equals("U") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4109_C + tab + T_FV_4109_M);
			} else {
				if (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4083_C + tab + T_FV_4083_M);
				// Added By amit for 4.5
				else if (LastTotalIncomeTaxDeductedAtSource.length() != LastTotalIncomeTaxDeductedAtSource.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4082_C + tab + T_FV_4082_M);
				}
				// Amit end for Fvu 4.5
				else {
					if (Mode.equals("A"))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4110_C + tab + T_FV_4110_M);
					else {
						if (LastTotalIncomeTaxDeductedAtSource.length() <= 15) {
							if (obj_FieldValidation.isDecimal(LastTotalIncomeTaxDeductedAtSource, 2))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4082_C + tab + T_FV_4082_M);
							else if (Double.parseDouble(LastTotalIncomeTaxDeductedAtSource.trim()) < 0)
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4082_C + tab + T_FV_4082_M);
							else {
								validLastTotalIncomeTaxDeductedAtSource = true;
								samScmLastTotalIncomeTaxDeductedAtSource = samScmLastTotalIncomeTaxDeductedAtSource + Double.parseDouble(LastTotalIncomeTaxDeductedAtSource.trim());
							}
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4082_C + tab + T_FV_4082_M);
					}
				}
			} // Validating LastTotalIncomeTaxDeductedAtSource
				// Validating TotalIncomeTaxDeductedAtSource 17
			boolean validTotalIncomeTaxDeductedAtSource = false;
			boolean totalIncTaxDedAtSrcZero = false;
			// This flag is set TRUE if the value of "Total Income Tax Deducted At Source"
			// is ZERO (0)
			boolean calTotITDedAtSrcVal = false;
			if (TotalIncomeTaxDeductedAtSource.equals(FIELD_NULL) || TotalIncomeTaxDeductedAtSource.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4039_C + tab + T_FV_4039_M);

			} else {
				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4046_C + tab + T_FV_4046_M);
				// Added By amit for 4.5
				else if (TotalIncomeTaxDeductedAtSource.length() != TotalIncomeTaxDeductedAtSource.trim().length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4039_C + tab + T_FV_4039_M);
				}
				// Amit end for Fvu 4.5
				else if (TotalIncomeTaxDeductedAtSource.length() <= 15) {
					if (obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4039_C + tab + T_FV_4039_M);
					}

					else if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) < 0) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4039_C + tab + T_FV_4039_M);
						parseableTotalDeduction = true;
					}
					// Added for FVU 4.4 by Shalin
					else if (TotalIncomeTaxDeductedAtSource.trim().length() != TotalIncomeTaxDeductedAtSource.length()) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4039_C + tab + T_FV_4039_M);
					}
					// ####################################
					// -- Code Added to check For TotalIncomeTaxDeductedAtSource when remark1 is B
					// --- Manvendra :: 15-Feb-2008
					// Code commented For FVU 3.0

					/*
					 * else if ( Remark1.equals("B") &&
					 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != 0 &&
					 * !paperReturnFile && FormNo.equals(FORM_26Q) && !Mode.equals("D") &&
					 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
					 * ChallanUpdationIndicatorForcurrentchallan.equals("0") && performDDvalidation)
					 * { Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo +
					 * tab + CurrentDeducteeDetailRecNo + tab + T_FV_4250_C + tab + T_FV_4250_M);
					 * isValid_B = false; parseableTotalDeduction = true; } else if (
					 * Remark1.equals("B") &&
					 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != 0 &&
					 * !paperReturnFile && !Mode.equals("D") && (sectionForThisChallan.equals("194")
					 * || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A")
					 * || sectionForThisChallan.equals("193")) && performDDvalidation) {
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo +
					 * tab + CurrentDeducteeDetailRecNo + tab + T_FV_4250_C + tab + T_FV_4250_M);
					 * isValid_B = false; parseableTotalDeduction = true; }
					 */

					// ####################################
					else {
						// Added to check date of deduction on the basis of Total deduction : Manvendra
						// Singh :: 25 Feb 2008
						parseableTotalDeduction = true;
						validTotalIncomeTaxDeductedAtSource = true;
						iTotalIncomeTaxDeductedAtSource = Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim());

						if (iTotalIncomeTaxDeductedAtSource == 0) {
							totalIncTaxDedAtSrcZero = true;
							calTotITDedAtSrcVal = true; // Set the Flag True
						}

						if (errorTDSIncomeTaxDD) {
							iTDSIncomeTaxDD = Double.parseDouble(TDSIncomeTaxDD.trim());
							// Added By faizan for fvu 4.5
							if (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)))
								SumTDSIncomeTaxDDfield14 = SumTDSIncomeTaxDDfield14 + iTDSIncomeTaxDD;
						}

						if (errorTDSSurchargeDD) {
							iTDSSurchargeDD = Double.parseDouble(TDSSurchargeDD.trim());
							// Added By faizan for fvu 4.5
							if (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)))
								SumTDSIncomeTaxDDfield15 = SumTDSIncomeTaxDDfield15 + iTDSSurchargeDD;
						}

						if (errorCessDD) {
							iCessDD = Double.parseDouble(TDSCessDD.trim());
							// Added By faizan for fvu 4.5
							if (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)))
								SumTDSIncomeTaxDDfield16 = SumTDSIncomeTaxDDfield16 + iCessDD;
						}

						sumOfIncomeTaxSurcharge = iTDSIncomeTaxDD + iTDSSurchargeDD + iCessDD;
						boolean validateFurther = true;
						if ((sumOfIncomeTaxSurcharge * 100) < (-1000.0 + (iTotalIncomeTaxDeductedAtSource * 100)) || (sumOfIncomeTaxSurcharge * 100) > (1000.0 + (iTotalIncomeTaxDeductedAtSource * 100))) {
							// if (paperReturnFile &&
							// (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0))
							// Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab +
							// CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
							// T_FV_4107_C + tab + T_FV_4107_M);
							// else
							// {
							// Str_Buffer.append(LineNo + tab + currentUploadType + tab +
							// CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
							// T_FV_4107_C + tab + T_FV_4107_M);
							// /* If the file is Electronic Return ie. NS1, SL1 ot TC1 and the Tolerance is
							// of more than 10.00
							// * than we will not validate further. "validateFurther" Flag is SET to FALSE.
							// */
							// validateFurther = false;
							// }
							if (paperReturnFile) {
								byPassBooking = true;
								paperReturnRelax = true;
								Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4107_C + tab + T_FV_4107_M);
							} else {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4107_C + tab + T_FV_4107_M);
								/*
								 * If the file is Electronic Return ie. NS1, SL1 ot TC1 and the Tolerance is of
								 * more than 10.00 than we will not validate further. "validateFurther" Flag is
								 * SET to FALSE.
								 */
								validateFurther = false;
							}

						}

						if (validateFurther) {
							if (LastTotalIncomeTaxDeductedAtSource.equals(FIELD_NULL) || LastTotalIncomeTaxDeductedAtSource.equals(FIELD_SEPERATOR))
								iLastTotalIncomeTaxDeductedAtSource = 0;
							else if (validLastTotalIncomeTaxDeductedAtSource) {
								iLastTotalIncomeTaxDeductedAtSource = Double.parseDouble(LastTotalIncomeTaxDeductedAtSource.trim());
							}

							if (Mode.equals("A") || Mode.equals("O")) {
								pval = pval + iTotalIncomeTaxDeductedAtSource;
							} else if (Mode.equals("U") && validLastTotalIncomeTaxDeductedAtSource) {
								iTotalIncomeTaxDeductedAtSource = iTotalIncomeTaxDeductedAtSource - iLastTotalIncomeTaxDeductedAtSource;
								pval = pval + iTotalIncomeTaxDeductedAtSource;
							} else if (Mode.equals("D") && validLastTotalIncomeTaxDeductedAtSource) {
								if (iTotalIncomeTaxDeductedAtSource != iLastTotalIncomeTaxDeductedAtSource)
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4108_C + tab + T_FV_4108_M);
								else
									nval = nval + iTotalIncomeTaxDeductedAtSource;
							} else if (!FormNo.equals(FORM_27Q) && Mode.equals("F") && iTotalIncomeTaxDeductedAtSource != iLastTotalIncomeTaxDeductedAtSource && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4345_C + tab + T_FV_4345_M); // added
																																																													// by
																																																													// shruti
																																																													// FVU
																																																													// 5.4
							}

							calTotITDedAtSrcVal = true; // Set the Flag True
						}
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4039_C + tab + T_FV_4039_M);
			} // Calculating "Total Income Tax Deducted At Source" for Provisional Receipt and
				// Statistic Report
			if (calTotITDedAtSrcVal) {
				if (Mode.equals("U") && receiptTotalITDeductedAtSrcUpdtMode.equals("-"))
					receiptTotalITDeductedAtSrcUpdtMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()));
				else if (Mode.equals("A") && receiptTotalITDeductedAtSrcAddMode.equals("-"))
					receiptTotalITDeductedAtSrcAddMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()));
				else if (Mode.equals("O") && receiptTotalITDeductedAtSrcOrigMode.equals("-"))
					receiptTotalITDeductedAtSrcOrigMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()));
				else if (Mode.equals("D") && receiptTotalITDeductedAtSrcDelMode.equals("-"))
					receiptTotalITDeductedAtSrcDelMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()));
				else if (isModeValid) { // d4 = Math.round((double)(d4 * 100)) /100.0;
					String statTotalITDeductedAtSrc = "0.00";
					if (Mode.equals("U")) {
						statTotalITDeductedAtSrc = receiptTotalITDeductedAtSrcUpdtMode;
					} else if (Mode.equals("A")) {
						statTotalITDeductedAtSrc = receiptTotalITDeductedAtSrcAddMode;
					} else if (Mode.equals("O")) {
						statTotalITDeductedAtSrc = receiptTotalITDeductedAtSrcOrigMode;
					} else if (Mode.equals("D")) {
						statTotalITDeductedAtSrc = receiptTotalITDeductedAtSrcDelMode;
					}

					double val1 = Double.parseDouble(statTotalITDeductedAtSrc.trim());
					double val2 = Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim());
					double val3 = val1 + val2;
					val3 = Math.round((double) (val3 * 100)) / 100.0;
					statTotalITDeductedAtSrc = obj_FieldValidation.changeNumberFormat(val3);
					if (Mode.equals("U")) {
						receiptTotalITDeductedAtSrcUpdtMode = statTotalITDeductedAtSrc;
					} else if (Mode.equals("A")) {
						receiptTotalITDeductedAtSrcAddMode = statTotalITDeductedAtSrc;
					} else if (Mode.equals("O")) {
						receiptTotalITDeductedAtSrcOrigMode = statTotalITDeductedAtSrc;
					} else if (Mode.equals("D")) {
						receiptTotalITDeductedAtSrcDelMode = statTotalITDeductedAtSrc;
					}
				}
			} // Calculating "Total Income Tax Deducted At Source" for Provisional Receipt and
				// Statistic Report
				// Validating LastTotalTaxDeposited 20
			boolean errorLastTotalTaxDeposited = false;
			if (LastTotalTaxDeposited.equals(FIELD_NULL) || LastTotalTaxDeposited.equals(FIELD_SEPERATOR)) {
				if (Mode.equals("D") || Mode.equals("U") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4175_C + tab + T_FV_4175_M);
				else
					errorLastTotalTaxDeposited = true;
			} else if (Mode.equals("A") || Mode.equals("O")) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4176_C + tab + T_FV_4176_M);
			}
			// Added By amit for 4.5
			else if (LastTotalTaxDeposited.length() != LastTotalTaxDeposited.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4175_C + tab + T_FV_4175_M);
			}
			// Amit end for Fvu 4.5
			else if (LastTotalTaxDeposited.length() > 15) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4175_C + tab + T_FV_4175_M);
			} else if (obj_FieldValidation.isDecimalNumber(LastTotalTaxDeposited)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4175_C + tab + T_FV_4175_M);
			} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(LastTotalTaxDeposited.trim()) != 0) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4208_C + tab + T_FV_4208_M);
			} else
				errorLastTotalTaxDeposited = true;
			// Validating LastTotalTaxDeposited 20
			// Validating TotalTaxDeposited 19
			boolean calTotTaxDepositedVal = false;
			if (TotalTaxDeposited.equals(FIELD_NULL) || TotalTaxDeposited.equals(FIELD_SEPERATOR)) {
				if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4115_C + tab + T_FV_4115_M);
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4209_C + tab + T_FV_4209_M);
			}
			// Added By amit for 4.5
			else if (TotalTaxDeposited.length() != TotalTaxDeposited.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4115_C + tab + T_FV_4115_M);
			}
			// Amit end for Fvu 4.5
			else if (TotalTaxDeposited.length() > 15) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4115_C + tab + T_FV_4115_M);
			} else if (obj_FieldValidation.isDecimalNumber(TotalTaxDeposited)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4115_C + tab + T_FV_4115_M);
			} else if (NillChallanIndicator.equals("Y") && Double.parseDouble(TotalTaxDeposited.trim()) != 0) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4207_C + tab + T_FV_4207_M);
			}
			// added by priyanka for FVU 4.7 (field 17=field 19)

			else if ((UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))))
					&& !(TotalIncomeTaxDeductedAtSource.equals(FIELD_NULL) || TotalIncomeTaxDeductedAtSource.equals(FIELD_SEPERATOR)) && Double.parseDouble(TotalTaxDeposited) != Double.parseDouble(TotalIncomeTaxDeductedAtSource)
					&& (!(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Remark1.equals("C") && Mode.equals("U")))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4332_C + tab + T_FV_4332_M);
			}
			/*
			 * Commented by ABhishek on 05032011 //M06_B_ADDED Added on 02/03/2011 else if(
			 * !Mode.equals("D") &&
			 * !obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource) &&
			 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0 &&
			 * Double.parseDouble(TotalTaxDeposited.trim()) != 0 ) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab +
			 * CurrentDeducteeDetailRecNo + tab + T_FV_4294_C + tab + T_FV_4294_M); }
			 * //M06_B END commented by abhishek
			 */

			// --------------####################################
			// -- Code Added to check For TotalTaxDeposited when remark1 is B --- Manvendra
			// :: 15-Feb-2008
			// Code Commented For FVU 3.0
			/*
			 * else if ( Remark1.equals("B") && Double.parseDouble(TotalTaxDeposited.trim())
			 * != 0 && !paperReturnFile && FormNo.equals(FORM_26Q) && !Mode.equals("D") &&
			 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
			 * ChallanUpdationIndicatorForcurrentchallan.equals("0") && performDDvalidation)
			 * { Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab +
			 * CurrentDeducteeDetailRecNo + tab + T_FV_4251_C + tab + T_FV_4251_M);
			 * isValid_B = false; } else if ( Remark1.equals("B") &&
			 * Double.parseDouble(TotalTaxDeposited.trim()) != 0 && !paperReturnFile &&
			 * !Mode.equals("D") && (sectionForThisChallan.equals("194") ||
			 * sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") ||
			 * sectionForThisChallan.equals("193")) && performDDvalidation) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab +
			 * CurrentDeducteeDetailRecNo + tab + T_FV_4251_C + tab + T_FV_4251_M);
			 * isValid_B = false; }
			 */

			else if ((Remark1.equals("A") || Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR) || Remark1.equals("T") || Remark1.equals("C")) // Remarks T and C added For FVU 3.0
					&& FormNo.equals(FORM_26Q) && !Mode.equals("D") && Double.parseDouble(TotalTaxDeposited.trim()) < 0 && !paperReturnFile && performDDvalidation)

				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4256_C + tab + T_FV_4256_M);

			// --########################################
			else {

				if (Mode.equals("A") || Mode.equals("O")) {

					pvalTotalIncomeTaxDeposited = pvalTotalIncomeTaxDeposited + Double.parseDouble(TotalTaxDeposited.trim());
					calTotTaxDepositedVal = true;

				} else if (Mode.equals("U") && errorLastTotalTaxDeposited && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {

					pvalTotalIncomeTaxDeposited = pvalTotalIncomeTaxDeposited + (Double.parseDouble(TotalTaxDeposited.trim()) - Double.parseDouble(LastTotalTaxDeposited.trim()));
					calTotTaxDepositedVal = true;

				} else if ((Mode.equals("D") && errorLastTotalTaxDeposited) || (Mode.equals("U") && errorLastTotalTaxDeposited && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))) {

					if (Double.parseDouble(TotalTaxDeposited.trim()) != Double.parseDouble(LastTotalTaxDeposited.trim()))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4177_C + tab + T_FV_4177_M);
					else {
						nvalTotalIncomeTaxDeposited = nvalTotalIncomeTaxDeposited + Double.parseDouble(TotalTaxDeposited.trim());
						calTotTaxDepositedVal = true;
					}

				}

			} // Validating TotalTaxDeposited

			// Calculating "Total Tax Deposited as per Deductee Annexure" for Provisional
			// Receipt and Statistic Report
			if (calTotTaxDepositedVal) {
				if (Mode.equals("U") && receiptTotofDepdAmtUpdtMode.equals("-"))
					receiptTotofDepdAmtUpdtMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalTaxDeposited.trim()));
				else if (Mode.equals("A") && receiptTotofDepdAmtAddMode.equals("-"))
					receiptTotofDepdAmtAddMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalTaxDeposited.trim()));
				else if (Mode.equals("O") && receiptTotofDepdAmtOrigMode.equals("-"))
					receiptTotofDepdAmtOrigMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalTaxDeposited.trim()));
				else if (Mode.equals("D") && receiptTotofDepdAmtDelMode.equals("-"))
					receiptTotofDepdAmtDelMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalTaxDeposited.trim()));
				else if (isModeValid) { // d4 = Math.round((double)(d4 * 100)) /100.0;
					String statTotalofDepositedAmount = "0.00";
					if (Mode.equals("U")) {
						statTotalofDepositedAmount = receiptTotofDepdAmtUpdtMode;
					} else if (Mode.equals("A")) {
						statTotalofDepositedAmount = receiptTotofDepdAmtAddMode;
					} else if (Mode.equals("O")) {
						statTotalofDepositedAmount = receiptTotofDepdAmtOrigMode;
					} else if (Mode.equals("D")) {
						statTotalofDepositedAmount = receiptTotofDepdAmtDelMode;
					}

					double val1 = Double.parseDouble(statTotalofDepositedAmount.trim());
					double val2 = Double.parseDouble(TotalTaxDeposited.trim());
					double val3 = val1 + val2;
					val3 = Math.round((double) (val3 * 100)) / 100.0;
					statTotalofDepositedAmount = obj_FieldValidation.changeNumberFormat(val3);
					if (Mode.equals("U")) {
						receiptTotofDepdAmtUpdtMode = statTotalofDepositedAmount;
					} else if (Mode.equals("A")) {
						receiptTotofDepdAmtAddMode = statTotalofDepositedAmount;
					} else if (Mode.equals("O")) {
						receiptTotofDepdAmtOrigMode = statTotalofDepositedAmount;
					} else if (Mode.equals("D")) {
						receiptTotofDepdAmtDelMode = statTotalofDepositedAmount;
					}
				}
			} // Calculating "Total Tax Deposited as per Deductee Annexure" for Provisional
				// Receipt and Statistic Report
				// Validating Total Value of Purchase 21
			if (TotalValueofPurchase.equals(FIELD_NULL) || TotalValueofPurchase.equals(FIELD_SEPERATOR)) {
				if (!Mode.equals("D") && FormNo.equals(FORM_27EQ) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Value of Purchase" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4128_C + tab + T_FV_4128_M);
			} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Value of Purchase" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4129_C + tab + T_FV_4129_M);
			} else if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Value of Purchase" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4130_C + tab + T_FV_4130_M);
			// Added By amit for 4.5
			else if (TotalValueofPurchase.length() != TotalValueofPurchase.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Value of Purchase" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4128_C + tab + T_FV_4128_M);
			}
			// Amit end for Fvu 4.5
			else if (TotalValueofPurchase.length() <= 15) {
				if (obj_FieldValidation.isDecimal(TotalValueofPurchase, 2))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Value of Purchase" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4128_C + tab + T_FV_4128_M);
				else if (Double.parseDouble(TotalValueofPurchase.trim()) < 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Value of Purchase" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4128_C + tab + T_FV_4128_M);
				else {
					if (statTotalValueofTurnover.equals("-"))
						statTotalValueofTurnover = obj_FieldValidation.changeNumberFormat(Double.parseDouble(TotalValueofPurchase.trim()));
					else {
						// d4 = Math.round((double)(d4 * 100)) /100.0;
						double val1 = Double.parseDouble(statTotalValueofTurnover.trim());
						double val2 = Double.parseDouble(TotalValueofPurchase.trim());
						double val3 = val1 + val2;
						val3 = Math.round((double) (val3 * 100)) / 100.0;
						statTotalValueofTurnover = obj_FieldValidation.changeNumberFormat(val3);
					}
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Value of Purchase" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4128_C + tab + T_FV_4128_M);
			// Validating Total Value of Purchase
			// Validating AmountOfPayment 22
			if (AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) {
				if (!Mode.equals("D") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4086_C + tab + T_FV_4086_M);
			} else if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4087_C + tab + T_FV_4087_M);
			// Added By amit for 4.5
			else if (AmountOfPayment.length() != AmountOfPayment.trim().length()) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4086_C + tab + T_FV_4086_M);
			}
			// Amit end for Fvu 4.5
			else if (AmountOfPayment.length() <= 15) {
				if (obj_FieldValidation.isDecimal(AmountOfPayment, 2))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4086_C + tab + T_FV_4086_M);
				else if (Double.parseDouble(AmountOfPayment.trim()) < 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4086_C + tab + T_FV_4086_M);
				// ############### Code Added For validatin Amount for valid PAN :: Manvendra
				// 15-Feb-2008
				else if (Double.parseDouble(AmountOfPayment.trim()) == 0 && !paperReturnFile && performDDvalidation && !(Mode.equals("U") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) // Changed
																																																			// by
																																																			// Shalin
																																																			// for
																																																			// FVU
																																																			// 4.1
				{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4246_C + tab + T_FV_4246_M);
					isValid_B = false;
				}

				// Added By amit for fvu 4.4
				else if (FormNo.equals(FORM_24Q) && Double.parseDouble(AmountOfPayment.trim()) > 999999999.00 && (UploadType.equals(UPLOADTYPE_REGULAR)
						|| (UploadType.equals(UPLOADTYPE_CORRECTION) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")))))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4086_C + tab + T_FV_4086_M);
					isValid_B = false; // dekhna padega bhaya
				} else if (AmountOfPayment.trim().length() != AmountOfPayment.length()) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4086_C + tab + T_FV_4086_M);
				}

				// Amit end
				// ##################################################################
				else if (validTotalIncomeTaxDeductedAtSource && (FileType.equals(FILETYPE_NONSALARY_ELECTRONIC) || FileType.equals(FILETYPE_NONSALARY_DIGITAL) || FileType.equals(FILETYPE_TCS_DIGITAL) || FileType.equals(FILETYPE_TCS_ELECTRONIC))) {
					if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) > Double.parseDouble(AmountOfPayment.trim())) {
						if (paperReturnFile) {
							byPassBooking = true;
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4213_C + tab + T_FV_4213_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4213_C + tab + T_FV_4213_M);
					} else {
						if (Mode.equals("U") && receiptTotalAmtPaidCrdtUpdateMode.equals("-"))
							receiptTotalAmtPaidCrdtUpdateMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(AmountOfPayment.trim()));
						else if (Mode.equals("A") && receiptTotalAmtPaidCrdtAddMode.equals("-"))
							receiptTotalAmtPaidCrdtAddMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(AmountOfPayment.trim()));
						else if (Mode.equals("O") && receiptTotalAmtPaidCrdtOriginalMode.equals("-"))
							receiptTotalAmtPaidCrdtOriginalMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(AmountOfPayment.trim()));
						else if (isModeValid) { // d4 = Math.round((double)(d4 * 100)) /100.0;
							String statTotalAmtPaidCrdt = "0.00";
							if (Mode.equals("U")) {
								statTotalAmtPaidCrdt = receiptTotalAmtPaidCrdtUpdateMode;
							} else if (Mode.equals("A")) {
								statTotalAmtPaidCrdt = receiptTotalAmtPaidCrdtAddMode;
							} else if (Mode.equals("O")) {
								statTotalAmtPaidCrdt = receiptTotalAmtPaidCrdtOriginalMode;
							}

							double val1 = Double.parseDouble(statTotalAmtPaidCrdt.trim());
							double val2 = Double.parseDouble(AmountOfPayment.trim());
							double val3 = val1 + val2;
							val3 = Math.round((double) (val3 * 100)) / 100.0;
							statTotalAmtPaidCrdt = obj_FieldValidation.changeNumberFormat(val3);
							if (Mode.equals("U")) {
								receiptTotalAmtPaidCrdtUpdateMode = statTotalAmtPaidCrdt;
							} else if (Mode.equals("A")) {
								receiptTotalAmtPaidCrdtAddMode = statTotalAmtPaidCrdt;
							} else if (Mode.equals("O")) {
								receiptTotalAmtPaidCrdtOriginalMode = statTotalAmtPaidCrdt;
							}
						} // Adding Data to string which is appended to StringBuffer to generate Statastic
							// File
					}
				}
				// added by Shalin for FVU 4.4
				else if (FormNo.equals(FORM_24Q) && !(Double.parseDouble(AmountOfPayment.trim()) >= Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()))) {
					if (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || ((Mode.equals("U") || Mode.equals("A")) && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
							|| (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O"))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4086_C + tab + T_FV_4086_M);
					}
				} else {
					if (Mode.equals("U") && receiptTotalAmtPaidCrdtUpdateMode.equals("-"))
						receiptTotalAmtPaidCrdtUpdateMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(AmountOfPayment.trim()));
					else if (Mode.equals("A") && receiptTotalAmtPaidCrdtAddMode.equals("-"))
						receiptTotalAmtPaidCrdtAddMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(AmountOfPayment.trim()));
					else if (Mode.equals("O") && receiptTotalAmtPaidCrdtOriginalMode.equals("-"))
						receiptTotalAmtPaidCrdtOriginalMode = obj_FieldValidation.changeNumberFormat(Double.parseDouble(AmountOfPayment.trim()));
					else if (isModeValid) {
						/*
						 * 23 July 2005 statTotalAmtPaidCrdt =
						 * Double.toString((Double.parseDouble(statTotalAmtPaidCrdt.trim()) +
						 * Double.parseDouble(AmountOfPayment.trim())) ); statTotalAmtPaidCrdt =
						 * obj_FieldValidation.changeNumberFormat(Double.parseDouble(
						 * statTotalAmtPaidCrdt.trim()));
						 */ // d4 = Math.round((double)(d4 * 100)) /100.0;
						String statTotalAmtPaidCrdt = "0.00";
						if (Mode.equals("U")) {
							statTotalAmtPaidCrdt = receiptTotalAmtPaidCrdtUpdateMode;
						} else if (Mode.equals("A")) {
							statTotalAmtPaidCrdt = receiptTotalAmtPaidCrdtAddMode;
						} else if (Mode.equals("O")) {
							statTotalAmtPaidCrdt = receiptTotalAmtPaidCrdtOriginalMode;
						}

						double val1 = Double.parseDouble(statTotalAmtPaidCrdt.trim());
						double val2 = Double.parseDouble(AmountOfPayment.trim());
						double val3 = val1 + val2;
						val3 = Math.round((double) (val3 * 100)) / 100.0;
						statTotalAmtPaidCrdt = obj_FieldValidation.changeNumberFormat(val3);
						if (Mode.equals("U")) {
							receiptTotalAmtPaidCrdtUpdateMode = statTotalAmtPaidCrdt;
						} else if (Mode.equals("A")) {
							receiptTotalAmtPaidCrdtAddMode = statTotalAmtPaidCrdt;
						} else if (Mode.equals("O")) {
							receiptTotalAmtPaidCrdtOriginalMode = statTotalAmtPaidCrdt;
						}
					} // Adding Data to string which is appended to StringBuffer to generate Statastic
						// File
				}

			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of Payment  / Credit / Debited ( Rs.)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4086_C + tab + T_FV_4086_M);
			// Validating AmountOfPayment
			// Validating DateOnWhichAmountPaid 23
			if (DateOnWhichAmountPaid.equals(FIELD_NULL) || DateOnWhichAmountPaid.equals(FIELD_SEPERATOR)) {
				if (!Mode.equals("D") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
			} else if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4090_C + tab + T_FV_4090_M);
			else if (DateOnWhichAmountPaid.length() == 8 && DateOnWhichAmountPaid.trim().length() == 8) {
				if (obj_FieldValidation.isInt(DateOnWhichAmountPaid))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
				else if (obj_FieldValidation.isDate(DateOnWhichAmountPaid)) {
					if (paperReturnFile) {
						if (DateOnWhichAmountPaid.equals(paperRetDateBankChalnDefValue)) {
							byPassBooking = true;
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
				} else if (obj_FieldValidation.isFutureDate(DateOnWhichAmountPaid)) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
				} else if ((FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q) || FormNo.equals(FORM_27EQ)) && obj_FieldValidation.dateWithinFinancialYearBefQuatEndDate(DateOnWhichAmountPaid, FinancialYr, Qperiod)) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4111_C + tab + T_FV_4111_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4111_C + tab + T_FV_4111_M);
				} else if (obj_FieldValidation.isDateGreaterThenRRRDatePresentDate(DateOnWhichAmountPaid, RRRDatePresentDate)) {
					if (paperReturnFile) {
						byPassBooking = true;
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount paid / Credited / Debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4089_C + tab + T_FV_4089_M);
			// Validating DateOnWhichAmountPaid
			// Validating DateOnWhichTaxDeducted 24
			if (DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR)) {

				if (totalIncTaxDedAtSrcZero) {
					/*
					 * If the value of "Total Income Tax Deducted At Source" is ZERO (0) than
					 * "Date On Which Tax Deducted" may be NULL.
					 */
				} else if (!Mode.equals("D") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {

					if (paperReturnFile) {
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					} // #################### Code changed for validaing if remark1 is A or null ...
						// Manvendra Singh :: Feb-2008
					else if (!FormNo.equals(FORM_26Q))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					else if ((Remark1.equals("A") || Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR) || Remark1.equals("T") || Remark1.equals("C")) && performDDvalidation) // Remarks T and C
																																															// Added For FVU 3.0
					{

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4260_C + tab + T_FV_4260_M);
					} else if (Remark1.equals("B") && performDDvalidation) {
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
				}
			}

			// ##############################################
			else if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4099_C + tab + T_FV_4099_M);

			// ------- Code Changed to check Null value in this date in case of remark1 as
			// B-- Manvendra :: 16-Feb-2008
			// #######################################################
			else if (Remark1.equals("B") && !paperReturnFile && FormNo.equals(FORM_26Q) && !Mode.equals("D") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && ChallanUpdationIndicatorForcurrentchallan.equals("0")
					&& (!SectionCode.equals("94J")) // added
													// for
													// FVU
													// 5.6
					&& performDDvalidation) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4252_C + tab + T_FV_4252_M);
				isValid_B = false;
			} else if (!isFinYrGrtrthn && Remark1.equals("B") && !paperReturnFile && !Mode.equals("D")
					&& (sectionForThisChallan.equals("194") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("193")) && performDDvalidation) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4252_C + tab + T_FV_4252_M);
				isValid_B = false;
			} else if (isFinYrGrtrthn && Remark1.equals("B") && !paperReturnFile && !Mode.equals("D")
					&& (sectionForThisDD.equals("194") || sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94A") || sectionForThisDD.equals("193") || sectionForThisDD.equals("94D")) // added "94D" for FVU 5.5
					&& performDDvalidation) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4252_C + tab + T_FV_4252_M);
				isValid_B = false;
			}

			// #############################################################3
			else if (DateOnWhichTaxDeducted.length() == 8 && DateOnWhichTaxDeducted.trim().length() == 8) {
				if (obj_FieldValidation.isInt(DateOnWhichTaxDeducted))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
				else if (obj_FieldValidation.isDate(DateOnWhichTaxDeducted)) {
					if (paperReturnFile) {
						if (DateOnWhichTaxDeducted.equals(paperRetDateBankChalnDefValue)) {
							paperReturnRelax = true;
							Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
				} else if (!paperReturnFile) {
					if (obj_FieldValidation.isFutureDate(DateOnWhichTaxDeducted))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					else if (obj_FieldValidation.isDateGreaterThenRRRDatePresentDate(DateOnWhichTaxDeducted, RRRDatePresentDate))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					// else if
					// (obj_FieldValidation.dateWithinFinancialYearBefQuatEndDate(DateOnWhichTaxDeducted,
					// FinancialYr, Qperiod))//Hashed by Abhishek on 27-02-2012
					else if (obj_FieldValidation.dateBefFinYr(DateOnWhichTaxDeducted, FinancialYr)) // Added by Abhishek
																									// on 27-02-2012
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					// Added by Shalin for FVu 4.1
					else if (!(FormNo.equals(FORM_24Q) && Qperiod.equals("Q4")) && obj_FieldValidation.dateBefQuatStartDate(DateOnWhichTaxDeducted, FinancialYr, Qperiod) && (UploadType.equals(UPLOADTYPE_REGULAR)
							|| (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4322_C + tab + T_FV_4322_M);
					}
					// #############################################################
					// --- Code added to check date on the basis of Total deduction :Manvendra Singh
					// 25-Feb-2008
					else if ((Remark1.equals("A") || Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR) || Remark1.equals("T") || Remark1.equals("C"))// Remarks T and C Added For FVU 3.0
							&& FormNo.equals(FORM_26Q) && !Mode.equals("D") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !paperReturnFile && parseableTotalDeduction && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0
							&& performDDvalidation)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4257_C + tab + T_FV_4257_M);
					else if (obj_FieldValidation.dateBefQuatEndDate(DateOnWhichTaxDeducted, FinancialYr, Qperiod))// Added
																													// by
																													// Abhishek
																													// on
																													// 05/03/2012
					{
						Str_Buffer.appendElectronicWarning(LineNo + tab + "Deductee" + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_4300_C + tab + T_FV_4300_M);
					}
					// #############################################################
				}

				else {
					if (obj_FieldValidation.isFutureDate(DateOnWhichTaxDeducted)) {
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					} else if (obj_FieldValidation.isDateGreaterThenRRRDatePresentDate(DateOnWhichTaxDeducted, RRRDatePresentDate)) {
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					}
					// else if
					// (obj_FieldValidation.dateWithinFinancialYearBefQuatEndDate(DateOnWhichTaxDeducted,
					// FinancialYr, Qperiod))//Hashed by Abhishek on 27/02/2012
					else if (obj_FieldValidation.dateBefFinYr(DateOnWhichTaxDeducted, FinancialYr))// Added by Abhishek
																									// on 27/02/2012
					{
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
					} else if (obj_FieldValidation.dateBefQuatEndDate(DateOnWhichTaxDeducted, FinancialYr, Qperiod))// Added
																													// by
																													// Abhishek
																													// on
																													// 05/03/2012
					{
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + "Deductee" + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_4300_C + tab + T_FV_4300_M);
					}

				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4098_C + tab + T_FV_4098_M);
			// Validating DateOnWhichTaxDeducted
			// Validating DateOfDeposit 25

			if (DateOfDeposit.equals(FIELD_NULL) || DateOfDeposit.equals(FIELD_SEPERATOR)) {
				if (FormNo.equals(FORM_24Q) && !Mode.equals("D") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deposit" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4079_C + tab + T_FV_4079_M);
			} else if (!FormNo.equals(FORM_24Q)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deposit" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4080_C + tab + T_FV_4080_M);
			} else if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deposit" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4081_C + tab + T_FV_4081_M);
			} else if (!DateOfDeposit.equals(DateOfBankChallanNo)) {
				if (paperReturnFile) {
					if (DateOfDeposit.equals(paperRetDateBankChalnDefValue)) {
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4212_C + tab + T_FV_4212_M);
					} else if (obj_FieldValidation.isDate(DateOfDeposit)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deposit" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4212_C + tab + T_FV_4212_M);
					} else {
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4212_C + tab + T_FV_4212_M);
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deposit" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4212_C + tab + T_FV_4212_M);
			} // Validating DateOfDeposit

			//Changes for CR#65617 START
			boolean IsAmountInField44Valid = true;
			boolean IsAmountInField45Valid = true;
			if((FormNo.equals(FORM_27Q) || FormNo.equals(FORM_26Q)) && Integer.parseInt(FinancialYr) >= 202021 && (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)))) {
				if(SectionCode.equals("4NF") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) 
						|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") ||Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
					if (CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_NULL) || CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_SEPERATOR)) {
						IsAmountInField44Valid = false;
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in excess of Rs. 20 lakhs but does not exceed Rs. 1 crore for cases covered by sub-clause (a) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6159_C + tab + T_FV_6159_M);
					} 
					if (IsAmountInField44Valid) {
						if (CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.length() <= 15) {
							if (obj_FieldValidation.isDecimalNumber(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N)) {
								IsAmountInField44Valid = false;
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in excess of Rs. 20 lakhs but does not exceed Rs. 1 crore for cases covered by sub-clause (a) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab +  CurrentDeducteeDetailRecNo + tab + T_FV_6163_C + tab + T_FV_6163_M);
							} else if (CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.length() != CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.trim().length()) {
								IsAmountInField44Valid = false;
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in excess of Rs. 20 lakhs but does not exceed Rs. 1 crore for cases covered by sub-clause (a) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab +  CurrentDeducteeDetailRecNo + tab + T_FV_6163_C + tab + T_FV_6163_M);
							} else if (Double.parseDouble(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.trim()) != 0 && !CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.trim().endsWith(".00")) {
								IsAmountInField44Valid = false;
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in excess of Rs. 20 lakhs but does not exceed Rs. 1 crore for cases covered by sub-clause (a) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab +  CurrentDeducteeDetailRecNo + tab + T_FV_6163_C + tab + T_FV_6163_M);
							}
						} else {
							IsAmountInField44Valid = false;
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in excess of Rs. 20 lakhs but does not exceed Rs. 1 crore for cases covered by sub-clause (a) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6163_C + tab + T_FV_6163_M);
						}
					} 
					
					if (CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_NULL) || CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_SEPERATOR)) {
						IsAmountInField45Valid = false;
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in access of Rs. 1 crore for cases covered by sub-clause (b) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6161_C + tab + T_FV_6161_M);
					}
					if (IsAmountInField45Valid){ 
						if(CashWithdrawalAmtInExcessOf1CrForSec194N.length() <= 15) {
							if (obj_FieldValidation.isDecimalNumber(CashWithdrawalAmtInExcessOf1CrForSec194N)) {
								IsAmountInField45Valid = false;
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in access of Rs. 1 crore for cases covered by sub-clause (b) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo +  tab + T_FV_6165_C + tab + T_FV_6165_M);
							} else if (CashWithdrawalAmtInExcessOf1CrForSec194N.length() != CashWithdrawalAmtInExcessOf1CrForSec194N.trim().length()) {
								IsAmountInField45Valid = false;
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in access of Rs. 1 crore for cases covered by sub-clause (b) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6165_C + tab + T_FV_6165_M);
							} else if (Double.parseDouble(CashWithdrawalAmtInExcessOf1CrForSec194N.trim()) != 0 && !CashWithdrawalAmtInExcessOf1CrForSec194N.trim().endsWith(".00")) {
								IsAmountInField45Valid = false;
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in access of Rs. 1 crore for cases covered by sub-clause (b) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6165_C + tab + T_FV_6165_M);
							} 
						} else {
							IsAmountInField45Valid = false;
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in access of Rs. 1 crore for cases covered by sub-clause (b) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6165_C + tab + T_FV_6165_M);
						}
					} 
					
					if (IsAmountInField44Valid && IsAmountInField45Valid){
						if(Double.parseDouble(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.trim()) > 0 && Double.parseDouble(CashWithdrawalAmtInExcessOf1CrForSec194N.trim()) > 0) {
							IsAmountInField44Valid = false;
							IsAmountInField45Valid = false;
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in access of Rs. 1 crore for cases covered by sub-clause (b) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6166_C + tab + T_FV_6166_M);
						}
					}
					
					if(IsAmountInField44Valid && IsAmountInField45Valid) {
						String final44Or45FieldAmount = null;
						if(Double.parseDouble(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N) > 0) {
							final44Or45FieldAmount = CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N;
						} else if(Double.parseDouble(CashWithdrawalAmtInExcessOf1CrForSec194N) > 0) {
							final44Or45FieldAmount = CashWithdrawalAmtInExcessOf1CrForSec194N;
						}
						if(final44Or45FieldAmount!= null && (Double.parseDouble(final44Or45FieldAmount.trim()) > Double.parseDouble(AmountOfPayment.trim()))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6170_C + tab + T_FV_6170_M);
						}
					}
				} else if (!SectionCode.equals("4NF")) {
					if (!CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_NULL) && !CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_SEPERATOR)) {
						IsAmountInField44Valid = false;
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in excess of Rs. 20 lakhs but does not exceed Rs. 1 crore for cases covered by sub-clause (a) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6173_C + tab + T_FV_6173_M);
					}
					if (!CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_NULL) && !CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_SEPERATOR)) {
						IsAmountInField45Valid = false;
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in access of Rs. 1 crore for cases covered by sub-clause (b) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6174_C + tab + T_FV_6174_M);
					}
				}
				
				if (FormNo.equals(FORM_26Q) && (Remark1.equals("C")) && IsAmountInField44Valid && IsAmountInField45Valid && (SectionCode.equals("4NF") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))//CR 65617. Observation No.23
						|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") ||Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) 
						&&  (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))) {
						String final44Or45FieldAmount = null;
						if (!(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_NULL) || CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_SEPERATOR))
								&& !(CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_NULL) || CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_SEPERATOR))) {
							if(Double.parseDouble(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N) > 0) {
								final44Or45FieldAmount = CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N;
							} else if(Double.parseDouble(CashWithdrawalAmtInExcessOf1CrForSec194N) > 0) {
								final44Or45FieldAmount = CashWithdrawalAmtInExcessOf1CrForSec194N;
							}
							if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(final44Or45FieldAmount.trim()) * 0.05)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
							} 
						}
				}
				
				//CR 65617. Observation No.23 START
				if(FormNo.equals(FORM_26Q) && (Remark1.equals("M") || Remark1.equals("O") || Remark1.equals("E")) && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6142_C + tab + T_FV_6142_M);
				}
				//CR 65617. Observation No.23 END
				
				//CR 65617. Observation No.24 START
				if (FormNo.equals(FORM_27Q) && (Remark1.equals("C")) && IsAmountInField44Valid && IsAmountInField45Valid && (SectionCode.equals("4NF") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) 
						|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") ||Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) 
						&&  (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))) {
						String final44Or45FieldAmount = null;
						if (!(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_NULL) || CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_SEPERATOR))
								&& !(CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_NULL) || CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_SEPERATOR))) {
							if(Double.parseDouble(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N) > 0) {
								final44Or45FieldAmount = CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N;
							} else if(Double.parseDouble(CashWithdrawalAmtInExcessOf1CrForSec194N) > 0) {
								final44Or45FieldAmount = CashWithdrawalAmtInExcessOf1CrForSec194N;
							}
							if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(final44Or45FieldAmount.trim()) * 0.05)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
							} 
						}
				}
				//CR 65617. Observation No.24 END
				
				//CR 65617. Observation No.24 START
				if(FormNo.equals(FORM_27Q) && (Remark1.equals("M") || Remark1.equals("O") || Remark1.equals("G")) && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6142_C + tab + T_FV_6142_M);
				}
				//CR 65617. Observation No.24 END
				
			} else if ((FormNo.equals(FORM_27Q) || FormNo.equals(FORM_26Q)) && (((Integer.parseInt(FinancialYr) < 202021)) || (Integer.parseInt(FinancialYr) == 202021 && Qperiod.equals("Q1")))) {//CR 65617. ObservationNo.18_250920
				if(!CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_NULL) && !CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N.equals(FIELD_SEPERATOR)) {
					IsAmountInField44Valid = false;
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in excess of Rs. 20 lakhs but does not exceed Rs. 1 crore for cases covered by sub-clause (a) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6160_C + tab + T_FV_6160_M);
				}
				if (!CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_NULL) && !CashWithdrawalAmtInExcessOf1CrForSec194N.equals(FIELD_SEPERATOR)) {
					IsAmountInField45Valid = false;
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal which is in access of Rs. 1 crore for cases covered by sub-clause (b) of clause (ii) of first provision to section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6162_C + tab + T_FV_6162_M);
				}
			}
			
			//Changes for CR#65617 END
			// Validating RateAtWhichTaxDeducted 26
			System.out.println("RateAtWhichTaxDeducted" + RateAtWhichTaxDeducted);
			if (FormNo.equals(FORM_24Q)) {
				if (!RateAtWhichTaxDeducted.equals(FIELD_NULL) && !RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4094_C + tab + T_FV_4094_M);
			} else {
				if (RateAtWhichTaxDeducted.equals(FIELD_NULL) || RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR)) {
					if (!Mode.equals("D") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4093_C + tab + T_FV_4093_M);
					}
				}

				else {

					if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4091_C + tab + T_FV_4091_M);
					}

					/*
					 * else if ( ( Remark2.equals("Y") && FormNo.equals(FORM_26Q) &&
					 * Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0 ) ||
					 * (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0 &&
					 * Double.parseDouble(RateAtWhichTaxDeducted.trim()) !=0) ) {
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo
					 * + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4288_C + tab + T_FV_4288_M );
					 * }
					 */// M06_E

					// Added By Amit for fvu 4.5 to handle space

					else if (RateAtWhichTaxDeducted.length() != RateAtWhichTaxDeducted.trim().length()) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4092_C + tab + T_FV_4092_M);
					}
					// Amit end for fvu 4.5
					else if (RateAtWhichTaxDeducted.length() <= 7) {
						if (obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4092_C + tab + T_FV_4092_M);
						} else if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) < 0) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4092_C + tab + T_FV_4092_M);
						}
						// ############# should be 0.00 if remark1 is a or null in electronic 26Q

						// Added By amit for Fvu 4.5
						else if ((Double.parseDouble(RateAtWhichTaxDeducted) > 99.9999) || (Double.parseDouble(RateAtWhichTaxDeducted) < 0.0000)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4092_C + tab + T_FV_4092_M);
						}
						// Amit end for Fvu 4.5
						// M06_B_ADDED
						/*
						 * else if ( !Mode.equals("D") && (( Remark1.equals("Y") &&
						 * FormNo.equals(FORM_26Q) && Double.parseDouble(RateAtWhichTaxDeducted.trim())
						 * != 0 ) ||
						 * (!obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource) &&
						 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0 &&
						 * Double.parseDouble(RateAtWhichTaxDeducted.trim()) !=0) ||
						 * (!obj_FieldValidation.isDecimalNumber(TotalTaxDeposited) &&
						 * Double.parseDouble(TotalTaxDeposited.trim()) == 0 &&
						 * Double.parseDouble(RateAtWhichTaxDeducted.trim()) !=0) ) )
						 */
						// Commented for FVU 3.2 as it allows Rate of Deduction > = 0
						/*
						 * else if ( !Mode.equals("D") && Remark1.equals("Y") && FormNo.equals(FORM_26Q)
						 * && Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0 ) {
						 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
						 * "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo
						 * + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4288_C + tab + T_FV_4288_M );
						 * }
						 */

						// M06_E

						// ------- Code Changed to check null value in this date in case of remark1 as
						// B-- Manvendra :: 16-Feb-2008
						else if (Remark1.equals("B") && !paperReturnFile && FormNo.equals(FORM_26Q) && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && ChallanUpdationIndicatorForcurrentchallan.equals("0") && performDDvalidation
								&& !(Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0) && (!SectionCode.equals("94J")) // added for FVU 5.6
						) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4259_C + tab + T_FV_4259_M);
							isValid_B = false;
						} else if (!isFinYrGrtrthn && Remark1.equals("B") && !paperReturnFile
								&& (sectionForThisChallan.equals("194") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("193")) && performDDvalidation
								&& !(Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4259_C + tab + T_FV_4259_M);
							isValid_B = false;
						} else if (isFinYrGrtrthn && Remark1.equals("B") && !paperReturnFile
								&& (sectionForThisDD.equals("194") || sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94A") || sectionForThisDD.equals("193") || sectionForThisDD.equals("94D")) // added "94D" for FVU 5.5
								&& performDDvalidation && !(Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4259_C + tab + T_FV_4259_M);
							isValid_B = false;
						} else if (isFinYrGrtrthn && Remark1.equals("B") && !paperReturnFile && (sectionForThisDD.equals("94J")) // Added condition
																																	// for FVU 5.6
								&& performDDvalidation && (Double.parseDouble(RateAtWhichTaxDeducted.trim()) > 0) && (DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4260_C + tab + T_FV_4260_M);
							isValid_B = false;
						} else if (isFinYrGrtrthn && Remark1.equals("B") && !paperReturnFile && (sectionForThisDD.equals("94J")) // Added condition
																																	// for FVU 5.6
								&& performDDvalidation && (Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0) && !(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4259_C + tab + T_FV_4252_M);
							isValid_B = false;
						}

						else if ((Remark1.equals("A") || Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR) || Remark1.equals("T") || Remark1.equals("C")) // Remarks T and C Added For FVU 3.0)
								&& FormNo.equals(FORM_26Q) && !paperReturnFile && performDDvalidation && !totalIncTaxDedAtSrcZero && Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4258_C + tab + T_FV_4258_M);

						// M03_B validation only for mode !=D

						// AMIT CHOLIA
						else if (validTotalIncomeTaxDeductedAtSource && !paperReturnFile && !Mode.equals("D") && !AmountOfPayment.equals(FIELD_NULL) && !AmountOfPayment.equals(FIELD_SEPERATOR)) {

							// M06_B commented as Remarks2 field requirement is reverted and its value is
							// incorporated in Remark1 field.
							// if( Remark2.equals(FIELD_NULL) || Remark2.equals(FIELD_SEPERATOR) )
							// M06_E The validation for TaxDeductedAmount should take place only if Remark2
							// field is null
							// {

							// Changes added for 6.6_2.162_2.1294 by Puja::start
							// Changes added for 6.8_2.164_2.1296 by pujabugfix2
							if ((FormNo.equals(FORM_27Q) || FormNo.equals(FORM_26Q)) && SectionCode.equals("94N") && ((Integer.parseInt(FinancialYr) == 201920 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))
									|| (Integer.parseInt(FinancialYr) >= 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
								if (!(amtOfCashWithIn194N.equals(FIELD_NULL) || amtOfCashWithIn194N.equals(FIELD_SEPERATOR) || amtOfCashWithIn194N.trim().length() == 0)) {
									if (amtOfCashWithIn194N.length() <= 15) {
										if (!obj_FieldValidation.isDecimal(amtOfCashWithIn194N, 2)) {
											dExpectedTaxDeductedAmount = Double.parseDouble(amtOfCashWithIn194N.trim()) * Double.parseDouble(RateAtWhichTaxDeducted.trim()) * 90 / 10000;

											dExpectedTaxDeductedAmount = obj_FieldValidation.roundDecimals(dExpectedTaxDeductedAmount, "#.##"); // round
																																				// the
																																				// value
																																				// to
																																				// two
																																				// decimal
																																				// places

											if (Math.ceil(dExpectedTaxDeductedAmount) != Math.round(dExpectedTaxDeductedAmount)) // ceil would always
																																	// give next
																																	// integer and
																																	// round will
																																	// round to the
																																	// nearest int.
																																	// check has been
																																	// performed at
																																	// this point to
																																	// see whether
																																	// dExpectedTaxDeductedAmount
																																	// 's decimal
																																	// value is >= .5
											{

												dExpectedTaxDeductedAmount = Math.round(dExpectedTaxDeductedAmount); // Round
																														// to
																														// nearest
																														// integer
																														// only
																														// if
																														// the
																														// decimal
																														// is
																														// less
																														// than
																														// .5;
																														// otherwise
																														// the
																														// value
																														// is
																														// kept
																														// unchanged.
											}

											if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) < dExpectedTaxDeductedAmount) {
												flgForThreshold = 1;
												Str_Buffer.append(
														LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4278_C + tab + T_FV_4278_M);
											}

										}
									}
								}
							} // Changes added for 6.6_2.162_2.1294 by Puja::end
							//Changes for CR#65617 START
							else if ((FormNo.equals(FORM_27Q) || FormNo.equals(FORM_26Q)) && SectionCode.equals("4NF") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) 
									|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") ||Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
								if (IsAmountInField44Valid && IsAmountInField45Valid) {
									String final44Or45FieldAmount = null;
									if(Double.parseDouble(CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N) > 0) {
										final44Or45FieldAmount = CashWithdrawalAmtInExcessOf20LacsAndLessThan1CrForSec194N;
									} else if(Double.parseDouble(CashWithdrawalAmtInExcessOf1CrForSec194N) > 0) {
										final44Or45FieldAmount = CashWithdrawalAmtInExcessOf1CrForSec194N;
									}
									if (final44Or45FieldAmount!=null && final44Or45FieldAmount.length() <= 15) {
										if (!obj_FieldValidation.isDecimal(final44Or45FieldAmount, 2)) {
											dExpectedTaxDeductedAmount = Double.parseDouble(final44Or45FieldAmount.trim()) * Double.parseDouble(RateAtWhichTaxDeducted.trim()) * 90 / 10000;
											dExpectedTaxDeductedAmount = obj_FieldValidation.roundDecimals(dExpectedTaxDeductedAmount, "#.##"); // round the value to two decimal places
											if (Math.ceil(dExpectedTaxDeductedAmount) != Math.round(dExpectedTaxDeductedAmount)) // ceil would always give next integer and round will round to the nearest int. check has been performed at this point to see whether dExpectedTaxDeductedAmount's decimal value is >= .5
											{
												dExpectedTaxDeductedAmount = Math.round(dExpectedTaxDeductedAmount); // Round to nearest  integer only  if the decimal is less  than .5; otherwise the value is kept unchanged.
											}
											if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) < dExpectedTaxDeductedAmount) {
												flgForThreshold = 1;
												Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4278_C + tab + T_FV_4278_M);
											}

										}
									}
								}
							}//Changes for CR#65617 END
							else if (AmountOfPayment.length() <= 15) {
								if (!obj_FieldValidation.isDecimal(AmountOfPayment, 2)) {
									// Commented for FVU 3.2 for the new validation added below
									/*
									 * if(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) <
									 * (Double.parseDouble(AmountOfPayment.trim()) *
									 * Double.parseDouble(RateAtWhichTaxDeducted.trim()) * 90 /10000)) //if entered
									 * tds amount is less than actual tds amount by more than 10%
									 * 
									 */
									dExpectedTaxDeductedAmount = Double.parseDouble(AmountOfPayment.trim()) * Double.parseDouble(RateAtWhichTaxDeducted.trim()) * 90 / 10000;

									dExpectedTaxDeductedAmount = obj_FieldValidation.roundDecimals(dExpectedTaxDeductedAmount, "#.##"); // round the
																																		// value to
																																		// two decimal
																																		// places

									if (Math.ceil(dExpectedTaxDeductedAmount) != Math.round(dExpectedTaxDeductedAmount)) // ceil
																															// would
																															// always
																															// give
																															// next
																															// integer
																															// and
																															// round
																															// will
																															// round
																															// to
																															// the
																															// nearest
																															// int.
																															// check
																															// has
																															// been
																															// performed
																															// at
																															// this
																															// point
																															// to
																															// see
																															// whether
																															// dExpectedTaxDeductedAmount
																															// 's
																															// decimal
																															// value
																															// is
																															// >=
																															// .5
									{

										dExpectedTaxDeductedAmount = Math.round(dExpectedTaxDeductedAmount); // Round to
																												// nearest
																												// integer
																												// only
																												// if
																												// the
																												// decimal
																												// is
																												// less
																												// than
																												// .5;
																												// otherwise
																												// the
																												// value
																												// is
																												// kept
																												// unchanged.
									}

									if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) < dExpectedTaxDeductedAmount) {
										flgForThreshold = 1;
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4278_C + tab + T_FV_4278_M);
									}

								}
							}

							// }
							// M03_E
						}
						/*
						 * Commented by Abhishek on 05/03/2011 //M06_B_ADDED Added on 02/03/2011
						 * if(!Mode.equals("D") &&
						 * !obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource) &&
						 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != 0 &&
						 * !obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4) &&
						 * Double.parseDouble(RateAtWhichTaxDeducted.trim()) ==0) {
						 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
						 * "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo +
						 * tab + CurrentDeducteeDetailRecNo + tab + T_FV_4292_C + tab + T_FV_4292_M); }
						 * if(!Mode.equals("D") &&
						 * !obj_FieldValidation.isDecimalNumber(TotalTaxDeposited) &&
						 * Double.parseDouble(TotalTaxDeposited.trim()) != 0 &&
						 * !obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4) &&
						 * Double.parseDouble(RateAtWhichTaxDeducted.trim()) ==0) {
						 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
						 * "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab +
						 * CurrentDeducteeDetailRecNo + tab + T_FV_4293_C + tab + T_FV_4293_M); }
						 * //M06_E
						 * 
						 * End of commented by Abhishek
						 */
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax Deducted / Collected" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4092_C + tab + T_FV_4092_M);
				}
			} // Validating RateAtWhichTaxDeducted
				// Validating GrossingUpIndicator 27

			if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27EQ)) {
				if (!GrossingUpIndicator.equals(FIELD_NULL) && !GrossingUpIndicator.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Grossing up Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4097_C + tab + T_FV_4097_M);
			} else if (!GrossingUpIndicator.equals(FIELD_NULL) && !GrossingUpIndicator.equals(FIELD_SEPERATOR)) {
				if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Grossing up Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4096_C + tab + T_FV_4096_M);
				else if ((GrossingUpIndicator.length() > 1) || obj_FieldValidation.isChar(GrossingUpIndicator) || !Character.isUpperCase(GrossingUpIndicator.charAt(0)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Grossing up Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4095_C + tab + T_FV_4095_M);
				else if (!GrossingUpIndicator.equals("Y") && !GrossingUpIndicator.equals("N"))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Grossing up Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4095_C + tab + T_FV_4095_M);
			}

			// Validating GrossingUpIndicator
			// Validating BookCashEntry 28

			if (isFinYrGrtrthn) // Added for FVU 3.8 by Shalin
			{
				if (!BookCashEntry.equals(FIELD_NULL) && !BookCashEntry.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Book Entry / Cash Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4304_C + tab + T_FV_4304_M);
			} else {
				if (FormNo.equals(FORM_24Q)) {
					if (!BookCashEntry.equals(FIELD_NULL) && !BookCashEntry.equals(FIELD_SEPERATOR))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Book Entry / Cash Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4179_C + tab + T_FV_4179_M);
				} else if (BookCashEntry.equals(FIELD_NULL) || BookCashEntry.equals(FIELD_SEPERATOR)) {
				} else if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Book Entry / Cash Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4180_C + tab + T_FV_4180_M);
				else if ((BookCashEntry.length() > 1) || obj_FieldValidation.isChar(BookCashEntry) || !Character.isUpperCase(BookCashEntry.charAt(0)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Book Entry / Cash Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4178_C + tab + T_FV_4178_M);
				else if (!BookCashEntry.equals("Y") && !BookCashEntry.equals("N"))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Book Entry / Cash Indicator" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4178_C + tab + T_FV_4178_M);
			}
			// Validating BookCashEntry

			// Validating DateOfFurnishingTaxDeductionCertificate 29 // 16 Feb field is made
			// NULL . therefore code commented
			if (!DateOfFurnishingTaxDeductionCertificate.equals(FIELD_NULL) && !DateOfFurnishingTaxDeductionCertificate.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of furnishing Tax Deduction Certificate" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4102_C + tab + T_FV_4102_M);
			// Validating DateOfFurnishingTaxDeductionCertificate

			// Validating Remark1 30 Reason for lower deduction/no deduction allowed values
			// are A, B or Null.
			//Changes added for 7.2_2.168_2.1300 Part 2 by Vinita (Code converted to method)
			isValid_B = validateRemark1Field(BH_BatchNo, ChallanDetailRecordNo,
					TransactionType, Qperiod, FinancialYr, UploadTypeDD,
					obj_StringBuffer, Str_Buffer, LineNo, DeducteeDetailRecNo,
					EmployeePan, TotalIncomeTaxDeductedAtSource,
					LastTotalIncomeTaxDeductedAtSource, TotalTaxDeposited,
					AmountOfPayment, DateOnWhichAmountPaid,
					RateAtWhichTaxDeducted, Remark1, SectionCode,
					flgForThreshold, obj_FieldValidation,
					isStructurallyValidPan, isValid_B,
					validLastTotalIncomeTaxDeductedAtSource);

			// Validating Remark2 31

			// M06_B

			// commented by Dhanya on 05/01/2011 for M06 as the requirement is revised
			// if((FormNo.equals("24Q") ||
			// TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))&&(!Remark2.equals(FIELD_NULL)
			// && !Remark2.equals(FIELD_SEPERATOR)))
			// M06_E
			if (FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q) || FormNo.equals(FORM_24Q)) {

				if (!Remark2.equals(FIELD_NULL) && !Remark2.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remark2" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4042_C + tab + T_FV_4042_M);

					/*
					 * if (Mode.equals("D") ||
					 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4101_C + tab + T_FV_4101_M); } else if (Remark2.length() > 75) {
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4042_C + tab + T_FV_4042_M); } else if
					 * (obj_FieldValidation.isValidCharString(Remark2)) Str_Buffer.append(LineNo +
					 * tab + currentUploadType + tab + CurrentchallanDetailRecordNo + tab +
					 * CurrentDeducteeDetailRecNo + tab + T_FV_4042_C + tab + T_FV_4042_M);
					 */

				}
				/*
				 * else if ( Remark1.equals("C") && !Remark2.equals(FIELD_NULL) &&
				 * !Remark2.equals(FIELD_SEPERATOR)) //No value for Remarks2 if Remark1 = 'C' {
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 2" + tab
				 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
				 * T_FV_4282_C + tab + T_FV_4282_M); } //M06_B values are allowed in Remarks2
				 * field; the allowed values are X and Y.
				 * 
				 * else if ( ((FormNo.equals(FORM_27EQ)||FormNo.equals(FORM_27Q)) ||
				 * (FormNo.equals(FORM_26Q) && ( sectionForThisChallan.equals("94F") ||
				 * sectionForThisChallan.equals("193") ) )) && !Remark2.equals(FIELD_NULL) &&
				 * !Remark2.equals(FIELD_SEPERATOR) && !Remark2.equals("X")) // only allowed
				 * value is 'X' or Null { Str_Buffer.append(LineNo + tab + currentUploadType +
				 * tab + "Remarks 2" + tab + CurrentchallanDetailRecordNo + tab +
				 * CurrentDeducteeDetailRecNo + tab + T_FV_4281_C + tab + T_FV_4281_M); } else
				 * if (!Remark2.equals(FIELD_NULL) && !Remark2.equals(FIELD_SEPERATOR) &&
				 * !Remark2.equals("X") && !Remark2.equals("Y")) { Str_Buffer.append(LineNo +
				 * tab + currentUploadType + tab + "Remarks 2" + tab +
				 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
				 * T_FV_4280_C + tab + T_FV_4280_M); }
				 */

				// Validating Remark3 32

				if (!Remark3.equals(FIELD_NULL) && !Remark3.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remark3" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4043_C + tab + T_FV_4043_M);

					/*
					 * if (Mode.equals("D") ||
					 * TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4116_C + tab + T_FV_4116_M); } else if (Remark3.length() > 14) {
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
					 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4043_C + tab + T_FV_4043_M); } else if
					 * (obj_FieldValidation.isValidCharString(Remark3)) Str_Buffer.append(LineNo +
					 * tab + currentUploadType + tab + CurrentchallanDetailRecordNo + tab +
					 * CurrentDeducteeDetailRecNo + tab + T_FV_4043_C + tab + T_FV_4043_M);
					 */
				} // Validating PermanentResidentEstablishment

			}

			// Validating PermanentResident 31
			if (FormNo.equals(FORM_27EQ)) {

				validateDeducteeNonResident(NonResident, EmployeePan, UploadType, TransactionType, PermanentResidentEstablishment, Str_Buffer);
			}
			// Added for FVU 3.8 by Shalin --- START

			// Validating Deductee Ref Number

			if (FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q) || FormNo.equals(FORM_27EQ)) {

				if (DedRefNum.equals(FIELD_NULL) || DedRefNum.equals(FIELD_SEPERATOR)) {
					// Amit added for FVU 4.4
					if ((EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (FormNo.equals(FORM_26Q))
							&& (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || (UploadType.equals(UPLOADTYPE_CORRECTION)
									&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")))))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee Reference Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4325_C + tab + T_FV_4325_M);

					}
					// Amit ends
				}

				else {

					if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee Reference Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4134_C + tab + T_FV_4134_M);

					else if (Mode.equals("D") && !LastEmployeePanRefNo.equals(DedRefNum)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee Reference Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4185_C + tab + T_FV_4185_M);
					}

					else if (DedRefNum.length() == 10 && DedRefNum.trim().length() == 10) { // Newly Added By Amit 4.4
						if (!obj_FieldValidation.isInt(DedRefNum)) {
							if (Long.parseLong(DedRefNum.trim()) == 0) {
								if ((EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (FormNo.equals(FORM_26Q))
										&& (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || (UploadType.equals(UPLOADTYPE_CORRECTION)
												&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")))))) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee Reference Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4325_C + tab + T_FV_4325_M);

								}
							}

						}

						// Newly Amit end
						else if (obj_FieldValidation.isAlphaNum(DedRefNum))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee Reference Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4325_C + tab + T_FV_4325_M);

					}

					else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee Reference Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4325_C + tab + T_FV_4325_M);
				}
			}

			// Validating Deductee Ref Number

			// Validating CertNumAo
			//true && (true || false && (false || false) && (true) && ) )

			if (isFinYrGrtrthn) {
				if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q)) {
					if (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("D")) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) && !CertNumAo.equals(FIELD_NULL)
							&& !CertNumAo.equals(FIELD_SEPERATOR)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4302_C + tab + T_FV_4302_M);
					}
					if (FormNo.equals(FORM_26Q) && (UploadType.equals(UPLOADTYPE_REGULAR)
							|| (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))
							&& Remark1.equals("A") && (CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR))) {

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4302_C + tab + T_FV_4302_M);
					} else if (FormNo.equals(FORM_24Q)
							&& (UploadType.equals(UPLOADTYPE_REGULAR)
									|| (UploadType.equals(UPLOADTYPE_CORRECTION) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)))
							&& (Remark1.equals("A") || Remark1.equals("B")) && (CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4302_C + tab + T_FV_4302_M);
					} else if (FormNo.equals(FORM_27Q) && (UploadType.equals(UPLOADTYPE_REGULAR)
							|| (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))
							&& (Remark1.equals("A") || Remark1.equals("B")) && (CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4302_C + tab + T_FV_4302_M);
					}
					// NEWLY ADDED BY AMIT FOR REMARKS For FVU 4.4

					else if (!(CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR)) && (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27Q))
							&& (Remark1.equals("C") || Remark1.equals("T") || Remark1.equals("Y") || Remark1.equals("S") || Remark1.equals("Z") || Remark1.equals("N")))// Changes added for
																																										// 6.6_2.162_2.1294
																																										// by Puja
					{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4326_C + tab + T_FV_4326_M);

					}

					// added for 4.9

					else if (!(CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR)) && FormNo.equals(FORM_26Q)
							&& ((Remark1.equals("B") && (Integer.parseInt(FinancialYr) < 201516 || (Integer.parseInt(FinancialYr) == 201516 && Qperiod.equals("Q2")) || (Integer.parseInt(FinancialYr) == 201516 && Qperiod.equals("Q1"))))
									|| Remark1.equals("C") || Remark1.equals("T") || Remark1.equals("Y") || Remark1.equals("S") || Remark1.equals("Z") || Remark1.equals("N")))// Changes
																																												// added for
																																												// 6.6_2.162_2.1294
																																												// by Puja
					{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number  issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4326_C + tab + T_FV_4326_M);

					}

					else if (FormNo.equals(FORM_26Q) && (Remark1.equals("B"))) {
						if ((Integer.parseInt(FinancialYr) == 201516 && Qperiod.equals("Q3")) || (Integer.parseInt(FinancialYr) == 201516 && Qperiod.equals("Q4")) || Integer.parseInt(FinancialYr) > 201516) {
							if (!obj_FieldValidation.isvalidCertificateNum(CertNumAo)) {
								Str_Buffer.append(
										LineNo + tab + currentUploadType + tab + "Certificate number  issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4324_C + tab + T_FV_4324_M);
							}
						}
					}

					// ended for 4.9
					// Amit END
					// Amit need to add here FVU 4.4
					/*
					 * else if(!(CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR)))
					 * { if(CertNumAo.length()>20) { Str_Buffer.append(LineNo + tab +
					 * currentUploadType + tab +
					 * "Certificate number issued by the Assessing Officer" + tab +
					 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4302_C + tab + T_FV_4302_M); } char [] ch = CertNumAo.toCharArray();
					 * boolean iscertvalid = false; for(int i =0 ; i<ch.length;i++) {
					 * if(!obj_FieldValidation.isAlphaNum(ch[i]+"")) { iscertvalid = true; break; }
					 * } if(!iscertvalid) { Str_Buffer.append(LineNo + tab + currentUploadType + tab
					 * + "Certificate number issued by the Assessing Officer" + tab +
					 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4302_C + tab + T_FV_4302_M); } }
					 */

					// Method for certi_num Changed By amit
					else if (!(CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR))) {
						if (CertNumAo.length() != 10) {
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4324_C + tab + T_FV_4324_M);
						} else { // char [] ch = CertNumAo.toCharArray(); Commented as no longer needed for FVU
									// 6.0 by Jacky
							boolean iscertvalid = true; // chenged By amit

							if (obj_FieldValidation.isAlphaNum(CertNumAo)) // Added for FVU 6.0 by Jacky to check if
																			// Certificate number issued by the
																			// Assessing Officer is Alphanumeric
							{
								iscertvalid = false;

							}

							/*
							 * for(int i =0 ; i<4;i++) Commented as no longer needed for FVU 6.0 by Jacky
							 * start { if(obj_FieldValidation.isInt(ch[i]+"")) { iscertvalid = false; break;
							 * } }
							 * 
							 * if(iscertvalid) { for(int i =4 ; i<6;i++) {
							 * if(obj_FieldValidation.isCharUpper(ch[i]+"")) { iscertvalid = false; break; }
							 * } }
							 * 
							 * if(iscertvalid) {
							 * 
							 * for(int i =6 ; i<9;i++) { if(obj_FieldValidation.isInt(ch[i]+"")) {
							 * iscertvalid = false; break; } }
							 * 
							 * }
							 * 
							 * if(iscertvalid) { for(int i =9 ; i<10;i++) {
							 * if(obj_FieldValidation.isCharUpper(ch[i]+"")) { iscertvalid = false; break; }
							 * } }
							 */ // Commented as no longer needed for FVU 6.0 by Jacky end
							if (!iscertvalid) {
								Str_Buffer.append(
										LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4324_C + tab + T_FV_4324_M);
							}
						}
						// added by nik for fvu 4.7
						// FVU 5.1
						if ((UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A"))))) {

							if (!(SectionCode.equals("92A") || SectionCode.equals("92B") || SectionCode.equals("92C") || SectionCode.equals("193") || SectionCode.equals("194") || SectionCode.equals("94A") || SectionCode.equals("94C")
									|| SectionCode.equals("94D") || SectionCode.equals("94G") || SectionCode.equals("94H") || SectionCode.equals("4IB") || SectionCode.equals("4IA") || SectionCode.equals("94J") || SectionCode.equals("94L")
									|| SectionCode.equals("195") || SectionCode.equals("A") || SectionCode.equals("B") || SectionCode.equals("C") || SectionCode.equals("D") || SectionCode.equals("E") || SectionCode.equals("F")
									|| SectionCode.equals("G") || SectionCode.equals("H") || SectionCode.equals("I") || SectionCode.equals("J") || SectionCode.equals("K") || SectionCode.equals("LBC") || SectionCode.equals("LBB")
									|| SectionCode.equals("L") || SectionCode.equals("M") || SectionCode.equals("N") || SectionCode.equals("4IC")|| SectionCode.equals("4JA") || SectionCode.equals("4JB") || SectionCode.equals("94O") || SectionCode.equals("96D") || SectionCode.equals("96Q"))) // added for FVU 5.1 //added // Test case 14 FVU 7.0 - Vinita
																																					// '4IC' for FVU 5.5 // Added 96D for FVU 7.2 24 Jun 2021 by Vinita //Changes added for 7.2_2.168_2.1300 Part 2 by Vinita
							{
								Str_Buffer.append(
										LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4326_C + tab + T_FV_4326_M);
							}
						}
						if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O"))
								|| (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))))) {
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4326_C + tab + T_FV_4326_M);
						}

						// ended by nik for fvu 4.7
					}
					// Amit end here

				}

				else if (FormNo.equals(FORM_27EQ)) {
					if (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("D")) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) && !CertNumAo.equals(FIELD_NULL)
							&& !CertNumAo.equals(FIELD_SEPERATOR)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4302_C + tab + T_FV_4302_M);
					}

					if ((UploadType.equals(UPLOADTYPE_REGULAR)
							|| (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))
							&& Remark1.equals("A") && (CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4302_C + tab + T_FV_4302_M);
					}
					// NEWLY ADDED BY AMIT FOR REMARKS For Fvu 4.4
					else if (!(CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR)) && FormNo.equals(FORM_27EQ)
							&& (Remark1.equals("B") || Remark1.equals("C") || Remark1.equals("T") || Remark1.equals("Y") || Remark1.equals("S") || Remark1.equals("Z") || Remark1.equals("N")))// Changes
																																																// added for
																																																// 6.6_2.162_2.1294
																																																// by Puja
					{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4326_C + tab + T_FV_4326_M);

					}

					// Amit end
					// Commented By amit
					/*
					 * else if(!(CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR)))
					 * { if(CertNumAo.length()>20) { Str_Buffer.append(LineNo + tab +
					 * currentUploadType + tab +
					 * "Certificate number issued by the Assessing Officer" + tab +
					 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4302_C + tab + T_FV_4302_M); } char [] ch = CertNumAo.toCharArray();
					 * boolean iscertvalid = false; for(int i =0 ; i<ch.length;i++) {
					 * if(!obj_FieldValidation.isAlphaNum(ch[i]+"")) { iscertvalid = true; break; }
					 * } if(!iscertvalid) { Str_Buffer.append(LineNo + tab + currentUploadType + tab
					 * + "Certificate number issued by the Assessing Officer" + tab +
					 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4302_C + tab + T_FV_4302_M); } }
					 */ // end comment

					// Changed By amit for FVU 4.4
					else if (!(CertNumAo.equals(FIELD_NULL) || CertNumAo.equals(FIELD_SEPERATOR))) {
						if (CertNumAo.length() != 10) {
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4324_C + tab + T_FV_4324_M);
						} else {
							// char [] ch = CertNumAo.toCharArray(); Commented as no longer needed for FVU
							// 6.0 by Jacky
							boolean iscertvalid = true; // chenged By amit

							if (obj_FieldValidation.isAlphaNum(CertNumAo)) // Added for FVU 6.0 by Jacky to check if
																			// Certificate number issued by the
																			// Assessing Officer is Alphanumeric
							{
								iscertvalid = false;

							}

							/*
							 * for(int i =0 ; i<4;i++) Commented as no longer needed for FVU 6.0 by Jacky
							 * start { if(obj_FieldValidation.isInt(ch[i]+"")) { iscertvalid = false; break;
							 * } }
							 * 
							 * if(iscertvalid) { for(int i =4 ; i<6;i++) {
							 * if(obj_FieldValidation.isCharUpper(ch[i]+"")) { iscertvalid = false; break; }
							 * } }
							 * 
							 * if(iscertvalid) {
							 * 
							 * for(int i =6 ; i<9;i++) { if(obj_FieldValidation.isInt(ch[i]+"")) {
							 * iscertvalid = false; break; } }
							 * 
							 * }
							 * 
							 * if(iscertvalid) { for(int i =9 ; i<10;i++) {
							 * if(obj_FieldValidation.isCharUpper(ch[i]+"")) { iscertvalid = false; break; }
							 * } }
							 */ // Commented as no longer needed for FVU 6.0 by Jacky end

							if (!iscertvalid) {
								Str_Buffer.append(
										LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4324_C + tab + T_FV_4324_M);
							}
						}
						// added by nik for fvu 4.7
						// FVU 5.1
						if ((UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A"))))) {
							if (!(SectionCode.equals("92A") || SectionCode.equals("92B") || SectionCode.equals("92C") || SectionCode.equals("193") || SectionCode.equals("194") || SectionCode.equals("94A") || SectionCode.equals("94C")
									|| SectionCode.equals("94D") || SectionCode.equals("94G") || SectionCode.equals("94H") || SectionCode.equals("4IB") || SectionCode.equals("4IA") || SectionCode.equals("94J") || SectionCode.equals("94L")
									|| SectionCode.equals("195") || SectionCode.equals("A") || SectionCode.equals("B") || SectionCode.equals("C") || SectionCode.equals("D") || SectionCode.equals("E") || SectionCode.equals("F")
									|| SectionCode.equals("G") || SectionCode.equals("H") || SectionCode.equals("I") || SectionCode.equals("J") || SectionCode.equals("K") || SectionCode.equals("LBC") || SectionCode.equals("LBB")
									|| SectionCode.equals("L") || SectionCode.equals("M") || SectionCode.equals("N") || SectionCode.equals("4JA") || SectionCode.equals("4JB"))) {
								Str_Buffer.append(
										LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4326_C + tab + T_FV_4326_M);
							}
						}
						if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O"))
								|| (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))))) {
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4326_C + tab + T_FV_4326_M);
						}

						// ended by nik for fvu 4.7
					}
					// Amit end here

				}
			} else {
				if (!CertNumAo.equals(FIELD_NULL) && !CertNumAo.equals(FIELD_SEPERATOR))

					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Certificate number issued by the Assessing Officer" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
			}

			// Validating CertNumAo
			
			// Added for FVU 7.0 - Vinita
			if(FormNo.equals(FORM_27EQ)){
				
			// Validating field 35 whthrPaymtLiablTds - Start
			if(!(whthrPaymtLiablTds.equals(FIELD_NULL) || whthrPaymtLiablTds.equals(FIELD_SEPERATOR))){
				if((UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))){
				if(((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
						&& (Remark1.equals("F") || Remark1.equals("G"))){
					if(!(whthrPaymtLiablTds.equals("Y") || whthrPaymtLiablTds.equals("N"))){
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Whether the payment by collectee is liable to TDS as per clause (a) of the fifth proviso to sub-section (1G) or second proviso to sub-section (1H) and whether TDS has been deducted from such payment (if either F or G is selected in 680)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6186_C + tab + T_FV_6186_M);
					}
				}
				else{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Whether the payment by collectee is liable to TDS as per clause (a) of the fifth proviso to sub-section (1G) or second proviso to sub-section (1H) and whether TDS has been deducted from such payment (if either F or G is selected in 680)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6187_C + tab + T_FV_6187_M);
				}	
				}
				else{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Whether the payment by collectee is liable to TDS as per clause (a) of the fifth proviso to sub-section (1G) or second proviso to sub-section (1H) and whether TDS has been deducted from such payment (if either F or G is selected in 680)" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
				}
			}
			// Validating whthrPaymtLiablTds - End
			
			// Validating field 36 challan Number - Start
			if(!(challanNumber.equals(FIELD_NULL) || challanNumber.equals(FIELD_SEPERATOR))){
				if((UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))){
					if(((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
							&& (whthrPaymtLiablTds.equals("Y"))){
					// check inter and 5 digit
						if(obj_FieldValidation.isInt(challanNumber) || challanNumber.length() != 5) // CR 70278 Obs 12, 13, 14, 15 FVU 7.0
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6188_C + tab + T_FV_6189_M);
					}
					else{
					// valid for Y and 202021
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6188_C + tab + T_FV_6188_M);
						}
					}
				else{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
				}
			}
			else if((challanNumber.equals(FIELD_NULL) || challanNumber.equals(FIELD_SEPERATOR)) && whthrPaymtLiablTds.equals("Y")){
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6188_C + tab + T_FV_6188_M);
			}
			// Validating field 36 challan Number - End
			
		//Validating field 37 datePaymtTds - Start
			if(!(datePaymtTds.equals(FIELD_NULL) || datePaymtTds.equals(FIELD_SEPERATOR))){
				if((UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))){
					if(((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
							&& (whthrPaymtLiablTds.equals("Y"))){
					// check date format
						if(obj_FieldValidation.isDate(datePaymtTds) || obj_FieldValidation.isFutureDate(datePaymtTds)) // CR 70278 Obs no 17 FVU 7.0 // Change in requirement FVU 7.0
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of payment of TDS to Central Government" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6190_C + tab + T_FV_6190_M);
					}
					else{
					// valid for Y and 202021
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of payment of TDS to Central Government" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6188_C + tab + T_FV_6188_M);
					}
				}
				else{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of payment of TDS to Central Government" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
				}
			}
			else if((datePaymtTds.equals(FIELD_NULL) || datePaymtTds.equals(FIELD_SEPERATOR)) && whthrPaymtLiablTds.equals("Y")){
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of payment of TDS to Central Government" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6188_C + tab + T_FV_6188_M);
			}
			//Validating field 37 datePaymtTds - End
			
			}
			// Validating TdsRate

			if (isFinYrGrtrthn) {
				/*
				 * if (TdsRate.equals(FIELD_NULL) || TdsRate.equals(FIELD_SEPERATOR)) {
				 * if(FormNo.equals(FORM_27Q)) Str_Buffer.append(LineNo + tab +
				 * currentUploadType + tab + "'Oltas  TDS / TCS -Income Tax '" + tab +
				 * CurrentchallanDetailRecordNo + tab + tab + T_FV_4301_C + tab + T_FV_4301_M);
				 * }
				 */
				// else
				// {

				if (!(TdsRate.equals(FIELD_NULL) || TdsRate.equals(FIELD_SEPERATOR))) {

					if (FormNo.equals(FORM_27Q)) {
						if (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("D")) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) && !TdsRate.equals(FIELD_NULL)
								&& !TdsRate.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS rate of ITD/DTAA" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
						} else if (!(TdsRate.trim().equals("A") || TdsRate.trim().equals("B"))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS rate of ITD/DTAA" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4311_C + tab + T_FV_4311_M);
						}
					
					
						// validate TdsRate for this section code 96D FVU 7.2 by Vinita - Start
						if(SectionCode.equals("96D") && (Integer.parseInt(FinancialYr) >= 202122)){
							if(!(TdsRate.trim().equals("A") || TdsRate.trim().equals("B"))){//Changes added for 7.4_2.170_2.1302 by Kiran added condition for A
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS rate of ITD/DTAA" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6207_C + tab + T_FV_6207_M);
							}
						}
						// validate TdsRate for this section code 96D FVU 7.2 by Vinita - End
					
					
					} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS rate of ITD/DTAA" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4311_C + tab + T_FV_4311_M);
					}
				}

				// }
			} else {
				if (!TdsRate.equals(FIELD_NULL) && !TdsRate.equals(FIELD_SEPERATOR)) {
					if (FormNo.equals(FORM_27Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TDS rate of ITD/DTAA" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					}
				}
			}

			// Validating TdsRate

			// Validating NatureOfRemittance

			if (isFinYrGrtrthn) {
				/*
				 * if (NatureOfRemittance.equals(FIELD_NULL) ||
				 * NatureOfRemittance.equals(FIELD_SEPERATOR)) { if(FormNo.equals(FORM_27Q))
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
				 * "'Oltas  TDS / TCS -Income Tax '" + tab + CurrentchallanDetailRecordNo + tab
				 * + tab + T_FV_4301_C + tab + T_FV_4301_M); }
				 */
				// else
				// {
				if (!(NatureOfRemittance.equals(FIELD_NULL) || NatureOfRemittance.equals(FIELD_SEPERATOR))) {
					if (FormNo.equals(FORM_27Q)) {
						if (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("D")) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
								&& !NatureOfRemittance.equals(FIELD_NULL) && !NatureOfRemittance.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
						} else if (obj_FieldValidation.isInt(NatureOfRemittance)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4312_C + tab + T_FV_4312_M);
						} else if (NatureOfRemittance.trim().length() > 3) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4312_C + tab + T_FV_4312_M);
						} else if (!((Integer.parseInt(NatureOfRemittance) > 0 && Integer.parseInt(NatureOfRemittance) < 65) || Integer.parseInt(NatureOfRemittance) == 99)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4312_C + tab + T_FV_4312_M);
						}
						// added by nik for FVU 4.6
						// updated by faizan for FVU 4.8
						else if (!(NatureOfRemittance.equals("27") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("16") || NatureOfRemittance.equals("28") || NatureOfRemittance.equals("31")
								|| NatureOfRemittance.equals("52") || NatureOfRemittance.equals("99")))
						// else if(!( NatureOfRemittance.equals("27") || NatureOfRemittance.equals("37")
						// || NatureOfRemittance.equals("63") || NatureOfRemittance.equals("64") ||
						// NatureOfRemittance.equals("21") || NatureOfRemittance.equals("49") ||
						// NatureOfRemittance.equals("16") || NatureOfRemittance.equals("28") ||
						// NatureOfRemittance.equals("31") || NatureOfRemittance.equals("52") ||
						// NatureOfRemittance.equals("99") ))
						// else if(!( NatureOfRemittance.equals("27") || NatureOfRemittance.equals("11")
						// || NatureOfRemittance.equals("37") || NatureOfRemittance.equals("63") ||
						// NatureOfRemittance.equals("64") || NatureOfRemittance.equals("21") ||
						// NatureOfRemittance.equals("49") || NatureOfRemittance.equals("16") ||
						// NatureOfRemittance.equals("28") || NatureOfRemittance.equals("31") ||
						// NatureOfRemittance.equals("52") || NatureOfRemittance.equals("99") ))
						{
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4312_C + tab + T_FV_4312_M);
						}
						// ended by nik for FVU 4.6
						else if (NatureOfRemittance.equals("11") || NatureOfRemittance.equals("37") || NatureOfRemittance.equals("63") || NatureOfRemittance.equals("64")) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_1043_C + tab + T_FV_1043_M);
						}
						// ended for FVU 4.8
						
						// Adding validation for FVU 7.2 for section code 96DP by Vinita : Start
						if((SectionCode !=null && SectionCode.equals("96D")) && (Integer.parseInt(FinancialYr) >= 202122 )
								&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))) {
							if(NatureOfRemittance != null && !(NatureOfRemittance.equals("16") || NatureOfRemittance.equals("27"))){
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6205_C + tab + T_FV_6205_M);
							}
						}
						// Adding validation for FVU 7.2 for section code 96DP by Vinita : End
						
					} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 2" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4312_C + tab + T_FV_4312_M);
					}
				} else { // added for FVU 5.7

					if (FormNo.equals(FORM_27Q) && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) { // added for
																																								// FVU 5.7
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4352_C + tab + T_FV_4352_M);
					}

				}

				// }
			} else {
				if (!NatureOfRemittance.equals(FIELD_NULL) && !NatureOfRemittance.equals(FIELD_SEPERATOR)) {
					if (FormNo.equals(FORM_27Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Nature Of Remittance" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 2" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					}
				}
			}

			// Validating NatureOfRemittance

			// Validating AckNoForm15CA

			if (isFinYrGrtrthn) {
				if (!(AckNoForm15CA.equals(FIELD_NULL) || AckNoForm15CA.equals(FIELD_SEPERATOR))) {

					if (FormNo.equals(FORM_27Q)) {
						if (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("D")) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) && !AckNoForm15CA.equals(FIELD_NULL)
								&& !AckNoForm15CA.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Unique acknowledgement number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
						}
						// added by faizan for fvu 4.5
						else if (!(UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Unique acknowledgement number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
						}
						// else if(AckNoForm15CA.trim().length()!=12)
						else if (AckNoForm15CA.trim().length() > 15 || AckNoForm15CA.trim().length() < 12) // Changed
																											// for FVU
																											// 4.2
						{
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Unique acknowledgement number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4313_C + tab + T_FV_4313_M);
						}
						// Added By amit for hanlde space for fvu 4.5
						else if (!(AckNoForm15CA.trim().length() == AckNoForm15CA.length())) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Unique acknowledgement number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4313_C + tab + T_FV_4313_M);
						}
						// ended by amit for fvu 4.5
						else {
							/*
							 * if (!AckNoForm15CA.substring(0,1).equals("R")) Str_Buffer.append(LineNo + tab
							 * + currentUploadType + tab + "Unique acknowledgement number " + tab +
							 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
							 * T_FV_4313_C + tab + T_FV_4313_M); else if
							 * (!obj_FieldValidation.isNumber(AckNoForm15CA.substring(1,5)))
							 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
							 * "Unique acknowledgement number " + tab + CurrentchallanDetailRecordNo + tab +
							 * CurrentDeducteeDetailRecNo + tab + T_FV_4313_C + tab + T_FV_4313_M); else if
							 * (obj_FieldValidation.isAlphaNum(AckNoForm15CA.substring(5,11)))
							 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
							 * "Unique acknowledgement number " + tab + CurrentchallanDetailRecordNo + tab +
							 * CurrentDeducteeDetailRecNo + tab + T_FV_4313_C + tab + T_FV_4313_M); else if
							 * (obj_FieldValidation.isChar(AckNoForm15CA.substring(11,12)))
							 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
							 * "Unique acknowledgement number " + tab + CurrentchallanDetailRecordNo + tab +
							 * CurrentDeducteeDetailRecNo + tab + T_FV_4313_C + tab + T_FV_4313_M);
							 */
							// Changed for FVu 4.2
							if (obj_FieldValidation.isAlphaNum(AckNoForm15CA))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Unique acknowledgement number " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4313_C + tab + T_FV_4313_M);
						}

					} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 3" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Unique acknowledgement number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4313_C + tab + T_FV_4313_M);
					}
				}

			} else {
				if (!AckNoForm15CA.equals(FIELD_NULL) && !AckNoForm15CA.equals(FIELD_SEPERATOR)) {
					if (FormNo.equals(FORM_27Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Unique acknowledgement number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 3" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					}

				}
			}
			// Validating AckNoForm15CA

			// Validating RemittanceCountry

			/*
			 * if(isFinYrGrtrthn) { /* if (RemittanceCountry.equals(FIELD_NULL) ||
			 * RemittanceCountry.equals(FIELD_SEPERATOR)) { if(FormNo.equals(FORM_27Q))
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 3" + tab
			 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4302_C + tab + T_FV_4302_M); } else {
			 */
			/*
			 * if (!(RemittanceCountry.equals(FIELD_NULL) ||
			 * RemittanceCountry.equals(FIELD_SEPERATOR))) { if(FormNo.equals(FORM_27Q) ) {
			 * if(UploadType.equals(UPLOADTYPE_CORRECTION) &&
			 * ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)&&
			 * Mode.equals("D")) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
			 * && !RemittanceCountry.equals(FIELD_NULL) &&
			 * !RemittanceCountry.equals(FIELD_SEPERATOR)) { Str_Buffer.append(LineNo + tab
			 * + currentUploadType + tab + "Country Name" + tab +
			 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4317_C + tab + T_FV_4317_M); } else
			 * if(obj_FieldValidation.isInt(RemittanceCountry)) { Str_Buffer.append(LineNo +
			 * tab + currentUploadType + tab + "Country Name" + tab +
			 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4314_C + tab + T_FV_4314_M); } else
			 * if(RemittanceCountry.trim().length()>3 ) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo
			 * + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
			 * } //Added for FVU 4.4 by Shalin else if(RemittanceCountry.trim().length() !=
			 * RemittanceCountry.length() ) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo
			 * + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
			 * } else if(!(Integer.parseInt(RemittanceCountry)>0 &&
			 * Integer.parseInt(RemittanceCountry)<287) ||
			 * Integer.parseInt(RemittanceCountry)==99) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo
			 * + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
			 * } } else if(FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) ||
			 * FormNo.equals(FORM_26Q) || (FormNo.equals(FORM_27Q) &&
			 * TRANSACTION_TYPE.equals(TRANSACTIONTYPE_CORRECTION_PAN))) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 4" + tab +
			 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4317_C + tab + T_FV_4317_M); } else { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo
			 * + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
			 * } } else {
			 * 
			 * if(FormNo.equals(FORM_27Q) &&
			 * !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) &&
			 * !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
			 * Mode.equals("D")) ) Str_Buffer.append(LineNo + tab + currentUploadType + tab
			 * + "Country Name" + tab + CurrentchallanDetailRecordNo + tab +
			 * CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M); } //} }
			 * else { if (!RemittanceCountry.equals(FIELD_NULL) &&
			 * !RemittanceCountry.equals(FIELD_SEPERATOR)) { if(FormNo.equals(FORM_27Q)) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" +
			 * tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4317_C + tab + T_FV_4317_M); } else if(FormNo.equals(FORM_24Q) ||
			 * FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 4" + tab +
			 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4317_C + tab + T_FV_4317_M); }
			 * 
			 * } }
			 */
			// Validating RemittanceCountry

			// commentedabove and calling below method for validation

			validateDeducteeRemittanceCountry(isFinYrGrtrthn, RemittanceCountry, FormNo, UploadType, TransactionType, Mode, Str_Buffer,SectionCode); //SectionCode added for FVU 7.2 by Vinita

			// Added For FVU 5.2,2.1280
			// Validating DeducteeEmailId

			if (FormNo.equals(FORM_27Q)) {
				if (DeducteeEmailId.equals(FIELD_NULL) || DeducteeEmailId.equals(FIELD_SEPERATOR)) {
					
					// If NatureOfRemittance is 16, then this field is mandatory - Obs no 1 - FVU 7.1 - Vinita
					
					if (((NatureOfRemittance.equals("27") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("52") || NatureOfRemittance.equals("31")) && Integer.parseInt(FinancialYr) >= 201617)
						|| (NatureOfRemittance.equals("16") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))))	) { /// added by shruti fvu 5.3

						if (!(RateAtWhichTaxDeducted.equals(FIELD_NULL) || RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							if ((Double.parseDouble(RateAtWhichTaxDeducted) < 20 && Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)))
									&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || UploadType.equals(UPLOADTYPE_REGULAR))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Email Id of Deductee" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4335_C + tab + T_FV_4335_M);
							}
						}

					}
					
				}
				/*
				 * else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * (!Mode.equals("A") && !Mode.equals("U"))){
				 * if(!(DeducteeEmailId.equals(FIELD_NULL)||DeducteeEmailId.equals(
				 * FIELD_SEPERATOR))){ Str_Buffer.append(LineNo + tab + currentUploadType + tab
				 * + "EmailId of Deductee" + tab + CurrentchallanDetailRecordNo + tab +
				 * CurrentDeducteeDetailRecNo + tab + T_FV_4335_C + tab + T_FV_4335_M); } }
				 */
				else {
					// Double.parseDouble(RateAtWhichTaxDeducted) < 20

					if (Integer.parseInt(FinancialYr) >= 201617 && Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
							&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || UploadType.equals(UPLOADTYPE_REGULAR))) {
						if (DeducteeEmailId.length() <= 75) {
							if ((obj_FieldValidation.isValidEmail(DeducteeEmailId))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Email Id of Deductee" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4335_C + tab + T_FV_4335_M);
							}

							// Added by shruti start FVU 5.3
							else if (!(NatureOfRemittance.equals("27") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("52") || NatureOfRemittance.equals("31") ||  NatureOfRemittance.equals("16"))) // Added for FVU 7.1 Obs no 1 - Vinita
							{
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Email Id of Deductee" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4340_C + tab + T_FV_4340_M);
							} // Added by shruti end

						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Email Id of Deductee" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4335_C + tab + T_FV_4335_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Email Id of Deductee" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4335_C + tab + T_FV_4335_M);

				}
			} else {
				if (!(DeducteeEmailId.equals(FIELD_NULL) || DeducteeEmailId.equals(FIELD_SEPERATOR))) {
					if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 5 " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
					}

				}

			}

			// End :: Validating DeducteeEmailId

			// Validating Contact number of deductee

			if (FormNo.equals(FORM_27Q)) {
				if (DeducteeContactNo.equals(FIELD_NULL) || DeducteeContactNo.equals(FIELD_SEPERATOR) || DeducteeContactNo.trim().length() == 0) {

					// Added for FVU 7.1 Obs no 1 - Vinita
					
					if (((NatureOfRemittance.equals("27") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("52") || NatureOfRemittance.equals("31")) && Integer.parseInt(FinancialYr) >= 201617)
							|| (NatureOfRemittance.equals("16") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))))) { /// added by shruti fvu 5.3

						if (!(RateAtWhichTaxDeducted.equals(FIELD_NULL) || RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							if ((Double.parseDouble(RateAtWhichTaxDeducted) < 20 && Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
											&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || UploadType.equals(UPLOADTYPE_REGULAR)))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Contact number of deductee" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4336_C + tab + T_FV_4336_M);
							}

						}

					}
					
				}

				/*
				 * else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * (!Mode.equals("A") && !Mode.equals("U"))){
				 * if(!(DeducteeContactNo.equals(FIELD_NULL)||DeducteeContactNo.equals(
				 * FIELD_SEPERATOR))){ Str_Buffer.append(LineNo + tab + currentUploadType + tab
				 * + "Contact number of deductee" + tab + CurrentchallanDetailRecordNo + tab +
				 * CurrentDeducteeDetailRecNo + tab + T_FV_4336_C + tab + T_FV_4336_M); } }
				 */
				else {
					// System.out.println("Long.parseLong(DeducteeContactNo)
					// ::"+Long.parseLong(DeducteeContactNo));
					// && Double.parseDouble(RateAtWhichTaxDeducted) < 20

					if (Integer.parseInt(FinancialYr) >= 201617 && Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
							&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || UploadType.equals(UPLOADTYPE_REGULAR))) {
						if (DeducteeContactNo.trim().length() <= 15) {
							if (obj_FieldValidation.isInt(DeducteeContactNo)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Contact number of deductee" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4336_C + tab + T_FV_4336_M);
							} else if (Long.parseLong(DeducteeContactNo) == 0) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Contact number of deductee " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4336_C + tab + T_FV_4336_M);
							}
							// Added by shruti start FVU 5.3
							else if (!(NatureOfRemittance.equals("27") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("52") || NatureOfRemittance.equals("31") || NatureOfRemittance.equals("16"))) // Added for FVU 7.1 Obs no 1 -Vinita
								{
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Contact number of deductee" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4341_C + tab + T_FV_4341_M);
							} // Added by shruti end
						} else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Contact number of deductee " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4336_C + tab + T_FV_4336_M);

					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Contact number of deductee " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4336_C + tab + T_FV_4336_M);

				}
			} else {
				if (!(DeducteeContactNo.equals(FIELD_NULL) || DeducteeContactNo.equals(FIELD_SEPERATOR))) {
					if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 6" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
					}

				}

			}

			// End :: Validating Contact number of deductee

			// Validating Address of deductee

			if (FormNo.equals(FORM_27Q)) {
				if (DeducteeAddress.equals(FIELD_NULL) || DeducteeAddress.equals(FIELD_SEPERATOR) || DeducteeAddress.trim().length() == 0) {

					// Added for FVU 7.1 Obs no 1 - vinita
					
					if (((NatureOfRemittance.equals("27") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("52") || NatureOfRemittance.equals("31")) && Integer.parseInt(FinancialYr) >= 201617)
							|| (NatureOfRemittance.equals("16") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))))) { /// added by shruti fvu 5.3

						if (!(RateAtWhichTaxDeducted.equals(FIELD_NULL) || RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							if ((Double.parseDouble(RateAtWhichTaxDeducted) < 20 && Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
											&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || UploadType.equals(UPLOADTYPE_REGULAR)))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Address of deductee in country of residence" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4337_C + tab + T_FV_4337_M);

							}
						}

					}
					
				}
				/*
				 * else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * (!Mode.equals("A") && !Mode.equals("U"))){
				 * if(!(DeducteeAddress.equals(FIELD_NULL)||DeducteeAddress.equals(
				 * FIELD_SEPERATOR))){ Str_Buffer.append(LineNo + tab + currentUploadType + tab
				 * + "Address of deductee in country of residence" + tab +
				 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
				 * T_FV_4337_C + tab + T_FV_4337_M); } }
				 */
				else {

					// && Double.parseDouble(RateAtWhichTaxDeducted) <20
					if (Integer.parseInt(FinancialYr) >= 201617 && Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
							&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || UploadType.equals(UPLOADTYPE_REGULAR))) {
						if (!(obj_FieldValidation.checkNonSpecialCharacterAndSpace(DeducteeAddress)))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Address of deductee in country of residence" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4337_C + tab + T_FV_4337_M);

						else if (DeducteeAddress.length() > 150) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Address of deductee in country of residence" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4337_C + tab + T_FV_4337_M);
						} else if (obj_FieldValidation.isNumeric(DeducteeAddress)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Address of deductee in country of residence" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4337_C + tab + T_FV_4337_M);
						} else if (obj_FieldValidation.isValidCharString_new(DeducteeAddress)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Address of deductee in country of residence" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4337_C + tab + T_FV_4337_M);
						}
						// Added by shruti start FVU 5.3
						else if (!(NatureOfRemittance.equals("27") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("52") || NatureOfRemittance.equals("31") || NatureOfRemittance.equals("16"))) // Added for FVU 7.1 Obs no 1 - Vinita
							{
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Address of deductee in country of residence" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4342_C + tab + T_FV_4342_M);
						} // Added by shruti end

					}

					else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Address of deductee in country of residence" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4337_C + tab + T_FV_4337_M);

				}

			} else {
				if (!(DeducteeAddress.equals(FIELD_NULL) || DeducteeAddress.equals(FIELD_SEPERATOR))) {
					if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 7" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
					}

				}

			}
			// End Validating Address of deductee

			if (FormNo.equals(FORM_27Q)) {
				// Validating Tax identification number

				if (TaxIdentificationNo.equals(FIELD_NULL) || TaxIdentificationNo.equals(FIELD_SEPERATOR) || TaxIdentificationNo.trim().length() == 0) {

					if (((NatureOfRemittance.equals("27") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("52") || NatureOfRemittance.equals("31")) && Integer.parseInt(FinancialYr) >= 201617) 
							|| (NatureOfRemittance.equals("16") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))))) { /// added by shruti fvu 5.3

						if (!(RateAtWhichTaxDeducted.equals(FIELD_NULL) || RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							if ((Double.parseDouble(RateAtWhichTaxDeducted) < 20 && Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
											&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || UploadType.equals(UPLOADTYPE_REGULAR)))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Tax identification number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4338_C + tab + T_FV_4338_M);
							}
						}

					}
				}
				/*
				 * else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
				 * (!Mode.equals("A") && !Mode.equals("U"))){
				 * if(!(TaxIdentificationNo.equals(FIELD_NULL)||TaxIdentificationNo.equals(
				 * FIELD_SEPERATOR))){ Str_Buffer.append(LineNo + tab + currentUploadType + tab
				 * + "Tax identification number " + tab + CurrentchallanDetailRecordNo + tab +
				 * CurrentDeducteeDetailRecNo + tab + T_FV_4338_C + tab + T_FV_4338_M); } }
				 */
				else {
					// System.out.println(" int value :"+Integer.parseInt(TaxIdentificationNo))
					// && Double.parseDouble(RateAtWhichTaxDeducted) < 20

					if (Integer.parseInt(FinancialYr) >= 201617 && Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
							&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || UploadType.equals(UPLOADTYPE_REGULAR))) {
						if (!(obj_FieldValidation.checkNonSpecialCharacter(TaxIdentificationNo)))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Tax identification number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4338_C + tab + T_FV_4338_M);

						else if (TaxIdentificationNo.length() > 25) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Tax identification number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4338_C + tab + T_FV_4338_M);
						}

						else if (obj_FieldValidation.checkAllzero(TaxIdentificationNo)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Tax identification number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4338_C + tab + T_FV_4338_M);
						}
						// Added by shruti start FVU 5.3
						else if (!(NatureOfRemittance.equals("27") || NatureOfRemittance.equals("49") || NatureOfRemittance.equals("21") || NatureOfRemittance.equals("52") || NatureOfRemittance.equals("31") || NatureOfRemittance.equals("16"))) // Added for FVU 7.1 Obs no 1 - Vinita
							{
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Tax identification number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4343_C + tab + T_FV_4343_M);
						} // Added by shruti end

					}

					else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Tax identification number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4338_C + tab + T_FV_4338_M);

				}
			} else {
				if (!(TaxIdentificationNo.equals(FIELD_NULL) || TaxIdentificationNo.equals(FIELD_SEPERATOR))) {
					if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 8" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
					}

				}
			}

			// End :: Validating Tax identification number

			// End :: Validating Tax identification number
			// end ::addded for FVU 5.2 and 2.1280

			// Changes added for 6.6_2.162_2.1294 by Puja::Start
			// Changes added for 6.8_2.164_2.1296 by pujabugfix2
			if ((FormNo.equals(FORM_27Q) || FormNo.equals(FORM_26Q)) && SectionCode.equals("94N") && ((Integer.parseInt(FinancialYr) == 201920 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))
					|| (Integer.parseInt(FinancialYr) >= 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
				if (!(amtOfCashWithIn194N.equals(FIELD_NULL) || amtOfCashWithIn194N.equals(FIELD_SEPERATOR) || amtOfCashWithIn194N.trim().length() == 0)) {
					if (amtOfCashWithIn194N.length() <= 15) {
						if (obj_FieldValidation.isDecimal(amtOfCashWithIn194N, 2)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
									+ T_FV_6141_C + tab + T_FV_6141_M);
						} else if (Double.parseDouble(amtOfCashWithIn194N.trim()) < 0) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
									+ T_FV_6141_C + tab + T_FV_6141_M);
						} else if (Double.parseDouble(amtOfCashWithIn194N.trim()) > Double.parseDouble(AmountOfPayment.trim())) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
									+ T_FV_6143_C + tab + T_FV_6143_M);
						}
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
								+ T_FV_6141_C + tab + T_FV_6141_M);
					}
				} else {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
							+ T_FV_6141_C + tab + T_FV_6141_M);
				}

			} else if (FormNo.equals(FORM_27Q) || FormNo.equals(FORM_26Q)) {
				if (!(amtOfCashWithIn194N.equals(FIELD_NULL) || amtOfCashWithIn194N.equals(FIELD_SEPERATOR) || amtOfCashWithIn194N.trim().length() == 0)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
							+ T_FV_6144_C + tab + T_FV_6144_M);
				}

			}

			//// Changes added for 6.6_2.162_2.1294 by Puja correction fix
			// Changes added for 6.8_2.164_2.1296 by pujabugfix2
			if ((FormNo.equals(FORM_27Q) || FormNo.equals(FORM_26Q)) && SectionCode.equals("94N") && ((Integer.parseInt(FinancialYr) == 201920 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))
					|| (Integer.parseInt(FinancialYr) >= 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
				if ((currentUploadType.equals(UPLOAD_TYPE_C3)) && !SectionCode.equals("94N")) {
					if (!(amtOfCashWithIn194N.equals(FIELD_NULL) || amtOfCashWithIn194N.equals(FIELD_SEPERATOR) || amtOfCashWithIn194N.trim().length() == 0)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
								+ T_FV_6144_C + tab + T_FV_6144_M);
					}
				} else if (currentUploadType.equals(UPLOAD_TYPE_C3) && SectionCode.equals("94N")) {
					if (!(amtOfCashWithIn194N.equals(FIELD_NULL) || amtOfCashWithIn194N.equals(FIELD_SEPERATOR) || amtOfCashWithIn194N.trim().length() == 0)) {
						if (amtOfCashWithIn194N.length() <= 15) {
							if (obj_FieldValidation.isDecimal(amtOfCashWithIn194N, 2)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo
										+ tab + T_FV_6141_C + tab + T_FV_6141_M);
							}
						} else {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
									+ T_FV_6141_C + tab + T_FV_6141_M);
						}
					}
				} else if (!currentUploadType.equals(UPLOAD_TYPE_C3) && !currentUploadType.equals(UPLOAD_TYPE_REGULAR)) {
					if (!(amtOfCashWithIn194N.equals(FIELD_NULL) || amtOfCashWithIn194N.equals(FIELD_SEPERATOR) || amtOfCashWithIn194N.trim().length() == 0)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount of cash withdrawal in excess of Rs. 1 crore as referred to in section 194N" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab
								+ T_FV_6144_C + tab + T_FV_6144_M);
					}
				}
			}

			if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ)) {

				if (!filler9.equals(FIELD_NULL) && !filler9.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "filler9" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6144_C + tab + T_FV_6144_M);
				}
				if (!(filler10.equals(FIELD_NULL) || filler10.equals(FIELD_SEPERATOR))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 9" + tab + CurrentchallanDetailRecordNo + tab + "NA" + tab + T_FV_6144_C + tab + T_FV_6144_M);
				}
				if (!(filler11.equals(FIELD_NULL) || filler11.equals(FIELD_SEPERATOR))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 10" + tab + CurrentchallanDetailRecordNo + tab + "NA" + tab + T_FV_6144_C + tab + T_FV_6144_M);
				}
			}
			if (!(filler12.equals(FIELD_NULL) || filler12.equals(FIELD_SEPERATOR))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 11" + tab + CurrentchallanDetailRecordNo + tab + "NA" + tab + T_FV_6144_C + tab + T_FV_6144_M);
			}
			if (!(filler13.equals(FIELD_NULL) || filler13.equals(FIELD_SEPERATOR))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 12" + tab + CurrentchallanDetailRecordNo + tab + "NA" + tab + T_FV_6144_C + tab + T_FV_6144_M);
			}
			// Changes added for 6.6_2.162_2.1294 by Puja::End
			// Added for fvu 3.8 by Shalin --- END

			// Validations Added For FVU 3.0 Annexure A Changes and Form No. 27EQ is added
			// for FVU 3.0 new changes
			if (!(Mode.equals("D")) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !FormNo.equals(FORM_27EQ)) // Added by Abhishek
			{
				/// If remarks is null and Tax deducted or deposited is greater than zero and
				/// PAN is structurally invalid then reject
				/// If remarks is T and sec is 194C and Tax deducted or deposited is greater
				/// than zero and PAN is structurally invalid then reject
				if (!isFinYrGrtrthn) {
					// Added for FVU 4.7
					if (!((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && FormNo.equals(FORM_27Q) && isFinYrGrtr && sectionForThisDD.equals("4LC") && obj_FieldValidation.isDateGreaterThanOldJune(DateOnWhichAmountPaid)
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A")))))) {
						if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR) || (Remark1.equals("T") && sectionForThisChallan.equals("94C"))) && !isStructurallyValidPan && Double.parseDouble(TotalIncomeTaxDeductedAtSource) >= 0
								&& Double.parseDouble(TotalTaxDeposited) >= 0)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4266_C + tab + T_FV_4266_M);
					} else if (Remark1.equals("A") && !isStructurallyValidPan && Double.parseDouble(TotalIncomeTaxDeductedAtSource) >= 0 && Double.parseDouble(TotalTaxDeposited) >= 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M);

					else if (Remark1.equals("C") && Double.parseDouble(TotalIncomeTaxDeductedAtSource) == 0 && Double.parseDouble(TotalTaxDeposited) >= 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4268_C + tab + T_FV_4268_M);

					else if ((sectionForThisChallan.equals("194") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("193")) && Remark1.equals("B")
							&& Double.parseDouble(TotalIncomeTaxDeductedAtSource) == 0 && Double.parseDouble(TotalTaxDeposited) == 0) {
						if (!isStructurallyValidPan)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4270_C + tab + T_FV_4270_M);
					}

					else if ((sectionForThisChallan.equals("194") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("193")) && Remark1.equals("B")
							&& Double.parseDouble(TotalIncomeTaxDeductedAtSource) >= 0 && Double.parseDouble(TotalTaxDeposited) >= 0) {
						if (isStructurallyValidPan)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4269_C + tab + T_FV_4269_M);
						else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4271_C + tab + T_FV_4271_M);
					}
				} else if (isFinYrGrtrthn) {

					// Added for FVU 4.7
					if (!((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && FormNo.equals(FORM_27Q) && isFinYrGrtr && sectionForThisDD.equals("4LC") && obj_FieldValidation.isDateGreaterThanOldJune(DateOnWhichAmountPaid)
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A")))))) {
						if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR) || (Remark1.equals("T") && sectionForThisDD.equals("94C"))) && !isStructurallyValidPan && Double.parseDouble(TotalIncomeTaxDeductedAtSource) >= 0
								&& Double.parseDouble(TotalTaxDeposited) >= 0)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4266_C + tab + T_FV_4266_M);
					} else if (Remark1.equals("A") && !isStructurallyValidPan && Double.parseDouble(TotalIncomeTaxDeductedAtSource) >= 0 && Double.parseDouble(TotalTaxDeposited) >= 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M);

					else if (Remark1.equals("C") && Double.parseDouble(TotalIncomeTaxDeductedAtSource) == 0 && Double.parseDouble(TotalTaxDeposited) >= 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4268_C + tab + T_FV_4268_M);

					else if ((sectionForThisDD.equals("194") || sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94A") || sectionForThisDD.equals("193") || sectionForThisDD.equals("94D") || sectionForThisDD.equals("94J")) // added "94D" for
																																																										// FVU 5.5 //Added
																																																										// 94J for FVU 5.6
							&& Remark1.equals("B") && Double.parseDouble(TotalIncomeTaxDeductedAtSource) == 0 && Double.parseDouble(TotalTaxDeposited) == 0) {
						if (!isStructurallyValidPan)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4270_C + tab + T_FV_4270_M);
					}

					else if ((sectionForThisDD.equals("194") || sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94A") || sectionForThisDD.equals("193") || sectionForThisDD.equals("94D") || sectionForThisDD.equals("94J")) // added "94D" for
																																																										// FVU 5.5 //Added
																																																										// 94J for FVU 5.6
							&& Remark1.equals("B") && Double.parseDouble(TotalIncomeTaxDeductedAtSource) >= 0 && Double.parseDouble(TotalTaxDeposited) >= 0) {
						if (isStructurallyValidPan)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4269_C + tab + T_FV_4269_M);
						else
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4271_C + tab + T_FV_4271_M);
					}
				}
			}
			// Validations For Annexure A

			// Commented below code and called validateDeducteePANDetails_new method
			/*
			 * //Added by Abhishek for remark='B' if(Remark1.equals("B") &&
			 * !FormNo.equals(FORM_26Q) &&
			 * !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) &&
			 * !FormNo.equals(FORM_27EQ)) //Chnages Done For FVU 3.0 new changes {
			 * if(UploadTypeDD.equals(UPLOADTYPE_REGULAR) && !isStructurallyValidPan)
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "Employee/Party PAN"+ tab +CurrentchallanDetailRecordNo + tab +
			 * CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M); else if
			 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
			 * Mode.equals("U") && !isStructurallyValidPan) Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Employee/Party PAN"+ tab
			 * +CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4267_C + tab + T_FV_4267_M); else if(
			 * ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) &&
			 * Mode.equals("A")) ||
			 * TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) &&
			 * !isStructurallyValidPan) Str_Buffer.append(LineNo + tab + currentUploadType +
			 * tab + "Employee/Party PAN"+ tab +CurrentchallanDetailRecordNo + tab +
			 * CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M); } // END
			 * for remark B // Added on 17/08/2012 if(Remark1.equals("S") &&
			 * !isStructurallyValidPan) { Str_Buffer.append(LineNo + tab + currentUploadType
			 * + tab + "Employee/Party PAN"+ tab +CurrentchallanDetailRecordNo + tab +
			 * CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M); }
			 */
			validateDeducteePANDetails_new(Remark1, FormNo, TransactionType, UploadTypeDD, isStructurallyValidPan, Str_Buffer);

			// ##########---validation added at last for Wrong B ----- Manvendra Singh ::
			// 18-Feb-2008
			if (!(EmployeePan.equals(FIELD_NULL) || EmployeePan.equals(FIELD_SEPERATOR) || (EmployeePan.trim().length() == 0))) {
				if (isFinYrGrtr) {
					if (!isFinYrGrtrthn && !(Mode.equals("D") || Mode.equals("U")) && Remark1.equals("B") && !isValid_B && !sectionForThisChallan.equals("K")) {
						totalPANtoValidate_in_batch++;
						if (isStructurallyValidPan)
							validPANtovalidate_in_batch++;
					} else if (isFinYrGrtrthn && !(Mode.equals("D") || Mode.equals("U")) && Remark1.equals("B") && !isValid_B && !sectionForThisDD.equals("K")) {
						totalPANtoValidate_in_batch++;
						if (isStructurallyValidPan)
							validPANtovalidate_in_batch++;
					}
				} else {
					if (!(Mode.equals("D") || Mode.equals("U")) && Remark1.equals("B") && !isValid_B) {
						totalPANtoValidate_in_batch++;
						if (isStructurallyValidPan)
							validPANtovalidate_in_batch++;
					}
				}
			}

			// #########################################################

		} // try
		catch (Exception e) {

			throw e;
		}
		return;
	} // method

	/**
	 * @param BH_BatchNo
	 * @param ChallanDetailRecordNo
	 * @param TransactionType
	 * @param Qperiod
	 * @param FinancialYr
	 * @param UploadTypeDD
	 * @param obj_StringBuffer
	 * @param Str_Buffer
	 * @param LineNo
	 * @param DeducteeDetailRecNo
	 * @param EmployeePan
	 * @param TotalIncomeTaxDeductedAtSource
	 * @param LastTotalIncomeTaxDeductedAtSource
	 * @param TotalTaxDeposited
	 * @param AmountOfPayment
	 * @param DateOnWhichAmountPaid
	 * @param RateAtWhichTaxDeducted
	 * @param Remark1
	 * @param SectionCode
	 * @param flgForThreshold
	 * @param obj_FieldValidation
	 * @param isStructurallyValidPan
	 * @param isValid_B
	 * @param validLastTotalIncomeTaxDeductedAtSource
	 * @return
	 */
	private boolean validateRemark1Field(String BH_BatchNo,
			String ChallanDetailRecordNo, String TransactionType,
			String Qperiod, String FinancialYr, String UploadTypeDD,
			StringBufferTemp obj_StringBuffer, StringBufferTemp Str_Buffer,
			String LineNo, String DeducteeDetailRecNo, String EmployeePan,
			String TotalIncomeTaxDeductedAtSource,
			String LastTotalIncomeTaxDeductedAtSource,
			String TotalTaxDeposited, String AmountOfPayment,
			String DateOnWhichAmountPaid, String RateAtWhichTaxDeducted,
			String Remark1, String SectionCode, int flgForThreshold,
			FieldValidation obj_FieldValidation,
			boolean isStructurallyValidPan, boolean isValid_B,
			boolean validLastTotalIncomeTaxDeductedAtSource) {
		if (Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) {
			if (FormNo.equals(FORM_27EQ) && Integer.parseInt(FinancialYr) >= 201718 && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
					&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))

			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4266_C + tab + T_FV_4266_M);
			}
			
			// Obs no 6 FVU 7.2 Part 2 16 Sep 2021
			if (FormNo.equals(FORM_26Q) && sectionForThisDD.equals("94K") && ((Integer.parseInt(FinancialYr) >= 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))) &&
					(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))

			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6215_C + tab + T_FV_6215_M);
			}
			
			
		}

		if (!Remark1.equals(FIELD_NULL) && !Remark1.equals(FIELD_SEPERATOR)) {
			// Added for FVU 4.2
			if (FormNo.equals(FORM_24Q) && ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.2)) && Remark1.equals("C")
					&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("A")))) // Changed
																																																										// for
																																																										// FVU
																																																										// 4.6
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4278_C + tab + T_FV_4278_M);
			}
			// if (Mode.equals("D") ||
			// TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) -- Commented by
			// Abhishek for mode D removal
			if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4100_C + tab + T_FV_4100_M);
			} else if (Remark1.length() > 1) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4041_C + tab + T_FV_4041_M);
			}

			else if (Remark1.equals("Z") && !(isFinYrGrtrthn && FormNo.equals(FORM_26Q))) // Added for FVU 3.8 by
																							// Shalin
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
			}
			// Added for FVU 4.0
			else if ((UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
					&& !Remark1.equals("A") && !Remark1.equals("B") && !Remark1.equals("S") && !Remark1.equals("Y") && !Remark1.equals("T") && !Remark1.equals("Z") && !Remark1.equals("N")  && !Remark1.equals("D") && !Remark1.equals("E") && !Remark1.equals("F") && !Remark1.equals("G") && !Remark1.equals("H") && !Remark1.equals("I") && !Remark1.equals("P") && !Remark1.equals("Q") && NillChallanIndicator.equals("Y"))// Changes
																																																								// added for
																																																								// 6.6_2.162_2.1294
																																																								// by Puja // added remarks FVU 7.2 Bug Fix no 2 Vinita // Obs no 1 FVU 7.2 21 Jun 2021 // Obs no 12 FVU 7.2 29 Jun 2021
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4320_C + tab + T_FV_4320_M);
			}

			// Added for FVU 3.8 by Shalin
			/*
			 * if(currentUploadType.equals(UPLOADTYPE_REGULAR) && !(Remark1.equals("S") ||
			 * Remark1.equals("T") || Remark1.equals("B")) && FormNo.equals(FORM_26Q)) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab
			 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4318_C + tab + T_FV_4318_M); }
			 * if(currentUploadType.equals(UPLOADTYPE_REGULAR) && !(Remark1.equals("S") ||
			 * Remark1.equals("T")) && (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27Q)
			 * || FormNo.equals(FORM_27EQ))) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo +
			 * tab + CurrentDeducteeDetailRecNo + tab + T_FV_4318_C + tab + T_FV_4318_M); }
			 */
			// #############------ Added For new Validation added for remark field 1
			// --Manvendra Singh :: 13-Feb-2008
			// M06_B_ADDED
			else if (FormNo.equals(FORM_26Q)) {
				if (!isFinYrGrtrthn) {
					// FVU 5.0 by priyaT :: sectionForThisChallan.equals("2AA") point 7
					if (Remark1.equals("B") && !paperReturnFile && !Mode.equals("D") && performDDvalidation) {
						if (!(sectionForThisChallan.equals("194") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("193") || sectionForThisChallan.equals("4DA")
								|| sectionForThisChallan.equals("2AA"))) // Section
																			// code
																			// 2AA
																			// added
																			// for
																			// FVU
																			// 5.0
																			// //
																			// Section
																			// code
																			// 4DA
																			// added
																			// for
																			// fvu
																			// 4.9
						// M01_E
						{
							isValid_B = false;
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4245_C + tab + T_FV_4245_M);
						}
					}

					else if (!(sectionForThisChallan.equals("94C")) && (Remark1.equals("T")) && (!Mode.equals("D")) && performDDvalidation) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4265_C + tab + T_FV_4265_M);
					}

					else if (!(sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("194") || sectionForThisChallan.equals("94B") || sectionForThisChallan.equals("4BB") || sectionForThisChallan.equals("94C")
							|| sectionForThisChallan.equals("94D") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94G") || sectionForThisChallan.equals("94H") || sectionForThisChallan.equals("94I")
							|| sectionForThisChallan.equals("94J") || sectionForThisChallan.equals("94L") || sectionForThisChallan.equals("193") || sectionForThisChallan.equals("94K") || sectionForThisChallan.equals("94O") || sectionForThisChallan.equals("94Q")) && !Mode.equals("D") && Remark1.equals("Y"))// Changes added
																																																										// for
																																																										// CR61109_6.7_2.163_2.1295
																																																										// by puja //Test case 9 FVU 7.0 - Vinita //Changes added for 7.2_2.168_2.1300 Part 2 by Vinita
					{
						// System.out.println(sectionForThisChallan);
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4282_C + tab + T_FV_4282_M);

					}

					else if (!Remark1.equals("A") && !Remark1.equals("B") && !Remark1.equals("C") && !Remark1.equals("T") && !Remark1.equals("Y")
							&& !(Remark1.equals("S") && sectionForThisChallan.equals("94J") && Integer.parseInt(FinancialYr) >= 201213)) // Added
																																			// By
																																			// AMI
																																			// For
																																			// FVU
																																			// 3.0
																																			// Modified
																																			// on
																																			// 16/08/2012
					{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4041_C + tab + T_FV_4041_M);
					}
				} else if (isFinYrGrtrthn) {

					// FVU 5.0 by priyaT :: sectionForThisChallan.equals("2AA")
					// Added new section code for FVU 5.1
					if (Remark1.equals("B") && !paperReturnFile && !Mode.equals("D") && performDDvalidation) {
						if (!(sectionForThisDD.equals("194") || sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94A") || sectionForThisDD.equals("193") || sectionForThisDD.equals("4DA") || sectionForThisDD.equals("2AA")
								|| (sectionForThisDD.equals("4IA")) || (sectionForThisDD.equals("4IB")) || (sectionForThisDD.equals("94D")) || (sectionForThisDD.equals("94J") || ((sectionForThisDD.equals("94K")) && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) >= 0.00)))) // Section // Obs no 12 FVU 7.2 Part 2 16 Sep 2021
																																													// code
																																													// 2AA
																																													// added
																																													// for
																																													// FVU
																																													// 5.0
																																													// //
																																													// Section
																																													// code
																																													// 4DA
																																													// added
																																													// for
																																													// fvu
																																													// 4.9
																																													// //
																																													// section
																																													// code
																																													// 94D
																																													// added
																																													// for
																																													// FVU
																																													// 5.5
																																													// //Section
																																													// code
																																													// 94J
																																													// added
																																													// for
																																													// FVU
																																													// 5.6
						// M01_E
						{
							isValid_B = false;
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1 " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4245_C + tab + T_FV_4245_M);
						}
					}

					else if (!(sectionForThisDD.equals("94C")) && (Remark1.equals("T")) && (!Mode.equals("D")) && performDDvalidation) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4265_C + tab + T_FV_4265_M);
					} else if (!(sectionForThisDD.equals("94A") || sectionForThisDD.equals("194") || sectionForThisDD.equals("94B") || sectionForThisDD.equals("4BB") || sectionForThisDD.equals("94C") || sectionForThisDD.equals("94D")
							|| sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94G") || sectionForThisDD.equals("94H") || sectionForThisDD.equals("4IA") || sectionForThisDD.equals("4IB") || sectionForThisDD.equals("94J")
							|| sectionForThisDD.equals("94L") || sectionForThisDD.equals("193") || sectionForThisDD.equals("94K") || sectionForThisDD.equals("4JA") || sectionForThisDD.equals("4JB") || sectionForThisDD.equals("94O") || sectionForThisDD.equals("94Q")) && !Mode.equals("D") && Remark1.equals("Y"))// Changes added for CR61109_6.7_2.163_2.1295 by puja
																																																													  //Changes added for 6.8_2.164_2.1296 by pujafunpoint1 
																																																														//Test case 9 FVU 7.0 - Vinita //Changes added for 7.2_2.168_2.1300 Part 2 by Vinita
					{
						// System.out.println(sectionForThisChallan);
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4282_C + tab + T_FV_4282_M);

					}

					else if ((Remark1.equals("R") && sectionForThisDD.equals("94A") && Integer.parseInt(FinancialYr) < 201819)) { // added remark
																																	// R for fvu
																																	// 5.8

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4353_C + tab + T_FV_4353_M);
					}

					else if (!Remark1.equals("A") && !Remark1.equals("B") && !Remark1.equals("C") && !Remark1.equals("T") && !Remark1.equals("Y") && !Remark1.equals("Z")
							&& !(Remark1.equals("S") && sectionForThisDD.equals("94J") && Integer.parseInt(FinancialYr) >= 201213) && !(Remark1.equals("R") && sectionForThisDD.equals("94A") && Integer.parseInt(FinancialYr) >= 201819)
							&& !(Remark1.equals("N") && sectionForThisDD.equals("94N") && Integer.parseInt(FinancialYr) >= 201920) && !(Remark1.equals("S") && (sectionForThisDD.equals("4JA") || sectionForThisDD.equals("4JB")) && Integer.parseInt(FinancialYr) >= 202021) //Changes added for CR62864_6.8_2.164_2.1296  by puja
							&& !(Remark1.equals("E") && Integer.parseInt(FinancialYr) >= 202021) && !(Remark1.equals("O") && (sectionForThisDD.equals("BA1") || sectionForThisDD.equals("BA2")) && Integer.parseInt(FinancialYr) >= 202021)//Changes for CR#65617
							&& !(Remark1.equals("D") && sectionForThisDD.equals("94A") && Integer.parseInt(FinancialYr) >= 202021) //Changes for CR#65617
							&& !((Remark1.equals("M") || Remark1.equals("C")) && sectionForThisDD.equals("4NF") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))//Changes for CR#65617
							|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))))
							&& !(Remark1.equals("P") && sectionForThisDD.equals("194") && Integer.parseInt(FinancialYr) >= 202122) // Obs no 5 : Added code FVU 7.2 22 Jun 2021
							&& !(Remark1.equals("Q") && sectionForThisDD.equals("94A") && Integer.parseInt(FinancialYr) >= 202122)
							&& !((Remark1.equals("U") && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) > 0.00) && !(sectionForThisDD.equals("2AA") || sectionForThisDD.equals("94B") || sectionForThisDD.equals("4BB") || sectionForThisDD.equals("LBC") || sectionForThisDD.equals("94N") || sectionForThisDD.equals("4NF")) && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || Integer.parseInt(FinancialYr) > 202122)) // Requirement update FVU 7.2 Part 2 18 Sep 2021 // Remove PAN condition FVU 7.2 21 Sep 2021 //change 92A to 2AA FVU 7.2 21 Sep 2021
							&& !((Remark1.equals("S") && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) >= 0.00) && (sectionForThisDD.equals("94Q")) && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || Integer.parseInt(FinancialYr) > 202122))){ 
						// Obs no 10 11 FVU 7.2 Part 2 16 Sep 2021
						//Changes added for 7.2_2.168_2.1300 Part 2 by Vinita : Start // Obs no 5 FVU 7.2 Part 2 16 Sep 2021 (close Bracket issue)
					//{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
					}
					
					// Obs no 5 : Commented code FVU 7.2 22 Jun 2021
					/*// Condition added for form 26Q Remarks 'P' and 'Q' FVU 7.2 by Vinita : Start
					else if (!(Remark1.equals("P") && sectionForThisDD.equals("P") && Integer.parseInt(FinancialYr) >= 202122) 
							&& !(Remark1.equals("Q") && sectionForThisDD.equals("94A") && Integer.parseInt(FinancialYr) >= 202122)){
						
					//{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
					}
					// Condition added for form 26Q Remarks 'P' and 'Q' FVU 7.2 by Vinita : End
*/
					// Added by priyanka for FVU 5.1
					
					else if (((sectionForThisDD.equals("LBB")) || (sectionForThisDD.equals("LBC"))) && !(Remark1.equals("A") || Remark1.equals("C") || Remark1.equals("Z") || Remark1.equals("E") || Remark1.equals("U"))) {//CR 65617. ObservationNo.16_250920 // Observation FVU 7.2 21 Sep 2021
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
					}
					// End

					if ((sectionForThisDD.equals("94D") || sectionForThisDD.equals("94J")) && (Integer.parseInt(FinancialYr) < 201718) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))
							&& Remark1.equals("B")) { // added
														// for
														// FVU
														// 5.5
														// //Adde
														// 94J
														// for
														// FVU
														// 5.6

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1  " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4349_C + tab + T_FV_4349_M);
					}

				}
			} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27Q)) {

				// Added by priyanka for FVU 5.1
				if (FormNo.equals(FORM_27Q) && ((sectionForThisDD.equals("LBB")) || (sectionForThisDD.equals("LBC"))) && (!(Remark1.equals("A") || Remark1.equals("C") || Remark1.equals("G") || Remark1.equals("J")))) {//CR 65617. ObservationNo.17_250920 // Obs no 8 FVU 7.2 Part 2 16 Sep 2021
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1 " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
				}
				// End
				else if (!isFinYrGrtrthn && !Remark1.equals("A") && !Remark1.equals("C") && !Remark1.equals("B")
						&& !(Remark1.equals("S") && sectionForThisChallan.equals("195") && Integer.parseInt(FinancialYr) >= 201213 && FormNo.equals(FORM_27Q))
						&& !(Remark1.equals("N") && SectionCode.equals("94N") && Integer.parseInt(FinancialYr) >= 201920 && FormNo.equals(FORM_27Q)))// Changes
																																						// added for
																																						// 6.6_2.162_2.1294
																																						// by Puja
				{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4280_C + tab + T_FV_4280_M);
				} else if (isFinYrGrtrthn && !Remark1.equals("A") && !Remark1.equals("C") && !Remark1.equals("B") && !(Remark1.equals("S") && sectionForThisDD.equals("195") && Integer.parseInt(FinancialYr) >= 201213 && FormNo.equals(FORM_27Q))
						&& !(Remark1.equals("N") && SectionCode.equals("94N") && Integer.parseInt(FinancialYr) >= 201920 && FormNo.equals(FORM_27Q))// Changes
																																					// added for
																																					// 6.6_2.162_2.1294
																																					// by Puja
						&& !(Remark1.equals("O") && (sectionForThisDD.equals("BA1") || sectionForThisDD.equals("BA2")) && Integer.parseInt(FinancialYr) >= 202021 && FormNo.equals(FORM_27Q))//Changes for CR#65617
						&& !(Remark1.equals("G") && (sectionForThisDD.equals("BA1") || sectionForThisDD.equals("BA2") || sectionForThisDD.equals("BA3")) && Integer.parseInt(FinancialYr) >= 202021 && FormNo.equals(FORM_27Q))//Changes for CR#65617
						&& !((Remark1.equals("M") || Remark1.equals("C") || Remark1.equals("G")) && sectionForThisDD.equals("4NF") && FormNo.equals(FORM_27Q) && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))//Changes for CR#65617
								|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))))//Changes for CR#65617
						&& !(Remark1.equals("G") && Integer.parseInt(FinancialYr) >= 202021 && FormNo.equals(FORM_27Q))	//CR 65617. ObservationNo.17_250920
						&& !((Remark1.equals("G") || Remark1.equals("I")) && sectionForThisDD.equals("96D") && (Integer.parseInt(FinancialYr) >= 202122) && FormNo.equals(FORM_27Q))
						&& !((Remark1.equals("G") || Remark1.equals("I") || Remark1.equals("H")) && sectionForThisDD.equals("6DA") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 ))
								 && FormNo.equals(FORM_27Q))
								 //Bracket issue check properly in remarks J // Requirement update FVU 7.2 Part 2 18 Sep 2021
						&& !((Remark1.equals("J") && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) > 0.00) && !(sectionForThisDD.equals("2AA") || sectionForThisDD.equals("LBC") || sectionForThisDD.equals("94N") || sectionForThisDD.equals("4NF")) && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202122 )) // Remove PAN condition FVU 7.2 21 Sep 2021 //change 92A to 2AA FVU 7.2 21 Sep 2021
								 && FormNo.equals(FORM_27Q))) // Obs no 1 FVU 7.2 21 Jun 2021 //Changes added for 7.2_2.168_2.1300 Part 2 by Vinita : Start
				{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4280_C + tab + T_FV_4280_M);
				}
			
				//Comment this code FVU 7.2 by Vinita 21 Jun 2021
			/*	// Changed added for FVU 7.2 for remarks 'I', 'H' for form 27Q, 'P','Q' for form 26Qby Vinita - Start			
				else if (isFinYrGrtrthn 
						&& !((Remark1.equals("G") || Remark1.equals("I")) && sectionForThisDD.equals("96D") && (Integer.parseInt(FinancialYr) >= 202122) && FormNo.equals(FORM_27Q))
						&& !((Remark1.equals("G") || Remark1.equals("I") || Remark1.equals("H")) && sectionForThisDD.equals("6DA") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 ))
								 && FormNo.equals(FORM_27Q))
						)
				{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4280_C + tab + T_FV_4280_M);
				}
				
				// Changed added for FVU 7.2 for remarks by Vinita - End
*/					
				
			} else if (FormNo.equals(FORM_27EQ)) {
				// Added by priyanka for FVU 5.1
				if (((sectionForThisDD.equals("L")) || (sectionForThisDD.equals("M")) || (sectionForThisDD.equals("N"))) && (!(Remark1.equals("A"))) && !(Remark1.equals("C") && Integer.parseInt(FinancialYr) >= 201718
						&& (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))
						&& !(Remark1.equals("I") && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || Integer.parseInt(FinancialYr) > 202122)
								 && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) // FVU 5.6 // Observation FVU 7.2 21 Sep 2021
				{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
				}
				// End
				// else if(!Remark1.equals("A") && !Remark1.equals("B") && !(Remark1.equals("C")
				// && SectionCode.equals("C") && Integer.parseInt(FinancialYr) >= 201718 &&
				// (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) ||
				// EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR)
				// ||UploadType.equals(UPLOADTYPE_CORRECTION) )) ) //added for FVU 5.5
				else if (!Remark1.equals("A") && !Remark1.equals("B") && !(Remark1.equals("C") && Integer.parseInt(FinancialYr) >= 201718
						&& (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))
						&& !((Remark1.equals("E") || Remark1.equals("F")) && (sectionForThisDD.equals("O") || sectionForThisDD.equals("P")) && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))
						&& !((Remark1.equals("E") || Remark1.equals("F") || Remark1.equals("D")) && (sectionForThisDD.equals("Q")) && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))
						&& !((Remark1.equals("G") || Remark1.equals("H")) && sectionForThisDD.equals("R") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))
						// Requirement update FVU 7.2 Part 2 18 Sep 2021
						&& !((Remark1.equals("I") && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) > 0.00)  && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202122)) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) // added for FVU 5.5.// Remove PAN condition FVU 7.2 21 Sep 2021
																																																									// FVU 5.6 // Test Case 9 Obs no 11 FVU 7.0 - Vinita    //Changes added for 7.2_2.168_2.1300 Part 2 by Vinita    
				{
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4281_C + tab + T_FV_4281_M);
				}
			
			}
			// M06_B
			if (Remark1.equals("C")) {
				// Changes done for FVU 3.0 new changes
				// cntTaxDeductedAtHighRate++;
				if (FormNo.equals(FORM_27EQ)) {
					// commented by Dhanya on 28/02/2011 as this code is included above for the
					// change M06.
					// Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab
					// + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					// T_FV_4041_C + tab + T_FV_4041_M);
				} else
					cntTaxDeductedAtHighRate++;

				// Changes done for FVU 3.0 new changes
				if (!FormNo.equals(FORM_27EQ)) {

					if (Mode.equals("D"))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4272_C + tab + T_FV_4272_M);
					// Added by Abhishek
					// added for FVU 5.5
					if (Mode.equals("U") && isStructurallyValidPan == false && validLastTotalIncomeTaxDeductedAtSource && !FormNo.equals(FORM_27Q)
							&& (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != Double.parseDouble(LastTotalIncomeTaxDeductedAtSource.trim())))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4274_C + tab + T_FV_4274_M);
					if (Mode.equals("U") && isStructurallyValidPan == false && validLastTotalIncomeTaxDeductedAtSource && FormNo.equals(FORM_27Q)
							&& (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != Double.parseDouble(LastTotalIncomeTaxDeductedAtSource.trim())))
						obj_StringBuffer
								.appendElectronicWarning(LineNo + tab + "Deductee" + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_3174_C + tab + T_FV_3174_M);

					// Commented for FVU 4.6
					/*
					 * if (Mode.equals("U") && isStructurallyValidPan == false &&
					 * errorLastTotalTaxDeposited && (Double.parseDouble(TotalTaxDeposited.trim())
					 * != Double.parseDouble(LastTotalTaxDeposited.trim())))
					 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab
					 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
					 * T_FV_4273_C + tab + T_FV_4273_M);
					 */
					// End
					// Added by Abhishek on 19/12/2011
					if (!obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4) && Double.parseDouble(RateAtWhichTaxDeducted.trim()) < 20 && !Mode.equals("D")) {
						if (!(FormNo.equals(FORM_27Q) && SectionCode.equals("4LC") && isFinYrGrtr && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
								&& obj_FieldValidation.isDateGreaterThanOldJune(DateOnWhichAmountPaid))) // Added
																											// for
																											// FVU
																											// 4.7
							Str_Buffer.appendElectronicWarning(LineNo + tab + "Deductee" + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_4298_C + tab + T_FV_4298_M);
					}
					// End
				}

				// Added for FVU 4.4 by Shalin
				if (isStructurallyValidPan == true && (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("A")))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4323_C + tab + T_FV_4323_M);
				}
			}

			if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_BATCH) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_CHALLAN) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_SALARY) && !FormNo.equals(FORM_27EQ)) // Changes
																																																										// For
																																																										// FVU
																																																										// 3.0
																																																										// new
																																																										// changes
				receiptCntTaxDeductedAtHighRate = Integer.toString(cntTaxDeductedAtHighRate);

			// Commented by Dhanya for FVU 3.2 on 05/04/2011
			// M06_B_ADDED
			/*
			 * if (Remark1.equals("Y") && !Mode.equals("D") && FormNo.equals(FORM_26Q) &&
			 * (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)||UploadTypeDD.
			 * equals(UPLOADTYPE_REGULAR)||TransactionType.equals(
			 * TRANSACTIONTYPE_ADDITION_CHALLAN))) {
			 * 
			 * /*if(!obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource) &&
			 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != 0) {
			 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
			 * "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo +
			 * tab + CurrentDeducteeDetailRecNo + tab + T_FV_4285_C + tab + T_FV_4285_M); }
			 * if(!obj_FieldValidation.isDecimalNumber(TotalTaxDeposited) &&
			 * Double.parseDouble(TotalTaxDeposited.trim()) != 0) { Str_Buffer.append(LineNo
			 * + tab + currentUploadType + tab + "Total Tax Deposited " + tab +
			 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4286_C + tab + T_FV_4286_M ); }
			 */
			/*
			 * if(!obj_FieldValidation.isDecimalNumber(TDSIncomeTaxDD) &&
			 * Double.parseDouble(TDSIncomeTaxDD.trim()) != 0) { Str_Buffer.append(LineNo +
			 * tab + currentUploadType + tab + "TDS / TCS -Income Tax for the period " + tab
			 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4289_C + tab + T_FV_4289_M); }
			 * if(!obj_FieldValidation.isDecimalNumber(TDSSurchargeDD) &&
			 * Double.parseDouble(TDSSurchargeDD.trim()) != 0) { Str_Buffer.append(LineNo +
			 * tab + currentUploadType + tab + "TDS / TCS -Surcharge  for the period " + tab
			 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4283_C + tab + T_FV_4283_M); }
			 * /*if(!DateOnWhichTaxDeducted.equals(FIELD_NULL) &&
			 * !DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR)) { Str_Buffer.append(LineNo +
			 * tab + currentUploadType + tab + "Date on which tax Deducted / Collected" +
			 * tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4287_C + tab + T_FV_4287_M); }
			 */
			/*
			 * if(!obj_FieldValidation.isDecimalNumber(TDSCessDD) &&
			 * Double.parseDouble(TDSCessDD.trim()) != 0) { Str_Buffer.append(LineNo + tab +
			 * currentUploadType + tab + "TDS / TCS -Cess" + tab +
			 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
			 * T_FV_4284_C + tab + T_FV_4284_M); }
			 * 
			 * }
			 */

			// M06_E
			// Added By Abhishek on 03/03/2011 for addition change of PAN not
			// in(PANNOTAVBL,PANAPPLIED,PANINVALID) for remark1 as Y
			if (Remark1.equals("Y") && !Mode.equals("D") && !isStructurallyValidPan
					&& (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4295_C + tab + T_FV_4295_M);
			}
			// End by Abhishek

			// Added for FVU 3.8 by Shalin

			if (isFinYrGrtrthn && Remark1.equals("Z") && !Mode.equals("D") && !isStructurallyValidPan) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4305_C + tab + T_FV_4305_M);
			}

			// Added by Dhanya on 31/03/2011 for FVU 3.2
			if (!isFinYrGrtrthn && Remark1.equals("Y") && !Mode.equals("D") && FormNo.equals(FORM_26Q)
					&& (sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("194") || sectionForThisChallan.equals("94B") || sectionForThisChallan.equals("4BB") || sectionForThisChallan.equals("94C")
							|| sectionForThisChallan.equals("94D") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94G") || sectionForThisChallan.equals("94H") || sectionForThisChallan.equals("94I")
							|| sectionForThisChallan.equals("94J") || sectionForThisChallan.equals("94L") || sectionForThisChallan.equals("193"))
					&& (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
				if (!obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource) && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != 0 && !obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4)
						&& Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4292_C + tab + T_FV_4292_M);
				}
			}

			else if (isFinYrGrtrthn && Remark1.equals("Y") && !Mode.equals("D") && FormNo.equals(FORM_26Q)
					&& (sectionForThisDD.equals("94A") || sectionForThisDD.equals("194") || sectionForThisDD.equals("94B") || sectionForThisDD.equals("4BB") || sectionForThisDD.equals("94C") || sectionForThisDD.equals("94D")
							|| sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94G") || sectionForThisDD.equals("94H") || sectionForThisDD.equals("4IA") || sectionForThisDD.equals("4IB") || sectionForThisDD.equals("94J")
							|| sectionForThisDD.equals("94L") || sectionForThisDD.equals("193") || sectionForThisDD.equals("4JA") || sectionForThisDD.equals("4JB"))// Changes added
																																										// for
																																										// 6.8_2.164_2.1296
																																										// by
																																										// puja_funPoint1
					&& (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {// Changes added for
																																																// 6.8_2.164_2.1296 by
																																																// pujafuncpoint1
				if (!obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource) && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != 0 && !obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4)
						&& Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4292_C + tab + T_FV_4292_M);
				}
			}
			// Ends Addition by Dhanya on 31/03/2011 for FVU 3.2
			//Changes added for FVU 7.4_2.170_2.1302 31stDec2021 by kiran
			if(Mode.equals("U")  && validLastTotalIncomeTaxDeductedAtSource && 
					(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) != Double.parseDouble(LastTotalIncomeTaxDeductedAtSource.trim())))		
			{
				if((FormNo.equals(FORM_26Q) && Remark1.equals("U"))
				|| (FormNo.equals(FORM_27Q) && Remark1.equals("J")) || (FormNo.equals(FORM_27EQ) && Remark1.equals("I")))
				 {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4274_C + tab + T_FV_4274_M);
				 }
			}	
			

		} // closes if (!Remark1.equals(FIELD_NULL) && !Remark1.equals(FIELD_SEPERATOR))
		else if (!isFinYrGrtrthn && !Mode.equals("D") && FormNo.equals(FORM_26Q) && !(!Remark1.equals(FIELD_NULL) && !Remark1.equals(FIELD_SEPERATOR))
				&& (sectionForThisChallan.equals("94A") || sectionForThisChallan.equals("194") || sectionForThisChallan.equals("94B") || sectionForThisChallan.equals("4BB") || sectionForThisChallan.equals("94C")
						|| sectionForThisChallan.equals("94D") || sectionForThisChallan.equals("4EE") || sectionForThisChallan.equals("94G") || sectionForThisChallan.equals("94H") || sectionForThisChallan.equals("94I")
						|| sectionForThisChallan.equals("94J") || sectionForThisChallan.equals("94L") || sectionForThisChallan.equals("193") || sectionForThisChallan.equals("4JA") || sectionForThisChallan.equals("4JB"))// Changes added for
																																																								// 6.8_2.164_2.1296 by
																																																								// puja_funPoint1
				&& (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
			if (!RateAtWhichTaxDeducted.equals(FIELD_NULL) && !RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR) && !obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4) && !obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource)
					&& !obj_FieldValidation.isDecimalNumber(TotalTaxDeposited)) {
				// commented for FVU 3.2 by Dhanya on 11/04/2011
				/*
				 * if(Double.parseDouble(RateAtWhichTaxDeducted.trim())== 0 &&
				 * Double.parseDouble(TotalTaxDeposited.trim()) == 0 &&
				 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) ==0)
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1 " + tab
				 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
				 * T_FV_4291_C + tab + T_FV_4291_M);
				 * 
				 * /* commented by Dhanya on 31/03/2011 for FVU 3.2 as deposit amount can be > 0
				 * even if TDS deducted is Zero else
				 * if(Double.parseDouble(RateAtWhichTaxDeducted.trim())== 0 &&
				 * Double.parseDouble(TotalTaxDeposited.trim()) != 0 &&
				 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) ==0)
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
				 * "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab +
				 * CurrentDeducteeDetailRecNo + tab + T_FV_4294_C + tab + T_FV_4294_M);
				 */

				/*
				 * else if(Double.parseDouble(RateAtWhichTaxDeducted.trim())== 0 &&
				 * Double.parseDouble(TotalTaxDeposited.trim()) != 0 &&
				 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) !=0)
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
				 * "Total Income Tax Deducted at Source " + tab + CurrentchallanDetailRecordNo +
				 * tab + CurrentDeducteeDetailRecNo + tab + T_FV_4296_C + tab + T_FV_4296_M);
				 */

				if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0 && Double.parseDouble(TotalTaxDeposited.trim()) != 0 && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0 && flgForThreshold == 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4296_C + tab + T_FV_4296_M);

				else if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0 && Double.parseDouble(TotalTaxDeposited.trim()) == 0 && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0 && flgForThreshold == 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4297_C + tab + T_FV_4297_M);

			}
		} else if (isFinYrGrtrthn && !Mode.equals("D") && FormNo.equals(FORM_26Q) && !(!Remark1.equals(FIELD_NULL) && !Remark1.equals(FIELD_SEPERATOR))
				&& (sectionForThisDD.equals("94A") || sectionForThisDD.equals("194") || sectionForThisDD.equals("94B") || sectionForThisDD.equals("4BB") || sectionForThisDD.equals("94C") || sectionForThisDD.equals("94D")
						|| sectionForThisDD.equals("4EE") || sectionForThisDD.equals("94G") || sectionForThisDD.equals("94H") || sectionForThisDD.equals("4IA") || sectionForThisDD.equals("4IB") || sectionForThisDD.equals("94J")
						|| sectionForThisDD.equals("94L") || sectionForThisDD.equals("193"))
				&& (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))) {
			if (!RateAtWhichTaxDeducted.equals(FIELD_NULL) && !RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR) && !obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4) && !obj_FieldValidation.isDecimalNumber(TotalIncomeTaxDeductedAtSource)
					&& !obj_FieldValidation.isDecimalNumber(TotalTaxDeposited)) {
				// commented for FVU 3.2 by Dhanya on 11/04/2011
				/*
				 * if(Double.parseDouble(RateAtWhichTaxDeducted.trim())== 0 &&
				 * Double.parseDouble(TotalTaxDeposited.trim()) == 0 &&
				 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) ==0)
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1 " + tab
				 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
				 * T_FV_4291_C + tab + T_FV_4291_M);
				 * 
				 * /* commented by Dhanya on 31/03/2011 for FVU 3.2 as deposit amount can be > 0
				 * even if TDS deducted is Zero else
				 * if(Double.parseDouble(RateAtWhichTaxDeducted.trim())== 0 &&
				 * Double.parseDouble(TotalTaxDeposited.trim()) != 0 &&
				 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) ==0)
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
				 * "Total Tax Deposited " + tab + CurrentchallanDetailRecordNo + tab +
				 * CurrentDeducteeDetailRecNo + tab + T_FV_4294_C + tab + T_FV_4294_M);
				 */

				/*
				 * else if(Double.parseDouble(RateAtWhichTaxDeducted.trim())== 0 &&
				 * Double.parseDouble(TotalTaxDeposited.trim()) != 0 &&
				 * Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) !=0)
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
				 * "Total Income Tax Deducted at Source " + tab + CurrentchallanDetailRecordNo +
				 * tab + CurrentDeducteeDetailRecNo + tab + T_FV_4296_C + tab + T_FV_4296_M);
				 */

				if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0 && Double.parseDouble(TotalTaxDeposited.trim()) != 0 && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0 && flgForThreshold == 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4296_C + tab + T_FV_4296_M);

				else if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0 && Double.parseDouble(TotalTaxDeposited.trim()) == 0 && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0 && flgForThreshold == 0)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4297_C + tab + T_FV_4297_M);

			}
		}
		// Added for FVU 4.0
		if ((UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
				&& NillChallanIndicator.equals("Y") && !sectionForThisDD.equals("94P") && (Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR))) {
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4320_C + tab + T_FV_4320_M);
		}

		// Start :: Priya :: Added validation for FVU 5.0 point 13 ::To Genareate
		// warning File for Remark C for Form 27Q

		if (Remark1.equals("C") && Mode.equals("U") && FormNo.equals(FORM_27Q) && UploadTypeDD.equals(UPLOADTYPE_CORRECTION) && (Integer.parseInt(FinancialYr) >= 201314)) {
			obj_StringBuffer.appendElectronicWarning(LineNo + tab + "Deductee" + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + "NA" + tab + "NA" + tab + "NA" + tab + T_FV_3174_C + tab + T_FV_3174_M);
		}

		
		return isValid_B;
	}

		/**
		 * @param TransactionType
		 * @param Str_Buffer
		 * @param LineNo
		 * @param DD_BatchNo
		 * @param ChallanRecordNo
		 * @param DeducteeDetailRecNo
		 * @param LastEmployeePan
		 * @param EmployeePan
		 */
		private void validateEmployeePan(String TransactionType,
				StringBufferTemp Str_Buffer, String LineNo, String DD_BatchNo,
				String ChallanRecordNo, String DeducteeDetailRecNo,
				String LastEmployeePan, String EmployeePan) {
			String cRec = null;
			String dRec = null;
			String pan = null;
			if (Integer.parseInt(DD_BatchNo) == 1 && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				String finalStr = ChallanRecordNo + "-" + DeducteeDetailRecNo + "-" + EmployeePan;
				deducteePanDeatil.add(finalStr);
				chk_C5 = 1;
			}

			else {
				if (chk_C5 == 1 && Integer.parseInt(DD_BatchNo) > 1 && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
					for (int i = 0; i < deducteePanDeatil.size(); i++) {
						String temp = deducteePanDeatil.get(i).toString();
						StringTokenizer st = new StringTokenizer(temp, "-");

						int k = 0;
						while (st.hasMoreTokens()) {
							String val = st.nextToken();

							if (k == 0)
								cRec = val;
							else if (k == 1)
								dRec = val;
							else
								pan = val;
							k++;
						}

						if (cRec.equals(ChallanRecordNo) && dRec.equals(DeducteeDetailRecNo)) {
							if (!(pan.equals(EmployeePan) && pan.equals(LastEmployeePan))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last  Employee/Party PAN Ref. No.111" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4331_C + tab + T_FV_4331_M);
							}
						}

					}
				}
			}
		}

	private void validateEmployeeName(String BH_BatchNo, String ChallanDetailRecordNo, String TransactionType, StringBufferTemp Str_Buffer, String LineNo, String DeducteeDetailRecNo, String EmployeeName, FieldValidation obj_FieldValidation) {
		if (EmployeeName.equals(FIELD_NULL) || EmployeeName.equals(FIELD_SEPERATOR) || EmployeeName.trim().length() == 0) {
			if (!Mode.equals("D") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				if (paperReturnFile) {
					paperReturnRelax = true;
					Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4012_C + tab + T_FV_4012_M);
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employee / Party" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4012_C + tab + T_FV_4012_M);
			}
		} else {
			if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employee / Party" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4186_C + tab + T_FV_4186_M);
			else if (EmployeeName.length() <= 75) {
				if (obj_FieldValidation.isValidCharString(EmployeeName)) { /*
																			 * if (paperReturnFile) { Str_Buffer.appendPaperWarning(LineNo + tab +
																			 * BH_BatchNo + tab + CurrentchallanDetailRecordNo + tab +
																			 * CurrentDeducteeDetailRecNo + tab + T_FV_4012_C + tab + T_FV_4012_M); } else
																			 */
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employee / Party" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4012_C + tab + T_FV_4012_M);
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Name of Employee / Party" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4012_C + tab + T_FV_4012_M);
		}
	}

	private void validateEmployeePanRefNo(String TransactionType, StringBufferTemp Str_Buffer, String LineNo, String LastEmployeePanRefNo, String EmployeePanRefNo, FieldValidation obj_FieldValidation) {
		if (FormNo.equals(FORM_24Q)) {
			if (EmployeePanRefNo.equals(FIELD_NULL) || EmployeePanRefNo.equals(FIELD_SEPERATOR)) {
				// M04_B commented as per the revised requirement. as the validation should be
				// same as that of FVU2.128
				/*
				 * if ( Mode.equals("D") && !LastEmployeePanRefNo.equals(FIELD_NULL) &&
				 * !LastEmployeePanRefNo.equals(FIELD_SEPERATOR)) { Str_Buffer.append(LineNo +
				 * tab + currentUploadType + tab + "Employee/Party PAN Ref. No." + tab +
				 * CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
				 * T_FV_4290_C + tab + T_FV_4290_M); }
				 */
				// M04_E
			} else {

				// M04_B
				// Commented for change M04 PAN Refernece No is allowed for Correction and
				// Regular statements
				/*
				 * //Added By AMI For FVU 3.0 if(UploadType.equals(UPLOADTYPE_REGULAR))
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab +
				 * "Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab +
				 * CurrentDeducteeDetailRecNo + tab + T_FV_4134_C + tab + T_FV_4134_M); //END
				 * 
				 */
				// M04_E

				if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4134_C + tab + T_FV_4134_M);

				else if (Mode.equals("D") && !LastEmployeePanRefNo.equals(EmployeePanRefNo)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4185_C + tab + T_FV_4185_M);
				}

				else if (EmployeePanRefNo.length() == 10 && EmployeePanRefNo.trim().length() == 10) {
					if (obj_FieldValidation.isAlphaNum(EmployeePanRefNo))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4010_C + tab + T_FV_4010_M);
					/*
					 * else if(!valueForPanRefNo) commented by Dhanya on 18/02/2011 as the PAN Ref
					 * No check should be same as that of FVU 2.128. valueForPanRefNo = true;
					 */
				}
				// //Added by Abhishek
				// else if(UploadType.equals(UPLOADTYPE_CORRECTION) &&
				// (EmployeePanRefNo.trim().equals(FIELD_NULL) ||
				// EmployeePanRefNo.trim().equals(FIELD_SEPERATOR)) )
				// {}
				// //END
				else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4010_C + tab + T_FV_4010_M);
			} // Validating EmployeePanRefNo
		}
	}

	private void validateLastEmployeePanRefNo(String TransactionType, String UploadTypeDD, StringBufferTemp Str_Buffer, String LineNo, String LastEmployeePanRefNo, FieldValidation obj_FieldValidation) {
		if (LastEmployeePanRefNo.equals(FIELD_NULL) || LastEmployeePanRefNo.equals(FIELD_SEPERATOR)) {
		} else {
			if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last  Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4133_C + tab + T_FV_4133_M);
			else if (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || Mode.equals("A"))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last  Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4063_C + tab + T_FV_4063_M);
			else if (LastEmployeePanRefNo.length() == 10 && LastEmployeePanRefNo.trim().length() == 10) {
				if (obj_FieldValidation.isAlphaNum(LastEmployeePanRefNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last  Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4062_C + tab + T_FV_4062_M);
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last  Employee/Party PAN Ref. No." + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4062_C + tab + T_FV_4062_M);
		}
	}

	private boolean validateLastEmployeePan(String TransactionType, String UploadTypeDD, StringBufferTemp Str_Buffer, String LineNo, String LastEmployeePan, String EmployeePan, FieldValidation obj_FieldValidation) {
		boolean validLastEmpPANStructure = false;
		if (LastEmployeePan.equals(FIELD_NULL) || LastEmployeePan.equals(FIELD_SEPERATOR)) {
			if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) { /* Last Employee PAN Must be NULL for Transaction type C5 */
			} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && !Mode.equals("A") && (!EmployeePan.equals(FIELD_NULL) && !EmployeePan.equals(FIELD_SEPERATOR)))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4061_C + tab + T_FV_4061_M);
		} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4132_C + tab + T_FV_4132_M);
		} else if (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) || Mode.equals("A"))
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4060_C + tab + T_FV_4060_M);
		else if (LastEmployeePan.length() > 10)
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4059_C + tab + T_FV_4059_M);
		else if (!LastEmployeePan.equals(PAN_NOT_AVAILABLE) && !LastEmployeePan.equals(PAN_APPLIED) && !LastEmployeePan.equals(PAN_INVALID)) {
			if ((LastEmployeePan.length() == 10) && (LastEmployeePan.trim().length() == 10)) {
				if (obj_FieldValidation.checkPan(LastEmployeePan))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4059_C + tab + T_FV_4059_M);
				else
					validLastEmpPANStructure = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Last Employee / Party  PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4059_C + tab + T_FV_4059_M);
		}
		return validLastEmpPANStructure;
	}

	private void validateDeducteeCode(String BH_BatchNo, String ChallanDetailRecordNo, String TransactionType, StringBufferTemp Str_Buffer, String LineNo, String DeducteeDetailRecNo, String DeducteeCode) {
		if (FormNo.equals(FORM_24Q)) {
			if (!DeducteeCode.equals(FIELD_NULL) && !DeducteeCode.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4058_C + tab + T_FV_4058_M);
		} else {
			if (DeducteeCode.equals(FIELD_NULL) || DeducteeCode.equals(FIELD_SEPERATOR)) {
				if (!Mode.equals("D") && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
					if (paperReturnFile) {
						paperReturnRelax = true;
						Str_Buffer.appendPaperWarning(LineNo + tab + BH_BatchNo + tab + ChallanDetailRecordNo + tab + DeducteeDetailRecNo + tab + T_FV_4057_C + tab + T_FV_4057_M);
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4057_C + tab + T_FV_4057_M);
				}
			} else {
				if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4183_C + tab + T_FV_4183_M);
				else if (!(DeducteeCode.equals("1")) && !(DeducteeCode.equals("2")))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4056_C + tab + T_FV_4056_M);
			}
		}
	}

	private void validateEmployeeSerialNo(String TransactionType, String Qperiod, String UploadTypeDD, StringBufferTemp Str_Buffer, String LineNo, String EmployeeSerialNo, String EmployeePan, FieldValidation obj_FieldValidation) {
		if (EmployeeSerialNo.equals(FIELD_NULL) || EmployeeSerialNo.equals(FIELD_SEPERATOR)) {
			if (FormNo.equals(FORM_24Q) && Qperiod.equals("Q4") && UploadTypeDD.equals(UPLOADTYPE_REGULAR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee Reference No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4033_C + tab + T_FV_4033_M);
			}
			// Amit cholia added here For FVU 4.4
			if ((EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && FormNo.equals(FORM_24Q) && (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || (UploadType.equals(UPLOADTYPE_CORRECTION)
					&& ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Mode.equals("A") || Mode.equals("U"))) || (TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN) && Mode.equals("O")))))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee Reference No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4325_C + tab + T_FV_4325_M);
			}

		} else {
			if (FormNo.equals(FORM_26Q) || FormNo.equals(FORM_27Q) || FormNo.equals(FORM_27EQ)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee Reference No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4055_C + tab + T_FV_4055_M);
			} else if (Mode.equals("D") || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee Reference No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4182_C + tab + T_FV_4182_M);
			} else {
				if (EmployeeSerialNo.length() <= 9) {
					if (obj_FieldValidation.isInt(EmployeeSerialNo))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee Reference No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4325_C + tab + T_FV_4325_M);
					else if (Integer.parseInt(EmployeeSerialNo.trim()) == 0)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee Reference No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4325_C + tab + T_FV_4325_M);
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee Reference No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4325_C + tab + T_FV_4325_M);
			}
		}
	}

	private void validateMode(String TransactionType, String UploadTypeDD, StringBufferTemp Str_Buffer, String LineNo, String DeducteeDetailRecNo, FieldValidation obj_FieldValidation) {
		if (Mode.equals(FIELD_NULL) || Mode.equals(FIELD_SEPERATOR)) {
			if (!TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4052_C + tab + T_FV_4052_M);
				isModeValid = false;
			}
		} else {

			// Added by Shalin for FVU 4.1

			if (Mode.equals("D") && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6049_C + tab + T_FV_6049_M);
			}
			// M01_B -- validating section!=null for c3
			if (!isFinYrGrtrthn && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (sectionForThisChallan.equals(FIELD_NULL) || sectionForThisChallan.equals(FIELD_SEPERATOR))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6041_C + tab + T_FV_6041_M);
			}
			if (isFinYrGrtrthn && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && !Mode.equals("D")) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
					&& (sectionForThisDD.equals(FIELD_NULL) || sectionForThisDD.equals(FIELD_SEPERATOR))) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6041_C + tab + T_FV_6041_M);
			}
			// M01_E

			if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !Mode.equals("F")) // && mode ==F condition
																								// added by shruti
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4211_C + tab + T_FV_4211_M);
				isModeValid = false;
			} else if (!Mode.equals("A") && !Mode.equals("U") && !Mode.equals("D") && !Mode.equals("O") && !Mode.equals("F")) // && mode ==F condition
																																// added by shruti
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4052_C + tab + T_FV_4052_M);
				isModeValid = false;
			} else if (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
				if (!(Mode.equals("O"))) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4053_C + tab + T_FV_4053_M);
					isModeValid = false;
				} else if (!DeducteeDetailRecNo.equals(FIELD_NULL) && !DeducteeDetailRecNo.equals(FIELD_SEPERATOR) && !obj_FieldValidation.isInt(DeducteeDetailRecNo))
					receiptLastDDNumber = Integer.toString(Integer.parseInt(DeducteeDetailRecNo.trim()));
			} else if (Mode.equals("O")) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4054_C + tab + T_FV_4054_M);
				isModeValid = false;
			} else if ((deducteeDetailAddMode == true) && !Mode.equals("A")) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4172_C + tab + T_FV_4172_M);
				isModeValid = false;
			} else if (Mode.equals("A")) {
				deducteeDetailAddMode = true;
				receiptLastDDNumber = Integer.toString(prevDeducteeRecCount);
			} else if (Mode.equals("F") && FormNo.equals(FORM_27Q)) // && mode ==F condition added by shruti
			{
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Mode" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4052_C + tab + T_FV_4052_M);
				isModeValid = false;
			}

		}
	}

	/**
	 * @param TransactionType
	 * @param Qperiod
	 * @param FinancialYr
	 * @param Str_Buffer
	 * @param LineNo
	 * @param EmployeePan
	 * @param TotalIncomeTaxDeductedAtSource
	 * @param AmountOfPayment
	 * @param DateOnWhichAmountPaid
	 * @param Remark1
	 * @param SectionCode
	 * @param obj_FieldValidation
	 */
	// Changes added for 6.8_2.164_2.1296 by puja_funPoint3
	private void validateSectionCode(String TransactionType, String Qperiod, String FinancialYr, StringBufferTemp Str_Buffer, String LineNo, String EmployeePan, String TotalIncomeTaxDeductedAtSource, String AmountOfPayment,
			String DateOnWhichAmountPaid, String Remark1, String SectionCode, FieldValidation obj_FieldValidation, String RateAtWhichTaxDeducted, String DateOnWhichTaxDeducted, String amtOfCashWithIn194N, String DeducteeEmailId, String DeducteeContactNo, String DeducteeAddress, String TaxIdentificationNo, String natureOfRemittance) {
		if (isFinYrGrtrthn) {
			if (UploadType.equals(UPLOADTYPE_CORRECTION) && (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("D")))) {
				if (!(SectionCode.equals(FIELD_NULL) || SectionCode.equals(FIELD_SEPERATOR)))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Section Code'" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);

			}

			else if (SectionCode.equals(FIELD_NULL) || SectionCode.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "'Section Code2'" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);

			}

			else if (SectionCode.length() <= 3) {
				if (FormNo.equals(FORM_24Q)) {
					if (!(SectionCode.equals("92A")) && !(SectionCode.equals("92B")) && !(SectionCode.equals("92C"))//Production problem FVU 7.2 05 Oct 2021 Added 92C
							&& !(SectionCode.equals("94P") && (Integer.parseInt(FinancialYr) >= 202122 ))) // Added section code 94P for form24Q FVU 7.2 by Vinita

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code3" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);
				
				
					// Validation for section code 94P FVU 7.2 by Vinita : Start
					
					if( (SectionCode!= null && SectionCode.equals("94P")) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)) &&
						(Integer.parseInt(FinancialYr) >= 202122)){
						
						// Existing validation for remark C
						if (Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))) {
							
								if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) 
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
							
						}
					
						// Nullifying condition // Obs Q4 correction 29 Jun 2021
						if(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
							if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
								if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) 
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6155_C + tab + T_FV_6155_M);
								if (!(RateAtWhichTaxDeducted.equals(FIELD_NULL) || RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR)) && Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) 
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
								if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) 
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}
						}
					
					
					}
					// Validation for section code 94P FVU 7.2 by Vinita : End
				
				
				} else if (FormNo.equals(FORM_26Q)) {
					if (!(SectionCode.equals("193")) && !(SectionCode.equals("94A")) && !(SectionCode.equals("94B")) && !(SectionCode.equals("4BB")) && !(SectionCode.equals("94C")) && !(SectionCode.equals("94D")) && !(SectionCode.equals("4EE"))
							&& !(SectionCode.equals("94F")) && !(SectionCode.equals("94G")) && !(SectionCode.equals("94H")) && !(SectionCode.equals("4IA")) && !(SectionCode.equals("4IB"))
							&& !(SectionCode.equals("94J") && Integer.parseInt(FinancialYr) <= 201920) && !(SectionCode.equals("94L")) && !(SectionCode.equals("194")) && !(SectionCode.equals("4BA") && Integer.parseInt(FinancialYr) >= 201415 && Integer.parseInt(FinancialYr) < 202021)//Changes for CR#65617. Condition of FY 202021 added.
							// && !(SectionCode.equals("LBA") && Integer.parseInt(FinancialYr) >= 201415) //
							// added for FVU 4.8
							&& !(SectionCode.equals("4DA") && Integer.parseInt(FinancialYr) >= 201415) && !(SectionCode.equals("LBB") && obj_FieldValidation.isDateGreaterThanJune(DateOnWhichAmountPaid) && Integer.parseInt(FinancialYr) >= 201516)
							// && !(SectionCode.equals("92D") &&
							// obj_FieldValidation.isDateGreaterThanJune(DateOnWhichAmountPaid) &&
							// Integer.parseInt(FinancialYr) >= 201516 )// Added for FVU 4.7
							&& !((SectionCode.equals("9IA") && Integer.parseInt(FinancialYr) >= 201314) && (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))) // Added
																																																						// for
																																																						// FVU
																																																						// 5.0
																																																						// point
																																																						// 12
							&& !(SectionCode.equals("2AA") && obj_FieldValidation.isDateGreaterThanJune(DateOnWhichAmountPaid) && Integer.parseInt(FinancialYr) >= 201516
									&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))

							// Added by priya for FVU5.1
							&& !(SectionCode.equals("LBC") && Integer.parseInt(FinancialYr) >= 201617
									&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))
							// End ::Added by priya for FVU5.1
							&& !(SectionCode.equals("4IC") && Integer.parseInt(FinancialYr) >= 201718 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) // FVU
																																																					// 5.5
							&& !(SectionCode.equals("94N") && Integer.parseInt(FinancialYr) >= 201920 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))// changes
																																																				// added
																																																				// for
																																																				// funct
																																																				// point
																																																				// 2
																																																				// for
																																																				// FVU
																																																				// 6.4
																																																				// by
																																																				// puja
							&& !(SectionCode.equals("94K") && Integer.parseInt(FinancialYr) >= 202021 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))// Changes
																																																				// added
																																																				// for
																																																				// CR61109_6.7_2.163_2.1295
																																																				// by
																																																				// puja(201920
																																																				// nneds
																																																				// to
																																																				// be
																																																				// changed
																																																				// to
																																																				// 202021)
							&& !((SectionCode.equals("4JA") || SectionCode.equals("4JB")) && Integer.parseInt(FinancialYr) >= 202021 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))// Changes
																																																													// added
																																																													// for
																																																													// 6.8_2.164_2.1296
																																																													// by
																																																													// puja_funPoint1
							&& !((SectionCode.equals("BA1") || SectionCode.equals("BA2")) && Integer.parseInt(FinancialYr) >= 202021 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))//Changes added for CR#65617
							&& !(SectionCode.equals("4NF") && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) &&
									((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))
									|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))))//Changes added for CR#65617
							// Changes for FVU 7.0 - Vinita : Start
							&& !((SectionCode.equals("94O")) && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
									&&  (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) )		
							// Changes for FVU 7.0 - Vinita : End
							//Changes added for 7.2_2.168_2.1300 Part 2 by Vinita : Start
							&& !((SectionCode.equals("94Q")) && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202122 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
									&&  (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) )		
							//Changes added for 7.2_2.168_2.1300 Part 2 by Vinita : End		
					)// Added for FVU 4.8
					{
						if ((SectionCode.equals("4IC") && Integer.parseInt(FinancialYr) < 201718 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))) { // FVU
																																																				// 5.5
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4350_C + tab + T_FV_4350_M);
						} else {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code4" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);
						}
					}
					// Added by amit for FVU 4.5
					else if ((SectionCode.equals("4BA") || SectionCode.equals("4DA")) && Integer.parseInt(FinancialYr) == 201415 && (Qperiod.equals("Q1") || Qperiod.equals("Q2")))
					// else if ((SectionCode.equals("LBA") || SectionCode.equals("4DA")) &&
					// Integer.parseInt(FinancialYr) == 201415 && (Qperiod.equals("Q1")||
					// Qperiod.equals("Q2")) )
					{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code5" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);
					} else if(SectionCode.equals("4BA") && Integer.parseInt(FinancialYr) >= 202021) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code5" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6172_C + tab + T_FV_6172_M);
					}
					// changes added for funct point 2 for FVU 6.4 by puja
					else if ((SectionCode.equals("94N") && !obj_FieldValidation.isDateGreaterThanAug(DateOnWhichAmountPaid))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6140_C + tab + T_FV_6140_M);
					} else if ((Remark1.equals("C") && SectionCode.equals("94N") && Integer.parseInt(FinancialYr) >= 201920 && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) { // Changes added for 6.8_2.164_2.1296 by puja_funPoint3
						if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(amtOfCashWithIn194N.trim()) * 0.05)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
						} // Changes added for 6.5_2.161_2.1293 by Puja//Changes added for
							// 6.8_2.164_2.1296 by pujabugfix2
					} else if (SectionCode.equals("94N") && ((Integer.parseInt(FinancialYr) == 201920 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))
							|| (Integer.parseInt(FinancialYr) >= 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
						if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
							if (!Remark1.equals("N")) {

								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6142_C + tab + T_FV_6142_M);
							}
							//CR 65617. Observation No.20 START
							if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}
							//CR 65617. Observation No.20 END
						}

						if (Remark1.equals("N") && !(Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0.0000)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
						}
						/*if (Remark1.equals("N") && (Double.parseDouble(AmountOfPayment.trim()) == 0.00)) {//Commented for CR#65617
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
						}*/
						
						//CR 65617. Observation No.20 START
						if(Remark1.equals("N") && (AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
						}
						//CR 65617. Observation No.20 END
						
						if (Remark1.equals("N") && !(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6147_C + tab + T_FV_6147_M);
						}
					} else if ((Remark1.equals("C") && SectionCode.equals("94K") && Integer.parseInt(FinancialYr) >= 202021// 201920 needs to changed
																															// to 202021
							&& (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) {
						if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
						} // Changes added for CR61109_6.7_2.163_2.1295 by puja
					}
					// Changes added for 6.8_2.164_2.1296 by puja_funPoint1 :START
					else if (((SectionCode.equals("4JA") || SectionCode.equals("4JB")) && Integer.parseInt(FinancialYr) >= 202021 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
							&& !obj_FieldValidation.isDateGreaterThanApr(DateOnWhichAmountPaid))) {

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6140_C + tab + T_FV_6140_M);

					} else if ((Remark1.equals("C") && (SectionCode.equals("4JA") || SectionCode.equals("4JB")) && Integer.parseInt(FinancialYr) >= 202021
							&& (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) {
						if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
						}

					} else if ((SectionCode.equals("4JA") || SectionCode.equals("4JB")) && Integer.parseInt(FinancialYr) >= 202021 && UploadType.equals(UPLOADTYPE_REGULAR) ) {
						if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
							if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6142_C + tab + T_FV_6142_M);
							}

							if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && !(Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0.0000)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
							}
							//Commented for CR#65617 START
							/*if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && (Double.parseDouble(AmountOfPayment.trim()) == 0.00)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}*/
							//Commented for CR#65617 END
							
							//CR 65617. Observation No.20 START
							if((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && (AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}
							//CR 65617. Observation No.20 END
							
							if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && !(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6147_C + tab + T_FV_6147_M);
							}
						}
					}else if ((SectionCode.equals("4JA") || SectionCode.equals("4JB")) && Integer.parseInt(FinancialYr) >= 202021  && TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
						if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
							if (!(Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0.0000)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
							}
							//Commented for CR#65617 START
							/*if (Double.parseDouble(AmountOfPayment.trim()) == 0.00) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}*/
							//Commented for CR#65617 END
							
							//CR 65617. Observation No.20 START
							if(Remark1.equals("N") && (AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}
							//CR 65617. Observation No.20 END
							
							if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6147_C + tab + T_FV_6147_M);
							}

						}
					} 
					// Changes added for 6.8_2.164_2.1296 by puja_funPoint1 :END
					//Changes for CR#65617 START
					else if(SectionCode.equals("94A") && !(Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR))) {
						if(Integer.parseInt(FinancialYr) >= 202021 && !(Remark1.equals("D") || Remark1.equals("E") || Remark1.equals("A") || Remark1.equals("B") || Remark1.equals("C") || Remark1.equals("R") || Remark1.equals("Y")) //CR 65617. ObservationNo.16_250920 //CR 65617. Observation No.25
								&& !(Remark1.equals("Q") && Integer.parseInt(FinancialYr) >= 202122)
								&& !(Remark1.equals("Z") && obj_FieldValidation.isDateOnorAfter17Sept2021(DateOnWhichAmountPaid) )//Changes added for 7.4_2.170_2.1302 by Kiran z remark for section 94A will be allowed only after 17thsept2021
								&& !((Remark1.equals("U") && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) > 0.00)
										&& ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))
												|| (Integer.parseInt(FinancialYr) > 202122)))) { // Obs no 5 FVU 7.2 by Vinita 22 Jun 2021 // Requirement update FVU 7.2 Part 2 18 Sep 2021 // Remove PAN condition FVU 7.2 21 Sep 2021
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6167_C + tab + T_FV_6167_M);//CR 65617. ObservationNo.16_250920 // Obs no 5 FVU 7.2 Part 2 16 Sep 2021
						} else if(Integer.parseInt(FinancialYr) < 202021 && Remark1.equals("D")) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6168_C + tab + T_FV_6168_M);//CR 65617. ObservationNo.16_250920
						}
					}
					//Section code 194LBA(a) & 194LBA(b) changes START
					else if(!Remark1.equals(FIELD_NULL) && !Remark1.equals(FIELD_SEPERATOR) && Remark1.equals("O")) {
							if(Integer.parseInt(FinancialYr) >= 202021 && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)) && !(SectionCode.equals("BA1") || SectionCode.equals("BA2")) ) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6149_C + tab + T_FV_6149_M);
							}
					} else if((SectionCode.equals("BA1") || SectionCode.equals("BA2")) && Integer.parseInt(FinancialYr) >= 202021) {//CR 65617. Observation No.23
						/*if(Double.parseDouble(AmountOfPayment.trim()) == 0.00) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
						}*/
						//CR 65617. Observation No.20 START
						if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {//CR 65617. Observation No.23
							if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6151_C + tab + T_FV_6151_M);
							}
							if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) {//CR 65617. Observation No.22
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
							}
							if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}
						}
						//CR 65617. Observation No.20 END
						
						//CR 65617. Observation No.23 START
						if ((Remark1.equals("C") || Remark1.equals("M") || Remark1.equals("O") || (Remark1.equals("E"))) && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
								&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))) {
							if(Remark1.equals("C")) {
								if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
								}
							}
							
							//CR 65617. ObservationNo.15_240920 START
							if((Remark1.equals("M") || Remark1.equals("O") || (Remark1.equals("E")))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
							}
							//CR 65617. ObservationNo.15_240920 END
						}
						//CR 65617. Observation No.23 END
						
					} /*else if ((Remark1.equals("C") || Remark1.equals("M") || Remark1.equals("O") || (Remark1.equals("E"))) && (SectionCode.equals("BA1") || SectionCode.equals("BA2")) && Integer.parseInt(FinancialYr) >= 202021 && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))//CR 65617. Observation No.23
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))) {
						if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
						} //CR 65617. Observation No.23 Commented
					}*/
					//CR 65617. ObservationNo.15_240920 START
					/*else if((Remark1.equals("O") || Remark1.equals("E")) && (SectionCode.equals("BA1") || SectionCode.equals("BA2")) && Integer.parseInt(FinancialYr) >= 202021 && EmployeePan.equals(PAN_NOT_AVAILABLE)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
					}*///CR 65617. Observation No.23 Commented
					//CR 65617. ObservationNo.15_240920 END
					//Section code 194LBA(a) & 194LBA(b) changes END
					
					//Section code 194NF changes START
					//CR 65617. ObservationNo.12_14_240920 START
					 else if(SectionCode.equals("4NF") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
							 if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
								 /*if(Double.parseDouble(AmountOfPayment.trim()) == 0.00) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
								}*/
								//CR 65617. Observation No.20 START
									if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
										if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
											Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6155_C + tab + T_FV_6155_M);
										}
										if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) {//CR 65617. Observation No.22
											Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
										}
										
										if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) {
											Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
										}
									}
								//CR 65617. Observation No.20 END
							 }
							 
							 if (Remark1.equals("Z")) {
								 Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
							 }
							 
							 if((Remark1.equals("M") || Remark1.equals("E")) && EmployeePan.equals(PAN_NOT_AVAILABLE)) {
								 Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
							 }
							 
					}
					//CR 65617. ObservationNo.12_14_240920 END
					//Section code 194NF changes END
					//Changes for CR#65617 END 
					
					// Changes for FVU 7.0 - Vinita : Start
					 else if(SectionCode.equals("94O") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
						 
						 // Nullifying condition
						 if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
								if (TotalIncomeTaxDeductedAtSource != null && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
									if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6177_C + tab + T_FV_6177_M);
									}
									if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6178_C + tab + T_FV_6178_M);
									}
								}
								/*//CR 70278 Obs 18 FVU 7.0
								else{
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6179_C + tab + T_FV_6179_M);
								}*/
						 }
						 
						 if ((Remark1.equals("C")  && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) {
								if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
								}

						 }
						 // Test case 3 FVU 7.0 - Vinita
						 else if (!(Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && !(Remark1.equals("A") || Remark1.equals("Y") || Remark1.equals("E") || Remark1.equals("U"))){ // Obs no 5 FVU 7.2 Part 2 16 Sep 2021
							 Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6194_C + tab + T_FV_6194_M);
						 }
						 
						 // Test case 15 FVU 7.0 - Vinita // CR 70278 Obs no 20 FVU 7.0 // FVU 7.1 Obs no 8 09 Mar 2021 - Vinita- Added remark Y
						 else if (UploadType.equals(UPLOADTYPE_REGULAR) && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00 && !Remark1.equals("A") && !Remark1.equals("Y")){
							 Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6195_C + tab + T_FV_6195_M);
						 }
						 
						// Observation no 7 FVU 7.0
						 else if (obj_FieldValidation.dateBefQuatStartDate(DateOnWhichAmountPaid, FinancialYr, Qperiod)) {

								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount received / debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4322_C + tab + T_FV_4322_M);

							}
						 // Observation no 10 FVU 7.0
						 else if((EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && !(Remark1.equals("C") || Remark1.equals("U"))){ // Observation 16 FVU 7.2 23 Sep 2021
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4280_C + tab + T_FV_4280_M);
								}
					 
					 
					 }
					// Changes for FVU 7.0 - Vinita : End
					
					
					//Changes added for 7.2_2.168_2.1300 Part 2 by Vinita : Start
					 
					 else if(SectionCode.equals("94Q") && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202122 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
						 
						 // Nullifying condition
						 if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
								if (TotalIncomeTaxDeductedAtSource != null && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
									if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6177_C + tab + T_FV_6177_M);
									}
									if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) {
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6178_C + tab + T_FV_6178_M);
									}
								}
						 }
						 
						 if ((Remark1.equals("C")  && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) {
								if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
								}

						 }
						 else if (!(Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && !(Remark1.equals("S") || Remark1.equals("U"))){
							 Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6210_C + tab + T_FV_6210_M);
						 }
						 
						 else if((EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && !(Remark1.equals("C") || Remark1.equals("U"))){ // Observation 16 FVU 7.2 23 Sep 2021
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4280_C + tab + T_FV_4280_M);
						 }
						 /**Commented for FVu 7.4_2.170_2.1302 Bug Fix by kiran
						 // Obs no 9 FVU 7.2 Part 2 16 Sep 2021
						 else if(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00){
						 	if(!Remark1.equals("S"))
						 		Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6214_C + tab + T_FV_6214_M);
						 
						 }**/
						 else if (obj_FieldValidation.isDateBeforeQuarter2(DateOnWhichAmountPaid)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6216_C + tab + T_FV_6216_M);
							}
					 
					 }// Changes added for 7.2_2.168_2.1300 Part 2 by Vinita - End
					//Changes added for 7.4_2.170_2.1302 by Kiran
					 
					
					
					

				} else if (FormNo.equals(FORM_27Q)) {
					// ADDED BY FAIZAN FOR FVU 4.8
					if (!(SectionCode.equals("94E")) && !(SectionCode.equals("195")) && !(SectionCode.equals("96A")) && !(SectionCode.equals("96B")) && !(SectionCode.equals("96C")) && !(SectionCode.equals("96D"))
							&& !(SectionCode.equals("4LB") && Integer.parseInt(FinancialYr) >= 201112) && !(SectionCode.equals("4LC") && Integer.parseInt(FinancialYr) >= 201213)
							&& !(SectionCode.equals("4LD") && Integer.parseInt(FinancialYr) >= 201314)// Modified on
																										// 13/08/2012
							&& !(SectionCode.equals("4BA") && Integer.parseInt(FinancialYr) >= 201415 && Integer.parseInt(FinancialYr) < 202021)// Modified on // 11/12/2014. //Changes for CR#65617. Condition of FY 202021 added.
							// && !(SectionCode.equals("LBA") && Integer.parseInt(FinancialYr) >= 201415)
							&& !(SectionCode.equals("LBB") && Integer.parseInt(FinancialYr) >= 201011) // 201516 Added
																										// for FVU 4.7
							&& !(SectionCode.equals("2AA") && obj_FieldValidation.isDateGreaterThanJune(DateOnWhichAmountPaid) && Integer.parseInt(FinancialYr) >= 201516)
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)))
							// Added by Priya for FVU 5.1
							&& !(SectionCode.equals("LBC") && Integer.parseInt(FinancialYr) >= 201617
									&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))
							// End :: Added by Priya for FVU 5.1
							// Changes added for 6.5_2.161_2.1293 by Puja
							&& !(SectionCode.equals("94N") && Integer.parseInt(FinancialYr) >= 201920 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))
							&& !((SectionCode.equals("BA1") || SectionCode.equals("BA2") || SectionCode.equals("BA3")) && Integer.parseInt(FinancialYr) >= 202021 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)))//Changes added for CR#65617
							&& !(SectionCode.equals("4NF") && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) && //Changes added for CR#65617
									((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) //Changes added for CR#65617
									|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))))//Changes added for CR#65617
							
							// Section code 196D(1A) added FVU 7.2 by Vinita
							&& !(SectionCode.equals("6DA") && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) 
									&& ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021))
									&& (obj_FieldValidation.isDateAfterOctober(DateOnWhichAmountPaid)))		
						) // Added for FVU 4.8
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);
					// ended for FVU 4.8
					// Added for FVU 4.0
					if (!DeductorType.equals("K") && !DeductorType.equals("M") && SectionCode.equals("4LC")) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4321_C + tab + T_FV_4321_M);
					}
					// Added by amit for FVU 4.5
					// added by faizan for FVU 4.8
					else if (SectionCode.equals("4BA") && Integer.parseInt(FinancialYr) == 201415 && Integer.parseInt(FinancialYr) >= 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2")))//Changes for CR#65617. Condition of FY 202021 added.
					// else if (SectionCode.equals("LBA") && Integer.parseInt(FinancialYr) == 201415
					// && (Qperiod.equals("Q1")|| Qperiod.equals("Q2")) )
					{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code7" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);
					}
					// Changes added for 6.5_2.161_2.1293 by Puja
					else if ((SectionCode.equals("94N") && !obj_FieldValidation.isDateGreaterThanAug(DateOnWhichAmountPaid))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6140_C + tab + T_FV_6140_M);
					} else if ((Remark1.equals("C") && SectionCode.equals("94N") && Integer.parseInt(FinancialYr) >= 201920 && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) {// Changes
																														// added
																														// for
																														// 6.8_2.164_2.1296
																														// by
																														// puja_funPoint3
						if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(amtOfCashWithIn194N.trim()) * 0.05)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
						} // Changes added for 6.5_2.161_2.1293 by Puja
					} else if (SectionCode.equals("94N") && ((Integer.parseInt(FinancialYr) == 201920 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))
							|| (Integer.parseInt(FinancialYr) >= 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) {
						if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
							if (!Remark1.equals("N")) {

								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6142_C + tab + T_FV_6142_M);
							}
							
							//CR 65617. Observation No.20 START
							if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}
							//CR 65617. Observation No.20 END
						}

						if (Remark1.equals("N") && !(Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0.0000)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
						}
						//Commented for CR#65617 START
						/*if (Remark1.equals("N") && (Double.parseDouble(AmountOfPayment.trim()) == 0.00)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
						}*/
						//Commented for CR#65617 END
						
						//CR 65617. Observation No.20 START
						if(Remark1.equals("N") && (AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
						}
						//CR 65617. Observation No.20 END
						
						if (Remark1.equals("N") && !(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6147_C + tab + T_FV_6147_M);
						}
					}
					//Changes for CR#65617 START
					/*else if(!Remark1.equals(FIELD_NULL) && !Remark1.equals(FIELD_SEPERATOR) && Remark1.equals("O") && !(SectionCode.equals("BA1") || SectionCode.equals("BA2"))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6155_C + tab + T_FV_6155_M);
					}*/
					else if((SectionCode.equals("BA1") || SectionCode.equals("BA2") || SectionCode.equals("BA3")) && Integer.parseInt(FinancialYr) >= 202021) {//CR 65617. Observation No.24
						//CR 65617. Observation No.20 START
						if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {//CR 65617. Observation No.24
							if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6151_C + tab + T_FV_6151_M);
							}
							if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) {//CR 65617. Observation No.22
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
							}
							if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}
						}
						//CR 65617. Observation No.20 END
						//CR 65617. Observation No.24 START
						if ((Remark1.equals("C") || Remark1.equals("M") || Remark1.equals("O") || (Remark1.equals("G"))) && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
								&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))) {
							if(Remark1.equals("C")) {
								if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
								}
							}
							
							//CR 65617. ObservationNo.15_240920 START
							if((Remark1.equals("M") || Remark1.equals("O") || (Remark1.equals("G")))) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
							}
							//CR 65617. ObservationNo.15_240920 END
						}
						//CR 65617. Observation No.24 END
							
						 /*else if ((Remark1.equals("C") || Remark1.equals("M") || Remark1.equals("O") || Remark1.equals("G")) && (SectionCode.equals("BA1") || SectionCode.equals("BA2") || SectionCode.equals("BA3")) && Integer.parseInt(FinancialYr) >= 202021 && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))//CR 65617. Observation No.24
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))) {
						if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
						}  */ //CR 65617. Observation No.24 Commented
					}
					//CR 65617. ObservationNo.12_240920 START
					else if(SectionCode.equals("4NF") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4")))
							|| (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))) 
					{		
						if(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
							//CR 65617. Observation No.20 START
							if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
								if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6155_C + tab + T_FV_6155_M);
								}
								if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) {//CR 65617. Observation No.22
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
								}
								
								if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
								}
							}
							//CR 65617. Observation No.20 END
						}
							
						 if (Remark1.equals("Z")) {
							 Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4315_C + tab + T_FV_4315_M);
						 }
						
					}//CR 65617. ObservationNo.12_240920 END
					else if(!Remark1.equals(FIELD_NULL) && !Remark1.equals(FIELD_SEPERATOR) && Remark1.equals("G")) {
						if(Integer.parseInt(FinancialYr) < 202021) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6171_C + tab + T_FV_6171_M); //Changes for #65617. ObservationNo.11_230920
						}
					}
					//Changes for CR#65617 END
					
					// Changes added for FVU 7.2 for section code 96D by Vinita : Start
					
					else if(SectionCode.equals("96D") && (Integer.parseInt(FinancialYr) >= 202122)
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))) 
					{
						
						// Remark C condition
						if(Remark1.equals("C")) {
							if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
							}
						}
						
						// Nullifying condition // Obs Q4 correction 29 Jun 2021
						if(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
							if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
								if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) 
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6155_C + tab + T_FV_6155_M);
								if (!(RateAtWhichTaxDeducted.equals(FIELD_NULL) || RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR)) && Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) 
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
								if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) 
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
							}
						}
						
						//Validation for madatory fields DeducteeEmailId, DeducteeContactNo, DeducteeAddress, TaxIdentificationNo
						if((DeducteeEmailId.equals(FIELD_NULL) || DeducteeEmailId.equals(FIELD_SEPERATOR))
								|| (DeducteeContactNo.equals(FIELD_NULL) || DeducteeContactNo.equals(FIELD_SEPERATOR))
								|| (DeducteeAddress.equals(FIELD_NULL) || DeducteeAddress.equals(FIELD_SEPERATOR))
								|| (TaxIdentificationNo.equals(FIELD_NULL) || TaxIdentificationNo.equals(FIELD_SEPERATOR))){
							//If rate of deduction is less than 20%
							//Remark value 'C' pan not available
							//Nature of remittances is 27, 49, 21, 52 or31,16.
							if( (obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4) && Double.parseDouble(RateAtWhichTaxDeducted.trim()) < 20) && (Remark1.equals("C")) && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
								&&	(natureOfRemittance.equals("27") || natureOfRemittance.equals("49") || natureOfRemittance.equals("21") || natureOfRemittance.equals("52") || natureOfRemittance.equals("31") || natureOfRemittance.equals("16"))){
								
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee Fields" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6209_C + tab + T_FV_6209_M);
								
							}	
						}
						
						// In case of no deduction
						if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
								if ( (Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) || !(Remark1.equals("I") || Remark1.equals("G"))) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6203_C + tab + T_FV_6203_M);
								}
					
						}
						// Obs no 10 FVU 7.2 by Vinita 22 Jun 2021 Commented
						/*if ((Remark1.equals("I") || Remark1.equals("G")) && !(Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00 && Double.parseDouble(RateAtWhichTaxDeducted.trim()) == 0.0000)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
						}*/
						
						// In case of nil challan return
						if(NillChallanIndicator != null && NillChallanIndicator.equals("Y")){
							if ((Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) || !Remark1.equals("I"))
							{
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6204_C + tab + T_FV_6204_M);
							}
						}
						
						
					}
					
						
					
					// Changes added for FVU 7.2 for section code 96D by Vinita : End
						
						
						// Changes added for section code 196D(1A) FVU 7.2 by Vinita : Start
						
					else	if( (SectionCode!= null && SectionCode.equals("6DA")) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)) &&
								((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021))
								&& (obj_FieldValidation.isDateAfterOctober(DateOnWhichAmountPaid)) ){
							
							// Existing validation for remark C
							if (Remark1.equals("C") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))) {
								
									if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) 
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
								
							}
						
							// Nullifying condition // Obs Q4 correction 29 Jun 2021
							if(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) {
								if (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
									if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) 
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6155_C + tab + T_FV_6155_M);
									if (!(RateAtWhichTaxDeducted.equals(FIELD_NULL) || RateAtWhichTaxDeducted.equals(FIELD_SEPERATOR)) && Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) 
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6145_C + tab + T_FV_6145_M);
									if(AmountOfPayment.equals(FIELD_NULL) || AmountOfPayment.equals(FIELD_SEPERATOR)) 
										Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6146_C + tab + T_FV_6146_M);
								}
							}
							
							
							// In case of no deduction and nil challan return, 'G','I','H' are applicable
							if ( (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) && (NillChallanIndicator != null && NillChallanIndicator.equals("Y"))) {
								if ( (Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) || !(Remark1.equals("I") || Remark1.equals("G") || Remark1.equals("H"))) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6203_C + tab + T_FV_6203_M);
								}
							}
							
							
							//Validation for madatory fields DeducteeEmailId, DeducteeContactNo, DeducteeAddress, TaxIdentificationNo
							if((DeducteeEmailId.equals(FIELD_NULL) || DeducteeEmailId.equals(FIELD_SEPERATOR))
									|| (DeducteeContactNo.equals(FIELD_NULL) || DeducteeContactNo.equals(FIELD_SEPERATOR))
									|| (DeducteeAddress.equals(FIELD_NULL) || DeducteeAddress.equals(FIELD_SEPERATOR))
									|| (TaxIdentificationNo.equals(FIELD_NULL) || TaxIdentificationNo.equals(FIELD_SEPERATOR))){
								//If rate of deduction is less than 20%
								//Remark value 'C' pan not available
								//Nature of remittances is 27, 49, 21, 52 or31,16.
								if( (obj_FieldValidation.isDecimal(RateAtWhichTaxDeducted, 4) && Double.parseDouble(RateAtWhichTaxDeducted.trim()) < 20) && (Remark1.equals("C")) && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
									&&	(natureOfRemittance.equals("27") || natureOfRemittance.equals("49") || natureOfRemittance.equals("21") || natureOfRemittance.equals("52") || natureOfRemittance.equals("31") || natureOfRemittance.equals("16"))){
									
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee Fields" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6209_C + tab + T_FV_6209_M);
									
								}	
							}
						
						}
						// Changes added for section code 196D(1A) FVU 7.2 by Vinita : End
					
				} else if (FormNo.equals(FORM_27EQ)) {
					
					System.out.println("section code ::"+SectionCode);
					System.out.println("pan::"+EmployeePan);
					System.out.println("rate"+RateAtWhichTaxDeducted);
					if (!(SectionCode.equals("A")) && !(SectionCode.equals("B")) && !(SectionCode.equals("C")) && !(SectionCode.equals("D")) && !(SectionCode.equals("E")) && !(SectionCode.equals("F")) && !(SectionCode.equals("G"))
							&& !(SectionCode.equals("H")) && !(SectionCode.equals("I")) && !(SectionCode.equals("J") && Integer.parseInt(FinancialYr) >= 201213) && !(SectionCode.equals("K") && Integer.parseInt(FinancialYr) >= 201213)
							// Added by Priya for FVU 5.1

							&& !(SectionCode.equals("L") && Integer.parseInt(FinancialYr) >= 201617
									&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))
							&& !(SectionCode.equals("M") && Integer.parseInt(FinancialYr) >= 201617
									&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))
							&& !(SectionCode.equals("N") && Integer.parseInt(FinancialYr) >= 201617
									&& (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))))

					// End :: Added by Priya for FVU 5.1
					// Changes for FVU 7.0 - Vinita : Start
							&& !((SectionCode.equals("O") || SectionCode.equals("P") || SectionCode.equals("Q") || SectionCode.equals("R")) && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
									&&  (UploadType.equals(UPLOADTYPE_REGULAR) || (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))) )
					
					// Changes for FVU 7.0 - Vinita : End
					) // Modified on 13/08/2012

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code8" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);

					// added by Shalin for FVU 4.4
					else if ((SectionCode.equals("J") || SectionCode.equals("K")) && Integer.parseInt(FinancialYr) == 201213 && Qperiod.equals("Q1")) {
						if (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code9" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);
					}
					/*
					 * else if (( SectionCode.equals("C") && Remark1.equals("C") &&
					 * Integer.parseInt(FinancialYr) >= 201718 && (
					 * EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) ||
					 * EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR)
					 * ||UploadType.equals(UPLOADTYPE_CORRECTION) ) ) ) //added for FVU 5.5
					 */
					else if ((Remark1.equals("C") && Integer.parseInt(FinancialYr) >= 201718 && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID))
							&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) // added
																														// for
																														// FVU
																														// 5.6
					{
						// System.out.println("Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim())+10)
						// "+ (Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim())+10));
						// System.out.println("(Double.parseDouble(AmountOfPayment.trim())*0.05) || "+
						// (Double.parseDouble(AmountOfPayment.trim())*0.05));
						
						// Added for FVU 7.1 Obs no 16 19 Mar 2021 - Vinita // Skipping below validation for section code R
						if(!SectionCode.equals("R")){
						if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
						}
						}
					}
				
				// Changes for FVU 7.0 - Vinita : Start
					
					else if((SectionCode.equals("O") || SectionCode.equals("P") || SectionCode.equals("Q") || SectionCode.equals("R"))
							&& !(Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR))){
						
						if(SectionCode.equals("O") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
								&& !(Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && !(Remark1.equals("C") || Remark1.equals("E") ||  Remark1.equals("F")) && !(Remark1.equals("I") && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || Integer.parseInt(FinancialYr) > 202122))) { // Observation FVU 7.2 21 Sep 2021
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6175_C + tab + T_FV_6175_M);
						} else if(SectionCode.equals("O") && (Integer.parseInt(FinancialYr) < 202021) ||  (Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2")))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6176_C + tab + T_FV_6176_M);
						}
						
						
						else if(SectionCode.equals("P") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
								&& !(Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && !(Remark1.equals("C") || Remark1.equals("E") ||  Remark1.equals("F")) && !(Remark1.equals("I") && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || Integer.parseInt(FinancialYr) > 202122))) { // Observation FVU 7.2 21 Sep 2021
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6180_C + tab + T_FV_6180_M);
						} else if(SectionCode.equals("P") && (Integer.parseInt(FinancialYr) < 202021) ||  (Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2")))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6181_C + tab + T_FV_6181_M);
						}
						
						else if(SectionCode.equals("Q") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
								&& !(Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && !(Remark1.equals("C") || Remark1.equals("D") || Remark1.equals("E") ||  Remark1.equals("F")) && !(Remark1.equals("I") && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || Integer.parseInt(FinancialYr) > 202122))) { // Observation FVU 7.2 21 Sep 2021
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6182_C + tab + T_FV_6182_M);
						} else if(SectionCode.equals("Q") && (Integer.parseInt(FinancialYr) < 202021) ||  (Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2")))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6183_C + tab + T_FV_6183_M);
						}
						
						else if(SectionCode.equals("R") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))
								&& !(Remark1.equals(FIELD_NULL) || Remark1.equals(FIELD_SEPERATOR)) && !(Remark1.equals("C") || Remark1.equals("G") ||  Remark1.equals("H")) && !(Remark1.equals("I") && ((Integer.parseInt(FinancialYr) == 202122 && (Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || Integer.parseInt(FinancialYr) > 202122))) { // Observation FVU 7.2 21 Sep 2021
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6184_C + tab + T_FV_6184_M);
						} else if(SectionCode.equals("R") && (Integer.parseInt(FinancialYr) < 202021) ||  (Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2")))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6185_C + tab + T_FV_6185_M);
						}
						
						// For FVU 7.1 Obs no 16 19 Mar 2021 - Vinita // Skipping section code R
						else if ((Remark1.equals("C") && !SectionCode.equals("R") && (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION)))) {
							if ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) {
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4348_C + tab + T_FV_4348_M);
							}

					 }
						
					}
					// Test case 7 FVU 7.0 
					if (((SectionCode.equals("O") || SectionCode.equals("P") || SectionCode.equals("Q") || SectionCode.equals("R")) && Integer.parseInt(FinancialYr) >= 202021 && (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE))
							&& obj_FieldValidation.dateBefQuatStartDate(DateOnWhichAmountPaid, FinancialYr, Qperiod))) {

						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date on which Amount received / debited" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4322_C + tab + T_FV_4322_M);

					} 
					
					// Added for FVU 7.1 - Obs no 2 For Sec code 'R' - Vinita
					
					if(SectionCode.equals("R") && ((Integer.parseInt(FinancialYr) == 202021 && (Qperiod.equals("Q3") || Qperiod.equals("Q4"))) || (Integer.parseInt(FinancialYr) > 202021 && (Qperiod.equals("Q1") || Qperiod.equals("Q2") || Qperiod.equals("Q3") || Qperiod.equals("Q4"))))){
						
						if(EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)){
							
							 if(((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)) || ((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) > (Double.parseDouble(AmountOfPayment.trim()) * 0.05))  ){
								 //valid
							 }
							
						}
						//Remove this condition - Obs no 5 09 Mar 2021 - Vinita
					/*	else{
							if((Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) + 10) < (Double.parseDouble(AmountOfPayment.trim()) * 0.05)){
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Amount paid/credited field" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6201_C + tab + T_FV_6201_M);
							}
						}*/
					
					}
					
					// nullifying conditions C3 (Section O,P,Q,R)
					if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (SectionCode.equals("O") || SectionCode.equals("P") || SectionCode.equals("Q") || SectionCode.equals("R"))) {
					if (TotalIncomeTaxDeductedAtSource != null && Double.parseDouble(TotalIncomeTaxDeductedAtSource.trim()) == 0.00) {
						if (!(DateOnWhichTaxDeducted.equals(FIELD_NULL) || DateOnWhichTaxDeducted.equals(FIELD_SEPERATOR))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Date of Deduction" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6177_C + tab + T_FV_6177_M);
						}
						if (Double.parseDouble(RateAtWhichTaxDeducted.trim()) != 0.0000) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Rate at which Tax deducted" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6178_C + tab + T_FV_6178_M);
						}
					}
					/* //CR 70278 Obs 18 FVU 7.0
					  else{
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Total Income Tax Deducted at Source TDS / TCS" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6179_C + tab + T_FV_6179_M);
					}*/
					}
					// Observation no 10. FVU 7.0
					if( (SectionCode.equals("O") || SectionCode.equals("P") || SectionCode.equals("Q") || SectionCode.equals("R"))
							&& (EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && !(Remark1.equals("C") || Remark1.equals("I"))){ // Observation 17 FVU 7.2 23 Sep 2021
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 1" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4280_C + tab + T_FV_4280_M);
					}
				// Changes for FVU 7.0 - Vinita : End
				}

			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code10" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4301_C + tab + T_FV_4301_M);

		} else {
			if (!SectionCode.equals(FIELD_NULL) && !SectionCode.equals(FIELD_SEPERATOR))

				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Section Code" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
		}
		sectionForThisDD = SectionCode;
	}

	private String validateDeducteeDetailRecNo(String TransactionType, String UploadTypeDD, StringBufferTemp Str_Buffer, String LineNo, String DeducteeDetailRecNo, FieldValidation obj_FieldValidation) {
		if (DeducteeDetailRecNo.equals(FIELD_NULL) || DeducteeDetailRecNo.equals(FIELD_SEPERATOR)) {
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Detail Record No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + "NA" + tab + T_FV_4007_C + tab + T_FV_4007_M);
			DeducteeDetailRecNo = "NA";
			CurrentchallanDetailRecordNo = "NA";
		} else {
			if (DeducteeDetailRecNo.length() <= 9) {
				if (obj_FieldValidation.isInt(DeducteeDetailRecNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Detail Record No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4007_C + tab + T_FV_4007_M);
				else {
					if (UploadTypeDD.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) {
						if (Integer.parseInt(DeducteeDetailRecNo.trim()) != DeducteeCount)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Detail Record No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4007_C + tab + T_FV_4007_M);
					} else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN)) {
						if (prevDeducteeRecCount >= Integer.parseInt(DeducteeDetailRecNo.trim())) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Detail Record No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_4125_C + tab + T_FV_4125_M);
						}
						prevDeducteeRecCount = Integer.parseInt(DeducteeDetailRecNo.trim());
					} else { // once ADD Mode is encountered in Correction file next Deductee detail record
								// number should be consecutive
						if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && (Integer.parseInt(DeducteeDetailRecNo.trim()) == 0))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Detail Record No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4007_C + tab + T_FV_4007_M);
						else if ((deducteeDetailAddMode == true) && ((prevDeducteeRecCount + 1) != Integer.parseInt(DeducteeDetailRecNo.trim()))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Detail Record No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4007_C + tab + T_FV_4007_M);
						} else if ((deducteeDetailAddMode == false) && (prevDeducteeRecCount >= Integer.parseInt(DeducteeDetailRecNo.trim()))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Detail Record No" + tab + CurrentchallanDetailRecordNo + tab + tab + T_FV_4125_C + tab + T_FV_4125_M);
						}
						prevDeducteeRecCount = Integer.parseInt(DeducteeDetailRecNo.trim());
					}
				}
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee / Party Detail Record No" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4007_C + tab + T_FV_4007_M);
		}
		return DeducteeDetailRecNo;
	}

	/**
	 * @param ChallanDetailRecordNo
	 * @param Str_Buffer
	 * @param LineNo
	 * @param ChallanRecordNo
	 * @param obj_FieldValidation
	 */
	private void validateChallanRecordNo(String ChallanDetailRecordNo, StringBufferTemp Str_Buffer, String LineNo, String ChallanRecordNo, FieldValidation obj_FieldValidation) {
		if (ChallanRecordNo.equals(FIELD_NULL) || ChallanRecordNo.equals(FIELD_SEPERATOR))
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4050_C + tab + T_FV_4050_M);
		else if (ChallanRecordNo.length() <= 9) {
			if (obj_FieldValidation.isInt(ChallanRecordNo))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4050_C + tab + T_FV_4050_M);
			else if (Integer.parseInt(ChallanRecordNo.trim()) != Integer.parseInt(ChallanDetailRecordNo.trim()))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4051_C + tab + T_FV_4051_M);
		} else
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Challan-Detail Record Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4050_C + tab + T_FV_4050_M);
	}

	/**
	 * @param BH_BatchNo
	 * @param Str_Buffer
	 * @param LineNo
	 * @param DD_BatchNo
	 * @param obj_FieldValidation
	 */
	private void validatingBatchNo(String BH_BatchNo, StringBufferTemp Str_Buffer, String LineNo, String DD_BatchNo, FieldValidation obj_FieldValidation) {
		if (DD_BatchNo.equals(FIELD_NULL) || DD_BatchNo.equals(FIELD_SEPERATOR))
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4005_C + tab + T_FV_4005_M);
		else if (DD_BatchNo.length() <= 9) {
			if (obj_FieldValidation.isInt(DD_BatchNo))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4005_C + tab + T_FV_4005_M);
			else if (Integer.parseInt(DD_BatchNo.trim()) != Integer.parseInt(BH_BatchNo.trim()))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4006_C + tab + T_FV_4006_M);
		} else
			Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Batch Number" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4005_C + tab + T_FV_4005_M);
	}

	// PAN VALIDATION /
	// priya
	private void validateBatchHeaderForPANCorrection(String batch, int LineCount, int BatchCount, String UploadType, String TanDedtr, StringBufferTemp obj_StringBuffer) throws Exception {
		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;
		// sumOfTotalIncomeTaxDeductedAtSource = 0;
		ChallanCount = 0;
		GrossTDSTotalAsPerChallan = null;
		TransactionType = null;
		FormNo = null;
		DeductorType = null;
		FinancialYr = null;
		boolean error_flag = false;
		boolean NullField = false;
		boolean error = false;
		boolean differenceInYear = false;
		boolean nullTanOfDeductor = false;
		boolean Assessment_Financial = false;
		boolean Caret = true;
		boolean FieldFound = false;
		int LCount = 0;
		char recognizePan;
		boolean isDeducteeCountValid = false;
		try {
			int Count_BH_Fields = 1;
			String LineNo = null;
			String RecType = null;
			String BH_BatchNo = null;
			String BatchUpdationIndicator = null;
			String CountOfDeducteeRec = null;
			String RRRNo = null;
			String RRRDate = null;
			String TanOfDeductor = null;
			String AssessmentYr = null;
			String PanBatchHash = null;
			FieldValidation obj_FieldValidation = new FieldValidation();
			FileGenerator obj_FileGenerator = new FileGenerator();
			StringTokenizer Obj_st = new StringTokenizer(batch, FIELD_SEPERATOR, true);
			int Count_BH_Field35 = 1;
			int localCaretCounterBHP11 = 0;
			while (Obj_st.hasMoreTokens()) {
				String val = Obj_st.nextToken();
				NullField = false;
				FieldFound = false;
				if ((val.equals(FIELD_SEPERATOR) && Caret)) {
					NullField = true;
					FieldFound = true;
				}
				if (val.equals(FIELD_SEPERATOR)) {
					Caret = true;
					if (localCaretCounterBHP11 == 0 && Count_BH_Field35 == 1) { // Count_BH_Fields++;
						LineNo = "";
					}
					localCaretCounterBHP11++;
				} else {
					Caret = false;
					FieldFound = true;
				}

				if (Count_BH_Field35 > 11) {
					break;
				}

				if (FieldFound) {

					switch (Count_BH_Field35) {
					case 1:
						LineNo = val;
						break;
					case 2:
						RecType = val;
						break;
					case 3:
						BH_BatchNo = val;
						break;
					case 4:
						CountOfDeducteeRec = val;
						break;
					case 5:
						FormNo = val;
						break;
					case 6:
						RRRNo = val;
						break;
					case 7:
						RRRDate = val;
						break;
					case 8:
						TanOfDeductor = val;
						break;
					case 9:
						AssessmentYr = val;
						break;
					case 10:
						FinancialYr = val;
						break;
					case 11:
						PanBatchHash = val;
						break;
					} // SWITCH
					Count_BH_Field35++;
				}
			} // WHILE
			if (localCaretCounterBHP11 != 10) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_2001_C + tab + T_FV_2001_M);
				return;
			} // Validating LineNo
			if (LineNo.equals(FIELD_NULL) || LineNo.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_2003_C + tab + T_FV_2003_M);
				LineNo = "NA";
			} else {
				if (LineNo.length() <= 9) {
					error = obj_FieldValidation.isInt(LineNo);
					if (error) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_2003_C + tab + T_FV_2003_M);
						LineNo = "NA";
					} else {
						LCount = Integer.parseInt(LineNo.trim());
						if (LCount != LineCount)

						{
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_2003_C + tab + T_FV_2003_M);
							LineNo = "NA";
						}
					}
				} else {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_2003_C + tab + T_FV_2003_M);
					LineNo = "NA";
				}
			} // Validating LineNo
				// Validating recordtype
			error = isValidRecType(LineNo, RecType, BATCH_HEADER_IDENTIFIER, Str_Buffer);
			if (error)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + BATCH_RECORD_TYPE + tab + tab + T_FV_2004_C + tab + T_FV_2004_M);
			// Validating recordtype
			// Validating BatchNo
			if (BH_BatchNo.equals(FIELD_NULL) || BH_BatchNo.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_2005_C + tab + T_FV_2005_M);
			else {
				if (BH_BatchNo.length() <= 9) {
					error = obj_FieldValidation.isInt(BH_BatchNo);
					if (error)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_2005_C + tab + T_FV_2005_M);
					else {
						int iBH_BatchNo = 0;
						iBH_BatchNo = Integer.parseInt(BH_BatchNo.trim());
						if (iBH_BatchNo != BatchCount)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_2005_C + tab + T_FV_2005_M);
					}
				} // if ((BatchNo.length() == 9&&
					// VARIABLE__LENGTH==false)||VARIABLE__LENGTH==true)
				else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_2005_C + tab + T_FV_2005_M);
			} // Validating BatchNo
				// Validating CountOfDeducteeDetail
			if (CountOfDeducteeRec.equals(FIELD_NULL) || CountOfDeducteeRec.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_2006_C + tab + T_FV_2006_M);
			else if (CountOfDeducteeRec.length() <= 9) {
				if (obj_FieldValidation.isInt(CountOfDeducteeRec))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_2006_C + tab + T_FV_2006_M);
				else if (Integer.parseInt(CountOfDeducteeRec.trim()) < 1)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_2006_C + tab + T_FV_2006_M);
				else
					isDeducteeCountValid = true;
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + Count_Of_Deductee_Records + tab + tab + tab + T_FV_2006_C + tab + T_FV_2006_M);
			// Validating CountOfDeducteeDetail
			// Validating Form No
			if (FormNo.equals(FIELD_NULL) || FormNo.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Form Number" + tab + tab + tab + T_FV_2064_C + tab + T_FV_2064_M);
				return;
			} else if (FileType.equals(FILETYPE_PAN_CORRECTION) && (!(FormNo.equals(FORM_26Q) || FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27Q) || FormNo.equals("A"))))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Form Number" + tab + tab + tab + T_FV_2099_C + tab + T_FV_2099_M);
			// Validating Form No
			// Validating RRRNo
			if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR)) {
				if (!RRRNo.equals(FIELD_NULL) && !RRRNo.equals(FIELD_SEPERATOR))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2020_C + tab + T_FV_2020_M);
			} else {
				if (RRRNo.equals(FIELD_NULL) || RRRNo.equals(FIELD_SEPERATOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2019_C + tab + T_FV_2019_M);
				} else {
					if ((RRRNo.length() == 15) && (RRRNo.trim().length() == 15)) {
						if (obj_FieldValidation.isInt(RRRNo))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
						else {
							if (obj_FieldValidation.isValidRrrNumber(RRRNo))
								Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
							else {
								String Tan_in_RRR = RRRNo.substring(0, 5);
								if (!Tan_in_RRR.equals(TanDedtr)) {
									Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
								}
							}
						}
					} else
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + RRR_NO + tab + tab + tab + T_FV_2018_C + tab + T_FV_2018_M);
				}
			} // Validating RRRNo
				// Validating RRRDate
			if (RRRDate.equals(FIELD_NULL) || RRRDate.equals(FIELD_SEPERATOR)) {
				if (TanTfcIdIndicator.equals(UPLOADED_BY_TFC))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
			} else {
				if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR)) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
				} else if ((RRRDate.length() == 8) && (RRRDate.trim().length() == 8)) {
					if (obj_FieldValidation.isInt(RRRDate))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
					else {
						if (obj_FieldValidation.isDate(RRRDate))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
						else if (obj_FieldValidation.isFutureDate(RRRDate))
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "RRR Date" + tab + tab + tab + T_FV_2022_C + tab + T_FV_2022_M);
			} // Validating RRRDate
				// Validating TanOfDeductor
				//
			if (TanOfDeductor.equals(FIELD_NULL) || TanOfDeductor.equals(FIELD_SEPERATOR)) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2027_C + tab + T_FV_2027_M);
			} else if ((TanOfDeductor.length() == 10) && (TanOfDeductor.trim().length() == 10)) {
				if (TanTfcIdIndicator.equals(UPLOADED_BY_DEDUCTOR) && (TanDedtr.length() == 10) && !TanOfDeductor.equals(TanDedtr))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2027_C + tab + T_FV_2027_M);
				else if (obj_FieldValidation.checkTan(TanOfDeductor))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2027_C + tab + T_FV_2027_M);
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "TAN of Deductor / Employer / Collector" + tab + tab + tab + T_FV_2027_C + tab + T_FV_2027_M);
			// Validating TanOfDeductor
			// Validating AssessmentYr
			boolean AssessmentYrCheck = false;
			if (AssessmentYr.equals(FIELD_NULL) || AssessmentYr.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2032_C + tab + T_FV_2032_M);
			else {
				if (AssessmentYr.length() == 6 && AssessmentYr.trim().length() == 6) {
					if (obj_FieldValidation.isInt(AssessmentYr)) {
						AssessmentYrCheck = true;
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2032_C + tab + T_FV_2032_M);
					} else {
						differenceInYear = obj_FieldValidation.isDifferenceInYearOne(AssessmentYr);
						if (differenceInYear)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2032_C + tab + T_FV_2032_M);
					}
				} else
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Assessment Year" + tab + tab + tab + T_FV_2032_C + tab + T_FV_2032_M);
			} // Validating AssessmentYr
				// Validating FinancialYr
			if (FinancialYr.equals(FIELD_NULL) || FinancialYr.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Finanacial Year" + tab + tab + tab + T_FV_2033_C + tab + T_FV_2033_M);
			else if (FinancialYr.length() == 6) {
				if (obj_FieldValidation.isInt(FinancialYr))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Finanacial Year" + tab + tab + tab + T_FV_2033_C + tab + T_FV_2033_M);
				else {
					differenceInYear = obj_FieldValidation.isDifferenceInYearOne(FinancialYr);
					if (differenceInYear)
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Finanacial Year" + tab + tab + tab + T_FV_2033_C + tab + T_FV_2033_M);
					else {
						Assessment_Financial = obj_FieldValidation.isAssmentYrFinancialYr(AssessmentYr, FinancialYr);
						if (Assessment_Financial)
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Finanacial Year" + tab + tab + tab + T_FV_2034_C + tab + T_FV_2034_M);
					}
				}
			} // if ((FinancialYr.length() == 6&&
				// VARIABLE__LENGTH==false)||VARIABLE__LENGTH==true)
			else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Finanacial Year" + tab + tab + tab + T_FV_2033_C + tab + T_FV_2033_M); // Validating
																																					// FinancialYr
		} catch (Exception e) {

			throw e;
		}
		return;
	} // Closing method ValidateBatchHeaderForPANCorrection

	private void validateDeducteeDetailsforPan(String deductee, int LineCount, int BH_BatchNo, String ChallanDetailRecordNo, StringBufferTemp obj_StringBuffer) throws Exception {
		StringBufferTemp Str_Buffer;
		Str_Buffer = obj_StringBuffer;
		boolean error_flag = false;
		boolean NullField = false;
		boolean error = false;
		boolean FieldFound = false;
		boolean Caret = false;
		boolean nullEmployeePan = false;
		int LCount = 0;
		int iDeducteeDetailRecNo = 0;
		int wrongDate = 0;
		boolean inPeriodAndFinancialYr = false;
		double iTotalIncomeTaxDeductedAtSource = 0;
		double iTDSIncomeTax = 0;
		double iTDSSurcharge = 0;
		double iCess = 0;
		double sumOfIncomeTaxSurcharge = 0;
		int SumOfTDSAndSurcharge = 0;
		String PanDDHash = null;
		Mode = null;
		try {
			String LineNo = null;
			String RecType = null;
			String EmployeePan = null;
			String EmployeePanRefNo = null;
			int Count_DD_field = 1;
			FieldValidation obj_FieldValidation = new FieldValidation();
			FileGenerator obj_FileGenerator = new FileGenerator();
			StringTokenizer Obj_st = new StringTokenizer(deductee, FIELD_SEPERATOR, true);
			int localCaretCounterPR = 0;
			while (Obj_st.hasMoreTokens()) {
				String val = Obj_st.nextToken();
				NullField = false;
				FieldFound = false;
				if ((val.equals(FIELD_SEPERATOR) && Caret) || val.trim().length() == 0) {
					NullField = true;
					FieldFound = true;
				}
				if (val.equals(FIELD_SEPERATOR)) {
					Caret = true;
					if (localCaretCounterPR == 0 && Count_DD_field == 1) {
						Count_DD_field++;
						LineNo = val;
					}
					localCaretCounterPR++;
				} else {
					Caret = false;
					FieldFound = true;
				}
				if (Count_DD_field > 5) {
					break;
				}
				if (FieldFound) {
					switch (Count_DD_field) {

					case 1:
						LineNo = val;
						break;
					case 2:
						RecType = val;
						break;
					case 3:
						EmployeePan = val;
						break;
					case 4:
						EmployeePanRefNo = val;
						break;
					case 5:
						PanDDHash = val;
						break;
					} // SWITCH
					Count_DD_field++;
				}
			} // WHILE

			if (localCaretCounterPR != 4) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "NA" + tab + tab + tab + T_FV_4001_C + tab + T_FV_4001_M);
				return;
			} // Validating LineNo
			if (LineNo.equals(FIELD_NULL) || LineNo.equals(FIELD_SEPERATOR))
				Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_4004_C + tab + T_FV_4004_M);
			else if (LineNo.length() <= 9) {
				if (obj_FieldValidation.isInt(LineNo))
					Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_4004_C + tab + T_FV_4004_M);
				else if (Integer.parseInt(LineNo.trim()) != LineCount)
					Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_4004_C + tab + T_FV_4004_M);
			} else
				Str_Buffer.append("NA" + tab + currentUploadType + tab + Line_Number + tab + tab + tab + T_FV_4004_C + tab + T_FV_4004_M);
			// Validating LineNo
			// Validating recordtype
			error = isValidRecType(LineNo, RecType, DEDUCTEE_HEADER_IDENTIFIER, Str_Buffer);
			if (error) {
				// Nahush 20 August 08
				if (Integer.parseInt(LineNo.trim()) != LineCount) {
					LineNo = "NA";
					obj_StringBuffer.append(LineNo + tab + currentUploadType + tab + DEDUCTEE_RECORD_TYPE + tab + tab + tab + T_FV_4003_C + tab + T_FV_4003_M);
				}

				Str_Buffer.append(LineNo + tab + currentUploadType + tab + DEDUCTEE_RECORD_TYPE + tab + tab + tab + T_FV_4002_C + tab + T_FV_4002_M);
			}
			// Validating recordtype
			// Validating EmployeePan
			if (EmployeePan.equals(FIELD_NULL) || EmployeePan.equals(FIELD_SEPERATOR))
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + tab + tab + T_FV_4118_C + tab + T_FV_4118_M);
			else if (EmployeePan.length() > 10)
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + tab + tab + T_FV_4009_C + tab + T_FV_4009_M);
			else if (EmployeePan.length() == 10 && EmployeePan.trim().length() == 10) { // 16 Feb PAN Validation is
																						// relaxed
				error = obj_FieldValidation.checkPan(EmployeePan);
				if (error)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + tab + tab + T_FV_4009_C + tab + T_FV_4009_M);
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee / Party  PAN" + tab + tab + tab + T_FV_4009_C + tab + T_FV_4009_M);
			// Validating EmployeePan
			// Validating EmployeePanRefNo
			if (EmployeePanRefNo == null) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN Ref. No." + tab + tab + tab + T_FV_4119_C + tab + T_FV_4119_M);
			} else if (EmployeePanRefNo.length() == 10 && EmployeePanRefNo.trim().length() == 10) {
				if (obj_FieldValidation.isAlphaNum(EmployeePanRefNo))
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN Ref. No." + tab + tab + tab + T_FV_4010_C + tab + T_FV_4010_M);
			} else
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "PAN Ref. No." + tab + tab + tab + T_FV_4010_C + tab + T_FV_4010_M);
		} catch (Exception e) {

			throw e;
		}
		return;
	}

	public String AdditionTotalAmountPaidCredited(String totalAmtPaidCrdtUpdateMode, String totalAmtPaidCrdtAddMode) { // Total
																														// of
																														// Total_Amount_paid_credited
																														// of
																														// Mode
																														// Update
																														// and
																														// Add
		double val1 = 0.00;
		double val2 = 0.00;
		double val3 = 0.00;
		String outputValue = null;
		if (!totalAmtPaidCrdtAddMode.equals("-")) {
			val1 = Double.parseDouble(totalAmtPaidCrdtAddMode.trim());
		}

		if (!totalAmtPaidCrdtUpdateMode.equals("-")) {
			val2 = Double.parseDouble(totalAmtPaidCrdtUpdateMode.trim());
		}

		val3 = val1 + val2;
		val3 = Math.round((double) (val3 * 100)) / 100.0;
		outputValue = obj_FieldValidation.changeNumberFormat(val3);
		return outputValue;
		// Total of Total_Amount_paid_credited of Mode Update and Add
	}

	public String AdditionTotalTaxDeducted(String totalITDeductedAtSrcUpdtMode, String totalITDeductedAtSrcAddMode, String totalITDeductedAtSrcDelMode) {
		// Total of Total_Tax_Deducted of Mode Update, Add and Delete
		double val1 = 0.00;
		double val2 = 0.00;
		double val3 = 0.00;
		double val4 = 0.00;
		String outputValue = null;
		if (!totalITDeductedAtSrcAddMode.equals("-")) {
			val1 = Double.parseDouble(totalITDeductedAtSrcAddMode.trim());
		}

		if (!totalITDeductedAtSrcUpdtMode.equals("-")) {
			val2 = Double.parseDouble(totalITDeductedAtSrcUpdtMode.trim());
		}

		if (!totalITDeductedAtSrcDelMode.equals("-")) {
			val3 = Double.parseDouble(totalITDeductedAtSrcDelMode.trim());
		}

		val4 = val1 + val2 + val3;
		val4 = Math.round((double) (val4 * 100)) / 100.0;
		outputValue = obj_FieldValidation.changeNumberFormat(val4);
		return outputValue;
		// Total of Total_Tax_Deducted of Mode Update, Add and Delete
	}

	public String AdditionTotalAmountDeposited(String totalOfDepdAmtUpdtMode, String totalOfDepdAmtAddMode, String totalOfDepdAmtDelMode) {
		// Total of Total_Amount_deposited of Mode Update, Add and Delete
		double val1 = 0.00;
		double val2 = 0.00;
		double val3 = 0.00;
		double val4 = 0.00;
		String outputValue = null;
		if (!totalOfDepdAmtAddMode.equals("-")) {
			val1 = Double.parseDouble(totalOfDepdAmtAddMode.trim());
		}

		if (!totalOfDepdAmtUpdtMode.equals("-")) {
			val2 = Double.parseDouble(totalOfDepdAmtUpdtMode.trim());
		}

		if (!totalOfDepdAmtDelMode.equals("-")) {
			val3 = Double.parseDouble(totalOfDepdAmtDelMode.trim());
		}

		val4 = val1 + val2 + val3;
		val4 = Math.round((double) (val4 * 100)) / 100.0;
		outputValue = obj_FieldValidation.changeNumberFormat(val4);
		return outputValue;
	}

	public String getMeteringFileSeqNo() {

		return meteringFileSeqNo;
	}

	public String getMeteringUploadType() {
		return meteringUploadType;
	}

	public String getMeteringFileType() {

		return meteringFileType;
	}

	public StringBuffer getReceiptString() {
		return receiptString;
	}

	public StringBuffer getStatisticFileStrBuff() {
		return statisticFileStrBuff;
	}

	// Added for change in statistics File Data ----- Nahush (21 Oct 08)

	public StringBuffer getStatisticSalStrBuff() {
		return staisticsSalStrBuff;
	}

	public Vector getMeteChlnDetailRecNo() {
		return meteChlnDetailRecNo;
	}

	public Vector getMeteOrigRRRNo() {
		return meteOrigRRRNo;
	}

	public Vector getMeteTANList() {
		return meteTANList;
	}

	public Vector getMeteTransactionTypeList() {
		return meteTransactionTypeList;
	}

	public Vector getMeteDDNumber() {
		return meteDDNumber;
	}

	public Vector getMeteChlnVector() {
		return meteChlnVector;
	}

	public void setReceiptString(StringBuffer buffer) {
		receiptString = buffer;
	}

	public void setStatisticFileStrBuff(StringBuffer buffer) {
		statisticFileStrBuff = buffer;
	}

	// Added for change in statistics File Data ----- Nahush (21 Oct 08)

	public void setStatisticSalStrBuff(StringBuffer buffer) {
		staisticsSalStrBuff = buffer;
	}

	public String getReceiptSDCountForC5() {
		return receiptSDCountForC5;
	}

	public String getMeteCorrectionFile() {
		return meteCorrectionFile;
	}

	public StringBuffer getGeneralFileInfoBuffer() {
		return generalFileInfoBuffer;
	}

	public void setGeneralFileInfoBuffer(StringBuffer buffer) {
		generalFileInfoBuffer = buffer;
	}

	public StringBuffer getSamScmData() {
		return samScmData;
	}

	public String getSamScmNoOfBatch() {
		return samScmNoOfBatch;
	}

	public int getLineCount() {
		return LineCount;
	}

	public int getSamScmLineCountOfFile() {
		return samScmLineCountOfFile;
	}

	public String getSAMHash() {
		return SAMHash;
	}

	public String getSAMVer() {
		return SAMVer;
	}

	public String getFileHash() {
		return FileHash;
	}

	public String getFVUVer() {
		return FVUVer;
	}

	public boolean isByPassBooking() {
		return byPassBooking;
	}

	public boolean isPaperReturnRelax() {
		return paperReturnRelax;
	}

	public void setPaperReturnRelax(boolean b) {
		paperReturnRelax = b;
	}
	// Nahush

	public String getcurrentUploadType() {
		return currentUploadType;
	}

	// Added By AMI For FVU 3.0
	public static StringBuffer getunmatchedChalanCntStrBuff() {
		return unmatchedChalanCntStrBuff;
	}

	public void setunmatchedChalanCntStrBuff(StringBuffer buffer) {
		unmatchedChalanCntStrBuff = buffer;
	}
	// public static void setunmatchedChalanCntStrBuffToNull()
	// {
	// unmatchedChalanCntStrBuff = null;
	// }

	// 19-Feb-2009 Added for BSR check - Nahush
	public boolean checkBSR(String bsr_code) {

		bsrFound = false;
		BSRList br = new BSRList();
		String s;
		bsrFromList = "";
		try {
			s = br.getBSRCodes();

			StringTokenizer st = new StringTokenizer(s, FIELD_SEPERATOR);
			while (st.hasMoreTokens()) {
				bsrFromList = st.nextToken();

				if (bsr_code.equals(bsrFromList))

					bsrFound = true;

			}

		}

		catch (Exception e) {

			e.printStackTrace();
		}
		return bsrFound;
	}

	public ArrayList getBSRDetails() {
		return bsrList;
	}

	public boolean ValidateConsHash(String fileName) throws IOException {
		BufferedReader bRead = null;
		boolean isConsValid = false;
		try {

			File file = new File(fileName);
			String consHashValue[] = null;
			long fileHash = 0;

			bRead = new BufferedReader(new FileReader(file));
			if (bRead != null) {

				boolean fh_flag = true;
				long appendPos = 0;
				String data = null;
				while (((data = bRead.readLine()) != null)) {

					if (fh_flag) {
						String dataForGettingHash = data + "manas";
						consHashValue = dataForGettingHash.split("\\^");
						fh_flag = false;
						// appendPos=data.length()-24;// hash code length (20) + carat count

						data = data.substring(0, data.length() - 24) + "^12345678901234567890^^^";
					}
					data = data + "\n";
					// System.out.println(data);
					fileHash += hashCode(data, true);

					//

				}
			}
			String calculatedHash = get20digitHashCode(fileHash);
			System.out.println("The 20 digit Hash code is  " + get20digitHashCode(fileHash));
			//System.out.println("The Hash value in file " + consHashValue[14]);
			// storing file hash in table
			if (get20digitHashCode(fileHash) != null && consHashValue[14] != null) {
				isConsValid = consHashValue[14].equals(get20digitHashCode(fileHash));
			}
			if (isConsValid) {
				consHashinFile = calculatedHash;
			}
		}

		finally {

			if (bRead != null)
				bRead.close();

		}
		return isConsValid;
	}

	public long hashCode(String recStr, boolean includeCaret) {
		long hc = 0;
		int i = 0;
		for (; i < recStr.length(); i++) {
			hc += (((int) recStr.charAt(i)) * (i + 1));
		}
		if (includeCaret == true)
			hc += ((i + 1) * ((int) '^'));
		
		return hc;
	}

	public String get20digitHashCode(long hashCode) {

		String hashCodeStr = Long.toString(hashCode);
		StringBuffer sb = new StringBuffer();
		for (int i = hashCodeStr.length(); i < 20; i++)
			sb.append('0');
		sb.append(hashCodeStr);
		return sb.toString();
	}

	public boolean[] matchConsFile(String fileName) throws IOException {
		BufferedReader readInput = null;
		boolean matchCons[] = { false, false, false };
		try {
			String inputFileConsHash[] = null;
			File file = new File(fileName);
			readInput = new BufferedReader(new FileReader(file));
			String firstLine = readInput.readLine();
			inputFileConsHash = (firstLine + "-").split("\\^");

			if (inputFileConsHash.length != 18) {
				matchCons[2] = false;
				return matchCons;
			} else {
				matchCons[2] = true;
			}
			System.out.println("The upload type " + inputFileConsHash[3] + "The Cons hash in file " + inputFileConsHash[17]);
			if (UPLOADTYPE_REGULAR.equals(inputFileConsHash[3])) {
				matchCons[0] = true;
			}
			if (UPLOADTYPE_CORRECTION.equals(inputFileConsHash[3]) && inputFileConsHash[17] != null && consHashinFile != null) {
				matchCons[1] = (inputFileConsHash[17].substring(0, inputFileConsHash[17].length() - 1)).equals(consHashinFile);
			}
		}

		finally {

			if (readInput != null) {
				readInput.close();
			}

		}
		return matchCons;

	}

	public String getTypeOfFile(String fileName) throws IOException {
		BufferedReader readInput = null;
		String FileHeader[] = null;
		try {
			File file = new File(fileName);
			readInput = new BufferedReader(new FileReader(file));
			String firstLine = readInput.readLine();
			FileHeader = (firstLine + "manas").split("\\^");
		} finally {
			if (readInput != null) {
				readInput.close();
			}

		}
		return FileHeader[3];
	}

	// Added by shruti as method size exceeded limit
	private StringBufferTemp validateDeducteePANDetails_new(String Remark1, String FormNo, String TransactionType, String UploadTypeDD, boolean isStructurallyValidPan, StringBufferTemp Str_Buffer

	) throws Exception {
		try {

			if (Remark1.equals("B") && !FormNo.equals(FORM_26Q) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !FormNo.equals(FORM_27EQ)) // Chnages
																																							// Done
																																							// For
																																							// FVU
																																							// 3.0
																																							// new
																																							// changes
			{
				if (UploadTypeDD.equals(UPLOADTYPE_REGULAR) && !isStructurallyValidPan)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M);
				else if (TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("U") && !isStructurallyValidPan)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M);
				else if (((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("A")) || TransactionType.equals(TRANSACTIONTYPE_ADDITION_CHALLAN)) && !isStructurallyValidPan)
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M);
			}
			// END for remark B
			// Added on 17/08/2012
			if (Remark1.equals("S") && !isStructurallyValidPan) {
				Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Employee/Party PAN" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4267_C + tab + T_FV_4267_M);
			}

		} // try
		catch (Exception e) {

			throw e;
		}
		return Str_Buffer;

	}

	private StringBufferTemp validateDeducteeRemittanceCountry(boolean isFinYrGrtrthn, String RemittanceCountry, String FormNo, String UploadType, String TransactionType, String Mode, StringBufferTemp Str_Buffer, String SectionCode) throws Exception {
		try {

			// Validating RemittanceCountry

			if (isFinYrGrtrthn) {
				/*
				 * if (RemittanceCountry.equals(FIELD_NULL) ||
				 * RemittanceCountry.equals(FIELD_SEPERATOR)) { if(FormNo.equals(FORM_27Q))
				 * Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Remarks 3" + tab
				 * + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab +
				 * T_FV_4302_C + tab + T_FV_4302_M); } else {
				 */
				if (!(RemittanceCountry.equals(FIELD_NULL) || RemittanceCountry.equals(FIELD_SEPERATOR))) {
					if (FormNo.equals(FORM_27Q)) {
						if (UploadType.equals(UPLOADTYPE_CORRECTION) && ((TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("D")) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN))
								&& !RemittanceCountry.equals(FIELD_NULL) && !RemittanceCountry.equals(FIELD_SEPERATOR)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
						} else if (obj_FieldValidation.isInt(RemittanceCountry)) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
						} else if (RemittanceCountry.trim().length() > 3) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
						}
						// Added for FVU 4.4 by Shalin
						else if (RemittanceCountry.trim().length() != RemittanceCountry.length()) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
						} else if (!(Integer.parseInt(RemittanceCountry) > 0 && Integer.parseInt(RemittanceCountry) < 287) || Integer.parseInt(RemittanceCountry) == 99) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
						}

					} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q) || (FormNo.equals(FORM_27Q) && TRANSACTION_TYPE.equals(TRANSACTIONTYPE_CORRECTION_PAN))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 4" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
					}
				} else {

					if (FormNo.equals(FORM_27Q) && !TransactionType.equals(TRANSACTIONTYPE_CORRECTION_PAN) && !(TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE) && Mode.equals("D")))
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4314_C + tab + T_FV_4314_M);
				
				
					// Added for FVU 7.2 section code 196DP by Vinita - Start
					if (FormNo.equals(FORM_27Q) && (SectionCode !=null && SectionCode.equals("96D")) && (Integer.parseInt(FinancialYr) >= 202122 )
						&& (UploadType.equals(UPLOADTYPE_REGULAR) || UploadType.equals(UPLOADTYPE_CORRECTION))){
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_6206_C + tab + T_FV_6206_M);
					}
					// Added for FVU 7.2 section code 196DP by Vinita - End
				}
				// }
			} else {
				if (!RemittanceCountry.equals(FIELD_NULL) && !RemittanceCountry.equals(FIELD_SEPERATOR)) {
					if (FormNo.equals(FORM_27Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Country Name" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					} else if (FormNo.equals(FORM_24Q) || FormNo.equals(FORM_27EQ) || FormNo.equals(FORM_26Q)) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Filler 4" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4317_C + tab + T_FV_4317_M);
					}

				}
			}
			// Validating RemittanceCountry

		} // try
		catch (Exception e) {

			throw e;
		}
		return Str_Buffer;

	}

	private StringBufferTemp validateDeducteeNonResident(String NonResident, String EmployeePan, String UploadType, String TransactionType, String PermanentResidentEstablishment, StringBufferTemp Str_Buffer) throws Exception {
		try {

			// Validating PermanentResident 31
			if (!NonResident.equals(FIELD_NULL) && !NonResident.equals(FIELD_SEPERATOR)) // FVU 5.7
			{
				if ((EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && FormNo.equals(FORM_27EQ)) {

					if ((UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) && Integer.parseInt(FinancialYr) >= 201718) {

						if (NonResident.equals("Y") && !(PermanentResidentEstablishment.equals("N") || PermanentResidentEstablishment.equals("Y"))) {
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Deductee is having Permanent Establishment in India " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4351_C + tab + T_FV_4351_M);
							// error = " Invalid value under field Permanent Resident Establishment .Allowed
							// values are Y or N (in capital) \n" ;
						}
						if (NonResident.equals("N") && !(PermanentResidentEstablishment.equals(FIELD_NULL) || PermanentResidentEstablishment.equals(FIELD_SEPERATOR))) {
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Deductee is having Permanent Establishment in India " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
							// error = " No value should be provided for field Permanent Resident
							// Establishment. \n";
						}

						if (!(NonResident.equals("N") || NonResident.equals("Y"))) {
							Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee is Non-Resident" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4351_C + tab + T_FV_4351_M);
							// error = "Invalid value under field Permanent Resident . Allowed values are Y
							// or N (in capital) \n";
						}

					} else {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee is Non-Resident" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
						if (!(PermanentResidentEstablishment.equals(FIELD_NULL) || PermanentResidentEstablishment.equals(FIELD_SEPERATOR))) {
							// error="No value should be provided under the field Permanent Resident
							// Establishment \n";
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Deductee is having Permanent Establishment in India " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
						}
					}

				} else {

					if ((UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) && Integer.parseInt(FinancialYr) >= 201718 && (NonResident.equals("N") || NonResident.equals("Y"))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee is Non-Resident" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
						// error = "For valid PAN no value should be provided under field Permanent
						// Resident. \n ";
						if (!(PermanentResidentEstablishment.equals(FIELD_NULL) || PermanentResidentEstablishment.equals(FIELD_SEPERATOR))) {
							// error="No value should be provided under the field Permanent Resident
							// Establishment \n";
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Deductee is having Permanent Establishment in India " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
						}

					}
					if ((UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) && Integer.parseInt(FinancialYr) < 201718) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee is Non-Resident" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
						// error = "For valid PAN no value should be provided under field Permanent
						// Resident. \n ";
						if (!(PermanentResidentEstablishment.equals(FIELD_NULL) || PermanentResidentEstablishment.equals(FIELD_SEPERATOR))) {
							// error="No value should be provided under the field Permanent Resident
							// Establishment \n";
							Str_Buffer.append(
									LineNo + tab + currentUploadType + tab + "Deductee is having Permanent Establishment in India " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
						}
					}

					// changes added for funct point 3 for FVU 6.4 by puja

					if (!(NonResident.equals("N") || NonResident.equals("Y"))) {
						Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee is Non-Resident" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4351_C + tab + T_FV_4351_M);
						// error = "Invalid value under field Permanent Resident . Allowed values are Y
						// or N (in capital) \n";
					}

				}
			} else {
				if ((EmployeePan.equals(PAN_NOT_AVAILABLE) || EmployeePan.equals(PAN_APPLIED) || EmployeePan.equals(PAN_INVALID)) && FormNo.equals(FORM_27EQ)
						&& (UploadType.equals(UPLOADTYPE_REGULAR) || TransactionType.equals(TRANSACTIONTYPE_CORRECTION_DEDUCTEE)) && Integer.parseInt(FinancialYr) >= 201718) {
					Str_Buffer.append(LineNo + tab + currentUploadType + tab + "Deductee is Non-Resident" + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4351_C + tab + T_FV_4351_M);
				} else {
					if ((PermanentResidentEstablishment.equals("N") || PermanentResidentEstablishment.equals("Y")) || !(PermanentResidentEstablishment.equals(FIELD_NULL) || PermanentResidentEstablishment.equals(FIELD_SEPERATOR))) { // Bug Fix in CR for FVU 7.0 - Vinita
						// error="No value should be provided under the field Permanent Resident
						// Establishment \n";
						Str_Buffer
								.append(LineNo + tab + currentUploadType + tab + "Deductee is having Permanent Establishment in India " + tab + CurrentchallanDetailRecordNo + tab + CurrentDeducteeDetailRecNo + tab + T_FV_4339_C + tab + T_FV_4339_M);
					}
				}
			}

		} // try
		catch (Exception e) {

			throw e;
		}
		return Str_Buffer;

	}

} // closing class